/***********************************************************************************/
/* Implementation of Gost Grasshopper Encryption Algorithm                         */
/* This program implements the test vectors set provided in the reference document */
/* provided by the Standartinform, Moscow, Russian Federation.                     */
/*                                                                                 */
/* Author: Eric Filiol                                                             */
/* This program is protected by the GPLv3                                          */
/***********************************************************************************/

/***********************************************************************************/
/* Data structures for the gost_grasshopper algorithm.                             */
/* Each block is an array of two 64-bit integers.                                  */
/* Key is an array of four 64-bit integers.                                        */
/* Index 0 contains the most significant 64-bit word while index 1 or 3 contains   */
/* the least significant 64-bit word.                                              */
/* All functions have the same name as in the reference document                   */
/***********************************************************************************/

/* The core nonlinear bijective permutation (S-Box) */
unsigned char pi[256] = {252, 238, 221,  17, 207, 110,  49,  22, 251, 196, 250, 218,  35, 197,   4,  77, 
                         233, 119, 240, 219, 147,  46, 153, 186,  23,  54, 241, 187,  20, 205,  95, 193, 
                         249,  24, 101,  90, 226,  92, 239,  33, 129,  28,  60,  66, 139,   1, 142,  79, 
                           5, 132,   2, 174, 227, 106, 143, 160,   6,  11, 237, 152, 127, 212, 211,  31, 
                         235,  52,  44,  81, 234, 200,  72, 171, 242,  42, 104, 162, 253,  58, 206, 204, 
                         181, 112,  14,  86,   8,  12, 118,  18, 191, 114,  19,  71, 156, 183,  93, 135, 
                          21, 161, 150,  41,  16, 123, 154, 199, 243, 145, 120, 111, 157, 158, 178, 177, 
                          50, 117,  25,  61, 255,  53, 138, 126, 109,  84, 198, 128, 195, 189,  13,  87, 
                         223, 245,  36, 169,  62, 168,  67, 201, 215, 121, 214, 246, 124,  34, 185,   3, 
                         224,  15, 236, 222, 122, 148, 176, 188, 220, 232,  40,  80,  78,  51,  10,  74, 
                         167, 151,  96, 115,  30,   0,  98,  68,  26, 184,  56, 130, 100, 159,  38,  65, 
                         173,  69,  70, 146,  39,  94,  85,  47, 140, 163, 165, 125, 105, 213, 149,  59, 
                           7,  88, 179,  64, 134, 172,  29, 247,  48,  55, 107, 228, 136, 217, 231, 137, 
                         225,  27, 131,  73,  76,  63, 248, 254, 141,  83, 170, 144, 202, 216, 133,  97, 
                          32, 113, 103, 164,  45,  43,   9,  91, 203, 155,  37, 208, 190, 229, 108,  82, 
                          89, 166, 116, 210, 230, 244, 180, 192, 209, 102, 175, 194,  57,  75,  99, 182};

/* The corresponding inverse permutation            */
unsigned char pi_inv[256] = {165,  45,  50, 143,  14,  48,  56, 192,  84, 230, 158,  57,  85, 126,  82, 145,
                             100,   3,  87,  90,  28,  96,   7,  24,  33, 114, 168, 209,  41, 198, 164,  63,
                             224,  39, 141,  12, 130, 234, 174, 180, 154,  99,  73, 229,  66, 228,  21, 183,
                             200,   6, 112, 157,  65, 117,  25, 201, 170, 252,  77, 191,  42, 115, 132, 213,
                             195, 175,  43, 134, 167, 177, 178,  91,  70, 211, 159, 253, 212,  15, 156,  47,
                             155,  67, 239, 217, 121, 182,  83, 127, 193, 240,  35, 231,  37,  94, 181,  30,
                             162, 223, 166, 254, 172,  34, 249, 226,  74, 188,  53, 202, 238, 120,   5, 107,
                              81, 225,  89, 163, 242, 113,  86,  17, 106, 137, 148, 101, 140, 187, 119,  60,
                             123,  40, 171, 210,  49, 222, 196,  95, 204, 207, 118,  44, 184, 216,  46,  54,
                             219, 105, 179,  20, 149, 190,  98, 161,  59,  22, 102, 233,  92, 108, 109, 173,
                              55,  97,  75, 185, 227, 186, 241, 160, 133, 131, 218,  71, 197, 176,  51, 250,
                             150, 111, 110, 194, 246,  80, 255,  93, 169, 142,  23,  27, 151, 125, 236,  88,
                             247,  31, 251, 124,   9,  13, 122, 103,  69, 135, 220, 232,  79,  29,  78,   4,
                             235, 248, 243,  62,  61, 189, 138, 136, 221, 205,  11,  19, 152,   2, 147, 128,
                             144, 208,  36,  52, 203, 237, 244, 206, 153,  16,  68,  64, 146,  58,   1,  38,
                              18,  26,  72, 104, 245, 129, 139, 199, 214,  32,  10,   8,   0,  76, 215, 116};


/* Precomputation of X.Y mod p(x) = x^8 + x^7 + x^6 + x + 1 where X and Y are elements in GF(2)[X]/p(x) */
unsigned char mult_mod_poly[256][256] = {
{  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0},

{  0,   1,   2,   3,   4,   5,   6,   7,   8,   9,  10,  11,  12,  13,  14,  15,  16,  17,  18,  19,  20,  21,  22,  23,  24,  25,  26,  27,  28,  29,  30,  31,
  32,  33,  34,  35,  36,  37,  38,  39,  40,  41,  42,  43,  44,  45,  46,  47,  48,  49,  50,  51,  52,  53,  54,  55,  56,  57,  58,  59,  60,  61,  62,  63,
  64,  65,  66,  67,  68,  69,  70,  71,  72,  73,  74,  75,  76,  77,  78,  79,  80,  81,  82,  83,  84,  85,  86,  87,  88,  89,  90,  91,  92,  93,  94,  95,
  96,  97,  98,  99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127,
 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159,
 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191,
 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223,
 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255},

{  0,   2,   4,   6,   8,  10,  12,  14,  16,  18,  20,  22,  24,  26,  28,  30,  32,  34,  36,  38,  40,  42,  44,  46,  48,  50,  52,  54,  56,  58,  60,  62,
  64,  66,  68,  70,  72,  74,  76,  78,  80,  82,  84,  86,  88,  90,  92,  94,  96,  98, 100, 102, 104, 106, 108, 110, 112, 114, 116, 118, 120, 122, 124, 126,
 128, 130, 132, 134, 136, 138, 140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 166, 168, 170, 172, 174, 176, 178, 180, 182, 184, 186, 188, 190,
 192, 194, 196, 198, 200, 202, 204, 206, 208, 210, 212, 214, 216, 218, 220, 222, 224, 226, 228, 230, 232, 234, 236, 238, 240, 242, 244, 246, 248, 250, 252, 254,
 195, 193, 199, 197, 203, 201, 207, 205, 211, 209, 215, 213, 219, 217, 223, 221, 227, 225, 231, 229, 235, 233, 239, 237, 243, 241, 247, 245, 251, 249, 255, 253,
 131, 129, 135, 133, 139, 137, 143, 141, 147, 145, 151, 149, 155, 153, 159, 157, 163, 161, 167, 165, 171, 169, 175, 173, 179, 177, 183, 181, 187, 185, 191, 189,
  67,  65,  71,  69,  75,  73,  79,  77,  83,  81,  87,  85,  91,  89,  95,  93,  99,  97, 103, 101, 107, 105, 111, 109, 115, 113, 119, 117, 123, 121, 127, 125,
   3,   1,   7,   5,  11,   9,  15,  13,  19,  17,  23,  21,  27,  25,  31,  29,  35,  33,  39,  37,  43,  41,  47,  45,  51,  49,  55,  53,  59,  57,  63,  61},

{  0,   3,   6,   5,  12,  15,  10,   9,  24,  27,  30,  29,  20,  23,  18,  17,  48,  51,  54,  53,  60,  63,  58,  57,  40,  43,  46,  45,  36,  39,  34,  33,
  96,  99, 102, 101, 108, 111, 106, 105, 120, 123, 126, 125, 116, 119, 114, 113,  80,  83,  86,  85,  92,  95,  90,  89,  72,  75,  78,  77,  68,  71,  66,  65,
 192, 195, 198, 197, 204, 207, 202, 201, 216, 219, 222, 221, 212, 215, 210, 209, 240, 243, 246, 245, 252, 255, 250, 249, 232, 235, 238, 237, 228, 231, 226, 225,
 160, 163, 166, 165, 172, 175, 170, 169, 184, 187, 190, 189, 180, 183, 178, 177, 144, 147, 150, 149, 156, 159, 154, 153, 136, 139, 142, 141, 132, 135, 130, 129,
  67,  64,  69,  70,  79,  76,  73,  74,  91,  88,  93,  94,  87,  84,  81,  82, 115, 112, 117, 118, 127, 124, 121, 122, 107, 104, 109, 110, 103, 100,  97,  98,
  35,  32,  37,  38,  47,  44,  41,  42,  59,  56,  61,  62,  55,  52,  49,  50,  19,  16,  21,  22,  31,  28,  25,  26,  11,   8,  13,  14,   7,   4,   1,   2,
 131, 128, 133, 134, 143, 140, 137, 138, 155, 152, 157, 158, 151, 148, 145, 146, 179, 176, 181, 182, 191, 188, 185, 186, 171, 168, 173, 174, 167, 164, 161, 162,
 227, 224, 229, 230, 239, 236, 233, 234, 251, 248, 253, 254, 247, 244, 241, 242, 211, 208, 213, 214, 223, 220, 217, 218, 203, 200, 205, 206, 199, 196, 193, 194},

{  0,   4,   8,  12,  16,  20,  24,  28,  32,  36,  40,  44,  48,  52,  56,  60,  64,  68,  72,  76,  80,  84,  88,  92,  96, 100, 104, 108, 112, 116, 120, 124,
 128, 132, 136, 140, 144, 148, 152, 156, 160, 164, 168, 172, 176, 180, 184, 188, 192, 196, 200, 204, 208, 212, 216, 220, 224, 228, 232, 236, 240, 244, 248, 252,
 195, 199, 203, 207, 211, 215, 219, 223, 227, 231, 235, 239, 243, 247, 251, 255, 131, 135, 139, 143, 147, 151, 155, 159, 163, 167, 171, 175, 179, 183, 187, 191,
  67,  71,  75,  79,  83,  87,  91,  95,  99, 103, 107, 111, 115, 119, 123, 127,   3,   7,  11,  15,  19,  23,  27,  31,  35,  39,  43,  47,  51,  55,  59,  63,
  69,  65,  77,  73,  85,  81,  93,  89, 101,  97, 109, 105, 117, 113, 125, 121,   5,   1,  13,   9,  21,  17,  29,  25,  37,  33,  45,  41,  53,  49,  61,  57,
 197, 193, 205, 201, 213, 209, 221, 217, 229, 225, 237, 233, 245, 241, 253, 249, 133, 129, 141, 137, 149, 145, 157, 153, 165, 161, 173, 169, 181, 177, 189, 185,
 134, 130, 142, 138, 150, 146, 158, 154, 166, 162, 174, 170, 182, 178, 190, 186, 198, 194, 206, 202, 214, 210, 222, 218, 230, 226, 238, 234, 246, 242, 254, 250,
  06,   2,  14,  10,  22,  18,  30,  26,  38,  34,  46,  42,  54,  50,  62,  58,  70,  66,  78,  74,  86,  82,  94,  90, 102,  98, 110, 106, 118, 114, 126, 122},

{  0,   5,  10,  15,  20,  17,  30,  27,  40,  45,  34,  39,  60,  57,  54,  51,  80,  85,  90,  95,  68,  65,  78,  75, 120, 125, 114, 119, 108, 105, 102,  99,
 160, 165, 170, 175, 180, 177, 190, 187, 136, 141, 130, 135, 156, 153, 150, 147, 240, 245, 250, 255, 228, 225, 238, 235, 216, 221, 210, 215, 204, 201, 198, 195,
 131, 134, 137, 140, 151, 146, 157, 152, 171, 174, 161, 164, 191, 186, 181, 176, 211, 214, 217, 220, 199, 194, 205, 200, 251, 254, 241, 244, 239, 234, 229, 224,
  35,  38,  41,  44,  55,  50,  61,  56,  11,  14,   1,   4,  31,  26,  21,  16, 115, 118, 121, 124, 103,  98, 109, 104,  91,  94,  81,  84,  79,  74,  69,  64,
 197, 192, 207, 202, 209, 212, 219, 222, 237, 232, 231, 226, 249, 252, 243, 246, 149, 144, 159, 154, 129, 132, 139, 142, 189, 184, 183, 178, 169, 172, 163, 166,
 101,  96, 111, 106, 113, 116, 123, 126,  77,  72,  71,  66,  89,  92,  83,  86,  53,  48,  63,  58,  33,  36,  43,  46,  29,  24,  23,  18,   9,  12,   3,   6,
  70,  67,  76,  73,  82,  87,  88,  93, 110, 107, 100,  97, 122, 127, 112, 117,  22,  19,  28,  25,   2,   7,   8,  13,  62,  59,  52,  49,  42,  47,  32,  37,
 230, 227, 236, 233, 242, 247, 248, 253, 206, 203, 196, 193, 218, 223, 208, 213, 182, 179, 188, 185, 162, 167, 168, 173, 158, 155, 148, 145, 138, 143, 128, 133},

{  0,   6,  12,  10,  24,  30,  20,  18,  48,  54,  60,  58,  40,  46,  36,  34,  96, 102, 108, 106, 120, 126, 116, 114,  80,  86,  92,  90,  72,  78,  68,  66,
 192, 198, 204, 202, 216, 222, 212, 210, 240, 246, 252, 250, 232, 238, 228, 226, 160, 166, 172, 170, 184, 190, 180, 178, 144, 150, 156, 154, 136, 142, 132, 130,
  67,  69,  79,  73,  91,  93,  87,  81, 115, 117, 127, 121, 107, 109, 103,  97,  35,  37,  47,  41,  59,  61,  55,  49,  19,  21,  31,  25,  11,  13,   7,   1,
 131, 133, 143, 137, 155, 157, 151, 145, 179, 181, 191, 185, 171, 173, 167, 161, 227, 229, 239, 233, 251, 253, 247, 241, 211, 213, 223, 217, 203, 205, 199, 193,
 134, 128, 138, 140, 158, 152, 146, 148, 182, 176, 186, 188, 174, 168, 162, 164, 230, 224, 234, 236, 254, 248, 242, 244, 214, 208, 218, 220, 206, 200, 194, 196,
  70,  64,  74,  76,  94,  88,  82,  84, 118, 112, 122, 124, 110, 104,  98, 100,  38,  32,  42,  44,  62,  56,  50,  52,  22,  16,  26,  28,  14,   8,   2,   4,
 197, 195, 201, 207, 221, 219, 209, 215, 245, 243, 249, 255, 237, 235, 225, 231, 165, 163, 169, 175, 189, 187, 177, 183, 149, 147, 153, 159, 141, 139, 129, 135,
   5,   3,   9,  15,  29,  27,  17,  23,  53,  51,  57,  63,  45,  43,  33,  39, 101,  99, 105, 111, 125, 123, 113, 119,  85,  83,  89,  95,  77,  75,  65,  71},

{  0,   7,  14,   9,  28,  27,  18,  21,  56,  63,  54,  49,  36,  35,  42,  45, 112, 119, 126, 121, 108, 107,  98, 101,  72,  79,  70,  65,  84,  83,  90,  93,
 224, 231, 238, 233, 252, 251, 242, 245, 216, 223, 214, 209, 196, 195, 202, 205, 144, 151, 158, 153, 140, 139, 130, 133, 168, 175, 166, 161, 180, 179, 186, 189,
   3,   4,  13,  10,  31,  24,  17,  22,  59,  60,  53,  50,  39,  32,  41,  46, 115, 116, 125, 122, 111, 104,  97, 102,  75,  76,  69,  66,  87,  80,  89,  94,
 227, 228, 237, 234, 255, 248, 241, 246, 219, 220, 213, 210, 199, 192, 201, 206, 147, 148, 157, 154, 143, 136, 129, 134, 171, 172, 165, 162, 183, 176, 185, 190,
   6,   1,   8,  15,  26,  29,  20,  19,  62,  57,  48,  55,  34,  37,  44,  43, 118, 113, 120, 127, 106, 109, 100,  99,  78,  73,  64,  71,  82,  85,  92,  91,
 230, 225, 232, 239, 250, 253, 244, 243, 222, 217, 208, 215, 194, 197, 204, 203, 150, 145, 152, 159, 138, 141, 132, 131, 174, 169, 160, 167, 178, 181, 188, 187,
   5,   2,  11,  12,  25,  30,  23,  16,  61,  58,  51,  52,  33,  38,  47,  40, 117, 114, 123, 124, 105, 110, 103,  96,  77,  74,  67,  68,  81,  86,  95,  88,
 229, 226, 235, 236, 249, 254, 247, 240, 221, 218, 211, 212, 193, 198, 207, 200, 149, 146, 155, 156, 137, 142, 135, 128, 173, 170, 163, 164, 177, 182, 191, 184},

{  0,   8,  16,  24,  32,  40,  48,  56,  64,  72,  80,  88,  96, 104, 112, 120, 128, 136, 144, 152, 160, 168, 176, 184, 192, 200, 208, 216, 224, 232, 240, 248,
 195, 203, 211, 219, 227, 235, 243, 251, 131, 139, 147, 155, 163, 171, 179, 187,  67,  75,  83,  91,  99, 107, 115, 123,   3,  11,  19,  27,  35,  43,  51,  59,
  69,  77,  85,  93, 101, 109, 117, 125,   5,  13,  21,  29,  37,  45,  53,  61, 197, 205, 213, 221, 229, 237, 245, 253, 133, 141, 149, 157, 165, 173, 181, 189,
 134, 142, 150, 158, 166, 174, 182, 190, 198, 206, 214, 222, 230, 238, 246, 254,   6,  14,  22,  30,  38,  46,  54,  62,  70,  78,  86,  94, 102, 110, 118, 126,
 138, 130, 154, 146, 170, 162, 186, 178, 202, 194, 218, 210, 234, 226, 250, 242,  10,   2,  26,  18,  42,  34,  58,  50,  74,  66,  90,  82, 106,  98, 122, 114,
  73,  65,  89,  81, 105,  97, 121, 113,   9,   1,  25,  17,  41,  33,  57,  49, 201, 193, 217, 209, 233, 225, 249, 241, 137, 129, 153, 145, 169, 161, 185, 177,
 207, 199, 223, 215, 239, 231, 255, 247, 143, 135, 159, 151, 175, 167, 191, 183,  79,  71,  95,  87, 111, 103, 127, 119,  15,   7,  31,  23,  47,  39,  63,  55,
  12,   4,  28,  20,  44,  36,  60,  52,  76,  68,  92,  84, 108, 100, 124, 116, 140, 132, 156, 148, 172, 164, 188, 180, 204, 196, 220, 212, 236, 228, 252, 244},

{  0,   9,  18,  27,  36,  45,  54,  63,  72,  65,  90,  83, 108, 101, 126, 119, 144, 153, 130, 139, 180, 189, 166, 175, 216, 209, 202, 195, 252, 245, 238, 231,
 227, 234, 241, 248, 199, 206, 213, 220, 171, 162, 185, 176, 143, 134, 157, 148, 115, 122,  97, 104,  87,  94,  69,  76,  59,  50,  41,  32,  31,  22,  13,   4,
   5,  12,  23,  30,  33,  40,  51,  58,  77,  68,  95,  86, 105,  96, 123, 114, 149, 156, 135, 142, 177, 184, 163, 170, 221, 212, 207, 198, 249, 240, 235, 226,
 230, 239, 244, 253, 194, 203, 208, 217, 174, 167, 188, 181, 138, 131, 152, 145, 118, 127, 100, 109,  82,  91,  64,  73,  62,  55,  44,  37,  26,  19,   8,   1,
  10,   3,  24,  17,  46,  39,  60,  53,  66,  75,  80,  89, 102, 111, 116, 125, 154, 147, 136, 129, 190, 183, 172, 165, 210, 219, 192, 201, 246, 255, 228, 237,
 233, 224, 251, 242, 205, 196, 223, 214, 161, 168, 179, 186, 133, 140, 151, 158, 121, 112, 107,  98,  93,  84,  79,  70,  49,  56,  35,  42,  21,  28,   7,  14,
  15,   6,  29,  20,  43,  34,  57,  48,  71,  78,  85,  92,  99, 106, 113, 120, 159, 150, 141, 132, 187, 178, 169, 160, 215, 222, 197, 204, 243, 250, 225, 232,
 236, 229, 254, 247, 200, 193, 218, 211, 164, 173, 182, 191, 128, 137, 146, 155, 124, 117, 110, 103,  88,  81,  74,  67,  52,  61,  38,  47,  16,  25,   2,  11},

{  0,  10,  20,  30,  40,  34,  60,  54,  80,  90,  68,  78, 120, 114, 108, 102, 160, 170, 180, 190, 136, 130, 156, 150, 240, 250, 228, 238, 216, 210, 204, 198,
 131, 137, 151, 157, 171, 161, 191, 181, 211, 217, 199, 205, 251, 241, 239, 229,  35,  41,  55,  61,  11,   1,  31,  21, 115, 121, 103, 109,  91,  81,  79,  69,
 197, 207, 209, 219, 237, 231, 249, 243, 149, 159, 129, 139, 189, 183, 169, 163, 101, 111, 113, 123,  77,  71,  89,  83,  53,  63,  33,  43,  29,  23,   9,   3,
  70,  76,  82,  88, 110, 100, 122, 112,  22,  28,   2,   8,  62,  52,  42,  32, 230, 236, 242, 248, 206, 196, 218, 208, 182, 188, 162, 168, 158, 148, 138, 128,
  73,  67,  93,  87,  97, 107, 117, 127,  25,  19,  13,   7,  49,  59,  37,  47, 233, 227, 253, 247, 193, 203, 213, 223, 185, 179, 173, 167, 145, 155, 133, 143,
 202, 192, 222, 212, 226, 232, 246, 252, 154, 144, 142, 132, 178, 184, 166, 172, 106,  96, 126, 116,  66,  72,  86,  92,  58,  48,  46,  36,  18,  24,   6,  12,
 140, 134, 152, 146, 164, 174, 176, 186, 220, 214, 200, 194, 244, 254, 224, 234,  44,  38,  56,  50,   4,  14,  16,  26, 124, 118, 104,  98,  84,  94,  64,  74,
  15,   5,  27,  17,  39,  45,  51,  57,  95,  85,  75,  65, 119, 125,  99, 105, 175, 165, 187, 177, 135, 141, 147, 153, 255, 245, 235, 225, 215, 221, 195, 201},

{  0,  11,  22,  29,  44,  39,  58,  49,  88,  83,  78,  69, 116, 127,  98, 105, 176, 187, 166, 173, 156, 151, 138, 129, 232, 227, 254, 245, 196, 207, 210, 217,
 163, 168, 181, 190, 143, 132, 153, 146, 251, 240, 237, 230, 215, 220, 193, 202,  19,  24,   5,  14,  63,  52,  41,  34,  75,  64,  93,  86, 103, 108, 113, 122,
 133, 142, 147, 152, 169, 162, 191, 180, 221, 214, 203, 192, 241, 250, 231, 236,  53,  62,  35,  40,  25,  18,  15,   4, 109, 102, 123, 112,  65,  74,  87,  92,
  38,  45,  48,  59,  10,   1,  28,  23, 126, 117, 104,  99,  82,  89,  68,  79, 150, 157, 128, 139, 186, 177, 172, 167, 206, 197, 216, 211, 226, 233, 244, 255,
 201, 194, 223, 212, 229, 238, 243, 248, 145, 154, 135, 140, 189, 182, 171, 160, 121, 114, 111, 100,  85,  94,  67,  72,  33,  42,  55,  60,  13,   6,  27,  16,
 106,  97, 124, 119,  70,  77,  80,  91,  50,  57,  36,  47,  30,  21,   8,   3, 218, 209, 204, 199, 246, 253, 224, 235, 130, 137, 148, 159, 174, 165, 184, 179,
  76,  71,  90,  81,  96, 107, 118, 125,  20,  31,   2,   9,  56,  51,  46,  37, 252, 247, 234, 225, 208, 219, 198, 205, 164, 175, 178, 185, 136, 131, 158, 149,
 239, 228, 249, 242, 195, 200, 213, 222, 183, 188, 161, 170, 155, 144, 141, 134,  95,  84,  73,  66, 115, 120, 101, 110,   7,  12,  17,  26,  43,  32,  61,  54},

{  0,  12,  24,  20,  48,  60,  40,  36,  96, 108, 120, 116,  80,  92,  72,  68, 192, 204, 216, 212, 240, 252, 232, 228, 160, 172, 184, 180, 144, 156, 136, 132,
  67,  79,  91,  87, 115, 127, 107, 103,  35,  47,  59,  55,  19,  31,  11,   7, 131, 143, 155, 151, 179, 191, 171, 167, 227, 239, 251, 247, 211, 223, 203, 199,
 134, 138, 158, 146, 182, 186, 174, 162, 230, 234, 254, 242, 214, 218, 206, 194,  70,  74,  94,  82, 118, 122, 110,  98,  38,  42,  62,  50,  22,  26,  14,   2,
 197, 201, 221, 209, 245, 249, 237, 225, 165, 169, 189, 177, 149, 153, 141, 129,   5,   9,  29,  17,  53,  57,  45,  33, 101, 105, 125, 113,  85,  89,  77,  65,
 207, 195, 215, 219, 255, 243, 231, 235, 175, 163, 183, 187, 159, 147, 135, 139,  15,   3,  23,  27,  63,  51,  39,  43, 111,  99, 119, 123,  95,  83,  71,  75,
 140, 128, 148, 152, 188, 176, 164, 168, 236, 224, 244, 248, 220, 208, 196, 200,  76,  64,  84,  88, 124, 112, 100, 104,  44,  32,  52,  56,  28,  16,   4,   8,
  73,  69,  81,  93, 121, 117,  97, 109,  41,  37,  49,  61,  25,  21,   1,  13, 137, 133, 145, 157, 185, 181, 161, 173, 233, 229, 241, 253, 217, 213, 193, 205,
  10,   6,  18,  30,  58,  54,  34,  46, 106, 102, 114, 126,  90,  86,  66,  78, 202, 198, 210, 222, 250, 246, 226, 238, 170, 166, 178, 190, 154, 150, 130, 142},

{  0,  13,  26,  23,  52,  57,  46,  35, 104, 101, 114, 127,  92,  81,  70,  75, 208, 221, 202, 199, 228, 233, 254, 243, 184, 181, 162, 175, 140, 129, 150, 155,
  99, 110, 121, 116,  87,  90,  77,  64,  11,   6,  17,  28,  63,  50,  37,  40, 179, 190, 169, 164, 135, 138, 157, 144, 219, 214, 193, 204, 239, 226, 245, 248,
 198, 203, 220, 209, 242, 255, 232, 229, 174, 163, 180, 185, 154, 151, 128, 141,  22,  27,  12,   1,  34,  47,  56,  53, 126, 115, 100, 105,  74,  71,  80,  93,
 165, 168, 191, 178, 145, 156, 139, 134, 205, 192, 215, 218, 249, 244, 227, 238, 117, 120, 111,  98,  65,  76,  91,  86,  29,  16,   7,  10,  41,  36,  51,  62,
  79,  66,  85,  88, 123, 118,  97, 108,  39,  42,  61,  48,  19,  30,   9,   4, 159, 146, 133, 136, 171, 166, 177, 188, 247, 250, 237, 224, 195, 206, 217, 212,
  44,  33,  54,  59,  24,  21,   2,  15,  68,  73,  94,  83, 112, 125, 106, 103, 252, 241, 230, 235, 200, 197, 210, 223, 148, 153, 142, 131, 160, 173, 186, 183,
 137, 132, 147, 158, 189, 176, 167, 170, 225, 236, 251, 246, 213, 216, 207, 194,  89,  84,  67,  78, 109,  96, 119, 122,  49,  60,  43,  38,   5,   8,  31,  18,
 234, 231, 240, 253, 222, 211, 196, 201, 130, 143, 152, 149, 182, 187, 172, 161,  58,  55,  32,  45,  14,   3,  20,  25,  82,  95,  72,  69, 102, 107, 124, 113},

{  0,  14,  28,  18,  56,  54,  36,  42, 112, 126, 108,  98,  72,  70,  84,  90, 224, 238, 252, 242, 216, 214, 196, 202, 144, 158, 140, 130, 168, 166, 180, 186,
   3,  13,  31,  17,  59,  53,  39,  41, 115, 125, 111,  97,  75,  69,  87,  89, 227, 237, 255, 241, 219, 213, 199, 201, 147, 157, 143, 129, 171, 165, 183, 185,
   6,   8,  26,  20,  62,  48,  34,  44, 118, 120, 106, 100,  78,  64,  82,  92, 230, 232, 250, 244, 222, 208, 194, 204, 150, 152, 138, 132, 174, 160, 178, 188,
   5,  11,  25,  23,  61,  51,  33,  47, 117, 123, 105, 103,  77,  67,  81,  95, 229, 235, 249, 247, 221, 211, 193, 207, 149, 155, 137, 135, 173, 163, 177, 191,
  12,   2,  16,  30,  52,  58,  40,  38, 124, 114,  96, 110,  68,  74,  88,  86, 236, 226, 240, 254, 212, 218, 200, 198, 156, 146, 128, 142, 164, 170, 184, 182,
  15,   1,  19,  29,  55,  57,  43,  37, 127, 113,  99, 109,  71,  73,  91,  85, 239, 225, 243, 253, 215, 217, 203, 197, 159, 145, 131, 141, 167, 169, 187, 181,
  10,   4,  22,  24,  50,  60,  46,  32, 122, 116, 102, 104,  66,  76,  94,  80, 234, 228, 246, 248, 210, 220, 206, 192, 154, 148, 134, 136, 162, 172, 190, 176,
   9,   7,  21,  27,  49,  63,  45,  35, 121, 119, 101, 107,  65,  79,  93,  83, 233, 231, 245, 251, 209, 223, 205, 195, 153, 151, 133, 139, 161, 175, 189, 179},

{  0,  15,  30,  17,  60,  51,  34,  45, 120, 119, 102, 105,  68,  75,  90,  85, 240, 255, 238, 225, 204, 195, 210, 221, 136, 135, 150, 153, 180, 187, 170, 165,
  35,  44,  61,  50,  31,  16,   1,  14,  91,  84,  69,  74, 103, 104, 121, 118, 211, 220, 205, 194, 239, 224, 241, 254, 171, 164, 181, 186, 151, 152, 137, 134,
  70,  73,  88,  87, 122, 117, 100, 107,  62,  49,  32,  47,   2,  13,  28,  19, 182, 185, 168, 167, 138, 133, 148, 155, 206, 193, 208, 223, 242, 253, 236, 227,
 101, 106, 123, 116,  89,  86,  71,  72,  29,  18,   3,  12,  33,  46,  63,  48, 149, 154, 139, 132, 169, 166, 183, 184, 237, 226, 243, 252, 209, 222, 207, 192,
 140, 131, 146, 157, 176, 191, 174, 161, 244, 251, 234, 229, 200, 199, 214, 217, 124, 115,  98, 109,  64,  79,  94,  81,   4,  11,  26,  21,  56,  55,  38,  41,
 175, 160, 177, 190, 147, 156, 141, 130, 215, 216, 201, 198, 235, 228, 245, 250,  95,  80,  65,  78,  99, 108, 125, 114,  39,  40,  57,  54,  27,  20,   5,  10,
 202, 197, 212, 219, 246, 249, 232, 231, 178, 189, 172, 163, 142, 129, 144, 159,  58,  53,  36,  43,   6,   9,  24,  23,  66,  77,  92,  83, 126, 113,  96, 111,
 233, 230, 247, 248, 213, 218, 203, 196, 145, 158, 143, 128, 173, 162, 179, 188,  25,  22,   7,   8,  37,  42,  59,  52,  97, 110, 127, 112,  93,  82,  67,  76},

{  0,  16,  32,  48,  64,  80,  96, 112, 128, 144, 160, 176, 192, 208, 224, 240, 195, 211, 227, 243, 131, 147, 163, 179,  67,  83,  99, 115,   3,  19,  35,  51,
  69,  85, 101, 117,   5,  21,  37,  53, 197, 213, 229, 245, 133, 149, 165, 181, 134, 150, 166, 182, 198, 214, 230, 246,   6,  22,  38,  54,  70,  86, 102, 118,
 138, 154, 170, 186, 202, 218, 234, 250,  10,  26,  42,  58,  74,  90, 106, 122,  73,  89, 105, 121,   9,  25,  41,  57, 201, 217, 233, 249, 137, 153, 169, 185,
 207, 223, 239, 255, 143, 159, 175, 191,  79,  95, 111, 127,  15,  31,  47,  63,  12,  28,  44,  60,  76,  92, 108, 124, 140, 156, 172, 188, 204, 220, 236, 252,
 215, 199, 247, 231, 151, 135, 183, 167,  87,  71, 119, 103,  23,   7,  55,  39,  20,   4,  52,  36,  84,  68, 116, 100, 148, 132, 180, 164, 212, 196, 244, 228,
 146, 130, 178, 162, 210, 194, 242, 226,  18,   2,  50,  34,  82,  66, 114,  98,  81,  65, 113,  97,  17,   1,  49,  33, 209, 193, 241, 225, 145, 129, 177, 161,
  93,  77, 125, 109,  29,  13,  61,  45, 221, 205, 253, 237, 157, 141, 189, 173, 158, 142, 190, 174, 222, 206, 254, 238,  30,  14,  62,  46,  94,  78, 126, 110,
  24,   8,  56,  40,  88,  72, 120, 104, 152, 136, 184, 168, 216, 200, 248, 232, 219, 203, 251, 235, 155, 139, 187, 171,  91,  75, 123, 107,  27,  11,  59,  43},

{  0,  17,  34,  51,  68,  85, 102, 119, 136, 153, 170, 187, 204, 221, 238, 255, 211, 194, 241, 224, 151, 134, 181, 164,  91,  74, 121, 104,  31,  14,  61,  44,
 101, 116,  71,  86,  33,  48,   3,  18, 237, 252, 207, 222, 169, 184, 139, 154, 182, 167, 148, 133, 242, 227, 208, 193,  62,  47,  28,  13, 122, 107,  88,  73,
 202, 219, 232, 249, 142, 159, 172, 189,  66,  83,  96, 113,   6,  23,  36,  53,  25,   8,  59,  42,  93,  76, 127, 110, 145, 128, 179, 162, 213, 196, 247, 230,
 175, 190, 141, 156, 235, 250, 201, 216,  39,  54,   5,  20,  99, 114,  65,  80, 124, 109,  94,  79,  56,  41,  26,  11, 244, 229, 214, 199, 176, 161, 146, 131,
  87,  70, 117, 100,  19,   2,  49,  32, 223, 206, 253, 236, 155, 138, 185, 168, 132, 149, 166, 183, 192, 209, 226, 243,  12,  29,  46,  63,  72,  89, 106, 123,
  50,  35,  16,   1, 118, 103,  84,  69, 186, 171, 152, 137, 254, 239, 220, 205, 225, 240, 195, 210, 165, 180, 135, 150, 105, 120,  75,  90,  45,  60,  15,  30,
 157, 140, 191, 174, 217, 200, 251, 234,  21,   4,  55,  38,  81,  64, 115,  98,  78,  95, 108, 125,  10,  27,  40,  57, 198, 215, 228, 245, 130, 147, 160, 177,
 248, 233, 218, 203, 188, 173, 158, 143, 112,  97,  82,  67,  52,  37,  22,   7,  43,  58,   9,  24, 111, 126,  77,  92, 163, 178, 129, 144, 231, 246, 197, 212},

{  0,  18,  36,  54,  72,  90, 108, 126, 144, 130, 180, 166, 216, 202, 252, 238, 227, 241, 199, 213, 171, 185, 143, 157, 115,  97,  87,  69,  59,  41,  31,  13,
   5,  23,  33,  51,  77,  95, 105, 123, 149, 135, 177, 163, 221, 207, 249, 235, 230, 244, 194, 208, 174, 188, 138, 152, 118, 100,  82,  64,  62,  44,  26,   8,
  10,  24,  46,  60,  66,  80, 102, 116, 154, 136, 190, 172, 210, 192, 246, 228, 233, 251, 205, 223, 161, 179, 133, 151, 121, 107,  93,  79,  49,  35,  21,   7,
  15,  29,  43,  57,  71,  85,  99, 113, 159, 141, 187, 169, 215, 197, 243, 225, 236, 254, 200, 218, 164, 182, 128, 146, 124, 110,  88,  74,  52,  38,  16,   2,
  20,   6,  48,  34,  92,  78, 120, 106, 132, 150, 160, 178, 204, 222, 232, 250, 247, 229, 211, 193, 191, 173, 155, 137, 103, 117,  67,  81,  47,  61,  11,  25,
  17,   3,  53,  39,  89,  75, 125, 111, 129, 147, 165, 183, 201, 219, 237, 255, 242, 224, 214, 196, 186, 168, 158, 140,  98, 112,  70,  84,  42,  56,  14,  28,
  30,  12,  58,  40,  86,  68, 114,  96, 142, 156, 170, 184, 198, 212, 226, 240, 253, 239, 217, 203, 181, 167, 145, 131, 109, 127,  73,  91,  37,  55,   1,  19,
  27,   9,  63,  45,  83,  65, 119, 101, 139, 153, 175, 189, 195, 209, 231, 245, 248, 234, 220, 206, 176, 162, 148, 134, 104, 122,  76,  94,  32,  50,   4,  22},

{  0,  19,  38,  53,  76,  95, 106, 121, 152, 139, 190, 173, 212, 199, 242, 225, 243, 224, 213, 198, 191, 172, 153, 138, 107, 120,  77,  94,  39,  52,   1,  18,
  37,  54,   3,  16, 105, 122,  79,  92, 189, 174, 155, 136, 241, 226, 215, 196, 214, 197, 240, 227, 154, 137, 188, 175,  78,  93, 104, 123,   2,  17,  36,  55,
  74,  89, 108, 127,   6,  21,  32,  51, 210, 193, 244, 231, 158, 141, 184, 171, 185, 170, 159, 140, 245, 230, 211, 192,  33,  50,   7,  20, 109, 126,  75,  88,
 111, 124,  73,  90,  35,  48,   5,  22, 247, 228, 209, 194, 187, 168, 157, 142, 156, 143, 186, 169, 208, 195, 246, 229,   4,  23,  34,  49,  72,  91, 110, 125,
 148, 135, 178, 161, 216, 203, 254, 237,  12,  31,  42,  57,  64,  83, 102, 117, 103, 116,  65,  82,  43,  56,  13,  30, 255, 236, 217, 202, 179, 160, 149, 134,
 177, 162, 151, 132, 253, 238, 219, 200,  41,  58,  15,  28, 101, 118,  67,  80,  66,  81, 100, 119,  14,  29,  40,  59, 218, 201, 252, 239, 150, 133, 176, 163,
 222, 205, 248, 235, 146, 129, 180, 167,  70,  85,  96, 115,  10,  25,  44,  63,  45,  62,  11,  24,  97, 114,  71,  84, 181, 166, 147, 128, 249, 234, 223, 204,
 251, 232, 221, 206, 183, 164, 145, 130,  99, 112,  69,  86,  47,  60,   9,  26,   8,  27,  46,  61,  68,  87,  98, 113, 144, 131, 182, 165, 220, 207, 250, 233},

{  0,  20,  40,  60,  80,  68, 120, 108, 160, 180, 136, 156, 240, 228, 216, 204, 131, 151, 171, 191, 211, 199, 251, 239,  35,  55,  11,  31, 115, 103,  91,  79,
 197, 209, 237, 249, 149, 129, 189, 169, 101, 113,  77,  89,  53,  33,  29,   9,  70,  82, 110, 122,  22,   2,  62,  42, 230, 242, 206, 218, 182, 162, 158, 138,
  73,  93,  97, 117,  25,  13,  49,  37, 233, 253, 193, 213, 185, 173, 145, 133, 202, 222, 226, 246, 154, 142, 178, 166, 106, 126,  66,  86,  58,  46,  18,   6,
 140, 152, 164, 176, 220, 200, 244, 224,  44,  56,   4,  16, 124, 104,  84,  64,  15,  27,  39,  51,  95,  75, 119,  99, 175, 187, 135, 147, 255, 235, 215, 195,
 146, 134, 186, 174, 194, 214, 234, 254,  50,  38,  26,  14,  98, 118,  74,  94,  17,   5,  57,  45,  65,  85, 105, 125, 177, 165, 153, 141, 225, 245, 201, 221,
  87,  67, 127, 107,   7,  19,  47,  59, 247, 227, 223, 203, 167, 179, 143, 155, 212, 192, 252, 232, 132, 144, 172, 184, 116,  96,  92,  72,  36,  48,  12,  24,
 219, 207, 243, 231, 139, 159, 163, 183, 123, 111,  83,  71,  43,  63,   3,  23,  88,  76, 112, 100,   8,  28,  32,  52, 248, 236, 208, 196, 168, 188, 128, 148,
  30,  10,  54,  34,  78,  90, 102, 114, 190, 170, 150, 130, 238, 250, 198, 210, 157, 137, 181, 161, 205, 217, 229, 241,  61,  41,  21,   1, 109, 121,  69,  81},

{  0,  21,  42,  63,  84,  65, 126, 107, 168, 189, 130, 151, 252, 233, 214, 195, 147, 134, 185, 172, 199, 210, 237, 248,  59,  46,  17,   4, 111, 122,  69,  80,
 229, 240, 207, 218, 177, 164, 155, 142,  77,  88, 103, 114,  25,  12,  51,  38, 118,  99,  92,  73,  34,  55,   8,  29, 222, 203, 244, 225, 138, 159, 160, 181,
   9,  28,  35,  54,  93,  72, 119,  98, 161, 180, 139, 158, 245, 224, 223, 202, 154, 143, 176, 165, 206, 219, 228, 241,  50,  39,  24,  13, 102, 115,  76,  89,
 236, 249, 198, 211, 184, 173, 146, 135,  68,  81, 110, 123,  16,   5,  58,  47, 127, 106,  85,  64,  43,  62,   1,  20, 215, 194, 253, 232, 131, 150, 169, 188,
  18,   7,  56,  45,  70,  83, 108, 121, 186, 175, 144, 133, 238, 251, 196, 209, 129, 148, 171, 190, 213, 192, 255, 234,  41,  60,   3,  22, 125, 104,  87,  66,
 247, 226, 221, 200, 163, 182, 137, 156,  95,  74, 117,  96,  11,  30,  33,  52, 100, 113,  78,  91,  48,  37,  26,  15, 204, 217, 230, 243, 152, 141, 178, 167,
  27,  14,  49,  36,  79,  90, 101, 112, 179, 166, 153, 140, 231, 242, 205, 216, 136, 157, 162, 183, 220, 201, 246, 227,  32,  53,  10,  31, 116,  97,  94,  75,
 254, 235, 212, 193, 170, 191, 128, 149,  86,  67, 124, 105,   2,  23,  40,  61, 109, 120,  71,  82,  57,  44,  19,   6, 197, 208, 239, 250, 145, 132, 187, 174},

{  0,  22,  44,  58,  88,  78, 116,  98, 176, 166, 156, 138, 232, 254, 196, 210, 163, 181, 143, 153, 251, 237, 215, 193,  19,   5,  63,  41,  75,  93, 103, 113,
 133, 147, 169, 191, 221, 203, 241, 231,  53,  35,  25,  15, 109, 123,  65,  87,  38,  48,  10,  28, 126, 104,  82,  68, 150, 128, 186, 172, 206, 216, 226, 244,
 201, 223, 229, 243, 145, 135, 189, 171, 121, 111,  85,  67,  33,  55,  13,  27, 106, 124,  70,  80,  50,  36,  30,   8, 218, 204, 246, 224, 130, 148, 174, 184,
  76,  90,  96, 118,  20,   2,  56,  46, 252, 234, 208, 198, 164, 178, 136, 158, 239, 249, 195, 213, 183, 161, 155, 141,  95,  73, 115, 101,   7,  17,  43,  61,
  81,  71, 125, 107,   9,  31,  37,  51, 225, 247, 205, 219, 185, 175, 149, 131, 242, 228, 222, 200, 170, 188, 134, 144,  66,  84, 110, 120,  26,  12,  54,  32,
 212, 194, 248, 238, 140, 154, 160, 182, 100, 114,  72,  94,  60,  42,  16,   6, 119,  97,  91,  77,  47,  57,   3,  21, 199, 209, 235, 253, 159, 137, 179, 165,
 152, 142, 180, 162, 192, 214, 236, 250,  40,  62,   4,  18, 112, 102,  92,  74,  59,  45,  23,   1,  99, 117,  79,  89, 139, 157, 167, 177, 211, 197, 255, 233,
  29,  11,  49,  39,  69,  83, 105, 127, 173, 187, 129, 151, 245, 227, 217, 207, 190, 168, 146, 132, 230, 240, 202, 220,  14,  24,  34,  52,  86,  64, 122, 108},

{  0,  23,  46,  57,  92,  75, 114, 101, 184, 175, 150, 129, 228, 243, 202, 221, 179, 164, 157, 138, 239, 248, 193, 214,  11,  28,  37,  50,  87,  64, 121, 110,
 165, 178, 139, 156, 249, 238, 215, 192,  29,  10,  51,  36,  65,  86, 111, 120,  22,   1,  56,  47,  74,  93, 100, 115, 174, 185, 128, 151, 242, 229, 220, 203,
 137, 158, 167, 176, 213, 194, 251, 236,  49,  38,  31,   8, 109, 122,  67,  84,  58,  45,  20,   3, 102, 113,  72,  95, 130, 149, 172, 187, 222, 201, 240, 231,
  44,  59,   2,  21, 112, 103,  94,  73, 148, 131, 186, 173, 200, 223, 230, 241, 159, 136, 177, 166, 195, 212, 237, 250,  39,  48,   9,  30, 123, 108,  85,  66,
 209, 198, 255, 232, 141, 154, 163, 180, 105, 126,  71,  80,  53,  34,  27,  12,  98, 117,  76,  91,  62,  41,  16,   7, 218, 205, 244, 227, 134, 145, 168, 191,
 116,  99,  90,  77,  40,  63,   6,  17, 204, 219, 226, 245, 144, 135, 190, 169, 199, 208, 233, 254, 155, 140, 181, 162, 127, 104,  81,  70,  35,  52,  13,  26,
  88,  79, 118,  97,   4,  19,  42,  61, 224, 247, 206, 217, 188, 171, 146, 133, 235, 252, 197, 210, 183, 160, 153, 142,  83,  68, 125, 106,  15,  24,  33,  54,
 253, 234, 211, 196, 161, 182, 143, 152,  69,  82, 107, 124,  25,  14,  55,  32,  78,  89,  96, 119,  18,   5,  60,  43, 246, 225, 216, 207, 170, 189, 132, 147},

{  0,  24,  48,  40,  96, 120,  80,  72, 192, 216, 240, 232, 160, 184, 144, 136,  67,  91, 115, 107,  35,  59,  19,  11, 131, 155, 179, 171, 227, 251, 211, 203,
 134, 158, 182, 174, 230, 254, 214, 206,  70,  94, 118, 110,  38,  62,  22,  14, 197, 221, 245, 237, 165, 189, 149, 141,   5,  29,  53,  45, 101, 125,  85,  77,
 207, 215, 255, 231, 175, 183, 159, 135,  15,  23,  63,  39, 111, 119,  95,  71, 140, 148, 188, 164, 236, 244, 220, 196,  76,  84, 124, 100,  44,  52,  28,   4,
  73,  81, 121,  97,  41,  49,  25,   1, 137, 145, 185, 161, 233, 241, 217, 193,  10,  18,  58,  34, 106, 114,  90,  66, 202, 210, 250, 226, 170, 178, 154, 130,
  93,  69, 109, 117,  61,  37,  13,  21, 157, 133, 173, 181, 253, 229, 205, 213,  30,   6,  46,  54, 126, 102,  78,  86, 222, 198, 238, 246, 190, 166, 142, 150,
 219, 195, 235, 243, 187, 163, 139, 147,  27,   3,  43,  51, 123,  99,  75,  83, 152, 128, 168, 176, 248, 224, 200, 208,  88,  64, 104, 112,  56,  32,   8,  16,
 146, 138, 162, 186, 242, 234, 194, 218,  82,  74,  98, 122,  50,  42,   2,  26, 209, 201, 225, 249, 177, 169, 129, 153,  17,   9,  33,  57, 113, 105,  65,  89,
  20,  12,  36,  60, 116, 108,  68,  92, 212, 204, 228, 252, 180, 172, 132, 156,  87,  79, 103, 127,  55,  47,   7,  31, 151, 143, 167, 191, 247, 239, 199, 223},

{  0,  25,  50,  43, 100, 125,  86,  79, 200, 209, 250, 227, 172, 181, 158, 135,  83,  74,  97, 120,  55,  46,   5,  28, 155, 130, 169, 176, 255, 230, 205, 212,
 166, 191, 148, 141, 194, 219, 240, 233, 110, 119,  92,  69,  10,  19,  56,  33, 245, 236, 199, 222, 145, 136, 163, 186,  61,  36,  15,  22,  89,  64, 107, 114,
 143, 150, 189, 164, 235, 242, 217, 192,  71,  94, 117, 108,  35,  58,  17,   8, 220, 197, 238, 247, 184, 161, 138, 147,  20,  13,  38,  63, 112, 105,  66,  91,
  41,  48,  27,   2,  77,  84, 127, 102, 225, 248, 211, 202, 133, 156, 183, 174, 122,  99,  72,  81,  30,   7,  44,  53, 178, 171, 128, 153, 214, 207, 228, 253,
 221, 196, 239, 246, 185, 160, 139, 146,  21,  12,  39,  62, 113, 104,  67,  90, 142, 151, 188, 165, 234, 243, 216, 193,  70,  95, 116, 109,  34,  59,  16,   9,
 123,  98,  73,  80,  31,   6,  45,  52, 179, 170, 129, 152, 215, 206, 229, 252,  40,  49,  26,   3,  76,  85, 126, 103, 224, 249, 210, 203, 132, 157, 182, 175,
  82,  75,  96, 121,  54,  47,   4,  29, 154, 131, 168, 177, 254, 231, 204, 213,   1,  24,  51,  42, 101, 124,  87,  78, 201, 208, 251, 226, 173, 180, 159, 134,
 244, 237, 198, 223, 144, 137, 162, 187,  60,  37,  14,  23,  88,  65, 106, 115, 167, 190, 149, 140, 195, 218, 241, 232, 111, 118,  93,  68,  11,  18,  57,  32},

{  0,  26,  52,  46, 104, 114,  92,  70, 208, 202, 228, 254, 184, 162, 140, 150,  99, 121,  87,  77,  11,  17,  63,  37, 179, 169, 135, 157, 219, 193, 239, 245,
 198, 220, 242, 232, 174, 180, 154, 128,  22,  12,  34,  56, 126, 100,  74,  80, 165, 191, 145, 139, 205, 215, 249, 227, 117, 111,  65,  91,  29,   7,  41,  51,
  79,  85, 123,  97,  39,  61,  19,   9, 159, 133, 171, 177, 247, 237, 195, 217,  44,  54,  24,   2,  68,  94, 112, 106, 252, 230, 200, 210, 148, 142, 160, 186,
 137, 147, 189, 167, 225, 251, 213, 207,  89,  67, 109, 119,  49,  43,   5,  31, 234, 240, 222, 196, 130, 152, 182, 172,  58,  32,  14,  20,  82,  72, 102, 124,
 158, 132, 170, 176, 246, 236, 194, 216,  78,  84, 122,  96,  38,  60,  18,   8, 253, 231, 201, 211, 149, 143, 161, 187,  45,  55,  25,   3,  69,  95, 113, 107,
  88,  66, 108, 118,  48,  42,   4,  30, 136, 146, 188, 166, 224, 250, 212, 206,  59,  33,  15,  21,  83,  73, 103, 125, 235, 241, 223, 197, 131, 153, 183, 173,
 209, 203, 229, 255, 185, 163, 141, 151,   1,  27,  53,  47, 105, 115,  93,  71, 178, 168, 134, 156, 218, 192, 238, 244,  98, 120,  86,  76,  10,  16,  62,  36,
  23,  13,  35,  57, 127, 101,  75,  81, 199, 221, 243, 233, 175, 181, 155, 129, 116, 110,  64,  90,  28,   6,  40,  50, 164, 190, 144, 138, 204, 214, 248, 226},

{  0,  27,  54,  45, 108, 119,  90,  65, 216, 195, 238, 245, 180, 175, 130, 153, 115, 104,  69,  94,  31,   4,  41,  50, 171, 176, 157, 134, 199, 220, 241, 234,
 230, 253, 208, 203, 138, 145, 188, 167,  62,  37,   8,  19,  82,  73, 100, 127, 149, 142, 163, 184, 249, 226, 207, 212,  77,  86, 123,  96,  33,  58,  23,  12,
  15,  20,  57,  34,  99, 120,  85,  78, 215, 204, 225, 250, 187, 160, 141, 150, 124, 103,  74,  81,  16,  11,  38,  61, 164, 191, 146, 137, 200, 211, 254, 229,
 233, 242, 223, 196, 133, 158, 179, 168,  49,  42,   7,  28,  93,  70, 107, 112, 154, 129, 172, 183, 246, 237, 192, 219,  66,  89, 116, 111,  46,  53,  24,   3,
  30,   5,  40,  51, 114, 105,  68,  95, 198, 221, 240, 235, 170, 177, 156, 135, 109, 118,  91,  64,   1,  26,  55,  44, 181, 174, 131, 152, 217, 194, 239, 244,
 248, 227, 206, 213, 148, 143, 162, 185,  32,  59,  22,  13,  76,  87, 122,  97, 139, 144, 189, 166, 231, 252, 209, 202,  83,  72, 101, 126,  63,  36,   9,  18,
  17,  10,  39,  60, 125, 102,  75,  80, 201, 210, 255, 228, 165, 190, 147, 136,  98, 121,  84,  79,  14,  21,  56,  35, 186, 161, 140, 151, 214, 205, 224, 251,
 247, 236, 193, 218, 155, 128, 173, 182,  47,  52,  25,   2,  67,  88, 117, 110, 132, 159, 178, 169, 232, 243, 222, 197,  92,  71, 106, 113,  48,  43,   6,  29},

{  0,  28,  56,  36, 112, 108,  72,  84, 224, 252, 216, 196, 144, 140, 168, 180,   3,  31,  59,  39, 115, 111,  75,  87, 227, 255, 219, 199, 147, 143, 171, 183,
   6,  26,  62,  34, 118, 106,  78,  82, 230, 250, 222, 194, 150, 138, 174, 178,   5,  25,  61,  33, 117, 105,  77,  81, 229, 249, 221, 193, 149, 137, 173, 177,
  12,  16,  52,  40, 124,  96,  68,  88, 236, 240, 212, 200, 156, 128, 164, 184,  15,  19,  55,  43, 127,  99,  71,  91, 239, 243, 215, 203, 159, 131, 167, 187,
  10,  22,  50,  46, 122, 102,  66,  94, 234, 246, 210, 206, 154, 134, 162, 190,   9,  21,  49,  45, 121, 101,  65,  93, 233, 245, 209, 205, 153, 133, 161, 189,
  24,   4,  32,  60, 104, 116,  80,  76, 248, 228, 192, 220, 136, 148, 176, 172,  27,   7,  35,  63, 107, 119,  83,  79, 251, 231, 195, 223, 139, 151, 179, 175,
  30,   2,  38,  58, 110, 114,  86,  74, 254, 226, 198, 218, 142, 146, 182, 170,  29,   1,  37,  57, 109, 113,  85,  73, 253, 225, 197, 217, 141, 145, 181, 169,
  20,   8,  44,  48, 100, 120,  92,  64, 244, 232, 204, 208, 132, 152, 188, 160,  23,  11,  47,  51, 103, 123,  95,  67, 247, 235, 207, 211, 135, 155, 191, 163,
  18,  14,  42,  54,  98, 126,  90,  70, 242, 238, 202, 214, 130, 158, 186, 166,  17,  13,  41,  53,  97, 125,  89,  69, 241, 237, 201, 213, 129, 157, 185, 165},

{  0,  29,  58,  39, 116, 105,  78,  83, 232, 245, 210, 207, 156, 129, 166, 187,  19,  14,  41,  52, 103, 122,  93,  64, 251, 230, 193, 220, 143, 146, 181, 168,
  38,  59,  28,   1,  82,  79, 104, 117, 206, 211, 244, 233, 186, 167, 128, 157,  53,  40,  15,  18,  65,  92, 123, 102, 221, 192, 231, 250, 169, 180, 147, 142,
  76,  81, 118, 107,  56,  37,   2,  31, 164, 185, 158, 131, 208, 205, 234, 247,  95,  66, 101, 120,  43,  54,  17,  12, 183, 170, 141, 144, 195, 222, 249, 228,
 106, 119,  80,  77,  30,   3,  36,  57, 130, 159, 184, 165, 246, 235, 204, 209, 121, 100,  67,  94,  13,  16,  55,  42, 145, 140, 171, 182, 229, 248, 223, 194,
 152, 133, 162, 191, 236, 241, 214, 203, 112, 109,  74,  87,   4,  25,  62,  35, 139, 150, 177, 172, 255, 226, 197, 216,  99, 126,  89,  68,  23,  10,  45,  48,
 190, 163, 132, 153, 202, 215, 240, 237,  86,  75, 108, 113,  34,  63,  24,   5, 173, 176, 151, 138, 217, 196, 227, 254,  69,  88, 127,  98,  49,  44,  11,  22,
 212, 201, 238, 243, 160, 189, 154, 135,  60,  33,   6,  27,  72,  85, 114, 111, 199, 218, 253, 224, 179, 174, 137, 148,  47,  50,  21,   8,  91,  70,  97, 124,
 242, 239, 200, 213, 134, 155, 188, 161,  26,   7,  32,  61, 110, 115,  84,  73, 225, 252, 219, 198, 149, 136, 175, 178,   9,  20,  51,  46, 125,  96,  71,  90},

{  0,  30,  60,  34, 120, 102,  68,  90, 240, 238, 204, 210, 136, 150, 180, 170,  35,  61,  31,   1,  91,  69, 103, 121, 211, 205, 239, 241, 171, 181, 151, 137,
  70,  88, 122, 100,  62,  32,   2,  28, 182, 168, 138, 148, 206, 208, 242, 236, 101, 123,  89,  71,  29,   3,  33,  63, 149, 139, 169, 183, 237, 243, 209, 207,
 140, 146, 176, 174, 244, 234, 200, 214, 124,  98,  64,  94,   4,  26,  56,  38, 175, 177, 147, 141, 215, 201, 235, 245,  95,  65,  99, 125,  39,  57,  27,   5,
 202, 212, 246, 232, 178, 172, 142, 144,  58,  36,   6,  24,  66,  92, 126,  96, 233, 247, 213, 203, 145, 143, 173, 179,  25,   7,  37,  59,  97, 127,  93,  67,
 219, 197, 231, 249, 163, 189, 159, 129,  43,  53,  23,   9,  83,  77, 111, 113, 248, 230, 196, 218, 128, 158, 188, 162,   8,  22,  52,  42, 112, 110,  76,  82,
 157, 131, 161, 191, 229, 251, 217, 199, 109, 115,  81,  79,  21,  11,  41,  55, 190, 160, 130, 156, 198, 216, 250, 228,  78,  80, 114, 108,  54,  40,  10,  20,
  87,  73, 107, 117,  47,  49,  19,  13, 167, 185, 155, 133, 223, 193, 227, 253, 116, 106,  72,  86,  12,  18,  48,  46, 132, 154, 184, 166, 252, 226, 192, 222,
  17,  15,  45,  51, 105, 119,  85,  75, 225, 255, 221, 195, 153, 135, 165, 187,  50,  44,  14,  16,  74,  84, 118, 104, 194, 220, 254, 224, 186, 164, 134, 152},

{  0,  31,  62,  33, 124,  99,  66,  93, 248, 231, 198, 217, 132, 155, 186, 165,  51,  44,  13,  18,  79,  80, 113, 110, 203, 212, 245, 234, 183, 168, 137, 150,
 102, 121,  88,  71,  26,   5,  36,  59, 158, 129, 160, 191, 226, 253, 220, 195,  85,  74, 107, 116,  41,  54,  23,   8, 173, 178, 147, 140, 209, 206, 239, 240,
 204, 211, 242, 237, 176, 175, 142, 145,  52,  43,  10,  21,  72,  87, 118, 105, 255, 224, 193, 222, 131, 156, 189, 162,   7,  24,  57,  38, 123, 100,  69,  90,
 170, 181, 148, 139, 214, 201, 232, 247,  82,  77, 108, 115,  46,  49,  16,  15, 153, 134, 167, 184, 229, 250, 219, 196,  97, 126,  95,  64,  29,   2,  35,  60,
  91,  68, 101, 122,  39,  56,  25,   6, 163, 188, 157, 130, 223, 192, 225, 254, 104, 119,  86,  73,  20,  11,  42,  53, 144, 143, 174, 177, 236, 243, 210, 205,
  61,  34,   3,  28,  65,  94, 127,  96, 197, 218, 251, 228, 185, 166, 135, 152,  14,  17,  48,  47, 114, 109,  76,  83, 246, 233, 200, 215, 138, 149, 180, 171,
 151, 136, 169, 182, 235, 244, 213, 202, 111, 112,  81,  78,  19,  12,  45,  50, 164, 187, 154, 133, 216, 199, 230, 249,  92,  67,  98, 125,  32,  63,  30,   1,
 241, 238, 207, 208, 141, 146, 179, 172,   9,  22,  55,  40, 117, 106,  75,  84, 194, 221, 252, 227, 190, 161, 128, 159,  58,  37,   4,  27,  70,  89, 120, 103},

{  0,  32,  64,  96, 128, 160, 192, 224, 195, 227, 131, 163,  67,  99,   3,  35,  69, 101,   5,  37, 197, 229, 133, 165, 134, 166, 198, 230,   6,  38,  70, 102,
 138, 170, 202, 234,  10,  42,  74, 106,  73, 105,   9,  41, 201, 233, 137, 169, 207, 239, 143, 175,  79, 111,  15,  47,  12,  44,  76, 108, 140, 172, 204, 236,
 215, 247, 151, 183,  87, 119,  23,  55,  20,  52,  84, 116, 148, 180, 212, 244, 146, 178, 210, 242,  18,  50,  82, 114,  81, 113,  17,  49, 209, 241, 145, 177,
  93, 125,  29,  61, 221, 253, 157, 189, 158, 190, 222, 254,  30,  62,  94, 126,  24,  56,  88, 120, 152, 184, 216, 248, 219, 251, 155, 187,  91, 123,  27,  59,
 109,  77,  45,  13, 237, 205, 173, 141, 174, 142, 238, 206,  46,  14, 110,  78,  40,   8, 104,  72, 168, 136, 232, 200, 235, 203, 171, 139, 107,  75,  43,  11,
 231, 199, 167, 135, 103,  71,  39,   7,  36,   4, 100,  68, 164, 132, 228, 196, 162, 130, 226, 194,  34,   2,  98,  66,  97,  65,  33,   1, 225, 193, 161, 129,
 186, 154, 250, 218,  58,  26, 122,  90, 121,  89,  57,  25, 249, 217, 185, 153, 255, 223, 191, 159, 127,  95,  63,  31,  60,  28, 124,  92, 188, 156, 252, 220,
  48,  16, 112,  80, 176, 144, 240, 208, 243, 211, 179, 147, 115,  83,  51,  19, 117,  85,  53,  21, 245, 213, 181, 149, 182, 150, 246, 214,  54,  22, 118,  86},

{  0,  33,  66,  99, 132, 165, 198, 231, 203, 234, 137, 168,  79, 110,  13,  44,  85, 116,  23,  54, 209, 240, 147, 178, 158, 191, 220, 253,  26,  59,  88, 121,
 170, 139, 232, 201,  46,  15, 108,  77,  97,  64,  35,   2, 229, 196, 167, 134, 255, 222, 189, 156, 123,  90,  57,  24,  52,  21, 118,  87, 176, 145, 242, 211,
 151, 182, 213, 244,  19,  50,  81, 112,  92, 125,  30,  63, 216, 249, 154, 187, 194, 227, 128, 161,  70, 103,   4,  37,   9,  40,  75, 106, 141, 172, 207, 238,
  61,  28, 127,  94, 185, 152, 251, 218, 246, 215, 180, 149, 114,  83,  48,  17, 104,  73,  42,  11, 236, 205, 174, 143, 163, 130, 225, 192,  39,   6, 101,  68,
 237, 204, 175, 142, 105,  72,  43,  10,  38,   7, 100,  69, 162, 131, 224, 193, 184, 153, 250, 219,  60,  29, 126,  95, 115,  82,  49,  16, 247, 214, 181, 148,
  71, 102,   5,  36, 195, 226, 129, 160, 140, 173, 206, 239,   8,  41,  74, 107,  18,  51,  80, 113, 150, 183, 212, 245, 217, 248, 155, 186,  93, 124,  31,  62,
 122,  91,  56,  25, 254, 223, 188, 157, 177, 144, 243, 210,  53,  20, 119,  86,  47,  14, 109,  76, 171, 138, 233, 200, 228, 197, 166, 135,  96,  65,  34,   3,
 208, 241, 146, 179,  84, 117,  22,  55,  27,  58,  89, 120, 159, 190, 221, 252, 133, 164, 199, 230,   1,  32,  67,  98,  78, 111,  12,  45, 202, 235, 136, 169},

{  0,  34,  68, 102, 136, 170, 204, 238, 211, 241, 151, 181,  91, 121,  31,  61, 101,  71,  33,   3, 237, 207, 169, 139, 182, 148, 242, 208,  62,  28, 122,  88,
 202, 232, 142, 172,  66,  96,   6,  36,  25,  59,  93, 127, 145, 179, 213, 247, 175, 141, 235, 201,  39,   5,  99,  65, 124,  94,  56,  26, 244, 214, 176, 146,
  87, 117,  19,  49, 223, 253, 155, 185, 132, 166, 192, 226,  12,  46,  72, 106,  50,  16, 118,  84, 186, 152, 254, 220, 225, 195, 165, 135, 105,  75,  45,  15,
 157, 191, 217, 251,  21,  55,  81, 115,  78, 108,  10,  40, 198, 228, 130, 160, 248, 218, 188, 158, 112,  82,  52,  22,  43,   9, 111,  77, 163, 129, 231, 197,
 174, 140, 234, 200,  38,   4,  98,  64, 125,  95,  57,  27, 245, 215, 177, 147, 203, 233, 143, 173,  67,  97,   7,  37,  24,  58,  92, 126, 144, 178, 212, 246,
 100,  70,  32,   2, 236, 206, 168, 138, 183, 149, 243, 209,  63,  29, 123,  89,   1,  35,  69, 103, 137, 171, 205, 239, 210, 240, 150, 180,  90, 120,  30,  60,
 249, 219, 189, 159, 113,  83,  53,  23,  42,   8, 110,  76, 162, 128, 230, 196, 156, 190, 216, 250,  20,  54,  80, 114,  79, 109,  11,  41, 199, 229, 131, 161,
  51,  17, 119,  85, 187, 153, 255, 221, 224, 194, 164, 134, 104,  74,  44,  14,  86, 116,  18,  48, 222, 252, 154, 184, 133, 167, 193, 227,  13,  47,  73, 107},

{  0,  35,  70, 101, 140, 175, 202, 233, 219, 248, 157, 190,  87, 116,  17,  50, 117,  86,  51,  16, 249, 218, 191, 156, 174, 141, 232, 203,  34,   1, 100,  71,
 234, 201, 172, 143, 102,  69,  32,   3,  49,  18, 119,  84, 189, 158, 251, 216, 159, 188, 217, 250,  19,  48,  85, 118,  68, 103,   2,  33, 200, 235, 142, 173,
  23,  52,  81, 114, 155, 184, 221, 254, 204, 239, 138, 169,  64,  99,   6,  37,  98,  65,  36,   7, 238, 205, 168, 139, 185, 154, 255, 220,  53,  22, 115,  80,
 253, 222, 187, 152, 113,  82,  55,  20,  38,   5,  96,  67, 170, 137, 236, 207, 136, 171, 206, 237,   4,  39,  66,  97,  83, 112,  21,  54, 223, 252, 153, 186,
  46,  13, 104,  75, 162, 129, 228, 199, 245, 214, 179, 144, 121,  90,  63,  28,  91, 120,  29,  62, 215, 244, 145, 178, 128, 163, 198, 229,  12,  47,  74, 105,
 196, 231, 130, 161,  72, 107,  14,  45,  31,  60,  89, 122, 147, 176, 213, 246, 177, 146, 247, 212,  61,  30, 123,  88, 106,  73,  44,  15, 230, 197, 160, 131,
  57,  26, 127,  92, 181, 150, 243, 208, 226, 193, 164, 135, 110,  77,  40,  11,  76, 111,  10,  41, 192, 227, 134, 165, 151, 180, 209, 242,  27,  56,  93, 126,
 211, 240, 149, 182,  95, 124,  25,  58,   8,  43,  78, 109, 132, 167, 194, 225, 166, 133, 224, 195,  42,   9, 108,  79, 125,  94,  59,  24, 241, 210, 183, 148},

{  0,  36,  72, 108, 144, 180, 216, 252, 227, 199, 171, 143, 115,  87,  59,  31,   5,  33,  77, 105, 149, 177, 221, 249, 230, 194, 174, 138, 118,  82,  62,  26,
  10,  46,  66, 102, 154, 190, 210, 246, 233, 205, 161, 133, 121,  93,  49,  21,  15,  43,  71,  99, 159, 187, 215, 243, 236, 200, 164, 128, 124,  88,  52,  16,
  20,  48,  92, 120, 132, 160, 204, 232, 247, 211, 191, 155, 103,  67,  47,  11,  17,  53,  89, 125, 129, 165, 201, 237, 242, 214, 186, 158,  98,  70,  42,  14,
  30,  58,  86, 114, 142, 170, 198, 226, 253, 217, 181, 145, 109,  73,  37,   1,  27,  63,  83, 119, 139, 175, 195, 231, 248, 220, 176, 148, 104,  76,  32,   4,
  40,  12,  96,  68, 184, 156, 240, 212, 203, 239, 131, 167,  91, 127,  19,  55,  45,   9, 101,  65, 189, 153, 245, 209, 206, 234, 134, 162,  94, 122,  22,  50,
  34,   6, 106,  78, 178, 150, 250, 222, 193, 229, 137, 173,  81, 117,  25,  61,  39,   3, 111,  75, 183, 147, 255, 219, 196, 224, 140, 168,  84, 112,  28,  56,
  60,  24, 116,  80, 172, 136, 228, 192, 223, 251, 151, 179,  79, 107,   7,  35,  57,  29, 113,  85, 169, 141, 225, 197, 218, 254, 146, 182,  74, 110,   2,  38,
  54,  18, 126,  90, 166, 130, 238, 202, 213, 241, 157, 185,  69,  97,  13,  41,  51,  23, 123,  95, 163, 135, 235, 207, 208, 244, 152, 188,  64, 100,   8,  44},

{  0,  37,  74, 111, 148, 177, 222, 251, 235, 206, 161, 132, 127,  90,  53,  16,  21,  48,  95, 122, 129, 164, 203, 238, 254, 219, 180, 145, 106,  79,  32,   5,
  42,  15,  96,  69, 190, 155, 244, 209, 193, 228, 139, 174,  85, 112,  31,  58,  63,  26, 117,  80, 171, 142, 225, 196, 212, 241, 158, 187,  64, 101,  10,  47,
  84, 113,  30,  59, 192, 229, 138, 175, 191, 154, 245, 208,  43,  14,  97,  68,  65, 100,  11,  46, 213, 240, 159, 186, 170, 143, 224, 197,  62,  27, 116,  81,
 126,  91,  52,  17, 234, 207, 160, 133, 149, 176, 223, 250,   1,  36,  75, 110, 107,  78,  33,   4, 255, 218, 181, 144, 128, 165, 202, 239,  20,  49,  94, 123,
 168, 141, 226, 199,  60,  25, 118,  83,  67, 102,   9,  44, 215, 242, 157, 184, 189, 152, 247, 210,  41,  12,  99,  70,  86, 115,  28,  57, 194, 231, 136, 173,
 130, 167, 200, 237,  22,  51,  92, 121, 105,  76,  35,   6, 253, 216, 183, 146, 151, 178, 221, 248,   3,  38,  73, 108, 124,  89,  54,  19, 232, 205, 162, 135,
 252, 217, 182, 147, 104,  77,  34,   7,  23,  50,  93, 120, 131, 166, 201, 236, 233, 204, 163, 134, 125,  88,  55,  18,   2,  39,  72, 109, 150, 179, 220, 249,
 214, 243, 156, 185,  66, 103,   8,  45,  61,  24, 119,  82, 169, 140, 227, 198, 195, 230, 137, 172,  87, 114,  29,  56,  40,  13,  98,  71, 188, 153, 246, 211},

{  0,  38,  76, 106, 152, 190, 212, 242, 243, 213, 191, 153, 107,  77,  39,   1,  37,   3, 105,  79, 189, 155, 241, 215, 214, 240, 154, 188,  78, 104,   2,  36,
  74, 108,   6,  32, 210, 244, 158, 184, 185, 159, 245, 211,  33,   7, 109,  75, 111,  73,  35,   5, 247, 209, 187, 157, 156, 186, 208, 246,   4,  34,  72, 110,
 148, 178, 216, 254,  12,  42,  64, 102, 103,  65,  43,  13, 255, 217, 179, 149, 177, 151, 253, 219,  41,  15, 101,  67,  66, 100,  14,  40, 218, 252, 150, 176,
 222, 248, 146, 180,  70,  96,  10,  44,  45,  11,  97,  71, 181, 147, 249, 223, 251, 221, 183, 145,  99,  69,  47,   9,   8,  46,  68,  98, 144, 182, 220, 250,
 235, 205, 167, 129, 115,  85,  63,  25,  24,  62,  84, 114, 128, 166, 204, 234, 206, 232, 130, 164,  86, 112,  26,  60,  61,  27, 113,  87, 165, 131, 233, 207,
 161, 135, 237, 203,  57,  31, 117,  83,  82, 116,  30,  56, 202, 236, 134, 160, 132, 162, 200, 238,  28,  58,  80, 118, 119,  81,  59,  29, 239, 201, 163, 133,
 127,  89,  51,  21, 231, 193, 171, 141, 140, 170, 192, 230,  20,  50,  88, 126,  90, 124,  22,  48, 194, 228, 142, 168, 169, 143, 229, 195,  49,  23, 125,  91,
  53,  19, 121,  95, 173, 139, 225, 199, 198, 224, 138, 172,  94, 120,  18,  52,  16,  54,  92, 122, 136, 174, 196, 226, 227, 197, 175, 137, 123,  93,  55,  17},

{  0,  39,  78, 105, 156, 187, 210, 245, 251, 220, 181, 146, 103,  64,  41,  14,  53,  18, 123,  92, 169, 142, 231, 192, 206, 233, 128, 167,  82, 117,  28,  59,
 106,  77,  36,   3, 246, 209, 184, 159, 145, 182, 223, 248,  13,  42,  67, 100,  95, 120,  17,  54, 195, 228, 141, 170, 164, 131, 234, 205,  56,  31, 118,  81,
 212, 243, 154, 189,  72, 111,   6,  33,  47,   8,  97,  70, 179, 148, 253, 218, 225, 198, 175, 136, 125,  90,  51,  20,  26,  61,  84, 115, 134, 161, 200, 239,
 190, 153, 240, 215,  34,   5, 108,  75,  69,  98,  11,  44, 217, 254, 151, 176, 139, 172, 197, 226,  23,  48,  89, 126, 112,  87,  62,  25, 236, 203, 162, 133,
 107,  76,  37,   2, 247, 208, 185, 158, 144, 183, 222, 249,  12,  43,  66, 101,  94, 121,  16,  55, 194, 229, 140, 171, 165, 130, 235, 204,  57,  30, 119,  80,
   1,  38,  79, 104, 157, 186, 211, 244, 250, 221, 180, 147, 102,  65,  40,  15,  52,  19, 122,  93, 168, 143, 230, 193, 207, 232, 129, 166,  83, 116,  29,  58,
 191, 152, 241, 214,  35,   4, 109,  74,  68,  99,  10,  45, 216, 255, 150, 177, 138, 173, 196, 227,  22,  49,  88, 127, 113,  86,  63,  24, 237, 202, 163, 132,
 213, 242, 155, 188,  73, 110,   7,  32,  46,   9,  96,  71, 178, 149, 252, 219, 224, 199, 174, 137, 124,  91,  50,  21,  27,  60,  85, 114, 135, 160, 201, 238},

{  0,  40,  80, 120, 160, 136, 240, 216, 131, 171, 211, 251,  35,  11, 115,  91, 197, 237, 149, 189, 101,  77,  53,  29,  70, 110,  22,  62, 230, 206, 182, 158,
  73,  97,  25,  49, 233, 193, 185, 145, 202, 226, 154, 178, 106,  66,  58,  18, 140, 164, 220, 244,  44,   4, 124,  84,  15,  39,  95, 119, 175, 135, 255, 215,
 146, 186, 194, 234,  50,  26,  98,  74,  17,  57,  65, 105, 177, 153, 225, 201,  87, 127,   7,  47, 247, 223, 167, 143, 212, 252, 132, 172, 116,  92,  36,  12,
 219, 243, 139, 163, 123,  83,  43,   3,  88, 112,   8,  32, 248, 208, 168, 128,  30,  54,  78, 102, 190, 150, 238, 198, 157, 181, 205, 229,  61,  21, 109,  69,
 231, 207, 183, 159,  71, 111,  23,  63, 100,  76,  52,  28, 196, 236, 148, 188,  34,  10, 114,  90, 130, 170, 210, 250, 161, 137, 241, 217,   1,  41,  81, 121,
 174, 134, 254, 214,  14,  38,  94, 118,  45,   5, 125,  85, 141, 165, 221, 245, 107,  67,  59,  19, 203, 227, 155, 179, 232, 192, 184, 144,  72,  96,  24,  48,
 117,  93,  37,  13, 213, 253, 133, 173, 246, 222, 166, 142,  86, 126,   6,  46, 176, 152, 224, 200,  16,  56,  64, 104,  51,  27,  99,  75, 147, 187, 195, 235,
  60,  20, 108,  68, 156, 180, 204, 228, 191, 151, 239, 199,  31,  55,  79, 103, 249, 209, 169, 129,  89, 113,   9,  33, 122,  82,  42,   2, 218, 242, 138, 162},

{  0,  41,  82, 123, 164, 141, 246, 223, 139, 162, 217, 240,  47,   6, 125,  84, 213, 252, 135, 174, 113,  88,  35,  10,  94, 119,  12,  37, 250, 211, 168, 129,
 105,  64,  59,  18, 205, 228, 159, 182, 226, 203, 176, 153,  70, 111,  20,  61, 188, 149, 238, 199,  24,  49,  74,  99,  55,  30, 101,  76, 147, 186, 193, 232,
 210, 251, 128, 169, 118,  95,  36,  13,  89, 112,  11,  34, 253, 212, 175, 134,   7,  46,  85, 124, 163, 138, 241, 216, 140, 165, 222, 247,  40,   1, 122,  83,
 187, 146, 233, 192,  31,  54,  77, 100,  48,  25,  98,  75, 148, 189, 198, 239, 110,  71,  60,  21, 202, 227, 152, 177, 229, 204, 183, 158,  65, 104,  19,  58,
 103,  78,  53,  28, 195, 234, 145, 184, 236, 197, 190, 151,  72,  97,  26,  51, 178, 155, 224, 201,  22,  63,  68, 109,  57,  16, 107,  66, 157, 180, 207, 230,
  14,  39,  92, 117, 170, 131, 248, 209, 133, 172, 215, 254,  33,   8, 115,  90, 219, 242, 137, 160, 127,  86,  45,   4,  80, 121,   2,  43, 244, 221, 166, 143,
 181, 156, 231, 206,  17,  56,  67, 106,  62,  23, 108,  69, 154, 179, 200, 225,  96,  73,  50,  27, 196, 237, 150, 191, 235, 194, 185, 144,  79, 102,  29,  52,
 220, 245, 142, 167, 120,  81,  42,   3,  87, 126,   5,  44, 243, 218, 161, 136,   9,  32,  91, 114, 173, 132, 255, 214, 130, 171, 208, 249,  38,  15, 116,  93},

{  0,  42,  84, 126, 168, 130, 252, 214, 147, 185, 199, 237,  59,  17, 111,  69, 229, 207, 177, 155,  77, 103,  25,  51, 118,  92,  34,   8, 222, 244, 138, 160,
   9,  35,  93, 119, 161, 139, 245, 223, 154, 176, 206, 228,  50,  24, 102,  76, 236, 198, 184, 146,  68, 110,  16,  58, 127,  85,  43,   1, 215, 253, 131, 169,
  18,  56,  70, 108, 186, 144, 238, 196, 129, 171, 213, 255,  41,   3, 125,  87, 247, 221, 163, 137,  95, 117,  11,  33, 100,  78,  48,  26, 204, 230, 152, 178,
  27,  49,  79, 101, 179, 153, 231, 205, 136, 162, 220, 246,  32,  10, 116,  94, 254, 212, 170, 128,  86, 124,   2,  40, 109,  71,  57,  19, 197, 239, 145, 187,
  36,  14, 112,  90, 140, 166, 216, 242, 183, 157, 227, 201,  31,  53,  75,  97, 193, 235, 149, 191, 105,  67,  61,  23,  82, 120,   6,  44, 250, 208, 174, 132,
  45,   7, 121,  83, 133, 175, 209, 251, 190, 148, 234, 192,  22,  60,  66, 104, 200, 226, 156, 182,  96,  74,  52,  30,  91, 113,  15,  37, 243, 217, 167, 141,
  54,  28,  98,  72, 158, 180, 202, 224, 165, 143, 241, 219,  13,  39,  89, 115, 211, 249, 135, 173, 123,  81,  47,   5,  64, 106,  20,  62, 232, 194, 188, 150,
  63,  21, 107,  65, 151, 189, 195, 233, 172, 134, 248, 210,   4,  46,  80, 122, 218, 240, 142, 164, 114,  88,  38,  12,  73,  99,  29,  55, 225, 203, 181, 159},

{  0,  43,  86, 125, 172, 135, 250, 209, 155, 176, 205, 230,  55,  28,  97,  74, 245, 222, 163, 136,  89, 114,  15,  36, 110,  69,  56,  19, 194, 233, 148, 191,
  41,   2, 127,  84, 133, 174, 211, 248, 178, 153, 228, 207,  30,  53,  72,  99, 220, 247, 138, 161, 112,  91,  38,  13,  71, 108,  17,  58, 235, 192, 189, 150,
  82, 121,   4,  47, 254, 213, 168, 131, 201, 226, 159, 180, 101,  78,  51,  24, 167, 140, 241, 218,  11,  32,  93, 118,  60,  23, 106,  65, 144, 187, 198, 237,
 123,  80,  45,   6, 215, 252, 129, 170, 224, 203, 182, 157,  76, 103,  26,  49, 142, 165, 216, 243,  34,   9, 116,  95,  21,  62,  67, 104, 185, 146, 239, 196,
 164, 143, 242, 217,   8,  35,  94, 117,  63,  20, 105,  66, 147, 184, 197, 238,  81, 122,   7,  44, 253, 214, 171, 128, 202, 225, 156, 183, 102,  77,  48,  27,
 141, 166, 219, 240,  33,  10, 119,  92,  22,  61,  64, 107, 186, 145, 236, 199, 120,  83,  46,   5, 212, 255, 130, 169, 227, 200, 181, 158,  79, 100,  25,  50,
 246, 221, 160, 139,  90, 113,  12,  39, 109,  70,  59,  16, 193, 234, 151, 188,   3,  40,  85, 126, 175, 132, 249, 210, 152, 179, 206, 229,  52,  31,  98,  73,
 223, 244, 137, 162, 115,  88,  37,  14,  68, 111,  18,  57, 232, 195, 190, 149,  42,   1, 124,  87, 134, 173, 208, 251, 177, 154, 231, 204,  29,  54,  75,  96},

{  0,  44,  88, 116, 176, 156, 232, 196, 163, 143, 251, 215,  19,  63,  75, 103, 133, 169, 221, 241,  53,  25, 109,  65,  38,  10, 126,  82, 150, 186, 206, 226,
 201, 229, 145, 189, 121,  85,  33,  13, 106,  70,  50,  30, 218, 246, 130, 174,  76,  96,  20,  56, 252, 208, 164, 136, 239, 195, 183, 155,  95, 115,   7,  43,
  81, 125,   9,  37, 225, 205, 185, 149, 242, 222, 170, 134,  66, 110,  26,  54, 212, 248, 140, 160, 100,  72,  60,  16, 119,  91,  47,   3, 199, 235, 159, 179,
 152, 180, 192, 236,  40,   4, 112,  92,  59,  23,  99,  79, 139, 167, 211, 255,  29,  49,  69, 105, 173, 129, 245, 217, 190, 146, 230, 202,  14,  34,  86, 122,
 162, 142, 250, 214,  18,  62,  74, 102,   1,  45,  89, 117, 177, 157, 233, 197,  39,  11, 127,  83, 151, 187, 207, 227, 132, 168, 220, 240,  52,  24, 108,  64,
 107,  71,  51,  31, 219, 247, 131, 175, 200, 228, 144, 188, 120,  84,  32,  12, 238, 194, 182, 154,  94, 114,   6,  42,  77,  97,  21,  57, 253, 209, 165, 137,
 243, 223, 171, 135,  67, 111,  27,  55,  80, 124,   8,  36, 224, 204, 184, 148, 118,  90,  46,   2, 198, 234, 158, 178, 213, 249, 141, 161, 101,  73,  61,  17,
  58,  22,  98,  78, 138, 166, 210, 254, 153, 181, 193, 237,  41,   5, 113,  93, 191, 147, 231, 203,  15,  35,  87, 123,  28,  48,  68, 104, 172, 128, 244, 216},

{  0,  45,  90, 119, 180, 153, 238, 195, 171, 134, 241, 220,  31,  50,  69, 104, 149, 184, 207, 226,  33,  12, 123,  86,  62,  19, 100,  73, 138, 167, 208, 253,
 233, 196, 179, 158,  93, 112,   7,  42,  66, 111,  24,  53, 246, 219, 172, 129, 124,  81,  38,  11, 200, 229, 146, 191, 215, 250, 141, 160,  99,  78,  57,  20,
  17,  60,  75, 102, 165, 136, 255, 210, 186, 151, 224, 205,  14,  35,  84, 121, 132, 169, 222, 243,  48,  29, 106,  71,  47,   2, 117,  88, 155, 182, 193, 236,
 248, 213, 162, 143,  76,  97,  22,  59,  83, 126,   9,  36, 231, 202, 189, 144, 109,  64,  55,  26, 217, 244, 131, 174, 198, 235, 156, 177, 114,  95,  40,   5,
  34,  15, 120,  85, 150, 187, 204, 225, 137, 164, 211, 254,  61,  16, 103,  74, 183, 154, 237, 192,   3,  46,  89, 116,  28,  49,  70, 107, 168, 133, 242, 223,
 203, 230, 145, 188, 127,  82,  37,   8,  96,  77,  58,  23, 212, 249, 142, 163,  94, 115,   4,  41, 234, 199, 176, 157, 245, 216, 175, 130,  65, 108,  27,  54,
  51,  30, 105,  68, 135, 170, 221, 240, 152, 181, 194, 239,  44,   1, 118,  91, 166, 139, 252, 209,  18,  63,  72, 101,  13,  32,  87, 122, 185, 148, 227, 206,
 218, 247, 128, 173, 110,  67,  52,  25, 113,  92,  43,   6, 197, 232, 159, 178,  79,  98,  21,  56, 251, 214, 161, 140, 228, 201, 190, 147,  80, 125,  10,  39},

{  0,  46,  92, 114, 184, 150, 228, 202, 179, 157, 239, 193,  11,  37,  87, 121, 165, 139, 249, 215,  29,  51,  65, 111,  22,  56,  74, 100, 174, 128, 242, 220,
 137, 167, 213, 251,  49,  31, 109,  67,  58,  20, 102,  72, 130, 172, 222, 240,  44,   2, 112,  94, 148, 186, 200, 230, 159, 177, 195, 237,  39,   9, 123,  85,
 209, 255, 141, 163, 105,  71,  53,  27,  98,  76,  62,  16, 218, 244, 134, 168, 116,  90,  40,   6, 204, 226, 144, 190, 199, 233, 155, 181, 127,  81,  35,  13,
  88, 118,   4,  42, 224, 206, 188, 146, 235, 197, 183, 153,  83, 125,  15,  33, 253, 211, 161, 143,  69, 107,  25,  55,  78,  96,  18,  60, 246, 216, 170, 132,
  97,  79,  61,  19, 217, 247, 133, 171, 210, 252, 142, 160, 106,  68,  54,  24, 196, 234, 152, 182, 124,  82,  32,  14, 119,  89,  43,   5, 207, 225, 147, 189,
 232, 198, 180, 154,  80, 126,  12,  34,  91, 117,   7,  41, 227, 205, 191, 145,  77,  99,  17,  63, 245, 219, 169, 135, 254, 208, 162, 140,  70, 104,  26,  52,
 176, 158, 236, 194,   8,  38,  84, 122,   3,  45,  95, 113, 187, 149, 231, 201,  21,  59,  73, 103, 173, 131, 241, 223, 166, 136, 250, 212,  30,  48,  66, 108,
  57,  23, 101,  75, 129, 175, 221, 243, 138, 164, 214, 248,  50,  28, 110,  64, 156, 178, 192, 238,  36,  10, 120,  86,  47,   1, 115,  93, 151, 185, 203, 229},

{  0,  47,  94, 113, 188, 147, 226, 205, 187, 148, 229, 202,   7,  40,  89, 118, 181, 154, 235, 196,   9,  38,  87, 120,  14,  33,  80, 127, 178, 157, 236, 195,
 169, 134, 247, 216,  21,  58,  75, 100,  18,  61,  76,  99, 174, 129, 240, 223,  28,  51,  66, 109, 160, 143, 254, 209, 167, 136, 249, 214,  27,  52,  69, 106,
 145, 190, 207, 224,  45,   2, 115,  92,  42,   5, 116,  91, 150, 185, 200, 231,  36,  11, 122,  85, 152, 183, 198, 233, 159, 176, 193, 238,  35,  12, 125,  82,
  56,  23, 102,  73, 132, 171, 218, 245, 131, 172, 221, 242,  63,  16,  97,  78, 141, 162, 211, 252,  49,  30, 111,  64,  54,  25, 104,  71, 138, 165, 212, 251,
 225, 206, 191, 144,  93, 114,   3,  44,  90, 117,   4,  43, 230, 201, 184, 151,  84, 123,  10,  37, 232, 199, 182, 153, 239, 192, 177, 158,  83, 124,  13,  34,
  72, 103,  22,  57, 244, 219, 170, 133, 243, 220, 173, 130,  79,  96,  17,  62, 253, 210, 163, 140,  65, 110,  31,  48,  70, 105,  24,  55, 250, 213, 164, 139,
 112,  95,  46,   1, 204, 227, 146, 189, 203, 228, 149, 186, 119,  88,  41,   6, 197, 234, 155, 180, 121,  86,  39,   8, 126,  81,  32,  15, 194, 237, 156, 179,
 217, 246, 135, 168, 101,  74,  59,  20,  98,  77,  60,  19, 222, 241, 128, 175, 108,  67,  50,  29, 208, 255, 142, 161, 215, 248, 137, 166, 107,  68,  53,  26},

{  0,  48,  96,  80, 192, 240, 160, 144,  67, 115,  35,  19, 131, 179, 227, 211, 134, 182, 230, 214,  70, 118,  38,  22, 197, 245, 165, 149,   5,  53, 101,  85,
 207, 255, 175, 159,  15,  63, 111,  95, 140, 188, 236, 220,  76, 124,  44,  28,  73, 121,  41,  25, 137, 185, 233, 217,  10,  58, 106,  90, 202, 250, 170, 154,
  93, 109,  61,  13, 157, 173, 253, 205,  30,  46, 126,  78, 222, 238, 190, 142, 219, 235, 187, 139,  27,  43, 123,  75, 152, 168, 248, 200,  88, 104,  56,   8,
 146, 162, 242, 194,  82,  98,  50,   2, 209, 225, 177, 129,  17,  33, 113,  65,  20,  36, 116,  68, 212, 228, 180, 132,  87, 103,  55,   7, 151, 167, 247, 199,
 186, 138, 218, 234, 122,  74,  26,  42, 249, 201, 153, 169,  57,   9,  89, 105,  60,  12,  92, 108, 252, 204, 156, 172, 127,  79,  31,  47, 191, 143, 223, 239,
 117,  69,  21,  37, 181, 133, 213, 229,  54,   6,  86, 102, 246, 198, 150, 166, 243, 195, 147, 163,  51,   3,  83,  99, 176, 128, 208, 224, 112,  64,  16,  32,
 231, 215, 135, 183,  39,  23,  71, 119, 164, 148, 196, 244, 100,  84,   4,  52,  97,  81,   1,  49, 161, 145, 193, 241,  34,  18,  66, 114, 226, 210, 130, 178,
  40,  24,  72, 120, 232, 216, 136, 184, 107,  91,  11,  59, 171, 155, 203, 251, 174, 158, 206, 254, 110,  94,  14,  62, 237, 221, 141, 189,  45,  29,  77, 125},

{  0,  49,  98,  83, 196, 245, 166, 151,  75, 122,  41,  24, 143, 190, 237, 220, 150, 167, 244, 197,  82,  99,  48,   1, 221, 236, 191, 142,  25,  40, 123,  74,
 239, 222, 141, 188,  43,  26,  73, 120, 164, 149, 198, 247,  96,  81,   2,  51, 121,  72,  27,  42, 189, 140, 223, 238,  50,   3,  80,  97, 246, 199, 148, 165,
  29,  44, 127,  78, 217, 232, 187, 138,  86, 103,  52,   5, 146, 163, 240, 193, 139, 186, 233, 216,  79, 126,  45,  28, 192, 241, 162, 147,   4,  53, 102,  87,
 242, 195, 144, 161,  54,   7,  84, 101, 185, 136, 219, 234, 125,  76,  31,  46, 100,  85,   6,  55, 160, 145, 194, 243,  47,  30,  77, 124, 235, 218, 137, 184,
  58,  11,  88, 105, 254, 207, 156, 173, 113,  64,  19,  34, 181, 132, 215, 230, 172, 157, 206, 255, 104,  89,  10,  59, 231, 214, 133, 180,  35,  18,  65, 112,
 213, 228, 183, 134,  17,  32, 115,  66, 158, 175, 252, 205,  90, 107,  56,   9,  67, 114,  33,  16, 135, 182, 229, 212,   8,  57, 106,  91, 204, 253, 174, 159,
  39,  22,  69, 116, 227, 210, 129, 176, 108,  93,  14,  63, 168, 153, 202, 251, 177, 128, 211, 226, 117,  68,  23,  38, 250, 203, 152, 169,  62,  15,  92, 109,
 200, 249, 170, 155,  12,  61, 110,  95, 131, 178, 225, 208,  71, 118,  37,  20,  94, 111,  60,  13, 154, 171, 248, 201,  21,  36, 119,  70, 209, 224, 179, 130},

{  0,  50, 100,  86, 200, 250, 172, 158,  83,  97,  55,   5, 155, 169, 255, 205, 166, 148, 194, 240, 110,  92,  10,  56, 245, 199, 145, 163,  61,  15,  89, 107,
 143, 189, 235, 217,  71, 117,  35,  17, 220, 238, 184, 138,  20,  38, 112,  66,  41,  27,  77, 127, 225, 211, 133, 183, 122,  72,  30,  44, 178, 128, 214, 228,
 221, 239, 185, 139,  21,  39, 113,  67, 142, 188, 234, 216,  70, 116,  34,  16, 123,  73,  31,  45, 179, 129, 215, 229,  40,  26,  76, 126, 224, 210, 132, 182,
  82,  96,  54,   4, 154, 168, 254, 204,   1,  51, 101,  87, 201, 251, 173, 159, 244, 198, 144, 162,  60,  14,  88, 106, 167, 149, 195, 241, 111,  93,  11,  57,
 121,  75,  29,  47, 177, 131, 213, 231,  42,  24,  78, 124, 226, 208, 134, 180, 223, 237, 187, 137,  23,  37, 115,  65, 140, 190, 232, 218,  68, 118,  32,  18,
 246, 196, 146, 160,  62,  12,  90, 104, 165, 151, 193, 243, 109,  95,   9,  59,  80,  98,  52,   6, 152, 170, 252, 206,   3,  49, 103,  85, 203, 249, 175, 157,
 164, 150, 192, 242, 108,  94,   8,  58, 247, 197, 147, 161,  63,  13,  91, 105,   2,  48, 102,  84, 202, 248, 174, 156,  81,  99,  53,   7, 153, 171, 253, 207,
  43,  25,  79, 125, 227, 209, 135, 181, 120,  74,  28,  46, 176, 130, 212, 230, 141, 191, 233, 219,  69, 119,  33,  19, 222, 236, 186, 136,  22,  36, 114,  64},

{  0,  51, 102,  85, 204, 255, 170, 153,  91, 104,  61,  14, 151, 164, 241, 194, 182, 133, 208, 227, 122,  73,  28,  47, 237, 222, 139, 184,  33,  18,  71, 116,
 175, 156, 201, 250,  99,  80,   5,  54, 244, 199, 146, 161,  56,  11,  94, 109,  25,  42, 127,  76, 213, 230, 179, 128,  66, 113,  36,  23, 142, 189, 232, 219,
 157, 174, 251, 200,  81,  98,  55,   4, 198, 245, 160, 147,  10,  57, 108,  95,  43,  24,  77, 126, 231, 212, 129, 178, 112,  67,  22,  37, 188, 143, 218, 233,
  50,   1,  84, 103, 254, 205, 152, 171, 105,  90,  15,  60, 165, 150, 195, 240, 132, 183, 226, 209,  72, 123,  46,  29, 223, 236, 185, 138,  19,  32, 117,  70,
 249, 202, 159, 172,  53,   6,  83,  96, 162, 145, 196, 247, 110,  93,   8,  59,  79, 124,  41,  26, 131, 176, 229, 214,  20,  39, 114,  65, 216, 235, 190, 141,
  86, 101,  48,   3, 154, 169, 252, 207,  13,  62, 107,  88, 193, 242, 167, 148, 224, 211, 134, 181,  44,  31,  74, 121, 187, 136, 221, 238, 119,  68,  17,  34,
 100,  87,   2,  49, 168, 155, 206, 253,  63,  12,  89, 106, 243, 192, 149, 166, 210, 225, 180, 135,  30,  45, 120,  75, 137, 186, 239, 220,  69, 118,  35,  16,
 203, 248, 173, 158,   7,  52,  97,  82, 144, 163, 246, 197,  92, 111,  58,   9, 125,  78,  27,  40, 177, 130, 215, 228,  38,  21,  64, 115, 234, 217, 140, 191},

{  0,  52, 104,  92, 208, 228, 184, 140,  99,  87,  11,  63, 179, 135, 219, 239, 198, 242, 174, 154,  22,  34, 126,  74, 165, 145, 205, 249, 117,  65,  29,  41,
  79, 123,  39,  19, 159, 171, 247, 195,  44,  24,  68, 112, 252, 200, 148, 160, 137, 189, 225, 213,  89, 109,  49,   5, 234, 222, 130, 182,  58,  14,  82, 102,
 158, 170, 246, 194,  78, 122,  38,  18, 253, 201, 149, 161,  45,  25,  69, 113,  88, 108,  48,   4, 136, 188, 224, 212,  59,  15,  83, 103, 235, 223, 131, 183,
 209, 229, 185, 141,   1,  53, 105,  93, 178, 134, 218, 238,  98,  86,  10,  62,  23,  35, 127,  75, 199, 243, 175, 155, 116,  64,  28,  40, 164, 144, 204, 248,
 255, 203, 151, 163,  47,  27,  71, 115, 156, 168, 244, 192,  76, 120,  36,  16,  57,  13,  81, 101, 233, 221, 129, 181,  90, 110,  50,   6, 138, 190, 226, 214,
 176, 132, 216, 236,  96,  84,   8,  60, 211, 231, 187, 143,   3,  55, 107,  95, 118,  66,  30,  42, 166, 146, 206, 250,  21,  33, 125,  73, 197, 241, 173, 153,
  97,  85,   9,  61, 177, 133, 217, 237,   2,  54, 106,  94, 210, 230, 186, 142, 167, 147, 207, 251, 119,  67,  31,  43, 196, 240, 172, 152,  20,  32, 124,  72,
  46,  26,  70, 114, 254, 202, 150, 162,  77, 121,  37,  17, 157, 169, 245, 193, 232, 220, 128, 180,  56,  12,  80, 100, 139, 191, 227, 215,  91, 111,  51,   7},

{  0,  53, 106,  95, 212, 225, 190, 139, 107,  94,   1,  52, 191, 138, 213, 224, 214, 227, 188, 137,   2,  55, 104,  93, 189, 136, 215, 226, 105,  92,   3,  54,
 111,  90,   5,  48, 187, 142, 209, 228,   4,  49, 110,  91, 208, 229, 186, 143, 185, 140, 211, 230, 109,  88,   7,  50, 210, 231, 184, 141,   6,  51, 108,  89,
 222, 235, 180, 129,  10,  63,  96,  85, 181, 128, 223, 234,  97,  84,  11,  62,   8,  61,  98,  87, 220, 233, 182, 131,  99,  86,   9,  60, 183, 130, 221, 232,
 177, 132, 219, 238, 101,  80,  15,  58, 218, 239, 176, 133,  14,  59, 100,  81, 103,  82,  13,  56, 179, 134, 217, 236,  12,  57, 102,  83, 216, 237, 178, 135,
 127,  74,  21,  32, 171, 158, 193, 244,  20,  33, 126,  75, 192, 245, 170, 159, 169, 156, 195, 246, 125,  72,  23,  34, 194, 247, 168, 157,  22,  35, 124,  73,
  16,  37, 122,  79, 196, 241, 174, 155, 123,  78,  17,  36, 175, 154, 197, 240, 198, 243, 172, 153,  18,  39, 120,  77, 173, 152, 199, 242, 121,  76,  19,  38,
 161, 148, 203, 254, 117,  64,  31,  42, 202, 255, 160, 149,  30,  43, 116,  65, 119,  66,  29,  40, 163, 150, 201, 252,  28,  41, 118,  67, 200, 253, 162, 151,
 206, 251, 164, 145,  26,  47, 112,  69, 165, 144, 207, 250, 113,  68,  27,  46,  24,  45, 114,  71, 204, 249, 166, 147, 115,  70,  25,  44, 167, 146, 205, 248},

{  0,  54, 108,  90, 216, 238, 180, 130, 115,  69,  31,  41, 171, 157, 199, 241, 230, 208, 138, 188,  62,   8,  82, 100, 149, 163, 249, 207,  77, 123,  33,  23,
  15,  57,  99,  85, 215, 225, 187, 141, 124,  74,  16,  38, 164, 146, 200, 254, 233, 223, 133, 179,  49,   7,  93, 107, 154, 172, 246, 192,  66, 116,  46,  24,
  30,  40, 114,  68, 198, 240, 170, 156, 109,  91,   1,  55, 181, 131, 217, 239, 248, 206, 148, 162,  32,  22,  76, 122, 139, 189, 231, 209,  83, 101,  63,   9,
  17,  39, 125,  75, 201, 255, 165, 147,  98,  84,  14,  56, 186, 140, 214, 224, 247, 193, 155, 173,  47,  25,  67, 117, 132, 178, 232, 222,  92, 106,  48,   6,
  60,  10,  80, 102, 228, 210, 136, 190,  79, 121,  35,  21, 151, 161, 251, 205, 218, 236, 182, 128,   2,  52, 110,  88, 169, 159, 197, 243, 113,  71,  29,  43,
  51,   5,  95, 105, 235, 221, 135, 177,  64, 118,  44,  26, 152, 174, 244, 194, 213, 227, 185, 143,  13,  59,  97,  87, 166, 144, 202, 252, 126,  72,  18,  36,
  34,  20,  78, 120, 250, 204, 150, 160,  81, 103,  61,  11, 137, 191, 229, 211, 196, 242, 168, 158,  28,  42, 112,  70, 183, 129, 219, 237, 111,  89,   3,  53,
  45,  27,  65, 119, 245, 195, 153, 175,  94, 104,  50,   4, 134, 176, 234, 220, 203, 253, 167, 145,  19,  37, 127,  73, 184, 142, 212, 226,  96,  86,  12,  58},

{  0,  55, 110,  89, 220, 235, 178, 133, 123,  76,  21,  34, 167, 144, 201, 254, 246, 193, 152, 175,  42,  29,  68, 115, 141, 186, 227, 212,  81, 102,  63,   8,
  47,  24,  65, 118, 243, 196, 157, 170,  84,  99,  58,  13, 136, 191, 230, 209, 217, 238, 183, 128,   5,  50, 107,  92, 162, 149, 204, 251, 126,  73,  16,  39,
  94, 105,  48,   7, 130, 181, 236, 219,  37,  18,  75, 124, 249, 206, 151, 160, 168, 159, 198, 241, 116,  67,  26,  45, 211, 228, 189, 138,  15,  56,  97,  86,
 113,  70,  31,  40, 173, 154, 195, 244,  10,  61, 100,  83, 214, 225, 184, 143, 135, 176, 233, 222,  91, 108,  53,   2, 252, 203, 146, 165,  32,  23,  78, 121,
 188, 139, 210, 229,  96,  87,  14,  57, 199, 240, 169, 158,  27,  44, 117,  66,  74, 125,  36,  19, 150, 161, 248, 207,  49,   6,  95, 104, 237, 218, 131, 180,
 147, 164, 253, 202,  79, 120,  33,  22, 232, 223, 134, 177,  52,   3,  90, 109, 101,  82,  11,  60, 185, 142, 215, 224,  30,  41, 112,  71, 194, 245, 172, 155,
 226, 213, 140, 187,  62,   9,  80, 103, 153, 174, 247, 192,  69, 114,  43,  28,  20,  35, 122,  77, 200, 255, 166, 145, 111,  88,   1,  54, 179, 132, 221, 234,
 205, 250, 163, 148,  17,  38, 127,  72, 182, 129, 216, 239, 106,  93,   4,  51,  59,  12,  85,  98, 231, 208, 137, 190,  64, 119,  46,  25, 156, 171, 242, 197},

{  0,  56, 112,  72, 224, 216, 144, 168,   3,  59, 115,  75, 227, 219, 147, 171,   6,  62, 118,  78, 230, 222, 150, 174,   5,  61, 117,  77, 229, 221, 149, 173,
  12,  52, 124,  68, 236, 212, 156, 164,  15,  55, 127,  71, 239, 215, 159, 167,  10,  50, 122,  66, 234, 210, 154, 162,   9,  49, 121,  65, 233, 209, 153, 161,
  24,  32, 104,  80, 248, 192, 136, 176,  27,  35, 107,  83, 251, 195, 139, 179,  30,  38, 110,  86, 254, 198, 142, 182,  29,  37, 109,  85, 253, 197, 141, 181,
  20,  44, 100,  92, 244, 204, 132, 188,  23,  47, 103,  95, 247, 207, 135, 191,  18,  42,  98,  90, 242, 202, 130, 186,  17,  41,  97,  89, 241, 201, 129, 185,
  48,   8,  64, 120, 208, 232, 160, 152,  51,  11,  67, 123, 211, 235, 163, 155,  54,  14,  70, 126, 214, 238, 166, 158,  53,  13,  69, 125, 213, 237, 165, 157,
  60,   4,  76, 116, 220, 228, 172, 148,  63,   7,  79, 119, 223, 231, 175, 151,  58,   2,  74, 114, 218, 226, 170, 146,  57,   1,  73, 113, 217, 225, 169, 145,
  40,  16,  88,  96, 200, 240, 184, 128,  43,  19,  91,  99, 203, 243, 187, 131,  46,  22,  94, 102, 206, 246, 190, 134,  45,  21,  93, 101, 205, 245, 189, 133,
  36,  28,  84, 108, 196, 252, 180, 140,  39,  31,  87, 111, 199, 255, 183, 143,  34,  26,  82, 106, 194, 250, 178, 138,  33,  25,  81, 105, 193, 249, 177, 137},

{  0,  57, 114,  75, 228, 221, 150, 175,  11,  50, 121,  64, 239, 214, 157, 164,  22,  47, 100,  93, 242, 203, 128, 185,  29,  36, 111,  86, 249, 192, 139, 178,
  44,  21,  94, 103, 200, 241, 186, 131,  39,  30,  85, 108, 195, 250, 177, 136,  58,   3,  72, 113, 222, 231, 172, 149,  49,   8,  67, 122, 213, 236, 167, 158,
  88,  97,  42,  19, 188, 133, 206, 247,  83, 106,  33,  24, 183, 142, 197, 252,  78, 119,  60,   5, 170, 147, 216, 225,  69, 124,  55,  14, 161, 152, 211, 234,
 116,  77,   6,  63, 144, 169, 226, 219, 127,  70,  13,  52, 155, 162, 233, 208,  98,  91,  16,  41, 134, 191, 244, 205, 105,  80,  27,  34, 141, 180, 255, 198,
 176, 137, 194, 251,  84, 109,  38,  31, 187, 130, 201, 240,  95, 102,  45,  20, 166, 159, 212, 237,  66, 123,  48,   9, 173, 148, 223, 230,  73, 112,  59,   2,
 156, 165, 238, 215, 120,  65,  10,  51, 151, 174, 229, 220, 115,  74,   1,  56, 138, 179, 248, 193, 110,  87,  28,  37, 129, 184, 243, 202, 101,  92,  23,  46,
 232, 209, 154, 163,  12,  53, 126,  71, 227, 218, 145, 168,   7,  62, 117,  76, 254, 199, 140, 181,  26,  35, 104,  81, 245, 204, 135, 190,  17,  40,  99,  90,
 196, 253, 182, 143,  32,  25,  82, 107, 207, 246, 189, 132,  43,  18,  89,  96, 210, 235, 160, 153,  54,  15,  68, 125, 217, 224, 171, 146,  61,   4,  79, 118},

{  0,  58, 116,  78, 232, 210, 156, 166,  19,  41, 103,  93, 251, 193, 143, 181,  38,  28,  82, 104, 206, 244, 186, 128,  53,  15,  65, 123, 221, 231, 169, 147,
  76, 118,  56,   2, 164, 158, 208, 234,  95, 101,  43,  17, 183, 141, 195, 249, 106,  80,  30,  36, 130, 184, 246, 204, 121,  67,  13,  55, 145, 171, 229, 223,
 152, 162, 236, 214, 112,  74,   4,  62, 139, 177, 255, 197,  99,  89,  23,  45, 190, 132, 202, 240,  86, 108,  34,  24, 173, 151, 217, 227,  69, 127,  49,  11,
 212, 238, 160, 154,  60,   6,  72, 114, 199, 253, 179, 137,  47,  21,  91,  97, 242, 200, 134, 188,  26,  32, 110,  84, 225, 219, 149, 175,   9,  51, 125,  71,
 243, 201, 135, 189,  27,  33, 111,  85, 224, 218, 148, 174,   8,  50, 124,  70, 213, 239, 161, 155,  61,   7,  73, 115, 198, 252, 178, 136,  46,  20,  90,  96,
 191, 133, 203, 241,  87, 109,  35,  25, 172, 150, 216, 226,  68, 126,  48,  10, 153, 163, 237, 215, 113,  75,   5,  63, 138, 176, 254, 196,  98,  88,  22,  44,
 107,  81,  31,  37, 131, 185, 247, 205, 120,  66,  12,  54, 144, 170, 228, 222,  77, 119,  57,   3, 165, 159, 209, 235,  94, 100,  42,  16, 182, 140, 194, 248,
  39,  29,  83, 105, 207, 245, 187, 129,  52,  14,  64, 122, 220, 230, 168, 146,   1,  59, 117,  79, 233, 211, 157, 167,  18,  40, 102,  92, 250, 192, 142, 180},

{  0,  59, 118,  77, 236, 215, 154, 161,  27,  32, 109,  86, 247, 204, 129, 186,  54,  13,  64, 123, 218, 225, 172, 151,  45,  22,  91,  96, 193, 250, 183, 140,
 108,  87,  26,  33, 128, 187, 246, 205, 119,  76,   1,  58, 155, 160, 237, 214,  90,  97,  44,  23, 182, 141, 192, 251,  65, 122,  55,  12, 173, 150, 219, 224,
 216, 227, 174, 149,  52,  15,  66, 121, 195, 248, 181, 142,  47,  20,  89,  98, 238, 213, 152, 163,   2,  57, 116,  79, 245, 206, 131, 184,  25,  34, 111,  84,
 180, 143, 194, 249,  88,  99,  46,  21, 175, 148, 217, 226,  67, 120,  53,  14, 130, 185, 244, 207, 110,  85,  24,  35, 153, 162, 239, 212, 117,  78,   3,  56,
 115,  72,   5,  62, 159, 164, 233, 210, 104,  83,  30,  37, 132, 191, 242, 201,  69, 126,  51,   8, 169, 146, 223, 228,  94, 101,  40,  19, 178, 137, 196, 255,
  31,  36, 105,  82, 243, 200, 133, 190,   4,  63, 114,  73, 232, 211, 158, 165,  41,  18,  95, 100, 197, 254, 179, 136,  50,   9,  68, 127, 222, 229, 168, 147,
 171, 144, 221, 230,  71, 124,  49,  10, 176, 139, 198, 253,  92, 103,  42,  17, 157, 166, 235, 208, 113,  74,   7,  60, 134, 189, 240, 203, 106,  81,  28,  39,
 199, 252, 177, 138,  43,  16,  93, 102, 220, 231, 170, 145,  48,  11,  70, 125, 241, 202, 135, 188,  29,  38, 107,  80, 234, 209, 156, 167,   6,  61, 112,  75},

{  0,  60, 120,  68, 240, 204, 136, 180,  35,  31,  91, 103, 211, 239, 171, 151,  70, 122,  62,   2, 182, 138, 206, 242, 101,  89,  29,  33, 149, 169, 237, 209,
 140, 176, 244, 200, 124,  64,   4,  56, 175, 147, 215, 235,  95,  99,  39,  27, 202, 246, 178, 142,  58,   6,  66, 126, 233, 213, 145, 173,  25,  37,  97,  93,
 219, 231, 163, 159,  43,  23,  83, 111, 248, 196, 128, 188,   8,  52, 112,  76, 157, 161, 229, 217, 109,  81,  21,  41, 190, 130, 198, 250,  78, 114,  54,  10,
  87, 107,  47,  19, 167, 155, 223, 227, 116,  72,  12,  48, 132, 184, 252, 192,  17,  45, 105,  85, 225, 221, 153, 165,  50,  14,  74, 118, 194, 254, 186, 134,
 117,  73,  13,  49, 133, 185, 253, 193,  86, 106,  46,  18, 166, 154, 222, 226,  51,  15,  75, 119, 195, 255, 187, 135,  16,  44, 104,  84, 224, 220, 152, 164,
 249, 197, 129, 189,   9,  53, 113,  77, 218, 230, 162, 158,  42,  22,  82, 110, 191, 131, 199, 251,  79, 115,  55,  11, 156, 160, 228, 216, 108,  80,  20,  40,
 174, 146, 214, 234,  94,  98,  38,  26, 141, 177, 245, 201, 125,  65,   5,  57, 232, 212, 144, 172,  24,  36,  96,  92, 203, 247, 179, 143,  59,   7,  67, 127,
  34,  30,  90, 102, 210, 238, 170, 150,   1,  61, 121,  69, 241, 205, 137, 181, 100,  88,  28,  32, 148, 168, 236, 208,  71, 123,  63,   3, 183, 139, 207, 243},

{  0,  61, 122,  71, 244, 201, 142, 179,  43,  22,  81, 108, 223, 226, 165, 152,  86, 107,  44,  17, 162, 159, 216, 229, 125,  64,   7,  58, 137, 180, 243, 206,
 172, 145, 214, 235,  88, 101,  34,  31, 135, 186, 253, 192, 115,  78,   9,  52, 250, 199, 128, 189,  14,  51, 116,  73, 209, 236, 171, 150,  37,  24,  95,  98,
 155, 166, 225, 220, 111,  82,  21,  40, 176, 141, 202, 247,  68, 121,  62,   3, 205, 240, 183, 138,  57,   4,  67, 126, 230, 219, 156, 161,  18,  47, 104,  85,
  55,  10,  77, 112, 195, 254, 185, 132,  28,  33, 102,  91, 232, 213, 146, 175,  97,  92,  27,  38, 149, 168, 239, 210,  74, 119,  48,  13, 190, 131, 196, 249,
 245, 200, 143, 178,   1,  60, 123,  70, 222, 227, 164, 153,  42,  23,  80, 109, 163, 158, 217, 228,  87, 106,  45,  16, 136, 181, 242, 207, 124,  65,   6,  59,
  89, 100,  35,  30, 173, 144, 215, 234, 114,  79,   8,  53, 134, 187, 252, 193,  15,  50, 117,  72, 251, 198, 129, 188,  36,  25,  94,  99, 208, 237, 170, 151,
 110,  83,  20,  41, 154, 167, 224, 221,  69, 120,  63,   2, 177, 140, 203, 246,  56,   5,  66, 127, 204, 241, 182, 139,  19,  46, 105,  84, 231, 218, 157, 160,
 194, 255, 184, 133,  54,  11,  76, 113, 233, 212, 147, 174,  29,  32, 103,  90, 148, 169, 238, 211,  96,  93,  26,  39, 191, 130, 197, 248,  75, 118,  49,  12},

{  0,  62, 124,  66, 248, 198, 132, 186,  51,  13,  79, 113, 203, 245, 183, 137, 102,  88,  26,  36, 158, 160, 226, 220,  85, 107,  41,  23, 173, 147, 209, 239,
 204, 242, 176, 142,  52,  10,  72, 118, 255, 193, 131, 189,   7,  57, 123,  69, 170, 148, 214, 232,  82, 108,  46,  16, 153, 167, 229, 219,  97,  95,  29,  35,
  91, 101,  39,  25, 163, 157, 223, 225, 104,  86,  20,  42, 144, 174, 236, 210,  61,   3,  65, 127, 197, 251, 185, 135,  14,  48, 114,  76, 246, 200, 138, 180,
 151, 169, 235, 213, 111,  81,  19,  45, 164, 154, 216, 230,  92,  98,  32,  30, 241, 207, 141, 179,   9,  55, 117,  75, 194, 252, 190, 128,  58,   4,  70, 120,
 182, 136, 202, 244,  78, 112,  50,  12, 133, 187, 249, 199, 125,  67,   1,  63, 208, 238, 172, 146,  40,  22,  84, 106, 227, 221, 159, 161,  27,  37, 103,  89,
 122,  68,   6,  56, 130, 188, 254, 192,  73, 119,  53,  11, 177, 143, 205, 243,  28,  34,  96,  94, 228, 218, 152, 166,  47,  17,  83, 109, 215, 233, 171, 149,
 237, 211, 145, 175,  21,  43, 105,  87, 222, 224, 162, 156,  38,  24,  90, 100, 139, 181, 247, 201, 115,  77,  15,  49, 184, 134, 196, 250,  64, 126,  60,   2,
  33,  31,  93,  99, 217, 231, 165, 155,  18,  44, 110,  80, 234, 212, 150, 168,  71, 121,  59,   5, 191, 129, 195, 253, 116,  74,   8,  54, 140, 178, 240, 206},

{  0,  63, 126,  65, 252, 195, 130, 189,  59,   4,  69, 122, 199, 248, 185, 134, 118,  73,   8,  55, 138, 181, 244, 203,  77, 114,  51,  12, 177, 142, 207, 240,
 236, 211, 146, 173,  16,  47, 110,  81, 215, 232, 169, 150,  43,  20,  85, 106, 154, 165, 228, 219, 102,  89,  24,  39, 161, 158, 223, 224,  93,  98,  35,  28,
  27,  36, 101,  90, 231, 216, 153, 166,  32,  31,  94,  97, 220, 227, 162, 157, 109,  82,  19,  44, 145, 174, 239, 208,  86, 105,  40,  23, 170, 149, 212, 235,
 247, 200, 137, 182,  11,  52, 117,  74, 204, 243, 178, 141,  48,  15,  78, 113, 129, 190, 255, 192, 125,  66,   3,  60, 186, 133, 196, 251,  70, 121,  56,   7,
  54,   9,  72, 119, 202, 245, 180, 139,  13,  50, 115,  76, 241, 206, 143, 176,  64, 127,  62,   1, 188, 131, 194, 253, 123,  68,   5,  58, 135, 184, 249, 198,
 218, 229, 164, 155,  38,  25,  88, 103, 225, 222, 159, 160,  29,  34,  99,  92, 172, 147, 210, 237,  80, 111,  46,  17, 151, 168, 233, 214, 107,  84,  21,  42,
  45,  18,  83, 108, 209, 238, 175, 144,  22,  41, 104,  87, 234, 213, 148, 171,  91, 100,  37,  26, 167, 152, 217, 230,  96,  95,  30,  33, 156, 163, 226, 221,
 193, 254, 191, 128,  61,   2,  67, 124, 250, 197, 132, 187,   6,  57, 120,  71, 183, 136, 201, 246,  75, 116,  53,  10, 140, 179, 242, 205, 112,  79,  14,  49},

{  0,  64, 128, 192, 195, 131,  67,   3,  69,   5, 197, 133, 134, 198,   6,  70, 138, 202,  10,  74,  73,   9, 201, 137, 207, 143,  79,  15,  12,  76, 140, 204,
 215, 151,  87,  23,  20,  84, 148, 212, 146, 210,  18,  82,  81,  17, 209, 145,  93,  29, 221, 157, 158, 222,  30,  94,  24,  88, 152, 216, 219, 155,  91,  27,
 109,  45, 237, 173, 174, 238,  46, 110,  40, 104, 168, 232, 235, 171, 107,  43, 231, 167, 103,  39,  36, 100, 164, 228, 162, 226,  34,  98,  97,  33, 225, 161,
 186, 250,  58, 122, 121,  57, 249, 185, 255, 191, 127,  63,  60, 124, 188, 252,  48, 112, 176, 240, 243, 179, 115,  51, 117,  53, 245, 181, 182, 246,  54, 118,
 218, 154,  90,  26,  25,  89, 153, 217, 159, 223,  31,  95,  92,  28, 220, 156,  80,  16, 208, 144, 147, 211,  19,  83,  21,  85, 149, 213, 214, 150,  86,  22,
  13,  77, 141, 205, 206, 142,  78,  14,  72,   8, 200, 136, 139, 203,  11,  75, 135, 199,   7,  71,  68,   4, 196, 132, 194, 130,  66,   2,   1,  65, 129, 193,
 183, 247,  55, 119, 116,  52, 244, 180, 242, 178, 114,  50,  49, 113, 177, 241,  61, 125, 189, 253, 254, 190, 126,  62, 120,  56, 248, 184, 187, 251,  59, 123,
  96,  32, 224, 160, 163, 227,  35,  99,  37, 101, 165, 229, 230, 166, 102,  38, 234, 170, 106,  42,  41, 105, 169, 233, 175, 239,  47, 111, 108,  44, 236, 172},

{  0,  65, 130, 195, 199, 134,  69,   4,  77,  12, 207, 142, 138, 203,   8,  73, 154, 219,  24,  89,  93,  28, 223, 158, 215, 150,  85,  20,  16,  81, 146, 211,
 247, 182, 117,  52,  48, 113, 178, 243, 186, 251,  56, 121, 125,  60, 255, 190, 109,  44, 239, 174, 170, 235,  40, 105,  32,  97, 162, 227, 231, 166, 101,  36,
  45, 108, 175, 238, 234, 171, 104,  41,  96,  33, 226, 163, 167, 230,  37, 100, 183, 246,  53, 116, 112,  49, 242, 179, 250, 187, 120,  57,  61, 124, 191, 254,
 218, 155,  88,  25,  29,  92, 159, 222, 151, 214,  21,  84,  80,  17, 210, 147,  64,   1, 194, 131, 135, 198,   5,  68,  13,  76, 143, 206, 202, 139,  72,   9,
  90,  27, 216, 153, 157, 220,  31,  94,  23,  86, 149, 212, 208, 145,  82,  19, 192, 129,  66,   3,   7,  70, 133, 196, 141, 204,  15,  78,  74,  11, 200, 137,
 173, 236,  47, 110, 106,  43, 232, 169, 224, 161,  98,  35,  39, 102, 165, 228,  55, 118, 181, 244, 240, 177, 114,  51, 122,  59, 248, 185, 189, 252,  63, 126,
 119,  54, 245, 180, 176, 241,  50, 115,  58, 123, 184, 249, 253, 188, 127,  62, 237, 172, 111,  46,  42, 107, 168, 233, 160, 225,  34,  99, 103,  38, 229, 164,
 128, 193,   2,  67,  71,   6, 197, 132, 205, 140,  79,  14,  10,  75, 136, 201,  26,  91, 152, 217, 221, 156,  95,  30,  87,  22, 213, 148, 144, 209,  18,  83},

{  0,  66, 132, 198, 203, 137,  79,  13,  85,  23, 209, 147, 158, 220,  26,  88, 170, 232,  46, 108,  97,  35, 229, 167, 255, 189, 123,  57,  52, 118, 176, 242,
 151, 213,  19,  81,  92,  30, 216, 154, 194, 128,  70,   4,   9,  75, 141, 207,  61, 127, 185, 251, 246, 180, 114,  48, 104,  42, 236, 174, 163, 225,  39, 101,
 237, 175, 105,  43,  38, 100, 162, 224, 184, 250,  60, 126, 115,  49, 247, 181,  71,   5, 195, 129, 140, 206,   8,  74,  18,  80, 150, 212, 217, 155,  93,  31,
 122,  56, 254, 188, 177, 243,  53, 119,  47, 109, 171, 233, 228, 166,  96,  34, 208, 146,  84,  22,  27,  89, 159, 221, 133, 199,   1,  67,  78,  12, 202, 136,
  25,  91, 157, 223, 210, 144,  86,  20,  76,  14, 200, 138, 135, 197,   3,  65, 179, 241,  55, 117, 120,  58, 252, 190, 230, 164,  98,  32,  45, 111, 169, 235,
 142, 204,  10,  72,  69,   7, 193, 131, 219, 153,  95,  29,  16,  82, 148, 214,  36, 102, 160, 226, 239, 173, 107,  41, 113,  51, 245, 183, 186, 248,  62, 124,
 244, 182, 112,  50,  63, 125, 187, 249, 161, 227,  37, 103, 106,  40, 238, 172,  94,  28, 218, 152, 149, 215,  17,  83,  11,  73, 143, 205, 192, 130,  68,   6,
  99,  33, 231, 165, 168, 234,  44, 110,  54, 116, 178, 240, 253, 191, 121,  59, 201, 139,  77,  15,   2,  64, 134, 196, 156, 222,  24,  90,  87,  21, 211, 145},

{  0,  67, 134, 197, 207, 140,  73,  10,  93,  30, 219, 152, 146, 209,  20,  87, 186, 249,  60, 127, 117,  54, 243, 176, 231, 164,  97,  34,  40, 107, 174, 237,
 183, 244,  49, 114, 120,  59, 254, 189, 234, 169, 108,  47,  37, 102, 163, 224,  13,  78, 139, 200, 194, 129,  68,   7,  80,  19, 214, 149, 159, 220,  25,  90,
 173, 238,  43, 104,  98,  33, 228, 167, 240, 179, 118,  53,  63, 124, 185, 250,  23,  84, 145, 210, 216, 155,  94,  29,  74,   9, 204, 143, 133, 198,   3,  64,
  26,  89, 156, 223, 213, 150,  83,  16,  71,   4, 193, 130, 136, 203,  14,  77, 160, 227,  38, 101, 111,  44, 233, 170, 253, 190, 123,  56,  50, 113, 180, 247,
 153, 218,  31,  92,  86,  21, 208, 147, 196, 135,  66,   1,  11,  72, 141, 206,  35,  96, 165, 230, 236, 175, 106,  41, 126,  61, 248, 187, 177, 242,  55, 116,
  46, 109, 168, 235, 225, 162, 103,  36, 115,  48, 245, 182, 188, 255,  58, 121, 148, 215,  18,  81,  91,  24, 221, 158, 201, 138,  79,  12,   6,  69, 128, 195,
  52, 119, 178, 241, 251, 184, 125,  62, 105,  42, 239, 172, 166, 229,  32,  99, 142, 205,   8,  75,  65,   2, 199, 132, 211, 144,  85,  22,  28,  95, 154, 217,
 131, 192,   5,  70,  76,  15, 202, 137, 222, 157,  88,  27,  17,  82, 151, 212,  57, 122, 191, 252, 246, 181, 112,  51, 100,  39, 226, 161, 171, 232,  45, 110},

{  0,  68, 136, 204, 211, 151,  91,  31, 101,  33, 237, 169, 182, 242,  62, 122, 202, 142,  66,   6,  25,  93, 145, 213, 175, 235,  39,  99, 124,  56, 244, 176,
  87,  19, 223, 155, 132, 192,  12,  72,  50, 118, 186, 254, 225, 165, 105,  45, 157, 217,  21,  81,  78,  10, 198, 130, 248, 188, 112,  52,  43, 111, 163, 231,
 174, 234,  38,  98, 125,  57, 245, 177, 203, 143,  67,   7,  24,  92, 144, 212, 100,  32, 236, 168, 183, 243,  63, 123,   1,  69, 137, 205, 210, 150,  90,  30,
 249, 189, 113,  53,  42, 110, 162, 230, 156, 216,  20,  80,  79,  11, 199, 131,  51, 119, 187, 255, 224, 164, 104,  44,  86,  18, 222, 154, 133, 193,  13,  73,
 159, 219,  23,  83,  76,   8, 196, 128, 250, 190, 114,  54,  41, 109, 161, 229,  85,  17, 221, 153, 134, 194,  14,  74,  48, 116, 184, 252, 227, 167, 107,  47,
 200, 140,  64,   4,  27,  95, 147, 215, 173, 233,  37,  97, 126,  58, 246, 178,   2,  70, 138, 206, 209, 149,  89,  29, 103,  35, 239, 171, 180, 240,  60, 120,
  49, 117, 185, 253, 226, 166, 106,  46,  84,  16, 220, 152, 135, 195,  15,  75, 251, 191, 115,  55,  40, 108, 160, 228, 158, 218,  22,  82,  77,   9, 197, 129,
 102,  34, 238, 170, 181, 241,  61, 121,   3,  71, 139, 207, 208, 148,  88,  28, 172, 232,  36,  96, 127,  59, 247, 179, 201, 141,  65,   5,  26,  94, 146, 214},

{  0,  69, 138, 207, 215, 146,  93,  24, 109,  40, 231, 162, 186, 255,  48, 117, 218, 159,  80,  21,  13,  72, 135, 194, 183, 242,  61, 120,  96,  37, 234, 175,
 119,  50, 253, 184, 160, 229,  42, 111,  26,  95, 144, 213, 205, 136,  71,   2, 173, 232,  39,  98, 122,  63, 240, 181, 192, 133,  74,  15,  23,  82, 157, 216,
 238, 171, 100,  33,  57, 124, 179, 246, 131, 198,   9,  76,  84,  17, 222, 155,  52, 113, 190, 251, 227, 166, 105,  44,  89,  28, 211, 150, 142, 203,   4,  65,
 153, 220,  19,  86,  78,  11, 196, 129, 244, 177, 126,  59,  35, 102, 169, 236,  67,   6, 201, 140, 148, 209,  30,  91,  46, 107, 164, 225, 249, 188, 115,  54,
  31,  90, 149, 208, 200, 141,  66,   7, 114,  55, 248, 189, 165, 224,  47, 106, 197, 128,  79,  10,  18,  87, 152, 221, 168, 237,  34, 103, 127,  58, 245, 176,
 104,  45, 226, 167, 191, 250,  53, 112,   5,  64, 143, 202, 210, 151,  88,  29, 178, 247,  56, 125, 101,  32, 239, 170, 223, 154,  85,  16,   8,  77, 130, 199,
 241, 180, 123,  62,  38,  99, 172, 233, 156, 217,  22,  83,  75,  14, 193, 132,  43, 110, 161, 228, 252, 185, 118,  51,  70,   3, 204, 137, 145, 212,  27,  94,
 134, 195,  12,  73,  81,  20, 219, 158, 235, 174,  97,  36,  60, 121, 182, 243,  92,  25, 214, 147, 139, 206,   1,  68,  49, 116, 187, 254, 230, 163, 108,  41},

{  0,  70, 140, 202, 219, 157,  87,  17, 117,  51, 249, 191, 174, 232,  34, 100, 234, 172, 102,  32,  49, 119, 189, 251, 159, 217,  19,  85,  68,   2, 200, 142,
  23,  81, 155, 221, 204, 138,  64,   6,  98,  36, 238, 168, 185, 255,  53, 115, 253, 187, 113,  55,  38,  96, 170, 236, 136, 206,   4,  66,  83,  21, 223, 153,
  46, 104, 162, 228, 245, 179, 121,  63,  91,  29, 215, 145, 128, 198,  12,  74, 196, 130,  72,  14,  31,  89, 147, 213, 177, 247,  61, 123, 106,  44, 230, 160,
  57, 127, 181, 243, 226, 164, 110,  40,  76,  10, 192, 134, 151, 209,  27,  93, 211, 149,  95,  25,   8,  78, 132, 194, 166, 224,  42, 108, 125,  59, 241, 183,
  92,  26, 208, 150, 135, 193,  11,  77,  41, 111, 165, 227, 242, 180, 126,  56, 182, 240,  58, 124, 109,  43, 225, 167, 195, 133,  79,   9,  24,  94, 148, 210,
  75,  13, 199, 129, 144, 214,  28,  90,  62, 120, 178, 244, 229, 163, 105,  47, 161, 231,  45, 107, 122,  60, 246, 176, 212, 146,  88,  30,  15,  73, 131, 197,
 114,  52, 254, 184, 169, 239,  37,  99,   7,  65, 139, 205, 220, 154,  80,  22, 152, 222,  20,  82,  67,   5, 207, 137, 237, 171,  97,  39,  54, 112, 186, 252,
 101,  35, 233, 175, 190, 248,  50, 116,  16,  86, 156, 218, 203, 141,  71,   1, 143, 201,   3,  69,  84,  18, 216, 158, 250, 188, 118,  48,  33, 103, 173, 235},

{  0,  71, 142, 201, 223, 152,  81,  22, 125,  58, 243, 180, 162, 229,  44, 107, 250, 189, 116,  51,  37,  98, 171, 236, 135, 192,   9,  78,  88,  31, 214, 145,
  55, 112, 185, 254, 232, 175, 102,  33,  74,  13, 196, 131, 149, 210,  27,  92, 205, 138,  67,   4,  18,  85, 156, 219, 176, 247,  62, 121, 111,  40, 225, 166,
 110,  41, 224, 167, 177, 246,  63, 120,  19,  84, 157, 218, 204, 139,  66,   5, 148, 211,  26,  93,  75,  12, 197, 130, 233, 174, 103,  32,  54, 113, 184, 255,
  89,  30, 215, 144, 134, 193,   8,  79,  36,  99, 170, 237, 251, 188, 117,  50, 163, 228,  45, 106, 124,  59, 242, 181, 222, 153,  80,  23,   1,  70, 143, 200,
 220, 155,  82,  21,   3,  68, 141, 202, 161, 230,  47, 104, 126,  57, 240, 183,  38,  97, 168, 239, 249, 190, 119,  48,  91,  28, 213, 146, 132, 195,  10,  77,
 235, 172, 101,  34,  52, 115, 186, 253, 150, 209,  24,  95,  73,  14, 199, 128,  17,  86, 159, 216, 206, 137,  64,   7, 108,  43, 226, 165, 179, 244,  61, 122,
 178, 245,  60, 123, 109,  42, 227, 164, 207, 136,  65,   6,  16,  87, 158, 217,  72,  15, 198, 129, 151, 208,  25,  94,  53, 114, 187, 252, 234, 173, 100,  35,
 133, 194,  11,  76,  90,  29, 212, 147, 248, 191, 118,  49,  39,  96, 169, 238, 127,  56, 241, 182, 160, 231,  46, 105,   2,  69, 140, 203, 221, 154,  83,  20},

{  0,  72, 144, 216, 227, 171, 115,  59,   5,  77, 149, 221, 230, 174, 118,  62,  10,  66, 154, 210, 233, 161, 121,  49,  15,  71, 159, 215, 236, 164, 124,  52,
  20,  92, 132, 204, 247, 191, 103,  47,  17,  89, 129, 201, 242, 186,  98,  42,  30,  86, 142, 198, 253, 181, 109,  37,  27,  83, 139, 195, 248, 176, 104,  32,
  40,  96, 184, 240, 203, 131,  91,  19,  45, 101, 189, 245, 206, 134,  94,  22,  34, 106, 178, 250, 193, 137,  81,  25,  39, 111, 183, 255, 196, 140,  84,  28,
  60, 116, 172, 228, 223, 151,  79,   7,  57, 113, 169, 225, 218, 146,  74,   2,  54, 126, 166, 238, 213, 157,  69,  13,  51, 123, 163, 235, 208, 152,  64,   8,
  80,  24, 192, 136, 179, 251,  35, 107,  85,  29, 197, 141, 182, 254,  38, 110,  90,  18, 202, 130, 185, 241,  41,  97,  95,  23, 207, 135, 188, 244,  44, 100,
  68,  12, 212, 156, 167, 239,  55, 127,  65,   9, 209, 153, 162, 234,  50, 122,  78,   6, 222, 150, 173, 229,  61, 117,  75,   3, 219, 147, 168, 224,  56, 112,
 120,  48, 232, 160, 155, 211,  11,  67, 125,  53, 237, 165, 158, 214,  14,  70, 114,  58, 226, 170, 145, 217,   1,  73, 119,  63, 231, 175, 148, 220,   4,  76,
 108,  36, 252, 180, 143, 199,  31,  87, 105,  33, 249, 177, 138, 194,  26,  82, 102,  46, 246, 190, 133, 205,  21,  93,  99,  43, 243, 187, 128, 200,  16,  88},

{  0,  73, 146, 219, 231, 174, 117,  60,  13,  68, 159, 214, 234, 163, 120,  49,  26,  83, 136, 193, 253, 180, 111,  38,  23,  94, 133, 204, 240, 185,  98,  43,
  52, 125, 166, 239, 211, 154,  65,   8,  57, 112, 171, 226, 222, 151,  76,   5,  46, 103, 188, 245, 201, 128,  91,  18,  35, 106, 177, 248, 196, 141,  86,  31,
 104,  33, 250, 179, 143, 198,  29,  84, 101,  44, 247, 190, 130, 203,  16,  89, 114,  59, 224, 169, 149, 220,   7,  78, 127,  54, 237, 164, 152, 209,  10,  67,
  92,  21, 206, 135, 187, 242,  41,  96,  81,  24, 195, 138, 182, 255,  36, 109,  70,  15, 212, 157, 161, 232,  51, 122,  75,   2, 217, 144, 172, 229,  62, 119,
 208, 153,  66,  11,  55, 126, 165, 236, 221, 148,  79,   6,  58, 115, 168, 225, 202, 131,  88,  17,  45, 100, 191, 246, 199, 142,  85,  28,  32, 105, 178, 251,
 228, 173, 118,  63,   3,  74, 145, 216, 233, 160, 123,  50,  14,  71, 156, 213, 254, 183, 108,  37,  25,  80, 139, 194, 243, 186,  97,  40,  20,  93, 134, 207,
 184, 241,  42,  99,  95,  22, 205, 132, 181, 252,  39, 110,  82,  27, 192, 137, 162, 235,  48, 121,  69,  12, 215, 158, 175, 230,  61, 116,  72,   1, 218, 147,
 140, 197,  30,  87, 107,  34, 249, 176, 129, 200,  19,  90, 102,  47, 244, 189, 150, 223,   4,  77, 113,  56, 227, 170, 155, 210,   9,  64, 124,  53, 238, 167},

{  0,  74, 148, 222, 235, 161, 127,  53,  21,  95, 129, 203, 254, 180, 106,  32,  42,  96, 190, 244, 193, 139,  85,  31,  63, 117, 171, 225, 212, 158,  64,  10,
  84,  30, 192, 138, 191, 245,  43,  97,  65,  11, 213, 159, 170, 224,  62, 116, 126,  52, 234, 160, 149, 223,   1,  75, 107,  33, 255, 181, 128, 202,  20,  94,
 168, 226,  60, 118,  67,   9, 215, 157, 189, 247,  41,  99,  86,  28, 194, 136, 130, 200,  22,  92, 105,  35, 253, 183, 151, 221,   3,  73, 124,  54, 232, 162,
 252, 182, 104,  34,  23,  93, 131, 201, 233, 163, 125,  55,   2,  72, 150, 220, 214, 156,  66,   8,  61, 119, 169, 227, 195, 137,  87,  29,  40,  98, 188, 246,
 147, 217,   7,  77, 120,  50, 236, 166, 134, 204,  18,  88, 109,  39, 249, 179, 185, 243,  45, 103,  82,  24, 198, 140, 172, 230,  56, 114,  71,  13, 211, 153,
 199, 141,  83,  25,  44, 102, 184, 242, 210, 152,  70,  12,  57, 115, 173, 231, 237, 167, 121,  51,   6,  76, 146, 216, 248, 178, 108,  38,  19,  89, 135, 205,
  59, 113, 175, 229, 208, 154,  68,  14,  46, 100, 186, 240, 197, 143,  81,  27,  17,  91, 133, 207, 250, 176, 110,  36,   4,  78, 144, 218, 239, 165, 123,  49,
 111,  37, 251, 177, 132, 206,  16,  90, 122,  48, 238, 164, 145, 219,   5,  79,  69,  15, 209, 155, 174, 228,  58, 112,  80,  26, 196, 142, 187, 241,  47, 101},

{  0,  75, 150, 221, 239, 164, 121,  50,  29,  86, 139, 192, 242, 185, 100,  47,  58, 113, 172, 231, 213, 158,  67,   8,  39, 108, 177, 250, 200, 131,  94,  21,
 116,  63, 226, 169, 155, 208,  13,  70, 105,  34, 255, 180, 134, 205,  16,  91,  78,   5, 216, 147, 161, 234,  55, 124,  83,  24, 197, 142, 188, 247,  42,  97,
 232, 163, 126,  53,   7,  76, 145, 218, 245, 190,  99,  40,  26,  81, 140, 199, 210, 153,  68,  15,  61, 118, 171, 224, 207, 132,  89,  18,  32, 107, 182, 253,
 156, 215,  10,  65, 115,  56, 229, 174, 129, 202,  23,  92, 110,  37, 248, 179, 166, 237,  48, 123,  73,   2, 223, 148, 187, 240,  45, 102,  84,  31, 194, 137,
  19,  88, 133, 206, 252, 183, 106,  33,  14,  69, 152, 211, 225, 170, 119,  60,  41,  98, 191, 244, 198, 141,  80,  27,  52, 127, 162, 233, 219, 144,  77,   6,
 103,  44, 241, 186, 136, 195,  30,  85, 122,  49, 236, 167, 149, 222,   3,  72,  93,  22, 203, 128, 178, 249,  36, 111,  64,  11, 214, 157, 175, 228,  57, 114,
 251, 176, 109,  38,  20,  95, 130, 201, 230, 173, 112,  59,   9,  66, 159, 212, 193, 138,  87,  28,  46, 101, 184, 243, 220, 151,  74,   1,  51, 120, 165, 238,
 143, 196,  25,  82,  96,  43, 246, 189, 146, 217,   4,  79, 125,  54, 235, 160, 181, 254,  35, 104,  90,  17, 204, 135, 168, 227,  62, 117,  71,  12, 209, 154},

{  0,  76, 152, 212, 243, 191, 107,  39,  37, 105, 189, 241, 214, 154,  78,   2,  74,   6, 210, 158, 185, 245,  33, 109, 111,  35, 247, 187, 156, 208,   4,  72,
 148, 216,  12,  64, 103,  43, 255, 179, 177, 253,  41, 101,  66,  14, 218, 150, 222, 146,  70,  10,  45,  97, 181, 249, 251, 183,  99,  47,   8,  68, 144, 220,
 235, 167, 115,  63,  24,  84, 128, 204, 206, 130,  86,  26,  61, 113, 165, 233, 161, 237,  57, 117,  82,  30, 202, 134, 132, 200,  28,  80, 119,  59, 239, 163,
 127,  51, 231, 171, 140, 192,  20,  88,  90,  22, 194, 142, 169, 229,  49, 125,  53, 121, 173, 225, 198, 138,  94,  18,  16,  92, 136, 196, 227, 175, 123,  55,
  21,  89, 141, 193, 230, 170, 126,  50,  48, 124, 168, 228, 195, 143,  91,  23,  95,  19, 199, 139, 172, 224,  52, 120, 122,  54, 226, 174, 137, 197,  17,  93,
 129, 205,  25,  85, 114,  62, 234, 166, 164, 232,  60, 112,  87,  27, 207, 131, 203, 135,  83,  31,  56, 116, 160, 236, 238, 162, 118,  58,  29,  81, 133, 201,
 254, 178, 102,  42,  13,  65, 149, 217, 219, 151,  67,  15,  40, 100, 176, 252, 180, 248,  44,  96,  71,  11, 223, 147, 145, 221,   9,  69,  98,  46, 250, 182,
 106,  38, 242, 190, 153, 213,   1,  77,  79,   3, 215, 155, 188, 240,  36, 104,  32, 108, 184, 244, 211, 159,  75,   7,   5,  73, 157, 209, 246, 186, 110,  34},

{  0,  77, 154, 215, 247, 186, 109,  32,  45,  96, 183, 250, 218, 151,  64,  13,  90,  23, 192, 141, 173, 224,  55, 122, 119,  58, 237, 160, 128, 205,  26,  87,
 180, 249,  46,  99,  67,  14, 217, 148, 153, 212,   3,  78, 110,  35, 244, 185, 238, 163, 116,  57,  25,  84, 131, 206, 195, 142,  89,  20,  52, 121, 174, 227,
 171, 230,  49, 124,  92,  17, 198, 139, 134, 203,  28,  81, 113,  60, 235, 166, 241, 188, 107,  38,   6,  75, 156, 209, 220, 145,  70,  11,  43, 102, 177, 252,
  31,  82, 133, 200, 232, 165, 114,  63,  50, 127, 168, 229, 197, 136,  95,  18,  69,   8, 223, 146, 178, 255,  40, 101, 104,  37, 242, 191, 159, 210,   5,  72,
 149, 216,  15,  66,  98,  47, 248, 181, 184, 245,  34, 111,  79,   2, 213, 152, 207, 130,  85,  24,  56, 117, 162, 239, 226, 175, 120,  53,  21,  88, 143, 194,
  33, 108, 187, 246, 214, 155,  76,   1,  12,  65, 150, 219, 251, 182,  97,  44, 123,  54, 225, 172, 140, 193,  22,  91,  86,  27, 204, 129, 161, 236,  59, 118,
  62, 115, 164, 233, 201, 132,  83,  30,  19,  94, 137, 196, 228, 169, 126,  51, 100,  41, 254, 179, 147, 222,   9,  68,  73,   4, 211, 158, 190, 243,  36, 105,
 138, 199,  16,  93, 125,  48, 231, 170, 167, 234,  61, 112,  80,  29, 202, 135, 208, 157,  74,   7,  39, 106, 189, 240, 253, 176, 103,  42,  10,  71, 144, 221},

{  0,  78, 156, 210, 251, 181, 103,  41,  53, 123, 169, 231, 206, 128,  82,  28, 106,  36, 246, 184, 145, 223,  13,  67,  95,  17, 195, 141, 164, 234,  56, 118,
 212, 154,  72,   6,  47,  97, 179, 253, 225, 175, 125,  51,  26,  84, 134, 200, 190, 240,  34, 108,  69,  11, 217, 151, 139, 197,  23,  89, 112,  62, 236, 162,
 107,  37, 247, 185, 144, 222,  12,  66,  94,  16, 194, 140, 165, 235,  57, 119,   1,  79, 157, 211, 250, 180, 102,  40,  52, 122, 168, 230, 207, 129,  83,  29,
 191, 241,  35, 109,  68,  10, 216, 150, 138, 196,  22,  88, 113,  63, 237, 163, 213, 155,  73,   7,  46,  96, 178, 252, 224, 174, 124,  50,  27,  85, 135, 201,
 214, 152,  74,   4,  45,  99, 177, 255, 227, 173, 127,  49,  24,  86, 132, 202, 188, 242,  32, 110,  71,   9, 219, 149, 137, 199,  21,  91, 114,  60, 238, 160,
   2,  76, 158, 208, 249, 183, 101,  43,  55, 121, 171, 229, 204, 130,  80,  30, 104,  38, 244, 186, 147, 221,  15,  65,  93,  19, 193, 143, 166, 232,  58, 116,
 189, 243,  33, 111,  70,   8, 218, 148, 136, 198,  20,  90, 115,  61, 239, 161, 215, 153,  75,   5,  44,  98, 176, 254, 226, 172, 126,  48,  25,  87, 133, 203,
 105,  39, 245, 187, 146, 220,  14,  64,  92,  18, 192, 142, 167, 233,  59, 117,   3,  77, 159, 209, 248, 182, 100,  42,  54, 120, 170, 228, 205, 131,  81,  31},

{  0,  79, 158, 209, 255, 176,  97,  46,  61, 114, 163, 236, 194, 141,  92,  19, 122,  53, 228, 171, 133, 202,  27,  84,  71,   8, 217, 150, 184, 247,  38, 105,
 244, 187, 106,  37,  11,  68, 149, 218, 201, 134,  87,  24,  54, 121, 168, 231, 142, 193,  16,  95, 113,  62, 239, 160, 179, 252,  45,  98,  76,   3, 210, 157,
  43, 100, 181, 250, 212, 155,  74,   5,  22,  89, 136, 199, 233, 166, 119,  56,  81,  30, 207, 128, 174, 225,  48, 127, 108,  35, 242, 189, 147, 220,  13,  66,
 223, 144,  65,  14,  32, 111, 190, 241, 226, 173, 124,  51,  29,  82, 131, 204, 165, 234,  59, 116,  90,  21, 196, 139, 152, 215,   6,  73, 103,  40, 249, 182,
  86,  25, 200, 135, 169, 230,  55, 120, 107,  36, 245, 186, 148, 219,  10,  69,  44,  99, 178, 253, 211, 156,  77,   2,  17,  94, 143, 192, 238, 161, 112,  63,
 162, 237,  60, 115,  93,  18, 195, 140, 159, 208,   1,  78,  96,  47, 254, 177, 216, 151,  70,   9,  39, 104, 185, 246, 229, 170, 123,  52,  26,  85, 132, 203,
 125,  50, 227, 172, 130, 205,  28,  83,  64,  15, 222, 145, 191, 240,  33, 110,   7,  72, 153, 214, 248, 183, 102,  41,  58, 117, 164, 235, 197, 138,  91,  20,
 137, 198,  23,  88, 118,  57, 232, 167, 180, 251,  42, 101,  75,   4, 213, 154, 243, 188, 109,  34,  12,  67, 146, 221, 206, 129,  80,  31,  49, 126, 175, 224},

{  0,  80, 160, 240, 131, 211,  35, 115, 197, 149, 101,  53,  70,  22, 230, 182,  73,  25, 233, 185, 202, 154, 106,  58, 140, 220,  44, 124,  15,  95, 175, 255,
 146, 194,  50,  98,  17,  65, 177, 225,  87,   7, 247, 167, 212, 132, 116,  36, 219, 139, 123,  43,  88,   8, 248, 168,  30,  78, 190, 238, 157, 205,  61, 109,
 231, 183,  71,  23, 100,  52, 196, 148,  34, 114, 130, 210, 161, 241,   1,  81, 174, 254,  14,  94,  45, 125, 141, 221, 107,  59, 203, 155, 232, 184,  72,  24,
 117,  37, 213, 133, 246, 166,  86,   6, 176, 224,  16,  64,  51,  99, 147, 195,  60, 108, 156, 204, 191, 239,  31,  79, 249, 169,  89,   9, 122,  42, 218, 138,
  13,  93, 173, 253, 142, 222,  46, 126, 200, 152, 104,  56,  75,  27, 235, 187,  68,  20, 228, 180, 199, 151, 103,  55, 129, 209,  33, 113,   2,  82, 162, 242,
 159, 207,  63, 111,  28,  76, 188, 236,  90,  10, 250, 170, 217, 137, 121,  41, 214, 134, 118,  38,  85,   5, 245, 165,  19,  67, 179, 227, 144, 192,  48,  96,
 234, 186,  74,  26, 105,  57, 201, 153,  47, 127, 143, 223, 172, 252,  12,  92, 163, 243,   3,  83,  32, 112, 128, 208, 102,  54, 198, 150, 229, 181,  69,  21,
 120,  40, 216, 136, 251, 171,  91,  11, 189, 237,  29,  77,  62, 110, 158, 206,  49,  97, 145, 193, 178, 226,  18,  66, 244, 164,  84,   4, 119,  39, 215, 135},

{  0,  81, 162, 243, 135, 214,  37, 116, 205, 156, 111,  62,  74,  27, 232, 185,  89,   8, 251, 170, 222, 143, 124,  45, 148, 197,  54, 103,  19,  66, 177, 224,
 178, 227,  16,  65,  53, 100, 151, 198, 127,  46, 221, 140, 248, 169,  90,  11, 235, 186,  73,  24, 108,  61, 206, 159,  38, 119, 132, 213, 161, 240,   3,  82,
 167, 246,   5,  84,  32, 113, 130, 211, 106,  59, 200, 153, 237, 188,  79,  30, 254, 175,  92,  13, 121,  40, 219, 138,  51,  98, 145, 192, 180, 229,  22,  71,
  21,  68, 183, 230, 146, 195,  48,  97, 216, 137, 122,  43,  95,  14, 253, 172,  76,  29, 238, 191, 203, 154, 105,  56, 129, 208,  35, 114,   6,  87, 164, 245,
 141, 220,  47, 126,  10,  91, 168, 249,  64,  17, 226, 179, 199, 150, 101,  52, 212, 133, 118,  39,  83,   2, 241, 160,  25,  72, 187, 234, 158, 207,  60, 109,
  63, 110, 157, 204, 184, 233,  26,  75, 242, 163,  80,   1, 117,  36, 215, 134, 102,  55, 196, 149, 225, 176,  67,  18, 171, 250,   9,  88,  44, 125, 142, 223,
  42, 123, 136, 217, 173, 252,  15,  94, 231, 182,  69,  20,  96,  49, 194, 147, 115,  34, 209, 128, 244, 165,  86,   7, 190, 239,  28,  77,  57, 104, 155, 202,
 152, 201,  58, 107,  31,  78, 189, 236,  85,   4, 247, 166, 210, 131, 112,  33, 193, 144,  99,  50,  70,  23, 228, 181,  12,  93, 174, 255, 139, 218,  41, 120},

{  0,  82, 164, 246, 139, 217,  47, 125, 213, 135, 113,  35,  94,  12, 250, 168, 105,  59, 205, 159, 226, 176,  70,  20, 188, 238,  24,  74,  55, 101, 147, 193,
 210, 128, 118,  36,  89,  11, 253, 175,   7,  85, 163, 241, 140, 222,  40, 122, 187, 233,  31,  77,  48,  98, 148, 198, 110,  60, 202, 152, 229, 183,  65,  19,
 103,  53, 195, 145, 236, 190,  72,  26, 178, 224,  22,  68,  57, 107, 157, 207,  14,  92, 170, 248, 133, 215,  33, 115, 219, 137, 127,  45,  80,   2, 244, 166,
 181, 231,  17,  67,  62, 108, 154, 200,  96,  50, 196, 150, 235, 185,  79,  29, 220, 142, 120,  42,  87,   5, 243, 161,   9,  91, 173, 255, 130, 208,  38, 116,
 206, 156, 106,  56,  69,  23, 225, 179,  27,  73, 191, 237, 144, 194,  52, 102, 167, 245,   3,  81,  44, 126, 136, 218, 114,  32, 214, 132, 249, 171,  93,  15,
  28,  78, 184, 234, 151, 197,  51,  97, 201, 155, 109,  63,  66,  16, 230, 180, 117,  39, 209, 131, 254, 172,  90,   8, 160, 242,   4,  86,  43, 121, 143, 221,
 169, 251,  13,  95,  34, 112, 134, 212, 124,  46, 216, 138, 247, 165,  83,   1, 192, 146, 100,  54,  75,  25, 239, 189,  21,  71, 177, 227, 158, 204,  58, 104,
 123,  41, 223, 141, 240, 162,  84,   6, 174, 252,  10,  88,  37, 119, 129, 211,  18,  64, 182, 228, 153, 203,  61, 111, 199, 149,  99,  49,  76,  30, 232, 186},

{  0,  83, 166, 245, 143, 220,  41, 122, 221, 142, 123,  40,  82,   1, 244, 167, 121,  42, 223, 140, 246, 165,  80,   3, 164, 247,   2,  81,  43, 120, 141, 222,
 242, 161,  84,   7, 125,  46, 219, 136,  47, 124, 137, 218, 160, 243,   6,  85, 139, 216,  45, 126,   4,  87, 162, 241,  86,   5, 240, 163, 217, 138, 127,  44,
  39, 116, 129, 210, 168, 251,  14,  93, 250, 169,  92,  15, 117,  38, 211, 128,  94,  13, 248, 171, 209, 130, 119,  36, 131, 208,  37, 118,  12,  95, 170, 249,
 213, 134, 115,  32,  90,   9, 252, 175,   8,  91, 174, 253, 135, 212,  33, 114, 172, 255,  10,  89,  35, 112, 133, 214, 113,  34, 215, 132, 254, 173,  88,  11,
  78,  29, 232, 187, 193, 146, 103,  52, 147, 192,  53, 102,  28,  79, 186, 233,  55, 100, 145, 194, 184, 235,  30,  77, 234, 185,  76,  31, 101,  54, 195, 144,
 188, 239,  26,  73,  51,  96, 149, 198,  97,  50, 199, 148, 238, 189,  72,  27, 197, 150,  99,  48,  74,  25, 236, 191,  24,  75, 190, 237, 151, 196,  49,  98,
 105,  58, 207, 156, 230, 181,  64,  19, 180, 231,  18,  65,  59, 104, 157, 206,  16,  67, 182, 229, 159, 204,  57, 106, 205, 158, 107,  56,  66,  17, 228, 183,
 155, 200,  61, 110,  20,  71, 178, 225,  70,  21, 224, 179, 201, 154, 111,  60, 226, 177,  68,  23, 109,  62, 203, 152,  63, 108, 153, 202, 176, 227,  22,  69},

{  0,  84, 168, 252, 147, 199,  59, 111, 229, 177,  77,  25, 118,  34, 222, 138,   9,  93, 161, 245, 154, 206,  50, 102, 236, 184,  68,  16, 127,  43, 215, 131,
  18,  70, 186, 238, 129, 213,  41, 125, 247, 163,  95,  11, 100,  48, 204, 152,  27,  79, 179, 231, 136, 220,  32, 116, 254, 170,  86,   2, 109,  57, 197, 145,
  36, 112, 140, 216, 183, 227,  31,  75, 193, 149, 105,  61,  82,   6, 250, 174,  45, 121, 133, 209, 190, 234,  22,  66, 200, 156,  96,  52,  91,  15, 243, 167,
  54,  98, 158, 202, 165, 241,  13,  89, 211, 135, 123,  47,  64,  20, 232, 188,  63, 107, 151, 195, 172, 248,   4,  80, 218, 142, 114,  38,  73,  29, 225, 181,
  72,  28, 224, 180, 219, 143, 115,  39, 173, 249,   5,  81,  62, 106, 150, 194,  65,  21, 233, 189, 210, 134, 122,  46, 164, 240,  12,  88,  55,  99, 159, 203,
  90,  14, 242, 166, 201, 157,  97,  53, 191, 235,  23,  67,  44, 120, 132, 208,  83,   7, 251, 175, 192, 148, 104,  60, 182, 226,  30,  74,  37, 113, 141, 217,
 108,  56, 196, 144, 255, 171,  87,   3, 137, 221,  33, 117,  26,  78, 178, 230, 101,  49, 205, 153, 246, 162,  94,  10, 128, 212,  40, 124,  19,  71, 187, 239,
 126,  42, 214, 130, 237, 185,  69,  17, 155, 207,  51, 103,   8,  92, 160, 244, 119,  35, 223, 139, 228, 176,  76,  24, 146, 198,  58, 110,   1,  85, 169, 253},

{  0,  85, 170, 255, 151, 194,  61, 104, 237, 184,  71,  18, 122,  47, 208, 133,  25,  76, 179, 230, 142, 219,  36, 113, 244, 161,  94,  11,  99,  54, 201, 156,
  50, 103, 152, 205, 165, 240,  15,  90, 223, 138, 117,  32,  72,  29, 226, 183,  43, 126, 129, 212, 188, 233,  22,  67, 198, 147, 108,  57,  81,   4, 251, 174,
 100,  49, 206, 155, 243, 166,  89,  12, 137, 220,  35, 118,  30,  75, 180, 225, 125,  40, 215, 130, 234, 191,  64,  21, 144, 197,  58, 111,   7,  82, 173, 248,
  86,   3, 252, 169, 193, 148, 107,  62, 187, 238,  17,  68,  44, 121, 134, 211,  79,  26, 229, 176, 216, 141, 114,  39, 162, 247,   8,  93,  53,  96, 159, 202,
 200, 157,  98,  55,  95,  10, 245, 160,  37, 112, 143, 218, 178, 231,  24,  77, 209, 132, 123,  46,  70,  19, 236, 185,  60, 105, 150, 195, 171, 254,   1,  84,
 250, 175,  80,   5, 109,  56, 199, 146,  23,  66, 189, 232, 128, 213,  42, 127, 227, 182,  73,  28, 116,  33, 222, 139,  14,  91, 164, 241, 153, 204,  51, 102,
 172, 249,   6,  83,  59, 110, 145, 196,  65,  20, 235, 190, 214, 131, 124,  41, 181, 224,  31,  74,  34, 119, 136, 221,  88,  13, 242, 167, 207, 154, 101,  48,
 158, 203,  52,  97,   9,  92, 163, 246, 115,  38, 217, 140, 228, 177,  78,  27, 135, 210,  45, 120,  16,  69, 186, 239, 106,  63, 192, 149, 253, 168,  87,   2},

{  0,  86, 172, 250, 155, 205,  55,  97, 245, 163,  89,  15, 110,  56, 194, 148,  41, 127, 133, 211, 178, 228,  30,  72, 220, 138, 112,  38,  71,  17, 235, 189,
  82,   4, 254, 168, 201, 159, 101,  51, 167, 241,  11,  93,  60, 106, 144, 198, 123,  45, 215, 129, 224, 182,  76,  26, 142, 216,  34, 116,  21,  67, 185, 239,
 164, 242,   8,  94,  63, 105, 147, 197,  81,   7, 253, 171, 202, 156, 102,  48, 141, 219,  33, 119,  22,  64, 186, 236, 120,  46, 212, 130, 227, 181,  79,  25,
 246, 160,  90,  12, 109,  59, 193, 151,   3,  85, 175, 249, 152, 206,  52,  98, 223, 137, 115,  37,  68,  18, 232, 190,  42, 124, 134, 208, 177, 231,  29,  75,
 139, 221,  39, 113,  16,  70, 188, 234, 126,  40, 210, 132, 229, 179,  73,  31, 162, 244,  14,  88,  57, 111, 149, 195,  87,   1, 251, 173, 204, 154,  96,  54,
 217, 143, 117,  35,  66,  20, 238, 184,  44, 122, 128, 214, 183, 225,  27,  77, 240, 166,  92,  10, 107,  61, 199, 145,   5,  83, 169, 255, 158, 200,  50, 100,
  47, 121, 131, 213, 180, 226,  24,  78, 218, 140, 118,  32,  65,  23, 237, 187,   6,  80, 170, 252, 157, 203,  49, 103, 243, 165,  95,   9, 104,  62, 196, 146,
 125,  43, 209, 135, 230, 176,  74,  28, 136, 222,  36, 114,  19,  69, 191, 233,  84,   2, 248, 174, 207, 153,  99,  53, 161, 247,  13,  91,  58, 108, 150, 192},

{  0,  87, 174, 249, 159, 200,  49, 102, 253, 170,  83,   4,  98,  53, 204, 155,  57, 110, 151, 192, 166, 241,   8,  95, 196, 147, 106,  61,  91,  12, 245, 162,
 114,  37, 220, 139, 237, 186,  67,  20, 143, 216,  33, 118,  16,  71, 190, 233,  75,  28, 229, 178, 212, 131, 122,  45, 182, 225,  24,  79,  41, 126, 135, 208,
 228, 179,  74,  29, 123,  44, 213, 130,  25,  78, 183, 224, 134, 209,  40, 127, 221, 138, 115,  36,  66,  21, 236, 187,  32, 119, 142, 217, 191, 232,  17,  70,
 150, 193,  56, 111,   9,  94, 167, 240, 107,  60, 197, 146, 244, 163,  90,  13, 175, 248,   1,  86,  48, 103, 158, 201,  82,   5, 252, 171, 205, 154,  99,  52,
  11,  92, 165, 242, 148, 195,  58, 109, 246, 161,  88,  15, 105,  62, 199, 144,  50, 101, 156, 203, 173, 250,   3,  84, 207, 152,  97,  54,  80,   7, 254, 169,
 121,  46, 215, 128, 230, 177,  72,  31, 132, 211,  42, 125,  27,  76, 181, 226,  64,  23, 238, 185, 223, 136, 113,  38, 189, 234,  19,  68,  34, 117, 140, 219,
 239, 184,  65,  22, 112,  39, 222, 137,  18,  69, 188, 235, 141, 218,  35, 116, 214, 129, 120,  47,  73,  30, 231, 176,  43, 124, 133, 210, 180, 227,  26,  77,
 157, 202,  51, 100,   2,  85, 172, 251,  96,  55, 206, 153, 255, 168,  81,   6, 164, 243,  10,  93,  59, 108, 149, 194,  89,  14, 247, 160, 198, 145, 104,  63},

{  0,  88, 176, 232, 163, 251,  19,  75, 133, 221,  53, 109,  38, 126, 150, 206, 201, 145, 121,  33, 106,  50, 218, 130,  76,  20, 252, 164, 239, 183,  95,   7,
  81,   9, 225, 185, 242, 170,  66,  26, 212, 140, 100,  60, 119,  47, 199, 159, 152, 192,  40, 112,  59,  99, 139, 211,  29,  69, 173, 245, 190, 230,  14,  86,
 162, 250,  18,  74,   1,  89, 177, 233,  39, 127, 151, 207, 132, 220,  52, 108, 107,  51, 219, 131, 200, 144, 120,  32, 238, 182,  94,   6,  77,  21, 253, 165,
 243, 171,  67,  27,  80,   8, 224, 184, 118,  46, 198, 158, 213, 141, 101,  61,  58,  98, 138, 210, 153, 193,  41, 113, 191, 231,  15,  87,  28,  68, 172, 244,
 135, 223,  55, 111,  36, 124, 148, 204,   2,  90, 178, 234, 161, 249,  17,  73,  78,  22, 254, 166, 237, 181,  93,   5, 203, 147, 123,  35, 104,  48, 216, 128,
 214, 142, 102,  62, 117,  45, 197, 157,  83,  11, 227, 187, 240, 168,  64,  24,  31,  71, 175, 247, 188, 228,  12,  84, 154, 194,  42, 114,  57,  97, 137, 209,
  37, 125, 149, 205, 134, 222,  54, 110, 160, 248,  16,  72,   3,  91, 179, 235, 236, 180,  92,   4,  79,  23, 255, 167, 105,  49, 217, 129, 202, 146, 122,  34,
 116,  44, 196, 156, 215, 143, 103,  63, 241, 169,  65,  25,  82,  10, 226, 186, 189, 229,  13,  85,  30,  70, 174, 246,  56,  96, 136, 208, 155, 195,  43, 115},

{  0,  89, 178, 235, 167, 254,  21,  76, 141, 212,  63, 102,  42, 115, 152, 193, 217, 128, 107,  50, 126,  39, 204, 149,  84,  13, 230, 191, 243, 170,  65,  24,
 113,  40, 195, 154, 214, 143, 100,  61, 252, 165,  78,  23,  91,   2, 233, 176, 168, 241,  26,  67,  15,  86, 189, 228,  37, 124, 151, 206, 130, 219,  48, 105,
 226, 187,  80,   9,  69,  28, 247, 174, 111,  54, 221, 132, 200, 145, 122,  35,  59,  98, 137, 208, 156, 197,  46, 119, 182, 239,   4,  93,  17,  72, 163, 250,
 147, 202,  33, 120,  52, 109, 134, 223,  30,  71, 172, 245, 185, 224,  11,  82,  74,  19, 248, 161, 237, 180,  95,   6, 199, 158, 117,  44,  96,  57, 210, 139,
   7,  94, 181, 236, 160, 249,  18,  75, 138, 211,  56,  97,  45, 116, 159, 198, 222, 135, 108,  53, 121,  32, 203, 146,  83,  10, 225, 184, 244, 173,  70,  31,
 118,  47, 196, 157, 209, 136,  99,  58, 251, 162,  73,  16,  92,   5, 238, 183, 175, 246,  29,  68,   8,  81, 186, 227,  34, 123, 144, 201, 133, 220,  55, 110,
 229, 188,  87,  14,  66,  27, 240, 169, 104,  49, 218, 131, 207, 150, 125,  36,  60, 101, 142, 215, 155, 194,  41, 112, 177, 232,   3,  90,  22,  79, 164, 253,
 148, 205,  38, 127,  51, 106, 129, 216,  25,  64, 171, 242, 190, 231,  12,  85,  77,  20, 255, 166, 234, 179,  88,   1, 192, 153, 114,  43, 103,  62, 213, 140},

{  0,  90, 180, 238, 171, 241,  31,  69, 149, 207,  33, 123,  62, 100, 138, 208, 233, 179,  93,   7,  66,  24, 246, 172, 124,  38, 200, 146, 215, 141,  99,  57,
  17,  75, 165, 255, 186, 224,  14,  84, 132, 222,  48, 106,  47, 117, 155, 193, 248, 162,  76,  22,  83,   9, 231, 189, 109,  55, 217, 131, 198, 156, 114,  40,
  34, 120, 150, 204, 137, 211,  61, 103, 183, 237,   3,  89,  28,  70, 168, 242, 203, 145, 127,  37,  96,  58, 212, 142,  94,   4, 234, 176, 245, 175,  65,  27,
  51, 105, 135, 221, 152, 194,  44, 118, 166, 252,  18,  72,  13,  87, 185, 227, 218, 128, 110,  52, 113,  43, 197, 159,  79,  21, 251, 161, 228, 190,  80,  10,
  68,  30, 240, 170, 239, 181,  91,   1, 209, 139, 101,  63, 122,  32, 206, 148, 173, 247,  25,  67,   6,  92, 178, 232,  56,  98, 140, 214, 147, 201,  39, 125,
  85,  15, 225, 187, 254, 164,  74,  16, 192, 154, 116,  46, 107,  49, 223, 133, 188, 230,   8,  82,  23,  77, 163, 249,  41, 115, 157, 199, 130, 216,  54, 108,
 102,  60, 210, 136, 205, 151, 121,  35, 243, 169,  71,  29,  88,   2, 236, 182, 143, 213,  59,  97,  36, 126, 144, 202,  26,  64, 174, 244, 177, 235,   5,  95,
 119,  45, 195, 153, 220, 134, 104,  50, 226, 184,  86,  12,  73,  19, 253, 167, 158, 196,  42, 112,  53, 111, 129, 219,  11,  81, 191, 229, 160, 250,  20,  78},

{  0,  91, 182, 237, 175, 244,  25,  66, 157, 198,  43, 112,  50, 105, 132, 223, 249, 162,  79,  20,  86,  13, 224, 187, 100,  63, 210, 137, 203, 144, 125,  38,
  49, 106, 135, 220, 158, 197,  40, 115, 172, 247,  26,  65,   3,  88, 181, 238, 200, 147, 126,  37, 103,  60, 209, 138,  85,  14, 227, 184, 250, 161,  76,  23,
  98,  57, 212, 143, 205, 150, 123,  32, 255, 164,  73,  18,  80,  11, 230, 189, 155, 192,  45, 118,  52, 111, 130, 217,   6,  93, 176, 235, 169, 242,  31,  68,
  83,   8, 229, 190, 252, 167,  74,  17, 206, 149, 120,  35,  97,  58, 215, 140, 170, 241,  28,  71,   5,  94, 179, 232,  55, 108, 129, 218, 152, 195,  46, 117,
 196, 159, 114,  41, 107,  48, 221, 134,  89,   2, 239, 180, 246, 173,  64,  27,  61, 102, 139, 208, 146, 201,  36, 127, 160, 251,  22,  77,  15,  84, 185, 226,
 245, 174,  67,  24,  90,   1, 236, 183, 104,  51, 222, 133, 199, 156, 113,  42,  12,  87, 186, 225, 163, 248,  21,  78, 145, 202,  39, 124,  62, 101, 136, 211,
 166, 253,  16,  75,   9,  82, 191, 228,  59,  96, 141, 214, 148, 207,  34, 121,  95,   4, 233, 178, 240, 171,  70,  29, 194, 153, 116,  47, 109,  54, 219, 128,
 151, 204,  33, 122,  56,  99, 142, 213,  10,  81, 188, 231, 165, 254,  19,  72, 110,  53, 216, 131, 193, 154, 119,  44, 243, 168,  69,  30,  92,   7, 234, 177},

{  0,  92, 184, 228, 179, 239,  11,  87, 165, 249,  29,  65,  22,  74, 174, 242, 137, 213,  49, 109,  58, 102, 130, 222,  44, 112, 148, 200, 159, 195,  39, 123,
 209, 141, 105,  53,  98,  62, 218, 134, 116,  40, 204, 144, 199, 155, 127,  35,  88,   4, 224, 188, 235, 183,  83,  15, 253, 161,  69,  25,  78,  18, 246, 170,
  97,  61, 217, 133, 210, 142, 106,  54, 196, 152, 124,  32, 119,  43, 207, 147, 232, 180,  80,  12,  91,   7, 227, 191,  77,  17, 245, 169, 254, 162,  70,  26,
 176, 236,   8,  84,   3,  95, 187, 231,  21,  73, 173, 241, 166, 250,  30,  66,  57, 101, 129, 221, 138, 214,  50, 110, 156, 192,  36, 120,  47, 115, 151, 203,
 194, 158, 122,  38, 113,  45, 201, 149, 103,  59, 223, 131, 212, 136, 108,  48,  75,  23, 243, 175, 248, 164,  64,  28, 238, 178,  86,  10,  93,   1, 229, 185,
  19,  79, 171, 247, 160, 252,  24,  68, 182, 234,  14,  82,   5,  89, 189, 225, 154, 198,  34, 126,  41, 117, 145, 205,  63,  99, 135, 219, 140, 208,  52, 104,
 163, 255,  27,  71,  16,  76, 168, 244,   6,  90, 190, 226, 181, 233,  13,  81,  42, 118, 146, 206, 153, 197,  33, 125, 143, 211,  55, 107,  60,  96, 132, 216,
 114,  46, 202, 150, 193, 157, 121,  37, 215, 139, 111,  51, 100,  56, 220, 128, 251, 167,  67,  31,  72,  20, 240, 172,  94,   2, 230, 186, 237, 177,  85,   9},

{  0,  93, 186, 231, 183, 234,  13,  80, 173, 240,  23,  74,  26,  71, 160, 253, 153, 196,  35, 126,  46, 115, 148, 201,  52, 105, 142, 211, 131, 222,  57, 100,
 241, 172,  75,  22,  70,  27, 252, 161,  92,   1, 230, 187, 235, 182,  81,  12, 104,  53, 210, 143, 223, 130, 101,  56, 197, 152, 127,  34, 114,  47, 200, 149,
  33, 124, 155, 198, 150, 203,  44, 113, 140, 209,  54, 107,  59, 102, 129, 220, 184, 229,   2,  95,  15,  82, 181, 232,  21,  72, 175, 242, 162, 255,  24,  69,
 208, 141, 106,  55, 103,  58, 221, 128, 125,  32, 199, 154, 202, 151, 112,  45,  73,  20, 243, 174, 254, 163,  68,  25, 228, 185,  94,   3,  83,  14, 233, 180,
  66,  31, 248, 165, 245, 168,  79,  18, 239, 178,  85,   8,  88,   5, 226, 191, 219, 134,  97,  60, 108,  49, 214, 139, 118,  43, 204, 145, 193, 156, 123,  38,
 179, 238,   9,  84,   4,  89, 190, 227,  30,  67, 164, 249, 169, 244,  19,  78,  42, 119, 144, 205, 157, 192,  39, 122, 135, 218,  61,  96,  48, 109, 138, 215,
  99,  62, 217, 132, 212, 137, 110,  51, 206, 147, 116,  41, 121,  36, 195, 158, 250, 167,  64,  29,  77,  16, 247, 170,  87,  10, 237, 176, 224, 189,  90,   7,
 146, 207,  40, 117,  37, 120, 159, 194,  63,  98, 133, 216, 136, 213,  50, 111,  11,  86, 177, 236, 188, 225,   6,  91, 166, 251,  28,  65,  17,  76, 171, 246},

{  0,  94, 188, 226, 187, 229,   7,  89, 181, 235,   9,  87,  14,  80, 178, 236, 169, 247,  21,  75,  18,  76, 174, 240,  28,  66, 160, 254, 167, 249,  27,  69,
 145, 207,  45, 115,  42, 116, 150, 200,  36, 122, 152, 198, 159, 193,  35, 125,  56, 102, 132, 218, 131, 221,  63,  97, 141, 211,  49, 111,  54, 104, 138, 212,
 225, 191,  93,   3,  90,   4, 230, 184,  84,  10, 232, 182, 239, 177,  83,  13,  72,  22, 244, 170, 243, 173,  79,  17, 253, 163,  65,  31,  70,  24, 250, 164,
 112,  46, 204, 146, 203, 149, 119,  41, 197, 155, 121,  39, 126,  32, 194, 156, 217, 135, 101,  59,  98,  60, 222, 128, 108,  50, 208, 142, 215, 137, 107,  53,
   1,  95, 189, 227, 186, 228,   6,  88, 180, 234,   8,  86,  15,  81, 179, 237, 168, 246,  20,  74,  19,  77, 175, 241,  29,  67, 161, 255, 166, 248,  26,  68,
 144, 206,  44, 114,  43, 117, 151, 201,  37, 123, 153, 199, 158, 192,  34, 124,  57, 103, 133, 219, 130, 220,  62,  96, 140, 210,  48, 110,  55, 105, 139, 213,
 224, 190,  92,   2,  91,   5, 231, 185,  85,  11, 233, 183, 238, 176,  82,  12,  73,  23, 245, 171, 242, 172,  78,  16, 252, 162,  64,  30,  71,  25, 251, 165,
 113,  47, 205, 147, 202, 148, 118,  40, 196, 154, 120,  38, 127,  33, 195, 157, 216, 134, 100,  58,  99,  61, 223, 129, 109,  51, 209, 143, 214, 136, 106,  52},

{  0,  95, 190, 225, 191, 224,   1,  94, 189, 226,   3,  92,   2,  93, 188, 227, 185, 230,   7,  88,   6,  89, 184, 231,   4,  91, 186, 229, 187, 228,   5,  90,
 177, 238,  15,  80,  14,  81, 176, 239,  12,  83, 178, 237, 179, 236,  13,  82,   8,  87, 182, 233, 183, 232,   9,  86, 181, 234,  11,  84,  10,  85, 180, 235,
 161, 254,  31,  64,  30,  65, 160, 255,  28,  67, 162, 253, 163, 252,  29,  66,  24,  71, 166, 249, 167, 248,  25,  70, 165, 250,  27,  68,  26,  69, 164, 251,
  16,  79, 174, 241, 175, 240,  17,  78, 173, 242,  19,  76,  18,  77, 172, 243, 169, 246,  23,  72,  22,  73, 168, 247,  20,  75, 170, 245, 171, 244,  21,  74,
 129, 222,  63,  96,  62,  97, 128, 223,  60,  99, 130, 221, 131, 220,  61,  98,  56, 103, 134, 217, 135, 216,  57, 102, 133, 218,  59, 100,  58, 101, 132, 219,
  48, 111, 142, 209, 143, 208,  49, 110, 141, 210,  51, 108,  50, 109, 140, 211, 137, 214,  55, 104,  54, 105, 136, 215,  52, 107, 138, 213, 139, 212,  53, 106,
  32, 127, 158, 193, 159, 192,  33, 126, 157, 194,  35, 124,  34, 125, 156, 195, 153, 198,  39, 120,  38, 121, 152, 199,  36, 123, 154, 197, 155, 196,  37, 122,
 145, 206,  47, 112,  46, 113, 144, 207,  44, 115, 146, 205, 147, 204,  45, 114,  40, 119, 150, 201, 151, 200,  41, 118, 149, 202,  43, 116,  42, 117, 148, 203},

{  0,  96, 192, 160,  67,  35, 131, 227, 134, 230,  70,  38, 197, 165,   5, 101, 207, 175,  15, 111, 140, 236,  76,  44,  73,  41, 137, 233,  10, 106, 202, 170,
  93,  61, 157, 253,  30, 126, 222, 190, 219, 187,  27, 123, 152, 248,  88,  56, 146, 242,  82,  50, 209, 177,  17, 113,  20, 116, 212, 180,  87,  55, 151, 247,
 186, 218, 122,  26, 249, 153,  57,  89,  60,  92, 252, 156, 127,  31, 191, 223, 117,  21, 181, 213,  54,  86, 246, 150, 243, 147,  51,  83, 176, 208, 112,  16,
 231, 135,  39,  71, 164, 196, 100,   4,  97,   1, 161, 193,  34,  66, 226, 130,  40,  72, 232, 136, 107,  11, 171, 203, 174, 206, 110,  14, 237, 141,  45,  77,
 183, 215, 119,  23, 244, 148,  52,  84,  49,  81, 241, 145, 114,  18, 178, 210, 120,  24, 184, 216,  59,  91, 251, 155, 254, 158,  62,  94, 189, 221, 125,  29,
 234, 138,  42,  74, 169, 201, 105,   9, 108,  12, 172, 204,  47,  79, 239, 143,  37,  69, 229, 133, 102,   6, 166, 198, 163, 195,  99,   3, 224, 128,  32,  64,
  13, 109, 205, 173,  78,  46, 142, 238, 139, 235,  75,  43, 200, 168,   8, 104, 194, 162,   2,  98, 129, 225,  65,  33,  68,  36, 132, 228,   7, 103, 199, 167,
  80,  48, 144, 240,  19, 115, 211, 179, 214, 182,  22, 118, 149, 245,  85,  53, 159, 255,  95,  63, 220, 188,  28, 124,  25, 121, 217, 185,  90,  58, 154, 250},

{  0,  97, 194, 163,  71,  38, 133, 228, 142, 239,  76,  45, 201, 168,  11, 106, 223, 190,  29, 124, 152, 249,  90,  59,  81,  48, 147, 242,  22, 119, 212, 181,
 125,  28, 191, 222,  58,  91, 248, 153, 243, 146,  49,  80, 180, 213, 118,  23, 162, 195,  96,   1, 229, 132,  39,  70,  44,  77, 238, 143, 107,  10, 169, 200,
 250, 155,  56,  89, 189, 220, 127,  30, 116,  21, 182, 215,  51,  82, 241, 144,  37,  68, 231, 134,  98,   3, 160, 193, 171, 202, 105,   8, 236, 141,  46,  79,
 135, 230,  69,  36, 192, 161,   2,  99,   9, 104, 203, 170,  78,  47, 140, 237,  88,  57, 154, 251,  31, 126, 221, 188, 214, 183,  20, 117, 145, 240,  83,  50,
  55,  86, 245, 148, 112,  17, 178, 211, 185, 216, 123,  26, 254, 159,  60,  93, 232, 137,  42,  75, 175, 206, 109,  12, 102,   7, 164, 197,  33,  64, 227, 130,
  74,  43, 136, 233,  13, 108, 207, 174, 196, 165,   6, 103, 131, 226,  65,  32, 149, 244,  87,  54, 210, 179,  16, 113,  27, 122, 217, 184,  92,  61, 158, 255,
 205, 172,  15, 110, 138, 235,  72,  41,  67,  34, 129, 224,   4, 101, 198, 167,  18, 115, 208, 177,  85,  52, 151, 246, 156, 253,  94,  63, 219, 186,  25, 120,
 176, 209, 114,  19, 247, 150,  53,  84,  62,  95, 252, 157, 121,  24, 187, 218, 111,  14, 173, 204,  40,  73, 234, 139, 225, 128,  35,  66, 166, 199, 100,   5},

{  0,  98, 196, 166,  75,  41, 143, 237, 150, 244,  82,  48, 221, 191,  25, 123, 239, 141,  43,  73, 164, 198,  96,   2, 121,  27, 189, 223,  50,  80, 246, 148,
  29, 127, 217, 187,  86,  52, 146, 240, 139, 233,  79,  45, 192, 162,   4, 102, 242, 144,  54,  84, 185, 219, 125,  31, 100,   6, 160, 194,  47,  77, 235, 137,
  58,  88, 254, 156, 113,  19, 181, 215, 172, 206, 104,  10, 231, 133,  35,  65, 213, 183,  17, 115, 158, 252,  90,  56,  67,  33, 135, 229,   8, 106, 204, 174,
  39,  69, 227, 129, 108,  14, 168, 202, 177, 211, 117,  23, 250, 152,  62,  92, 200, 170,  12, 110, 131, 225,  71,  37,  94,  60, 154, 248,  21, 119, 209, 179,
 116,  22, 176, 210,  63,  93, 251, 153, 226, 128,  38,  68, 169, 203, 109,  15, 155, 249,  95,  61, 208, 178,  20, 118,  13, 111, 201, 171,  70,  36, 130, 224,
 105,  11, 173, 207,  34,  64, 230, 132, 255, 157,  59,  89, 180, 214, 112,  18, 134, 228,  66,  32, 205, 175,   9, 107,  16, 114, 212, 182,  91,  57, 159, 253,
  78,  44, 138, 232,   5, 103, 193, 163, 216, 186,  28, 126, 147, 241,  87,  53, 161, 195, 101,   7, 234, 136,  46,  76,  55,  85, 243, 145, 124,  30, 184, 218,
  83,  49, 151, 245,  24, 122, 220, 190, 197, 167,   1,  99, 142, 236,  74,  40, 188, 222, 120,  26, 247, 149,  51,  81,  42,  72, 238, 140,  97,   3, 165, 199},

{  0,  99, 198, 165,  79,  44, 137, 234, 158, 253,  88,  59, 209, 178,  23, 116, 255, 156,  57,  90, 176, 211, 118,  21,  97,   2, 167, 196,  46,  77, 232, 139,
  61,  94, 251, 152, 114,  17, 180, 215, 163, 192, 101,   6, 236, 143,  42,  73, 194, 161,   4, 103, 141, 238,  75,  40,  92,  63, 154, 249,  19, 112, 213, 182,
 122,  25, 188, 223,  53,  86, 243, 144, 228, 135,  34,  65, 171, 200, 109,  14, 133, 230,  67,  32, 202, 169,  12, 111,  27, 120, 221, 190,  84,  55, 146, 241,
  71,  36, 129, 226,   8, 107, 206, 173, 217, 186,  31, 124, 150, 245,  80,  51, 184, 219, 126,  29, 247, 148,  49,  82,  38,  69, 224, 131, 105,  10, 175, 204,
 244, 151,  50,  81, 187, 216, 125,  30, 106,   9, 172, 207,  37,  70, 227, 128,  11, 104, 205, 174,  68,  39, 130, 225, 149, 246,  83,  48, 218, 185,  28, 127,
 201, 170,  15, 108, 134, 229,  64,  35,  87,  52, 145, 242,  24, 123, 222, 189,  54,  85, 240, 147, 121,  26, 191, 220, 168, 203, 110,  13, 231, 132,  33,  66,
 142, 237,  72,  43, 193, 162,   7, 100,  16, 115, 214, 181,  95,  60, 153, 250, 113,  18, 183, 212,  62,  93, 248, 155, 239, 140,  41,  74, 160, 195, 102,   5,
 179, 208, 117,  22, 252, 159,  58,  89,  45,  78, 235, 136,  98,   1, 164, 199,  76,  47, 138, 233,   3,  96, 197, 166, 210, 177,  20, 119, 157, 254,  91,  56},

{  0, 100, 200, 172,  83,  55, 155, 255, 166, 194, 110,  10, 245, 145,  61,  89, 143, 235,  71,  35, 220, 184,  20, 112,  41,  77, 225, 133, 122,  30, 178, 214,
 221, 185,  21, 113, 142, 234,  70,  34, 123,  31, 179, 215,  40,  76, 224, 132,  82,  54, 154, 254,   1, 101, 201, 173, 244, 144,  60,  88, 167, 195, 111,  11,
 121,  29, 177, 213,  42,  78, 226, 134, 223, 187,  23, 115, 140, 232,  68,  32, 246, 146,  62,  90, 165, 193, 109,   9,  80,  52, 152, 252,   3, 103, 203, 175,
 164, 192, 108,   8, 247, 147,  63,  91,   2, 102, 202, 174,  81,  53, 153, 253,  43,  79, 227, 135, 120,  28, 176, 212, 141, 233,  69,  33, 222, 186,  22, 114,
 242, 150,  58,  94, 161, 197, 105,  13,  84,  48, 156, 248,   7,  99, 207, 171, 125,  25, 181, 209,  46,  74, 230, 130, 219, 191,  19, 119, 136, 236,  64,  36,
  47,  75, 231, 131, 124,  24, 180, 208, 137, 237,  65,  37, 218, 190,  18, 118, 160, 196, 104,  12, 243, 151,  59,  95,   6,  98, 206, 170,  85,  49, 157, 249,
 139, 239,  67,  39, 216, 188,  16, 116,  45,  73, 229, 129, 126,  26, 182, 210,   4,  96, 204, 168,  87,  51, 159, 251, 162, 198, 106,  14, 241, 149,  57,  93,
  86,  50, 158, 250,   5,  97, 205, 169, 240, 148,  56,  92, 163, 199, 107,  15, 217, 189,  17, 117, 138, 238,  66,  38, 127,  27, 183, 211,  44,  72, 228, 128},

{  0, 101, 202, 175,  87,  50, 157, 248, 174, 203, 100,   1, 249, 156,  51,  86, 159, 250,  85,  48, 200, 173,   2, 103,  49,  84, 251, 158, 102,   3, 172, 201,
 253, 152,  55,  82, 170, 207,  96,   5,  83,  54, 153, 252,   4,  97, 206, 171,  98,   7, 168, 205,  53,  80, 255, 154, 204, 169,   6,  99, 155, 254,  81,  52,
  57,  92, 243, 150, 110,  11, 164, 193, 151, 242,  93,  56, 192, 165,  10, 111, 166, 195, 108,   9, 241, 148,  59,  94,   8, 109, 194, 167,  95,  58, 149, 240,
 196, 161,  14, 107, 147, 246,  89,  60, 106,  15, 160, 197,  61,  88, 247, 146,  91,  62, 145, 244,  12, 105, 198, 163, 245, 144,  63,  90, 162, 199, 104,  13,
 114,  23, 184, 221,  37,  64, 239, 138, 220, 185,  22, 115, 139, 238,  65,  36, 237, 136,  39,  66, 186, 223, 112,  21,  67,  38, 137, 236,  20, 113, 222, 187,
 143, 234,  69,  32, 216, 189,  18, 119,  33,  68, 235, 142, 118,  19, 188, 217,  16, 117, 218, 191,  71,  34, 141, 232, 190, 219, 116,  17, 233, 140,  35,  70,
  75,  46, 129, 228,  28, 121, 214, 179, 229, 128,  47,  74, 178, 215, 120,  29, 212, 177,  30, 123, 131, 230,  73,  44, 122,  31, 176, 213,  45,  72, 231, 130,
 182, 211, 124,  25, 225, 132,  43,  78,  24, 125, 210, 183,  79,  42, 133, 224,  41,  76, 227, 134, 126,  27, 180, 209, 135, 226,  77,  40, 208, 181,  26, 127},

{  0, 102, 204, 170,  91,  61, 151, 241, 182, 208, 122,  28, 237, 139,  33,  71, 175, 201,  99,   5, 244, 146,  56,  94,  25, 127, 213, 179,  66,  36, 142, 232,
 157, 251,  81,  55, 198, 160,  10, 108,  43,  77, 231, 129, 112,  22, 188, 218,  50,  84, 254, 152, 105,  15, 165, 195, 132, 226,  72,  46, 223, 185,  19, 117,
 249, 159,  53,  83, 162, 196, 110,   8,  79,  41, 131, 229,  20, 114, 216, 190,  86,  48, 154, 252,  13, 107, 193, 167, 224, 134,  44,  74, 187, 221, 119,  17,
 100,   2, 168, 206,  63,  89, 243, 149, 210, 180,  30, 120, 137, 239,  69,  35, 203, 173,   7,  97, 144, 246,  92,  58, 125,  27, 177, 215,  38,  64, 234, 140,
  49,  87, 253, 155, 106,  12, 166, 192, 135, 225,  75,  45, 220, 186,  16, 118, 158, 248,  82,  52, 197, 163,   9, 111,  40,  78, 228, 130, 115,  21, 191, 217,
 172, 202,  96,   6, 247, 145,  59,  93,  26, 124, 214, 176,  65,  39, 141, 235,   3, 101, 207, 169,  88,  62, 148, 242, 181, 211, 121,  31, 238, 136,  34,  68,
 200, 174,   4,  98, 147, 245,  95,  57, 126,  24, 178, 212,  37,  67, 233, 143, 103,   1, 171, 205,  60,  90, 240, 150, 209, 183,  29, 123, 138, 236,  70,  32,
  85,  51, 153, 255,  14, 104, 194, 164, 227, 133,  47,  73, 184, 222, 116,  18, 250, 156,  54,  80, 161, 199, 109,  11,  76,  42, 128, 230,  23, 113, 219, 189},

{  0, 103, 206, 169,  95,  56, 145, 246, 190, 217, 112,  23, 225, 134,  47,  72, 191, 216, 113,  22, 224, 135,  46,  73,   1, 102, 207, 168,  94,  57, 144, 247,
 189, 218, 115,  20, 226, 133,  44,  75,   3, 100, 205, 170,  92,  59, 146, 245,   2, 101, 204, 171,  93,  58, 147, 244, 188, 219, 114,  21, 227, 132,  45,  74,
 185, 222, 119,  16, 230, 129,  40,  79,   7,  96, 201, 174,  88,  63, 150, 241,   6,  97, 200, 175,  89,  62, 151, 240, 184, 223, 118,  17, 231, 128,  41,  78,
   4,  99, 202, 173,  91,  60, 149, 242, 186, 221, 116,  19, 229, 130,  43,  76, 187, 220, 117,  18, 228, 131,  42,  77,   5,  98, 203, 172,  90,  61, 148, 243,
 177, 214, 127,  24, 238, 137,  32,  71,  15, 104, 193, 166,  80,  55, 158, 249,  14, 105, 192, 167,  81,  54, 159, 248, 176, 215, 126,  25, 239, 136,  33,  70,
  12, 107, 194, 165,  83,  52, 157, 250, 178, 213, 124,  27, 237, 138,  35,  68, 179, 212, 125,  26, 236, 139,  34,  69,  13, 106, 195, 164,  82,  53, 156, 251,
   8, 111, 198, 161,  87,  48, 153, 254, 182, 209, 120,  31, 233, 142,  39,  64, 183, 208, 121,  30, 232, 143,  38,  65,   9, 110, 199, 160,  86,  49, 152, 255,
 181, 210, 123,  28, 234, 141,  36,  67,  11, 108, 197, 162,  84,  51, 154, 253,  10, 109, 196, 163,  85,  50, 155, 252, 180, 211, 122,  29, 235, 140,  37,  66},

{  0, 104, 208, 184,  99,  11, 179, 219, 198, 174,  22, 126, 165, 205, 117,  29,  79,  39, 159, 247,  44,  68, 252, 148, 137, 225,  89,  49, 234, 130,  58,  82,
 158, 246,  78,  38, 253, 149,  45,  69,  88,  48, 136, 224,  59,  83, 235, 131, 209, 185,   1, 105, 178, 218,  98,  10,  23, 127, 199, 175, 116,  28, 164, 204,
 255, 151,  47,  71, 156, 244,  76,  36,  57,  81, 233, 129,  90,  50, 138, 226, 176, 216,  96,   8, 211, 187,   3, 107, 118,  30, 166, 206,  21, 125, 197, 173,
  97,   9, 177, 217,   2, 106, 210, 186, 167, 207, 119,  31, 196, 172,  20, 124,  46,  70, 254, 150,  77,  37, 157, 245, 232, 128,  56,  80, 139, 227,  91,  51,
  61,  85, 237, 133,  94,  54, 142, 230, 251, 147,  43,  67, 152, 240,  72,  32, 114,  26, 162, 202,  17, 121, 193, 169, 180, 220, 100,  12, 215, 191,   7, 111,
 163, 203, 115,  27, 192, 168,  16, 120, 101,  13, 181, 221,   6, 110, 214, 190, 236, 132,  60,  84, 143, 231,  95,  55,  42,  66, 250, 146,  73,  33, 153, 241,
 194, 170,  18, 122, 161, 201, 113,  25,   4, 108, 212, 188, 103,  15, 183, 223, 141, 229,  93,  53, 238, 134,  62,  86,  75,  35, 155, 243,  40,  64, 248, 144,
  92,  52, 140, 228,  63,  87, 239, 135, 154, 242,  74,  34, 249, 145,  41,  65,  19, 123, 195, 171, 112,  24, 160, 200, 213, 189,   5, 109, 182, 222, 102,  14},

{  0, 105, 210, 187, 103,  14, 181, 220, 206, 167,  28, 117, 169, 192, 123,  18,  95,  54, 141, 228,  56,  81, 234, 131, 145, 248,  67,  42, 246, 159,  36,  77,
 190, 215, 108,   5, 217, 176,  11,  98, 112,  25, 162, 203,  23, 126, 197, 172, 225, 136,  51,  90, 134, 239,  84,  61,  47,  70, 253, 148,  72,  33, 154, 243,
 191, 214, 109,   4, 216, 177,  10,  99, 113,  24, 163, 202,  22, 127, 196, 173, 224, 137,  50,  91, 135, 238,  85,  60,  46,  71, 252, 149,  73,  32, 155, 242,
   1, 104, 211, 186, 102,  15, 180, 221, 207, 166,  29, 116, 168, 193, 122,  19,  94,  55, 140, 229,  57,  80, 235, 130, 144, 249,  66,  43, 247, 158,  37,  76,
 189, 212, 111,   6, 218, 179,   8,  97, 115,  26, 161, 200,  20, 125, 198, 175, 226, 139,  48,  89, 133, 236,  87,  62,  44,  69, 254, 151,  75,  34, 153, 240,
   3, 106, 209, 184, 100,  13, 182, 223, 205, 164,  31, 118, 170, 195, 120,  17,  92,  53, 142, 231,  59,  82, 233, 128, 146, 251,  64,  41, 245, 156,  39,  78,
   2, 107, 208, 185, 101,  12, 183, 222, 204, 165,  30, 119, 171, 194, 121,  16,  93,  52, 143, 230,  58,  83, 232, 129, 147, 250,  65,  40, 244, 157,  38,  79,
 188, 213, 110,   7, 219, 178,   9,  96, 114,  27, 160, 201,  21, 124, 199, 174, 227, 138,  49,  88, 132, 237,  86,  63,  45,  68, 255, 150,  74,  35, 152, 241},

{  0, 106, 212, 190, 107,   1, 191, 213, 214, 188,   2, 104, 189, 215, 105,   3, 111,   5, 187, 209,   4, 110, 208, 186, 185, 211, 109,   7, 210, 184,   6, 108,
 222, 180,  10,  96, 181, 223,  97,  11,   8,  98, 220, 182,  99,   9, 183, 221, 177, 219, 101,  15, 218, 176,  14, 100, 103,  13, 179, 217,  12, 102, 216, 178,
 127,  21, 171, 193,  20, 126, 192, 170, 169, 195, 125,  23, 194, 168,  22, 124,  16, 122, 196, 174, 123,  17, 175, 197, 198, 172,  18, 120, 173, 199, 121,  19,
 161, 203, 117,  31, 202, 160,  30, 116, 119,  29, 163, 201,  28, 118, 200, 162, 206, 164,  26, 112, 165, 207, 113,  27,  24, 114, 204, 166, 115,  25, 167, 205,
 254, 148,  42,  64, 149, 255,  65,  43,  40,  66, 252, 150,  67,  41, 151, 253, 145, 251,  69,  47, 250, 144,  46,  68,  71,  45, 147, 249,  44,  70, 248, 146,
  32,  74, 244, 158,  75,  33, 159, 245, 246, 156,  34,  72, 157, 247,  73,  35,  79,  37, 155, 241,  36,  78, 240, 154, 153, 243,  77,  39, 242, 152,  38,  76,
 129, 235,  85,  63, 234, 128,  62,  84,  87,  61, 131, 233,  60,  86, 232, 130, 238, 132,  58,  80, 133, 239,  81,  59,  56,  82, 236, 134,  83,  57, 135, 237,
  95,  53, 139, 225,  52,  94, 224, 138, 137, 227,  93,  55, 226, 136,  54,  92,  48,  90, 228, 142,  91,  49, 143, 229, 230, 140,  50,  88, 141, 231,  89,  51},

{  0, 107, 214, 189, 111,   4, 185, 210, 222, 181,   8,  99, 177, 218, 103,  12, 127,  20, 169, 194,  16, 123, 198, 173, 161, 202, 119,  28, 206, 165,  24, 115,
 254, 149,  40,  67, 145, 250,  71,  44,  32,  75, 246, 157,  79,  36, 153, 242, 129, 234,  87,  60, 238, 133,  56,  83,  95,  52, 137, 226,  48,  91, 230, 141,
  63,  84, 233, 130,  80,  59, 134, 237, 225, 138,  55,  92, 142, 229,  88,  51,  64,  43, 150, 253,  47,  68, 249, 146, 158, 245,  72,  35, 241, 154,  39,  76,
 193, 170,  23, 124, 174, 197, 120,  19,  31, 116, 201, 162, 112,  27, 166, 205, 190, 213, 104,   3, 209, 186,   7, 108,  96,  11, 182, 221,  15, 100, 217, 178,
 126,  21, 168, 195,  17, 122, 199, 172, 160, 203, 118,  29, 207, 164,  25, 114,   1, 106, 215, 188, 110,   5, 184, 211, 223, 180,   9,  98, 176, 219, 102,  13,
 128, 235,  86,  61, 239, 132,  57,  82,  94,  53, 136, 227,  49,  90, 231, 140, 255, 148,  41,  66, 144, 251,  70,  45,  33,  74, 247, 156,  78,  37, 152, 243,
  65,  42, 151, 252,  46,  69, 248, 147, 159, 244,  73,  34, 240, 155,  38,  77,  62,  85, 232, 131,  81,  58, 135, 236, 224, 139,  54,  93, 143, 228,  89,  50,
 191, 212, 105,   2, 208, 187,   6, 109,  97,  10, 183, 220,  14, 101, 216, 179, 192, 171,  22, 125, 175, 196, 121,  18,  30, 117, 200, 163, 113,  26, 167, 204},

{  0, 108, 216, 180, 115,  31, 171, 199, 230, 138,  62,  82, 149, 249,  77,  33,  15,  99, 215, 187, 124,  16, 164, 200, 233, 133,  49,  93, 154, 246,  66,  46,
  30, 114, 198, 170, 109,   1, 181, 217, 248, 148,  32,  76, 139, 231,  83,  63,  17, 125, 201, 165,  98,  14, 186, 214, 247, 155,  47,  67, 132, 232,  92,  48,
  60,  80, 228, 136,  79,  35, 151, 251, 218, 182,   2, 110, 169, 197, 113,  29,  51,  95, 235, 135,  64,  44, 152, 244, 213, 185,  13,  97, 166, 202, 126,  18,
  34,  78, 250, 150,  81,  61, 137, 229, 196, 168,  28, 112, 183, 219, 111,   3,  45,  65, 245, 153,  94,  50, 134, 234, 203, 167,  19, 127, 184, 212,  96,  12,
 120,  20, 160, 204,  11, 103, 211, 191, 158, 242,  70,  42, 237, 129,  53,  89, 119,  27, 175, 195,   4, 104, 220, 176, 145, 253,  73,  37, 226, 142,  58,  86,
 102,  10, 190, 210,  21, 121, 205, 161, 128, 236,  88,  52, 243, 159,  43,  71, 105,   5, 177, 221,  26, 118, 194, 174, 143, 227,  87,  59, 252, 144,  36,  72,
  68,  40, 156, 240,  55,  91, 239, 131, 162, 206, 122,  22, 209, 189,   9, 101,  75,  39, 147, 255,  56,  84, 224, 140, 173, 193, 117,  25, 222, 178,   6, 106,
  90,  54, 130, 238,  41,  69, 241, 157, 188, 208, 100,   8, 207, 163,  23, 123,  85,  57, 141, 225,  38,  74, 254, 146, 179, 223, 107,   7, 192, 172,  24, 116},

{  0, 109, 218, 183, 119,  26, 173, 192, 238, 131,  52,  89, 153, 244,  67,  46,  31, 114, 197, 168, 104,   5, 178, 223, 241, 156,  43,  70, 134, 235,  92,  49,
  62,  83, 228, 137,  73,  36, 147, 254, 208, 189,  10, 103, 167, 202, 125,  16,  33,  76, 251, 150,  86,  59, 140, 225, 207, 162,  21, 120, 184, 213,  98,  15,
 124,  17, 166, 203,  11, 102, 209, 188, 146, 255,  72,  37, 229, 136,  63,  82,  99,  14, 185, 212,  20, 121, 206, 163, 141, 224,  87,  58, 250, 151,  32,  77,
  66,  47, 152, 245,  53,  88, 239, 130, 172, 193, 118,  27, 219, 182,   1, 108,  93,  48, 135, 234,  42,  71, 240, 157, 179, 222, 105,   4, 196, 169,  30, 115,
 248, 149,  34,  79, 143, 226,  85,  56,  22, 123, 204, 161,  97,  12, 187, 214, 231, 138,  61,  80, 144, 253,  74,  39,   9, 100, 211, 190, 126,  19, 164, 201,
 198, 171,  28, 113, 177, 220, 107,   6,  40,  69, 242, 159,  95,  50, 133, 232, 217, 180,   3, 110, 174, 195, 116,  25,  55,  90, 237, 128,  64,  45, 154, 247,
 132, 233,  94,  51, 243, 158,  41,  68, 106,   7, 176, 221,  29, 112, 199, 170, 155, 246,  65,  44, 236, 129,  54,  91, 117,  24, 175, 194,   2, 111, 216, 181,
 186, 215,  96,  13, 205, 160,  23, 122,  84,  57, 142, 227,  35,  78, 249, 148, 165, 200, 127,  18, 210, 191,   8, 101,  75,  38, 145, 252,  60,  81, 230, 139},

{  0, 110, 220, 178, 123,  21, 167, 201, 246, 152,  42,  68, 141, 227,  81,  63,  47,  65, 243, 157,  84,  58, 136, 230, 217, 183,   5, 107, 162, 204, 126,  16,
  94,  48, 130, 236,  37,  75, 249, 151, 168, 198, 116,  26, 211, 189,  15,  97, 113,  31, 173, 195,  10, 100, 214, 184, 135, 233,  91,  53, 252, 146,  32,  78,
 188, 210,  96,  14, 199, 169,  27, 117,  74,  36, 150, 248,  49,  95, 237, 131, 147, 253,  79,  33, 232, 134,  52,  90, 101,  11, 185, 215,  30, 112, 194, 172,
 226, 140,  62,  80, 153, 247,  69,  43,  20, 122, 200, 166, 111,   1, 179, 221, 205, 163,  17, 127, 182, 216, 106,   4,  59,  85, 231, 137,  64,  46, 156, 242,
 187, 213, 103,   9, 192, 174,  28, 114,  77,  35, 145, 255,  54,  88, 234, 132, 148, 250,  72,  38, 239, 129,  51,  93,  98,  12, 190, 208,  25, 119, 197, 171,
 229, 139,  57,  87, 158, 240,  66,  44,  19, 125, 207, 161, 104,   6, 180, 218, 202, 164,  22, 120, 177, 223, 109,   3,  60,  82, 224, 142,  71,  41, 155, 245,
   7, 105, 219, 181, 124,  18, 160, 206, 241, 159,  45,  67, 138, 228,  86,  56,  40,  70, 244, 154,  83,  61, 143, 225, 222, 176,   2, 108, 165, 203, 121,  23,
  89,  55, 133, 235,  34,  76, 254, 144, 175, 193, 115,  29, 212, 186,   8, 102, 118,  24, 170, 196,  13,  99, 209, 191, 128, 238,  92,  50, 251, 149,  39,  73},

{  0, 111, 222, 177, 127,  16, 161, 206, 254, 145,  32,  79, 129, 238,  95,  48,  63,  80, 225, 142,  64,  47, 158, 241, 193, 174,  31, 112, 190, 209,  96,  15,
 126,  17, 160, 207,   1, 110, 223, 176, 128, 239,  94,  49, 255, 144,  33,  78,  65,  46, 159, 240,  62,  81, 224, 143, 191, 208,  97,  14, 192, 175,  30, 113,
 252, 147,  34,  77, 131, 236,  93,  50,   2, 109, 220, 179, 125,  18, 163, 204, 195, 172,  29, 114, 188, 211,  98,  13,  61,  82, 227, 140,  66,  45, 156, 243,
 130, 237,  92,  51, 253, 146,  35,  76, 124,  19, 162, 205,   3, 108, 221, 178, 189, 210,  99,  12, 194, 173,  28, 115,  67,  44, 157, 242,  60,  83, 226, 141,
  59,  84, 229, 138,  68,  43, 154, 245, 197, 170,  27, 116, 186, 213, 100,  11,   4, 107, 218, 181, 123,  20, 165, 202, 250, 149,  36,  75, 133, 234,  91,  52,
  69,  42, 155, 244,  58,  85, 228, 139, 187, 212, 101,  10, 196, 171,  26, 117, 122,  21, 164, 203,   5, 106, 219, 180, 132, 235,  90,  53, 251, 148,  37,  74,
 199, 168,  25, 118, 184, 215, 102,   9,  57,  86, 231, 136,  70,  41, 152, 247, 248, 151,  38,  73, 135, 232,  89,  54,   6, 105, 216, 183, 121,  22, 167, 200,
 185, 214, 103,   8, 198, 169,  24, 119,  71,  40, 153, 246,  56,  87, 230, 137, 134, 233,  88,  55, 249, 150,  39,  72, 120,  23, 166, 201,   7, 104, 217, 182},

{  0, 112, 224, 144,   3, 115, 227, 147,   6, 118, 230, 150,   5, 117, 229, 149,  12, 124, 236, 156,  15, 127, 239, 159,  10, 122, 234, 154,   9, 121, 233, 153,
  24, 104, 248, 136,  27, 107, 251, 139,  30, 110, 254, 142,  29, 109, 253, 141,  20, 100, 244, 132,  23, 103, 247, 135,  18,  98, 242, 130,  17,  97, 241, 129,
  48,  64, 208, 160,  51,  67, 211, 163,  54,  70, 214, 166,  53,  69, 213, 165,  60,  76, 220, 172,  63,  79, 223, 175,  58,  74, 218, 170,  57,  73, 217, 169,
  40,  88, 200, 184,  43,  91, 203, 187,  46,  94, 206, 190,  45,  93, 205, 189,  36,  84, 196, 180,  39,  87, 199, 183,  34,  82, 194, 178,  33,  81, 193, 177,
  96,  16, 128, 240,  99,  19, 131, 243, 102,  22, 134, 246, 101,  21, 133, 245, 108,  28, 140, 252, 111,  31, 143, 255, 106,  26, 138, 250, 105,  25, 137, 249,
 120,   8, 152, 232, 123,  11, 155, 235, 126,  14, 158, 238, 125,  13, 157, 237, 116,   4, 148, 228, 119,   7, 151, 231, 114,   2, 146, 226, 113,   1, 145, 225,
  80,  32, 176, 192,  83,  35, 179, 195,  86,  38, 182, 198,  85,  37, 181, 197,  92,  44, 188, 204,  95,  47, 191, 207,  90,  42, 186, 202,  89,  41, 185, 201,
  72,  56, 168, 216,  75,  59, 171, 219,  78,  62, 174, 222,  77,  61, 173, 221,  68,  52, 164, 212,  71,  55, 167, 215,  66,  50, 162, 210,  65,  49, 161, 209},

{  0, 113, 226, 147,   7, 118, 229, 148,  14, 127, 236, 157,   9, 120, 235, 154,  28, 109, 254, 143,  27, 106, 249, 136,  18,  99, 240, 129,  21, 100, 247, 134,
  56,  73, 218, 171,  63,  78, 221, 172,  54,  71, 212, 165,  49,  64, 211, 162,  36,  85, 198, 183,  35,  82, 193, 176,  42,  91, 200, 185,  45,  92, 207, 190,
 112,   1, 146, 227, 119,   6, 149, 228, 126,  15, 156, 237, 121,   8, 155, 234, 108,  29, 142, 255, 107,  26, 137, 248,  98,  19, 128, 241, 101,  20, 135, 246,
  72,  57, 170, 219,  79,  62, 173, 220,  70,  55, 164, 213,  65,  48, 163, 210,  84,  37, 182, 199,  83,  34, 177, 192,  90,  43, 184, 201,  93,  44, 191, 206,
 224, 145,   2, 115, 231, 150,   5, 116, 238, 159,  12, 125, 233, 152,  11, 122, 252, 141,  30, 111, 251, 138,  25, 104, 242, 131,  16,  97, 245, 132,  23, 102,
 216, 169,  58,  75, 223, 174,  61,  76, 214, 167,  52,  69, 209, 160,  51,  66, 196, 181,  38,  87, 195, 178,  33,  80, 202, 187,  40,  89, 205, 188,  47,  94,
 144, 225, 114,   3, 151, 230, 117,   4, 158, 239, 124,  13, 153, 232, 123,  10, 140, 253, 110,  31, 139, 250, 105,  24, 130, 243,  96,  17, 133, 244, 103,  22,
 168, 217,  74,  59, 175, 222,  77,  60, 166, 215,  68,  53, 161, 208,  67,  50, 180, 197,  86,  39, 179, 194,  81,  32, 186, 203,  88,  41, 189, 204,  95,  46},

{  0, 114, 228, 150,  11, 121, 239, 157,  22, 100, 242, 128,  29, 111, 249, 139,  44,  94, 200, 186,  39,  85, 195, 177,  58,  72, 222, 172,  49,  67, 213, 167,
  88,  42, 188, 206,  83,  33, 183, 197,  78,  60, 170, 216,  69,  55, 161, 211, 116,   6, 144, 226, 127,  13, 155, 233,  98,  16, 134, 244, 105,  27, 141, 255,
 176, 194,  84,  38, 187, 201,  95,  45, 166, 212,  66,  48, 173, 223,  73,  59, 156, 238, 120,  10, 151, 229, 115,   1, 138, 248, 110,  28, 129, 243, 101,  23,
 232, 154,  12, 126, 227, 145,   7, 117, 254, 140,  26, 104, 245, 135,  17,  99, 196, 182,  32,  82, 207, 189,  43,  89, 210, 160,  54,  68, 217, 171,  61,  79,
 163, 209,  71,  53, 168, 218,  76,  62, 181, 199,  81,  35, 190, 204,  90,  40, 143, 253, 107,  25, 132, 246,  96,  18, 153, 235, 125,  15, 146, 224, 118,   4,
 251, 137,  31, 109, 240, 130,  20, 102, 237, 159,   9, 123, 230, 148,   2, 112, 215, 165,  51,  65, 220, 174,  56,  74, 193, 179,  37,  87, 202, 184,  46,  92,
  19,  97, 247, 133,  24, 106, 252, 142,   5, 119, 225, 147,  14, 124, 234, 152,  63,  77, 219, 169,  52,  70, 208, 162,  41,  91, 205, 191,  34,  80, 198, 180,
  75,  57, 175, 221,  64,  50, 164, 214,  93,  47, 185, 203,  86,  36, 178, 192, 103,  21, 131, 241, 108,  30, 136, 250, 113,   3, 149, 231, 122,   8, 158, 236},

{  0, 115, 230, 149,  15, 124, 233, 154,  30, 109, 248, 139,  17,  98, 247, 132,  60,  79, 218, 169,  51,  64, 213, 166,  34,  81, 196, 183,  45,  94, 203, 184,
 120,  11, 158, 237, 119,   4, 145, 226, 102,  21, 128, 243, 105,  26, 143, 252,  68,  55, 162, 209,  75,  56, 173, 222,  90,  41, 188, 207,  85,  38, 179, 192,
 240, 131,  22, 101, 255, 140,  25, 106, 238, 157,   8, 123, 225, 146,   7, 116, 204, 191,  42,  89, 195, 176,  37,  86, 210, 161,  52,  71, 221, 174,  59,  72,
 136, 251, 110,  29, 135, 244,  97,  18, 150, 229, 112,   3, 153, 234, 127,  12, 180, 199,  82,  33, 187, 200,  93,  46, 170, 217,  76,  63, 165, 214,  67,  48,
  35,  80, 197, 182,  44,  95, 202, 185,  61,  78, 219, 168,  50,  65, 212, 167,  31, 108, 249, 138,  16,  99, 246, 133,   1, 114, 231, 148,  14, 125, 232, 155,
  91,  40, 189, 206,  84,  39, 178, 193,  69,  54, 163, 208,  74,  57, 172, 223, 103,  20, 129, 242, 104,  27, 142, 253, 121,  10, 159, 236, 118,   5, 144, 227,
 211, 160,  53,  70, 220, 175,  58,  73, 205, 190,  43,  88, 194, 177,  36,  87, 239, 156,   9, 122, 224, 147,   6, 117, 241, 130,  23, 100, 254, 141,  24, 107,
 171, 216,  77,  62, 164, 215,  66,  49, 181, 198,  83,  32, 186, 201,  92,  47, 151, 228, 113,   2, 152, 235, 126,  13, 137, 250, 111,  28, 134, 245,  96,  19},

{  0, 116, 232, 156,  19, 103, 251, 143,  38,  82, 206, 186,  53,  65, 221, 169,  76,  56, 164, 208,  95,  43, 183, 195, 106,  30, 130, 246, 121,  13, 145, 229,
 152, 236, 112,   4, 139, 255,  99,  23, 190, 202,  86,  34, 173, 217,  69,  49, 212, 160,  60,  72, 199, 179,  47,  91, 242, 134,  26, 110, 225, 149,   9, 125,
 243, 135,  27, 111, 224, 148,   8, 124, 213, 161,  61,  73, 198, 178,  46,  90, 191, 203,  87,  35, 172, 216,  68,  48, 153, 237, 113,   5, 138, 254,  98,  22,
 107,  31, 131, 247, 120,  12, 144, 228,  77,  57, 165, 209,  94,  42, 182, 194,  39,  83, 207, 187,  52,  64, 220, 168,   1, 117, 233, 157,  18, 102, 250, 142,
  37,  81, 205, 185,  54,  66, 222, 170,   3, 119, 235, 159,  16, 100, 248, 140, 105,  29, 129, 245, 122,  14, 146, 230,  79,  59, 167, 211,  92,  40, 180, 192,
 189, 201,  85,  33, 174, 218,  70,  50, 155, 239, 115,   7, 136, 252,  96,  20, 241, 133,  25, 109, 226, 150,  10, 126, 215, 163,  63,  75, 196, 176,  44,  88,
 214, 162,  62,  74, 197, 177,  45,  89, 240, 132,  24, 108, 227, 151,  11, 127, 154, 238, 114,   6, 137, 253,  97,  21, 188, 200,  84,  32, 175, 219,  71,  51,
  78,  58, 166, 210,  93,  41, 181, 193, 104,  28, 128, 244, 123,  15, 147, 231,   2, 118, 234, 158,  17, 101, 249, 141,  36,  80, 204, 184,  55,  67, 223, 171},

{  0, 117, 234, 159,  23,  98, 253, 136,  46,  91, 196, 177,  57,  76, 211, 166,  92,  41, 182, 195,  75,  62, 161, 212, 114,   7, 152, 237, 101,  16, 143, 250,
 184, 205,  82,  39, 175, 218,  69,  48, 150, 227, 124,   9, 129, 244, 107,  30, 228, 145,  14, 123, 243, 134,  25, 108, 202, 191,  32,  85, 221, 168,  55,  66,
 179, 198,  89,  44, 164, 209,  78,  59, 157, 232, 119,   2, 138, 255,  96,  21, 239, 154,   5, 112, 248, 141,  18, 103, 193, 180,  43,  94, 214, 163,  60,  73,
  11, 126, 225, 148,  28, 105, 246, 131,  37,  80, 207, 186,  50,  71, 216, 173,  87,  34, 189, 200,  64,  53, 170, 223, 121,  12, 147, 230, 110,  27, 132, 241,
 165, 208,  79,  58, 178, 199,  88,  45, 139, 254,  97,  20, 156, 233, 118,   3, 249, 140,  19, 102, 238, 155,   4, 113, 215, 162,  61,  72, 192, 181,  42,  95,
  29, 104, 247, 130,  10, 127, 224, 149,  51,  70, 217, 172,  36,  81, 206, 187,  65,  52, 171, 222,  86,  35, 188, 201, 111,  26, 133, 240, 120,  13, 146, 231,
  22,  99, 252, 137,   1, 116, 235, 158,  56,  77, 210, 167,  47,  90, 197, 176,  74,  63, 160, 213,  93,  40, 183, 194, 100,  17, 142, 251, 115,   6, 153, 236,
 174, 219,  68,  49, 185, 204,  83,  38, 128, 245, 106,  31, 151, 226, 125,   8, 242, 135,  24, 109, 229, 144,  15, 122, 220, 169,  54,  67, 203, 190,  33,  84},

{  0, 118, 236, 154,  27, 109, 247, 129,  54,  64, 218, 172,  45,  91, 193, 183, 108,  26, 128, 246, 119,   1, 155, 237,  90,  44, 182, 192,  65,  55, 173, 219,
 216, 174,  52,  66, 195, 181,  47,  89, 238, 152,   2, 116, 245, 131,  25, 111, 180, 194,  88,  46, 175, 217,  67,  53, 130, 244, 110,  24, 153, 239, 117,   3,
 115,   5, 159, 233, 104,  30, 132, 242,  69,  51, 169, 223,  94,  40, 178, 196,  31, 105, 243, 133,   4, 114, 232, 158,  41,  95, 197, 179,  50,  68, 222, 168,
 171, 221,  71,  49, 176, 198,  92,  42, 157, 235, 113,   7, 134, 240, 106,  28, 199, 177,  43,  93, 220, 170,  48,  70, 241, 135,  29, 107, 234, 156,   6, 112,
 230, 144,  10, 124, 253, 139,  17, 103, 208, 166,  60,  74, 203, 189,  39,  81, 138, 252, 102,  16, 145, 231, 125,  11, 188, 202,  80,  38, 167, 209,  75,  61,
  62,  72, 210, 164,  37,  83, 201, 191,   8, 126, 228, 146,  19, 101, 255, 137,  82,  36, 190, 200,  73,  63, 165, 211, 100,  18, 136, 254, 127,   9, 147, 229,
 149, 227, 121,  15, 142, 248,  98,  20, 163, 213,  79,  57, 184, 206,  84,  34, 249, 143,  21,  99, 226, 148,  14, 120, 207, 185,  35,  85, 212, 162,  56,  78,
  77,  59, 161, 215,  86,  32, 186, 204, 123,  13, 151, 225,  96,  22, 140, 250,  33,  87, 205, 187,  58,  76, 214, 160,  23,  97, 251, 141,  12, 122, 224, 150},

{  0, 119, 238, 153,  31, 104, 241, 134,  62,  73, 208, 167,  33,  86, 207, 184, 124,  11, 146, 229,  99,  20, 141, 250,  66,  53, 172, 219,  93,  42, 179, 196,
 248, 143,  22,  97, 231, 144,   9, 126, 198, 177,  40,  95, 217, 174,  55,  64, 132, 243, 106,  29, 155, 236, 117,   2, 186, 205,  84,  35, 165, 210,  75,  60,
  51,  68, 221, 170,  44,  91, 194, 181,  13, 122, 227, 148,  18, 101, 252, 139,  79,  56, 161, 214,  80,  39, 190, 201, 113,   6, 159, 232, 110,  25, 128, 247,
 203, 188,  37,  82, 212, 163,  58,  77, 245, 130,  27, 108, 234, 157,   4, 115, 183, 192,  89,  46, 168, 223,  70,  49, 137, 254, 103,  16, 150, 225, 120,  15,
 102,  17, 136, 255, 121,  14, 151, 224,  88,  47, 182, 193,  71,  48, 169, 222,  26, 109, 244, 131,   5, 114, 235, 156,  36,  83, 202, 189,  59,  76, 213, 162,
 158, 233, 112,   7, 129, 246, 111,  24, 160, 215,  78,  57, 191, 200,  81,  38, 226, 149,  12, 123, 253, 138,  19, 100, 220, 171,  50,  69, 195, 180,  45,  90,
  85,  34, 187, 204,  74,  61, 164, 211, 107,  28, 133, 242, 116,   3, 154, 237,  41,  94, 199, 176,  54,  65, 216, 175,  23,  96, 249, 142,   8, 127, 230, 145,
 173, 218,  67,  52, 178, 197,  92,  43, 147, 228, 125,  10, 140, 251,  98,  21, 209, 166,  63,  72, 206, 185,  32,  87, 239, 152,   1, 118, 240, 135,  30, 105},

{  0, 120, 240, 136,  35,  91, 211, 171,  70,  62, 182, 206, 101,  29, 149, 237, 140, 244, 124,   4, 175, 215,  95,  39, 202, 178,  58,  66, 233, 145,  25,  97,
 219, 163,  43,  83, 248, 128,   8, 112, 157, 229, 109,  21, 190, 198,  78,  54,  87,  47, 167, 223, 116,  12, 132, 252,  17, 105, 225, 153,  50,  74, 194, 186,
 117,  13, 133, 253,  86,  46, 166, 222,  51,  75, 195, 187,  16, 104, 224, 152, 249, 129,   9, 113, 218, 162,  42,  82, 191, 199,  79,  55, 156, 228, 108,  20,
 174, 214,  94,  38, 141, 245, 125,   5, 232, 144,  24,  96, 203, 179,  59,  67,  34,  90, 210, 170,   1, 121, 241, 137, 100,  28, 148, 236,  71,  63, 183, 207,
 234, 146,  26,  98, 201, 177,  57,  65, 172, 212,  92,  36, 143, 247, 127,   7, 102,  30, 150, 238,  69,  61, 181, 205,  32,  88, 208, 168,   3, 123, 243, 139,
  49,  73, 193, 185,  18, 106, 226, 154, 119,  15, 135, 255,  84,  44, 164, 220, 189, 197,  77,  53, 158, 230, 110,  22, 251, 131,  11, 115, 216, 160,  40,  80,
 159, 231, 111,  23, 188, 196,  76,  52, 217, 161,  41,  81, 250, 130,  10, 114,  19, 107, 227, 155,  48,  72, 192, 184,  85,  45, 165, 221, 118,  14, 134, 254,
  68,  60, 180, 204, 103,  31, 151, 239,   2, 122, 242, 138,  33,  89, 209, 169, 200, 176,  56,  64, 235, 147,  27,  99, 142, 246, 126,   6, 173, 213,  93,  37},

{  0, 121, 242, 139,  39,  94, 213, 172,  78,  55, 188, 197, 105,  16, 155, 226, 156, 229, 110,  23, 187, 194,  73,  48, 210, 171,  32,  89, 245, 140,   7, 126,
 251, 130,   9, 112, 220, 165,  46,  87, 181, 204,  71,  62, 146, 235,  96,  25, 103,  30, 149, 236,  64,  57, 178, 203,  41,  80, 219, 162,  14, 119, 252, 133,
  53,  76, 199, 190,  18, 107, 224, 153, 123,   2, 137, 240,  92,  37, 174, 215, 169, 208,  91,  34, 142, 247, 124,   5, 231, 158,  21, 108, 192, 185,  50,  75,
 206, 183,  60,  69, 233, 144,  27,  98, 128, 249, 114,  11, 167, 222,  85,  44,  82,  43, 160, 217, 117,  12, 135, 254,  28, 101, 238, 151,  59,  66, 201, 176,
 106,  19, 152, 225,  77,  52, 191, 198,  36,  93, 214, 175,   3, 122, 241, 136, 246, 143,   4, 125, 209, 168,  35,  90, 184, 193,  74,  51, 159, 230, 109,  20,
 145, 232,  99,  26, 182, 207,  68,  61, 223, 166,  45,  84, 248, 129,  10, 115,  13, 116, 255, 134,  42,  83, 216, 161,  67,  58, 177, 200, 100,  29, 150, 239,
  95,  38, 173, 212, 120,   1, 138, 243,  17, 104, 227, 154,  54,  79, 196, 189, 195, 186,  49,  72, 228, 157,  22, 111, 141, 244, 127,   6, 170, 211,  88,  33,
 164, 221,  86,  47, 131, 250, 113,   8, 234, 147,  24,  97, 205, 180,  63,  70,  56,  65, 202, 179,  31, 102, 237, 148, 118,  15, 132, 253,  81,  40, 163, 218},

{  0, 122, 244, 142,  43,  81, 223, 165,  86,  44, 162, 216, 125,   7, 137, 243, 172, 214,  88,  34, 135, 253, 115,   9, 250, 128,  14, 116, 209, 171,  37,  95,
 155, 225, 111,  21, 176, 202,  68,  62, 205, 183,  57,  67, 230, 156,  18, 104,  55,  77, 195, 185,  28, 102, 232, 146,  97,  27, 149, 239,  74,  48, 190, 196,
 245, 143,   1, 123, 222, 164,  42,  80, 163, 217,  87,  45, 136, 242, 124,   6,  89,  35, 173, 215, 114,   8, 134, 252,  15, 117, 251, 129,  36,  94, 208, 170,
 110,  20, 154, 224,  69,  63, 177, 203,  56,  66, 204, 182,  19, 105, 231, 157, 194, 184,  54,  76, 233, 147,  29, 103, 148, 238,  96,  26, 191, 197,  75,  49,
  41,  83, 221, 167,   2, 120, 246, 140, 127,   5, 139, 241,  84,  46, 160, 218, 133, 255, 113,  11, 174, 212,  90,  32, 211, 169,  39,  93, 248, 130,  12, 118,
 178, 200,  70,  60, 153, 227, 109,  23, 228, 158,  16, 106, 207, 181,  59,  65,  30, 100, 234, 144,  53,  79, 193, 187,  72,  50, 188, 198,  99,  25, 151, 237,
 220, 166,  40,  82, 247, 141,   3, 121, 138, 240, 126,   4, 161, 219,  85,  47, 112,  10, 132, 254,  91,  33, 175, 213,  38,  92, 210, 168,  13, 119, 249, 131,
  71,  61, 179, 201, 108,  22, 152, 226,  17, 107, 229, 159,  58,  64, 206, 180, 235, 145,  31, 101, 192, 186,  52,  78, 189, 199,  73,  51, 150, 236,  98,  24},

{  0, 123, 246, 141,  47,  84, 217, 162,  94,  37, 168, 211, 113,  10, 135, 252, 188, 199,  74,  49, 147, 232, 101,  30, 226, 153,  20, 111, 205, 182,  59,  64,
 187, 192,  77,  54, 148, 239,  98,  25, 229, 158,  19, 104, 202, 177,  60,  71,   7, 124, 241, 138,  40,  83, 222, 165,  89,  34, 175, 212, 118,  13, 128, 251,
 181, 206,  67,  56, 154, 225, 108,  23, 235, 144,  29, 102, 196, 191,  50,  73,   9, 114, 255, 132,  38,  93, 208, 171,  87,  44, 161, 218, 120,   3, 142, 245,
  14, 117, 248, 131,  33,  90, 215, 172,  80,  43, 166, 221, 127,   4, 137, 242, 178, 201,  68,  63, 157, 230, 107,  16, 236, 151,  26,  97, 195, 184,  53,  78,
 169, 210,  95,  36, 134, 253, 112,  11, 247, 140,   1, 122, 216, 163,  46,  85,  21, 110, 227, 152,  58,  65, 204, 183,  75,  48, 189, 198, 100,  31, 146, 233,
  18, 105, 228, 159,  61,  70, 203, 176,  76,  55, 186, 193,  99,  24, 149, 238, 174, 213,  88,  35, 129, 250, 119,  12, 240, 139,   6, 125, 223, 164,  41,  82,
  28, 103, 234, 145,  51,  72, 197, 190,  66,  57, 180, 207, 109,  22, 155, 224, 160, 219,  86,  45, 143, 244, 121,   2, 254, 133,   8, 115, 209, 170,  39,  92,
 167, 220,  81,  42, 136, 243, 126,   5, 249, 130,  15, 116, 214, 173,  32,  91,  27,  96, 237, 150,  52,  79, 194, 185,  69,  62, 179, 200, 106,  17, 156, 231},

{  0, 124, 248, 132,  51,  79, 203, 183, 102,  26, 158, 226,  85,  41, 173, 209, 204, 176,  52,  72, 255, 131,   7, 123, 170, 214,  82,  46, 153, 229,  97,  29,
  91,  39, 163, 223, 104,  20, 144, 236,  61,  65, 197, 185,  14, 114, 246, 138, 151, 235, 111,  19, 164, 216,  92,  32, 241, 141,   9, 117, 194, 190,  58,  70,
 182, 202,  78,  50, 133, 249, 125,   1, 208, 172,  40,  84, 227, 159,  27, 103, 122,   6, 130, 254,  73,  53, 177, 205,  28,  96, 228, 152,  47,  83, 215, 171,
 237, 145,  21, 105, 222, 162,  38,  90, 139, 247, 115,  15, 184, 196,  64,  60,  33,  93, 217, 165,  18, 110, 234, 150,  71,  59, 191, 195, 116,   8, 140, 240,
 175, 211,  87,  43, 156, 224, 100,  24, 201, 181,  49,  77, 250, 134,   2, 126,  99,  31, 155, 231,  80,  44, 168, 212,   5, 121, 253, 129,  54,  74, 206, 178,
 244, 136,  12, 112, 199, 187,  63,  67, 146, 238, 106,  22, 161, 221,  89,  37,  56,  68, 192, 188,  11, 119, 243, 143,  94,  34, 166, 218, 109,  17, 149, 233,
  25, 101, 225, 157,  42,  86, 210, 174, 127,   3, 135, 251,  76,  48, 180, 200, 213, 169,  45,  81, 230, 154,  30,  98, 179, 207,  75,  55, 128, 252, 120,   4,
  66,  62, 186, 198, 113,  13, 137, 245,  36,  88, 220, 160,  23, 107, 239, 147, 142, 242, 118,  10, 189, 193,  69,  57, 232, 148,  16, 108, 219, 167,  35,  95},

{  0, 125, 250, 135,  55,  74, 205, 176, 110,  19, 148, 233,  89,  36, 163, 222, 220, 161,  38,  91, 235, 150,  17, 108, 178, 207,  72,  53, 133, 248, 127,   2,
 123,   6, 129, 252,  76,  49, 182, 203,  21, 104, 239, 146,  34,  95, 216, 165, 167, 218,  93,  32, 144, 237, 106,  23, 201, 180,  51,  78, 254, 131,   4, 121,
 246, 139,  12, 113, 193, 188,  59,  70, 152, 229,  98,  31, 175, 210,  85,  40,  42,  87, 208, 173,  29,  96, 231, 154,  68,  57, 190, 195, 115,  14, 137, 244,
 141, 240, 119,  10, 186, 199,  64,  61, 227, 158,  25, 100, 212, 169,  46,  83,  81,  44, 171, 214, 102,  27, 156, 225,  63,  66, 197, 184,   8, 117, 242, 143,
  47,  82, 213, 168,  24, 101, 226, 159,  65,  60, 187, 198, 118,  11, 140, 241, 243, 142,   9, 116, 196, 185,  62,  67, 157, 224, 103,  26, 170, 215,  80,  45,
  84,  41, 174, 211,  99,  30, 153, 228,  58,  71, 192, 189,  13, 112, 247, 138, 136, 245, 114,  15, 191, 194,  69,  56, 230, 155,  28,  97, 209, 172,  43,  86,
 217, 164,  35,  94, 238, 147,  20, 105, 183, 202,  77,  48, 128, 253, 122,   7,   5, 120, 255, 130,  50,  79, 200, 181, 107,  22, 145, 236,  92,  33, 166, 219,
 162, 223,  88,  37, 149, 232, 111,  18, 204, 177,  54,  75, 251, 134,   1, 124, 126,   3, 132, 249,  73,  52, 179, 206,  16, 109, 234, 151,  39,  90, 221, 160},

{  0, 126, 252, 130,  59,  69, 199, 185, 118,   8, 138, 244,  77,  51, 177, 207, 236, 146,  16, 110, 215, 169,  43,  85, 154, 228, 102,  24, 161, 223,  93,  35,
  27, 101, 231, 153,  32,  94, 220, 162, 109,  19, 145, 239,  86,  40, 170, 212, 247, 137,  11, 117, 204, 178,  48,  78, 129, 255, 125,   3, 186, 196,  70,  56,
  54,  72, 202, 180,  13, 115, 241, 143,  64,  62, 188, 194, 123,   5, 135, 249, 218, 164,  38,  88, 225, 159,  29,  99, 172, 210,  80,  46, 151, 233, 107,  21,
  45,  83, 209, 175,  22, 104, 234, 148,  91,  37, 167, 217,  96,  30, 156, 226, 193, 191,  61,  67, 250, 132,   6, 120, 183, 201,  75,  53, 140, 242, 112,  14,
 108,  18, 144, 238,  87,  41, 171, 213,  26, 100, 230, 152,  33,  95, 221, 163, 128, 254, 124,   2, 187, 197,  71,  57, 246, 136,  10, 116, 205, 179,  49,  79,
 119,   9, 139, 245,  76,  50, 176, 206,   1, 127, 253, 131,  58,  68, 198, 184, 155, 229, 103,  25, 160, 222,  92,  34, 237, 147,  17, 111, 214, 168,  42,  84,
  90,  36, 166, 216,  97,  31, 157, 227,  44,  82, 208, 174,  23, 105, 235, 149, 182, 200,  74,  52, 141, 243, 113,  15, 192, 190,  60,  66, 251, 133,   7, 121,
  65,  63, 189, 195, 122,   4, 134, 248,  55,  73, 203, 181,  12, 114, 240, 142, 173, 211,  81,  47, 150, 232, 106,  20, 219, 165,  39,  89, 224, 158,  28,  98},

{  0, 127, 254, 129,  63,  64, 193, 190, 126,   1, 128, 255,  65,  62, 191, 192, 252, 131,   2, 125, 195, 188,  61,  66, 130, 253, 124,   3, 189, 194,  67,  60,
  59,  68, 197, 186,   4, 123, 250, 133,  69,  58, 187, 196, 122,   5, 132, 251, 199, 184,  57,  70, 248, 135,   6, 121, 185, 198,  71,  56, 134, 249, 120,   7,
 118,   9, 136, 247,  73,  54, 183, 200,   8, 119, 246, 137,  55,  72, 201, 182, 138, 245, 116,  11, 181, 202,  75,  52, 244, 139,  10, 117, 203, 180,  53,  74,
  77,  50, 179, 204, 114,  13, 140, 243,  51,  76, 205, 178,  12, 115, 242, 141, 177, 206,  79,  48, 142, 241, 112,  15, 207, 176,  49,  78, 240, 143,  14, 113,
 236, 147,  18, 109, 211, 172,  45,  82, 146, 237, 108,  19, 173, 210,  83,  44,  16, 111, 238, 145,  47,  80, 209, 174, 110,  17, 144, 239,  81,  46, 175, 208,
 215, 168,  41,  86, 232, 151,  22, 105, 169, 214,  87,  40, 150, 233, 104,  23,  43,  84, 213, 170,  20, 107, 234, 149,  85,  42, 171, 212, 106,  21, 148, 235,
 154, 229, 100,  27, 165, 218,  91,  36, 228, 155,  26, 101, 219, 164,  37,  90, 102,  25, 152, 231,  89,  38, 167, 216,  24, 103, 230, 153,  39,  88, 217, 166,
 161, 222,  95,  32, 158, 225,  96,  31, 223, 160,  33,  94, 224, 159,  30,  97,  93,  34, 163, 220,  98,  29, 156, 227,  35,  92, 221, 162,  28,  99, 226, 157},

{  0, 128, 195,  67,  69, 197, 134,   6, 138,  10,  73, 201, 207,  79,  12, 140, 215,  87,  20, 148, 146,  18,  81, 209,  93, 221, 158,  30,  24, 152, 219,  91,
 109, 237, 174,  46,  40, 168, 235, 107, 231, 103,  36, 164, 162,  34,  97, 225, 186,  58, 121, 249, 255, 127,  60, 188,  48, 176, 243, 115, 117, 245, 182,  54,
 218,  90,  25, 153, 159,  31,  92, 220,  80, 208, 147,  19,  21, 149, 214,  86,  13, 141, 206,  78,  72, 200, 139,  11, 135,   7,  68, 196, 194,  66,   1, 129,
 183,  55, 116, 244, 242, 114,  49, 177,  61, 189, 254, 126, 120, 248, 187,  59,  96, 224, 163,  35,  37, 165, 230, 102, 234, 106,  41, 169, 175,  47, 108, 236,
 119, 247, 180,  52,  50, 178, 241, 113, 253, 125,  62, 190, 184,  56, 123, 251, 160,  32,  99, 227, 229, 101,  38, 166,  42, 170, 233, 105, 111, 239, 172,  44,
  26, 154, 217,  89,  95, 223, 156,  28, 144,  16,  83, 211, 213,  85,  22, 150, 205,  77,  14, 142, 136,   8,  75, 203,  71, 199, 132,   4,   2, 130, 193,  65,
 173,  45, 110, 238, 232, 104,  43, 171,  39, 167, 228, 100,  98, 226, 161,  33, 122, 250, 185,  57,  63, 191, 252, 124, 240, 112,  51, 179, 181,  53, 118, 246,
 192,  64,   3, 131, 133,   5,  70, 198,  74, 202, 137,   9,  15, 143, 204,  76,  23, 151, 212,  84,  82, 210, 145,  17, 157,  29,  94, 222, 216,  88,  27, 155},

{  0, 129, 193,  64,  65, 192, 128,   1, 130,   3,  67, 194, 195,  66,   2, 131, 199,  70,   6, 135, 134,   7,  71, 198,  69, 196, 132,   5,   4, 133, 197,  68,
  77, 204, 140,  13,  12, 141, 205,  76, 207,  78,  14, 143, 142,  15,  79, 206, 138,  11,  75, 202, 203,  74,  10, 139,   8, 137, 201,  72,  73, 200, 136,   9,
 154,  27,  91, 218, 219,  90,  26, 155,  24, 153, 217,  88,  89, 216, 152,  25,  93, 220, 156,  29,  28, 157, 221,  92, 223,  94,  30, 159, 158,  31,  95, 222,
 215,  86,  22, 151, 150,  23,  87, 214,  85, 212, 148,  21,  20, 149, 213,  84,  16, 145, 209,  80,  81, 208, 144,  17, 146,  19,  83, 210, 211,  82,  18, 147,
 247, 118,  54, 183, 182,  55, 119, 246, 117, 244, 180,  53,  52, 181, 245, 116,  48, 177, 241, 112, 113, 240, 176,  49, 178,  51, 115, 242, 243, 114,  50, 179,
 186,  59, 123, 250, 251, 122,  58, 187,  56, 185, 249, 120, 121, 248, 184,  57, 125, 252, 188,  61,  60, 189, 253, 124, 255, 126,  62, 191, 190,  63, 127, 254,
 109, 236, 172,  45,  44, 173, 237, 108, 239, 110,  46, 175, 174,  47, 111, 238, 170,  43, 107, 234, 235, 106,  42, 171,  40, 169, 233, 104, 105, 232, 168,  41,
  32, 161, 225,  96,  97, 224, 160,  33, 162,  35,  99, 226, 227,  98,  34, 163, 231, 102,  38, 167, 166,  39, 103, 230, 101, 228, 164,  37,  36, 165, 229, 100},

{  0, 130, 199,  69,  77, 207, 138,   8, 154,  24,  93, 223, 215,  85,  16, 146, 247, 117,  48, 178, 186,  56, 125, 255, 109, 239, 170,  40,  32, 162, 231, 101,
  45, 175, 234, 104,  96, 226, 167,  37, 183,  53, 112, 242, 250, 120,  61, 191, 218,  88,  29, 159, 151,  21,  80, 210,  64, 194, 135,   5,  13, 143, 202,  72,
  90, 216, 157,  31,  23, 149, 208,  82, 192,  66,   7, 133, 141,  15,  74, 200, 173,  47, 106, 232, 224,  98,  39, 165,  55, 181, 240, 114, 122, 248, 189,  63,
 119, 245, 176,  50,  58, 184, 253, 127, 237, 111,  42, 168, 160,  34, 103, 229, 128,   2,  71, 197, 205,  79,  10, 136,  26, 152, 221,  95,  87, 213, 144,  18,
 180,  54, 115, 241, 249, 123,  62, 188,  46, 172, 233, 107,  99, 225, 164,  38,  67, 193, 132,   6,  14, 140, 201,  75, 217,  91,  30, 156, 148,  22,  83, 209,
 153,  27,  94, 220, 212,  86,  19, 145,   3, 129, 196,  70,  78, 204, 137,  11, 110, 236, 169,  43,  35, 161, 228, 102, 244, 118,  51, 177, 185,  59, 126, 252,
 238, 108,  41, 171, 163,  33, 100, 230, 116, 246, 179,  49,  57, 187, 254, 124,  25, 155, 222,  92,  84, 214, 147,  17, 131,   1,  68, 198, 206,  76,   9, 139,
 195,  65,   4, 134, 142,  12,  73, 203,  89, 219, 158,  28,  20, 150, 211,  81,  52, 182, 243, 113, 121, 251, 190,  60, 174,  44, 105, 235, 227,  97,  36, 166},

{  0, 131, 197,  70,  73, 202, 140,  15, 146,  17,  87, 212, 219,  88,  30, 157, 231, 100,  34, 161, 174,  45, 107, 232, 117, 246, 176,  51,  60, 191, 249, 122,
  13, 142, 200,  75,  68, 199, 129,   2, 159,  28,  90, 217, 214,  85,  19, 144, 234, 105,  47, 172, 163,  32, 102, 229, 120, 251, 189,  62,  49, 178, 244, 119,
  26, 153, 223,  92,  83, 208, 150,  21, 136,  11,  77, 206, 193,  66,   4, 135, 253, 126,  56, 187, 180,  55, 113, 242, 111, 236, 170,  41,  38, 165, 227,  96,
  23, 148, 210,  81,  94, 221, 155,  24, 133,   6,  64, 195, 204,  79,   9, 138, 240, 115,  53, 182, 185,  58, 124, 255,  98, 225, 167,  36,  43, 168, 238, 109,
  52, 183, 241, 114, 125, 254, 184,  59, 166,  37,  99, 224, 239, 108,  42, 169, 211,  80,  22, 149, 154,  25,  95, 220,  65, 194, 132,   7,   8, 139, 205,  78,
  57, 186, 252, 127, 112, 243, 181,  54, 171,  40, 110, 237, 226,  97,  39, 164, 222,  93,  27, 152, 151,  20,  82, 209,  76, 207, 137,  10,   5, 134, 192,  67,
  46, 173, 235, 104, 103, 228, 162,  33, 188,  63, 121, 250, 245, 118,  48, 179, 201,  74,  12, 143, 128,   3,  69, 198,  91, 216, 158,  29,  18, 145, 215,  84,
  35, 160, 230, 101, 106, 233, 175,  44, 177,  50, 116, 247, 248, 123,  61, 190, 196,  71,   1, 130, 141,  14,  72, 203,  86, 213, 147,  16,  31, 156, 218,  89},

{  0, 132, 203,  79,  85, 209, 158,  26, 170,  46,  97, 229, 255, 123,  52, 176, 151,  19,  92, 216, 194,  70,   9, 141,  61, 185, 246, 114, 104, 236, 163,  39,
 237, 105,  38, 162, 184,  60, 115, 247,  71, 195, 140,   8,  18, 150, 217,  93, 122, 254, 177,  53,  47, 171, 228,  96, 208,  84,  27, 159, 133,   1,  78, 202,
  25, 157, 210,  86,  76, 200, 135,   3, 179,  55, 120, 252, 230,  98,  45, 169, 142,  10,  69, 193, 219,  95,  16, 148,  36, 160, 239, 107, 113, 245, 186,  62,
 244, 112,  63, 187, 161,  37, 106, 238,  94, 218, 149,  17,  11, 143, 192,  68,  99, 231, 168,  44,  54, 178, 253, 121, 201,  77,   2, 134, 156,  24,  87, 211,
  50, 182, 249, 125, 103, 227, 172,  40, 152,  28,  83, 215, 205,  73,   6, 130, 165,  33, 110, 234, 240, 116,  59, 191,  15, 139, 196,  64,  90, 222, 145,  21,
 223,  91,  20, 144, 138,  14,  65, 197, 117, 241, 190,  58,  32, 164, 235, 111,  72, 204, 131,   7,  29, 153, 214,  82, 226, 102,  41, 173, 183,  51, 124, 248,
  43, 175, 224, 100, 126, 250, 181,  49, 129,   5,  74, 206, 212,  80,  31, 155, 188,  56, 119, 243, 233, 109,  34, 166,  22, 146, 221,  89,  67, 199, 136,  12,
 198,  66,  13, 137, 147,  23,  88, 220, 108, 232, 167,  35,  57, 189, 242, 118,  81, 213, 154,  30,   4, 128, 207,  75, 251, 127,  48, 180, 174,  42, 101, 225},

{  0, 133, 201,  76,  81, 212, 152,  29, 162,  39, 107, 238, 243, 118,  58, 191, 135,   2,  78, 203, 214,  83,  31, 154,  37, 160, 236, 105, 116, 241, 189,  56,
 205,  72,   4, 129, 156,  25,  85, 208, 111, 234, 166,  35,  62, 187, 247, 114,  74, 207, 131,   6,  27, 158, 210,  87, 232, 109,  33, 164, 185,  60, 112, 245,
  89, 220, 144,  21,   8, 141, 193,  68, 251, 126,  50, 183, 170,  47,  99, 230, 222,  91,  23, 146, 143,  10,  70, 195, 124, 249, 181,  48,  45, 168, 228,  97,
 148,  17,  93, 216, 197,  64,  12, 137,  54, 179, 255, 122, 103, 226, 174,  43,  19, 150, 218,  95,  66, 199, 139,  14, 177,  52, 120, 253, 224, 101,  41, 172,
 178,  55, 123, 254, 227, 102,  42, 175,  16, 149, 217,  92,  65, 196, 136,  13,  53, 176, 252, 121, 100, 225, 173,  40, 151,  18,  94, 219, 198,  67,  15, 138,
 127, 250, 182,  51,  46, 171, 231,  98, 221,  88,  20, 145, 140,   9,  69, 192, 248, 125,  49, 180, 169,  44,  96, 229,  90, 223, 147,  22,  11, 142, 194,  71,
 235, 110,  34, 167, 186,  63, 115, 246,  73, 204, 128,   5,  24, 157, 209,  84, 108, 233, 165,  32,  61, 184, 244, 113, 206,  75,   7, 130, 159,  26,  86, 211,
  38, 163, 239, 106, 119, 242, 190,  59, 132,   1,  77, 200, 213,  80,  28, 153, 161,  36, 104, 237, 240, 117,  57, 188,   3, 134, 202,  79,  82, 215, 155,  30},

{  0, 134, 207,  73,  93, 219, 146,  20, 186,  60, 117, 243, 231,  97,  40, 174, 183,  49, 120, 254, 234, 108,  37, 163,  13, 139, 194,  68,  80, 214, 159,  25,
 173,  43,  98, 228, 240, 118,  63, 185,  23, 145, 216,  94,  74, 204, 133,   3,  26, 156, 213,  83,  71, 193, 136,  14, 160,  38, 111, 233, 253, 123,  50, 180,
 153,  31,  86, 208, 196,  66,  11, 141,  35, 165, 236, 106, 126, 248, 177,  55,  46, 168, 225, 103, 115, 245, 188,  58, 148,  18,  91, 221, 201,  79,   6, 128,
  52, 178, 251, 125, 105, 239, 166,  32, 142,   8,  65, 199, 211,  85,  28, 154, 131,   5,  76, 202, 222,  88,  17, 151,  57, 191, 246, 112, 100, 226, 171,  45,
 241, 119,  62, 184, 172,  42,  99, 229,  75, 205, 132,   2,  22, 144, 217,  95,  70, 192, 137,  15,  27, 157, 212,  82, 252, 122,  51, 181, 161,  39, 110, 232,
  92, 218, 147,  21,   1, 135, 206,  72, 230,  96,  41, 175, 187,  61, 116, 242, 235, 109,  36, 162, 182,  48, 121, 255,  81, 215, 158,  24,  12, 138, 195,  69,
 104, 238, 167,  33,  53, 179, 250, 124, 210,  84,  29, 155, 143,   9,  64, 198, 223,  89,  16, 150, 130,   4,  77, 203, 101, 227, 170,  44,  56, 190, 247, 113,
 197,  67,  10, 140, 152,  30,  87, 209, 127, 249, 176,  54,  34, 164, 237, 107, 114, 244, 189,  59,  47, 169, 224, 102, 200,  78,   7, 129, 149,  19,  90, 220},

{  0, 135, 205,  74,  89, 222, 148,  19, 178,  53, 127, 248, 235, 108,  38, 161, 167,  32, 106, 237, 254, 121,  51, 180,  21, 146, 216,  95,  76, 203, 129,   6,
 141,  10,  64, 199, 212,  83,  25, 158,  63, 184, 242, 117, 102, 225, 171,  44,  42, 173, 231,  96, 115, 244, 190,  57, 152,  31,  85, 210, 193,  70,  12, 139,
 217,  94,  20, 147, 128,   7,  77, 202, 107, 236, 166,  33,  50, 181, 255, 120, 126, 249, 179,  52,  39, 160, 234, 109, 204,  75,   1, 134, 149,  18,  88, 223,
  84, 211, 153,  30,  13, 138, 192,  71, 230,  97,  43, 172, 191,  56, 114, 245, 243, 116,  62, 185, 170,  45, 103, 224,  65, 198, 140,  11,  24, 159, 213,  82,
 113, 246, 188,  59,  40, 175, 229,  98, 195,  68,  14, 137, 154,  29,  87, 208, 214,  81,  27, 156, 143,   8,  66, 197, 100, 227, 169,  46,  61, 186, 240, 119,
 252, 123,  49, 182, 165,  34, 104, 239,  78, 201, 131,   4,  23, 144, 218,  93,  91, 220, 150,  17,   2, 133, 207,  72, 233, 110,  36, 163, 176,  55, 125, 250,
 168,  47, 101, 226, 241, 118,  60, 187,  26, 157, 215,  80,  67, 196, 142,   9,  15, 136, 194,  69,  86, 209, 155,  28, 189,  58, 112, 247, 228,  99,  41, 174,
  37, 162, 232, 111, 124, 251, 177,  54, 151,  16,  90, 221, 206,  73,   3, 132, 130,   5,  79, 200, 219,  92,  22, 145,  48, 183, 253, 122, 105, 238, 164,  35},

{  0, 136, 211,  91, 101, 237, 182,  62, 202,  66,  25, 145, 175,  39, 124, 244,  87, 223, 132,  12,  50, 186, 225, 105, 157,  21,  78, 198, 248, 112,  43, 163,
 174,  38, 125, 245, 203,  67,  24, 144, 100, 236, 183,  63,   1, 137, 210,  90, 249, 113,  42, 162, 156,  20,  79, 199,  51, 187, 224, 104,  86, 222, 133,  13,
 159,  23,  76, 196, 250, 114,  41, 161,  85, 221, 134,  14,  48, 184, 227, 107, 200,  64,  27, 147, 173,  37, 126, 246,   2, 138, 209,  89, 103, 239, 180,  60,
  49, 185, 226, 106,  84, 220, 135,  15, 251, 115,  40, 160, 158,  22,  77, 197, 102, 238, 181,  61,   3, 139, 208,  88, 172,  36, 127, 247, 201,  65,  26, 146,
 253, 117,  46, 166, 152,  16,  75, 195,  55, 191, 228, 108,  82, 218, 129,   9, 170,  34, 121, 241, 207,  71,  28, 148,  96, 232, 179,  59,   5, 141, 214,  94,
  83, 219, 128,   8,  54, 190, 229, 109, 153,  17,  74, 194, 252, 116,  47, 167,   4, 140, 215,  95,  97, 233, 178,  58, 206,  70,  29, 149, 171,  35, 120, 240,
  98, 234, 177,  57,   7, 143, 212,  92, 168,  32, 123, 243, 205,  69,  30, 150,  53, 189, 230, 110,  80, 216, 131,  11, 255, 119,  44, 164, 154,  18,  73, 193,
 204,  68,  31, 151, 169,  33, 122, 242,   6, 142, 213,  93,  99, 235, 176,  56, 155,  19,  72, 192, 254, 118,  45, 165,  81, 217, 130,  10,  52, 188, 231, 111},

{  0, 137, 209,  88,  97, 232, 176,  57, 194,  75,  19, 154, 163,  42, 114, 251,  71, 206, 150,  31,  38, 175, 247, 126, 133,  12,  84, 221, 228, 109,  53, 188,
 142,   7,  95, 214, 239, 102,  62, 183,  76, 197, 157,  20,  45, 164, 252, 117, 201,  64,  24, 145, 168,  33, 121, 240,  11, 130, 218,  83, 106, 227, 187,  50,
 223,  86,  14, 135, 190,  55, 111, 230,  29, 148, 204,  69, 124, 245, 173,  36, 152,  17,  73, 192, 249, 112,  40, 161,  90, 211, 139,   2,  59, 178, 234,  99,
  81, 216, 128,   9,  48, 185, 225, 104, 147,  26,  66, 203, 242, 123,  35, 170,  22, 159, 199,  78, 119, 254, 166,  47, 212,  93,   5, 140, 181,  60, 100, 237,
 125, 244, 172,  37,  28, 149, 205,  68, 191,  54, 110, 231, 222,  87,  15, 134,  58, 179, 235,  98,  91, 210, 138,   3, 248, 113,  41, 160, 153,  16,  72, 193,
 243, 122,  34, 171, 146,  27,  67, 202,  49, 184, 224, 105,  80, 217, 129,   8, 180,  61, 101, 236, 213,  92,   4, 141, 118, 255, 167,  46,  23, 158, 198,  79,
 162,  43, 115, 250, 195,  74,  18, 155,  96, 233, 177,  56,   1, 136, 208,  89, 229, 108,  52, 189, 132,  13,  85, 220,  39, 174, 246, 127,  70, 207, 151,  30,
  44, 165, 253, 116,  77, 196, 156,  21, 238, 103,  63, 182, 143,   6,  94, 215, 107, 226, 186,  51,  10, 131, 219,  82, 169,  32, 120, 241, 200,  65,  25, 144},

{  0, 138, 215,  93, 109, 231, 186,  48, 218,  80,  13, 135, 183,  61,  96, 234, 119, 253, 160,  42,  26, 144, 205,  71, 173,  39, 122, 240, 192,  74,  23, 157,
 238, 100,  57, 179, 131,   9,  84, 222,  52, 190, 227, 105,  89, 211, 142,   4, 153,  19,  78, 196, 244, 126,  35, 169,  67, 201, 148,  30,  46, 164, 249, 115,
  31, 149, 200,  66, 114, 248, 165,  47, 197,  79,  18, 152, 168,  34, 127, 245, 104, 226, 191,  53,   5, 143, 210,  88, 178,  56, 101, 239, 223,  85,   8, 130,
 241, 123,  38, 172, 156,  22,  75, 193,  43, 161, 252, 118,  70, 204, 145,  27, 134,  12,  81, 219, 235,  97,  60, 182,  92, 214, 139,   1,  49, 187, 230, 108,
  62, 180, 233,  99,  83, 217, 132,  14, 228, 110,  51, 185, 137,   3,  94, 212,  73, 195, 158,  20,  36, 174, 243, 121, 147,  25,  68, 206, 254, 116,  41, 163,
 208,  90,   7, 141, 189,  55, 106, 224,  10, 128, 221,  87, 103, 237, 176,  58, 167,  45, 112, 250, 202,  64,  29, 151, 125, 247, 170,  32,  16, 154, 199,  77,
  33, 171, 246, 124,  76, 198, 155,  17, 251, 113,  44, 166, 150,  28,  65, 203,  86, 220, 129,  11,  59, 177, 236, 102, 140,   6,  91, 209, 225, 107,  54, 188,
 207,  69,  24, 146, 162,  40, 117, 255,  21, 159, 194,  72, 120, 242, 175,  37, 184,  50, 111, 229, 213,  95,   2, 136,  98, 232, 181,  63,  15, 133, 216,  82},

{  0, 139, 213,  94, 105, 226, 188,  55, 210,  89,   7, 140, 187,  48, 110, 229, 103, 236, 178,  57,  14, 133, 219,  80, 181,  62,  96, 235, 220,  87,   9, 130,
 206,  69,  27, 144, 167,  44, 114, 249,  28, 151, 201,  66, 117, 254, 160,  43, 169,  34, 124, 247, 192,  75,  21, 158, 123, 240, 174,  37,  18, 153, 199,  76,
  95, 212, 138,   1,  54, 189, 227, 104, 141,   6,  88, 211, 228, 111,  49, 186,  56, 179, 237, 102,  81, 218, 132,  15, 234,  97,  63, 180, 131,   8,  86, 221,
 145,  26,  68, 207, 248, 115,  45, 166,  67, 200, 150,  29,  42, 161, 255, 116, 246, 125,  35, 168, 159,  20,  74, 193,  36, 175, 241, 122,  77, 198, 152,  19,
 190,  53, 107, 224, 215,  92,   2, 137, 108, 231, 185,  50,   5, 142, 208,  91, 217,  82,  12, 135, 176,  59, 101, 238,  11, 128, 222,  85,  98, 233, 183,  60,
 112, 251, 165,  46,  25, 146, 204,  71, 162,  41, 119, 252, 203,  64,  30, 149,  23, 156, 194,  73, 126, 245, 171,  32, 197,  78,  16, 155, 172,  39, 121, 242,
 225, 106,  52, 191, 136,   3,  93, 214,  51, 184, 230, 109,  90, 209, 143,   4, 134,  13,  83, 216, 239, 100,  58, 177,  84, 223, 129,  10,  61, 182, 232,  99,
  47, 164, 250, 113,  70, 205, 147,  24, 253, 118,  40, 163, 148,  31,  65, 202,  72, 195, 157,  22,  33, 170, 244, 127, 154,  17,  79, 196, 243, 120,  38, 173},

{  0, 140, 219,  87, 117, 249, 174,  34, 234, 102,  49, 189, 159,  19,  68, 200,  23, 155, 204,  64,  98, 238, 185,  53, 253, 113,  38, 170, 136,   4,  83, 223,
  46, 162, 245, 121,  91, 215, 128,  12, 196,  72,  31, 147, 177,  61, 106, 230,  57, 181, 226, 110,  76, 192, 151,  27, 211,  95,   8, 132, 166,  42, 125, 241,
  92, 208, 135,  11,  41, 165, 242, 126, 182,  58, 109, 225, 195,  79,  24, 148,  75, 199, 144,  28,  62, 178, 229, 105, 161,  45, 122, 246, 212,  88,  15, 131,
 114, 254, 169,  37,   7, 139, 220,  80, 152,  20,  67, 207, 237,  97,  54, 186, 101, 233, 190,  50,  16, 156, 203,  71, 143,   3,  84, 216, 250, 118,  33, 173,
 184,  52,  99, 239, 205,  65,  22, 154,  82, 222, 137,   5,  39, 171, 252, 112, 175,  35, 116, 248, 218,  86,   1, 141,  69, 201, 158,  18,  48, 188, 235, 103,
 150,  26,  77, 193, 227, 111,  56, 180, 124, 240, 167,  43,   9, 133, 210,  94, 129,  13,  90, 214, 244, 120,  47, 163, 107, 231, 176,  60,  30, 146, 197,  73,
 228, 104,  63, 179, 145,  29,  74, 198,  14, 130, 213,  89, 123, 247, 160,  44, 243, 127,  40, 164, 134,  10,  93, 209,  25, 149, 194,  78, 108, 224, 183,  59,
 202,  70,  17, 157, 191,  51, 100, 232,  32, 172, 251, 119,  85, 217, 142,   2, 221,  81,   6, 138, 168,  36, 115, 255,  55, 187, 236,  96,  66, 206, 153,  21},

{  0, 141, 217,  84, 113, 252, 168,  37, 226, 111,  59, 182, 147,  30,  74, 199,   7, 138, 222,  83, 118, 251, 175,  34, 229, 104,  60, 177, 148,  25,  77, 192,
  14, 131, 215,  90, 127, 242, 166,  43, 236,  97,  53, 184, 157,  16,  68, 201,   9, 132, 208,  93, 120, 245, 161,  44, 235, 102,  50, 191, 154,  23,  67, 206,
  28, 145, 197,  72, 109, 224, 180,  57, 254, 115,  39, 170, 143,   2,  86, 219,  27, 150, 194,  79, 106, 231, 179,  62, 249, 116,  32, 173, 136,   5,  81, 220,
  18, 159, 203,  70,  99, 238, 186,  55, 240, 125,  41, 164, 129,  12,  88, 213,  21, 152, 204,  65, 100, 233, 189,  48, 247, 122,  46, 163, 134,  11,  95, 210,
  56, 181, 225, 108,  73, 196, 144,  29, 218,  87,   3, 142, 171,  38, 114, 255,  63, 178, 230, 107,  78, 195, 151,  26, 221,  80,   4, 137, 172,  33, 117, 248,
  54, 187, 239,  98,  71, 202, 158,  19, 212,  89,  13, 128, 165,  40, 124, 241,  49, 188, 232, 101,  64, 205, 153,  20, 211,  94,  10, 135, 162,  47, 123, 246,
  36, 169, 253, 112,  85, 216, 140,   1, 198,  75,  31, 146, 183,  58, 110, 227,  35, 174, 250, 119,  82, 223, 139,   6, 193,  76,  24, 149, 176,  61, 105, 228,
  42, 167, 243, 126,  91, 214, 130,  15, 200,  69,  17, 156, 185,  52,  96, 237,  45, 160, 244, 121,  92, 209, 133,   8, 207,  66,  22, 155, 190,  51, 103, 234},

{  0, 142, 223,  81, 125, 243, 162,  44, 250, 116,  37, 171, 135,   9,  88, 214,  55, 185, 232, 102,  74, 196, 149,  27, 205,  67,  18, 156, 176,  62, 111, 225,
 110, 224, 177,  63,  19, 157, 204,  66, 148,  26,  75, 197, 233, 103,  54, 184,  89, 215, 134,   8,  36, 170, 251, 117, 163,  45, 124, 242, 222,  80,   1, 143,
 220,  82,   3, 141, 161,  47, 126, 240,  38, 168, 249, 119,  91, 213, 132,  10, 235, 101,  52, 186, 150,  24,  73, 199,  17, 159, 206,  64, 108, 226, 179,  61,
 178,  60, 109, 227, 207,  65,  16, 158,  72, 198, 151,  25,  53, 187, 234, 100, 133,  11,  90, 212, 248, 118,  39, 169, 127, 241, 160,  46,   2, 140, 221,  83,
 123, 245, 164,  42,   6, 136, 217,  87, 129,  15,  94, 208, 252, 114,  35, 173,  76, 194, 147,  29,  49, 191, 238,  96, 182,  56, 105, 231, 203,  69,  20, 154,
  21, 155, 202,  68, 104, 230, 183,  57, 239,  97,  48, 190, 146,  28,  77, 195,  34, 172, 253, 115,  95, 209, 128,  14, 216,  86,   7, 137, 165,  43, 122, 244,
 167,  41, 120, 246, 218,  84,   5, 139,  93, 211, 130,  12,  32, 174, 255, 113, 144,  30,  79, 193, 237,  99,  50, 188, 106, 228, 181,  59,  23, 153, 200,  70,
 201,  71,  22, 152, 180,  58, 107, 229,  51, 189, 236,  98,  78, 192, 145,  31, 254, 112,  33, 175, 131,  13,  92, 210,   4, 138, 219,  85, 121, 247, 166,  40},

{  0, 143, 221,  82, 121, 246, 164,  43, 242, 125,  47, 160, 139,   4,  86, 217,  39, 168, 250, 117,  94, 209, 131,  12, 213,  90,   8, 135, 172,  35, 113, 254,
  78, 193, 147,  28,  55, 184, 234, 101, 188,  51,  97, 238, 197,  74,  24, 151, 105, 230, 180,  59,  16, 159, 205,  66, 155,  20,  70, 201, 226, 109,  63, 176,
 156,  19,  65, 206, 229, 106,  56, 183, 110, 225, 179,  60,  23, 152, 202,  69, 187,  52, 102, 233, 194,  77,  31, 144,  73, 198, 148,  27,  48, 191, 237,  98,
 210,  93,  15, 128, 171,  36, 118, 249,  32, 175, 253, 114,  89, 214, 132,  11, 245, 122,  40, 167, 140,   3,  81, 222,   7, 136, 218,  85, 126, 241, 163,  44,
 251, 116,  38, 169, 130,  13,  95, 208,   9, 134, 212,  91, 112, 255, 173,  34, 220,  83,   1, 142, 165,  42, 120, 247,  46, 161, 243, 124,  87, 216, 138,   5,
 181,  58, 104, 231, 204,  67,  17, 158,  71, 200, 154,  21,  62, 177, 227, 108, 146,  29,  79, 192, 235, 100,  54, 185,  96, 239, 189,  50,  25, 150, 196,  75,
 103, 232, 186,  53,  30, 145, 195,  76, 149,  26,  72, 199, 236,  99,  49, 190,  64, 207, 157,  18,  57, 182, 228, 107, 178,  61, 111, 224, 203,  68,  22, 153,
  41, 166, 244, 123,  80, 223, 141,   2, 219,  84,   6, 137, 162,  45, 127, 240,  14, 129, 211,  92, 119, 248, 170,  37, 252, 115,  33, 174, 133,  10,  88, 215},

{  0, 144, 227, 115,   5, 149, 230, 118,  10, 154, 233, 121,  15, 159, 236, 124,  20, 132, 247, 103,  17, 129, 242,  98,  30, 142, 253, 109,  27, 139, 248, 104,
  40, 184, 203,  91,  45, 189, 206,  94,  34, 178, 193,  81,  39, 183, 196,  84,  60, 172, 223,  79,  57, 169, 218,  74,  54, 166, 213,  69,  51, 163, 208,  64,
  80, 192, 179,  35,  85, 197, 182,  38,  90, 202, 185,  41,  95, 207, 188,  44,  68, 212, 167,  55,  65, 209, 162,  50,  78, 222, 173,  61,  75, 219, 168,  56,
 120, 232, 155,  11, 125, 237, 158,  14, 114, 226, 145,   1, 119, 231, 148,   4, 108, 252, 143,  31, 105, 249, 138,  26, 102, 246, 133,  21,  99, 243, 128,  16,
 160,  48,  67, 211, 165,  53,  70, 214, 170,  58,  73, 217, 175,  63,  76, 220, 180,  36,  87, 199, 177,  33,  82, 194, 190,  46,  93, 205, 187,  43,  88, 200,
 136,  24, 107, 251, 141,  29, 110, 254, 130,  18,  97, 241, 135,  23, 100, 244, 156,  12, 127, 239, 153,   9, 122, 234, 150,   6, 117, 229, 147,   3, 112, 224,
 240,  96,  19, 131, 245, 101,  22, 134, 250, 106,  25, 137, 255, 111,  28, 140, 228, 116,   7, 151, 225, 113,   2, 146, 238, 126,  13, 157, 235, 123,   8, 152,
 216,  72,  59, 171, 221,  77,  62, 174, 210,  66,  49, 161, 215,  71,  52, 164, 204,  92,  47, 191, 201,  89,  42, 186, 198,  86,  37, 181, 195,  83,  32, 176},

{  0, 145, 225, 112,   1, 144, 224, 113,   2, 147, 227, 114,   3, 146, 226, 115,   4, 149, 229, 116,   5, 148, 228, 117,   6, 151, 231, 118,   7, 150, 230, 119,
   8, 153, 233, 120,   9, 152, 232, 121,  10, 155, 235, 122,  11, 154, 234, 123,  12, 157, 237, 124,  13, 156, 236, 125,  14, 159, 239, 126,  15, 158, 238, 127,
  16, 129, 241,  96,  17, 128, 240,  97,  18, 131, 243,  98,  19, 130, 242,  99,  20, 133, 245, 100,  21, 132, 244, 101,  22, 135, 247, 102,  23, 134, 246, 103,
  24, 137, 249, 104,  25, 136, 248, 105,  26, 139, 251, 106,  27, 138, 250, 107,  28, 141, 253, 108,  29, 140, 252, 109,  30, 143, 255, 110,  31, 142, 254, 111,
  32, 177, 193,  80,  33, 176, 192,  81,  34, 179, 195,  82,  35, 178, 194,  83,  36, 181, 197,  84,  37, 180, 196,  85,  38, 183, 199,  86,  39, 182, 198,  87,
  40, 185, 201,  88,  41, 184, 200,  89,  42, 187, 203,  90,  43, 186, 202,  91,  44, 189, 205,  92,  45, 188, 204,  93,  46, 191, 207,  94,  47, 190, 206,  95,
  48, 161, 209,  64,  49, 160, 208,  65,  50, 163, 211,  66,  51, 162, 210,  67,  52, 165, 213,  68,  53, 164, 212,  69,  54, 167, 215,  70,  55, 166, 214,  71,
  56, 169, 217,  72,  57, 168, 216,  73,  58, 171, 219,  74,  59, 170, 218,  75,  60, 173, 221,  76,  61, 172, 220,  77,  62, 175, 223,  78,  63, 174, 222,  79},

{  0, 146, 231, 117,  13, 159, 234, 120,  26, 136, 253, 111,  23, 133, 240,  98,  52, 166, 211,  65,  57, 171, 222,  76,  46, 188, 201,  91,  35, 177, 196,  86,
 104, 250, 143,  29, 101, 247, 130,  16, 114, 224, 149,   7, 127, 237, 152,  10,  92, 206, 187,  41,  81, 195, 182,  36,  70, 212, 161,  51,  75, 217, 172,  62,
 208,  66,  55, 165, 221,  79,  58, 168, 202,  88,  45, 191, 199,  85,  32, 178, 228, 118,   3, 145, 233, 123,  14, 156, 254, 108,  25, 139, 243,  97,  20, 134,
 184,  42,  95, 205, 181,  39,  82, 192, 162,  48,  69, 215, 175,  61,  72, 218, 140,  30, 107, 249, 129,  19, 102, 244, 150,   4, 113, 227, 155,   9, 124, 238,
  99, 241, 132,  22, 110, 252, 137,  27, 121, 235, 158,  12, 116, 230, 147,   1,  87, 197, 176,  34,  90, 200, 189,  47,  77, 223, 170,  56,  64, 210, 167,  53,
  11, 153, 236, 126,   6, 148, 225, 115,  17, 131, 246, 100,  28, 142, 251, 105,  63, 173, 216,  74,  50, 160, 213,  71,  37, 183, 194,  80,  40, 186, 207,  93,
 179,  33,  84, 198, 190,  44,  89, 203, 169,  59,  78, 220, 164,  54,  67, 209, 135,  21,  96, 242, 138,  24, 109, 255, 157,  15, 122, 232, 144,   2, 119, 229,
 219,  73,  60, 174, 214,  68,  49, 163, 193,  83,  38, 180, 204,  94,  43, 185, 239, 125,   8, 154, 226, 112,   5, 151, 245, 103,  18, 128, 248, 106,  31, 141},

{  0, 147, 229, 118,   9, 154, 236, 127,  18, 129, 247, 100,  27, 136, 254, 109,  36, 183, 193,  82,  45, 190, 200,  91,  54, 165, 211,  64,  63, 172, 218,  73,
  72, 219, 173,  62,  65, 210, 164,  55,  90, 201, 191,  44,  83, 192, 182,  37, 108, 255, 137,  26, 101, 246, 128,  19, 126, 237, 155,   8, 119, 228, 146,   1,
 144,   3, 117, 230, 153,  10, 124, 239, 130,  17, 103, 244, 139,  24, 110, 253, 180,  39,  81, 194, 189,  46,  88, 203, 166,  53,  67, 208, 175,  60,  74, 217,
 216,  75,  61, 174, 209,  66,  52, 167, 202,  89,  47, 188, 195,  80,  38, 181, 252, 111,  25, 138, 245, 102,  16, 131, 238, 125,  11, 152, 231, 116,   2, 145,
 227, 112,   6, 149, 234, 121,  15, 156, 241,  98,  20, 135, 248, 107,  29, 142, 199,  84,  34, 177, 206,  93,  43, 184, 213,  70,  48, 163, 220,  79,  57, 170,
 171,  56,  78, 221, 162,  49,  71, 212, 185,  42,  92, 207, 176,  35,  85, 198, 143,  28, 106, 249, 134,  21,  99, 240, 157,  14, 120, 235, 148,   7, 113, 226,
 115, 224, 150,   5, 122, 233, 159,  12,  97, 242, 132,  23, 104, 251, 141,  30,  87, 196, 178,  33,  94, 205, 187,  40,  69, 214, 160,  51,  76, 223, 169,  58,
  59, 168, 222,  77,  50, 161, 215,  68,  41, 186, 204,  95,  32, 179, 197,  86,  31, 140, 250, 105,  22, 133, 243,  96,  13, 158, 232, 123,   4, 151, 225, 114},

{  0, 148, 235, 127,  21, 129, 254, 106,  42, 190, 193,  85,  63, 171, 212,  64,  84, 192, 191,  43,  65, 213, 170,  62, 126, 234, 149,   1, 107, 255, 128,  20,
 168,  60,  67, 215, 189,  41,  86, 194, 130,  22, 105, 253, 151,   3, 124, 232, 252, 104,  23, 131, 233, 125,   2, 150, 214,  66,  61, 169, 195,  87,  40, 188,
 147,   7, 120, 236, 134,  18, 109, 249, 185,  45,  82, 198, 172,  56,  71, 211, 199,  83,  44, 184, 210,  70,  57, 173, 237, 121,   6, 146, 248, 108,  19, 135,
  59, 175, 208,  68,  46, 186, 197,  81,  17, 133, 250, 110,   4, 144, 239, 123, 111, 251, 132,  16, 122, 238, 145,   5,  69, 209, 174,  58,  80, 196, 187,  47,
 229, 113,  14, 154, 240, 100,  27, 143, 207,  91,  36, 176, 218,  78,  49, 165, 177,  37,  90, 206, 164,  48,  79, 219, 155,  15, 112, 228, 142,  26, 101, 241,
  77, 217, 166,  50,  88, 204, 179,  39, 103, 243, 140,  24, 114, 230, 153,  13,  25, 141, 242, 102,  12, 152, 231, 115,  51, 167, 216,  76,  38, 178, 205,  89,
 118, 226, 157,   9,  99, 247, 136,  28,  92, 200, 183,  35,  73, 221, 162,  54,  34, 182, 201,  93,  55, 163, 220,  72,   8, 156, 227, 119,  29, 137, 246,  98,
 222,  74,  53, 161, 203,  95,  32, 180, 244,  96,  31, 139, 225, 117,  10, 158, 138,  30,  97, 245, 159,  11, 116, 224, 160,  52,  75, 223, 181,  33,  94, 202},

{  0, 149, 233, 124,  17, 132, 248, 109,  34, 183, 203,  94,  51, 166, 218,  79,  68, 209, 173,  56,  85, 192, 188,  41, 102, 243, 143,  26, 119, 226, 158,  11,
 136,  29,  97, 244, 153,  12, 112, 229, 170,  63,  67, 214, 187,  46,  82, 199, 204,  89,  37, 176, 221,  72,  52, 161, 238, 123,   7, 146, 255, 106,  22, 131,
 211,  70,  58, 175, 194,  87,  43, 190, 241, 100,  24, 141, 224, 117,   9, 156, 151,   2, 126, 235, 134,  19, 111, 250, 181,  32,  92, 201, 164,  49,  77, 216,
  91, 206, 178,  39,  74, 223, 163,  54, 121, 236, 144,   5, 104, 253, 129,  20,  31, 138, 246,  99,  14, 155, 231, 114,  61, 168, 212,  65,  44, 185, 197,  80,
 101, 240, 140,  25, 116, 225, 157,   8,  71, 210, 174,  59,  86, 195, 191,  42,  33, 180, 200,  93,  48, 165, 217,  76,   3, 150, 234, 127,  18, 135, 251, 110,
 237, 120,   4, 145, 252, 105,  21, 128, 207,  90,  38, 179, 222,  75,  55, 162, 169,  60,  64, 213, 184,  45,  81, 196, 139,  30,  98, 247, 154,  15, 115, 230,
 182,  35,  95, 202, 167,  50,  78, 219, 148,   1, 125, 232, 133,  16, 108, 249, 242, 103,  27, 142, 227, 118,  10, 159, 208,  69,  57, 172, 193,  84,  40, 189,
  62, 171, 215,  66,  47, 186, 198,  83,  28, 137, 245,  96,  13, 152, 228, 113, 122, 239, 147,   6, 107, 254, 130,  23,  88, 205, 177,  36,  73, 220, 160,  53},

{  0, 150, 239, 121,  29, 139, 242, 100,  58, 172, 213,  67,  39, 177, 200,  94, 116, 226, 155,  13, 105, 255, 134,  16,  78, 216, 161,  55,  83, 197, 188,  42,
 232, 126,   7, 145, 245,  99,  26, 140, 210,  68,  61, 171, 207,  89,  32, 182, 156,  10, 115, 229, 129,  23, 110, 248, 166,  48,  73, 223, 187,  45,  84, 194,
  19, 133, 252, 106,  14, 152, 225, 119,  41, 191, 198,  80,  52, 162, 219,  77, 103, 241, 136,  30, 122, 236, 149,   3,  93, 203, 178,  36,  64, 214, 175,  57,
 251, 109,  20, 130, 230, 112,   9, 159, 193,  87,  46, 184, 220,  74,  51, 165, 143,  25,  96, 246, 146,   4, 125, 235, 181,  35,  90, 204, 168,  62,  71, 209,
  38, 176, 201,  95,  59, 173, 212,  66,  28, 138, 243, 101,   1, 151, 238, 120,  82, 196, 189,  43,  79, 217, 160,  54, 104, 254, 135,  17, 117, 227, 154,  12,
 206,  88,  33, 183, 211,  69,  60, 170, 244,  98,  27, 141, 233, 127,   6, 144, 186,  44,  85, 195, 167,  49,  72, 222, 128,  22, 111, 249, 157,  11, 114, 228,
  53, 163, 218,  76,  40, 190, 199,  81,  15, 153, 224, 118,  18, 132, 253, 107,  65, 215, 174,  56,  92, 202, 179,  37, 123, 237, 148,   2, 102, 240, 137,  31,
 221,  75,  50, 164, 192,  86,  47, 185, 231, 113,   8, 158, 250, 108,  21, 131, 169,  63,  70, 208, 180,  34,  91, 205, 147,   5, 124, 234, 142,  24,  97, 247},

{  0, 151, 237, 122,  25, 142, 244,  99,  50, 165, 223,  72,  43, 188, 198,  81, 100, 243, 137,  30, 125, 234, 144,   7,  86, 193, 187,  44,  79, 216, 162,  53,
 200,  95,  37, 178, 209,  70,  60, 171, 250, 109,  23, 128, 227, 116,  14, 153, 172,  59,  65, 214, 181,  34,  88, 207, 158,   9, 115, 228, 135,  16, 106, 253,
  83, 196, 190,  41,  74, 221, 167,  48,  97, 246, 140,  27, 120, 239, 149,   2,  55, 160, 218,  77,  46, 185, 195,  84,   5, 146, 232, 127,  28, 139, 241, 102,
 155,  12, 118, 225, 130,  21, 111, 248, 169,  62,  68, 211, 176,  39,  93, 202, 255, 104,  18, 133, 230, 113,  11, 156, 205,  90,  32, 183, 212,  67,  57, 174,
 166,  49,  75, 220, 191,  40,  82, 197, 148,   3, 121, 238, 141,  26,  96, 247, 194,  85,  47, 184, 219,  76,  54, 161, 240, 103,  29, 138, 233, 126,   4, 147,
 110, 249, 131,  20, 119, 224, 154,  13,  92, 203, 177,  38,  69, 210, 168,  63,  10, 157, 231, 112,  19, 132, 254, 105,  56, 175, 213,  66,  33, 182, 204,  91,
 245,  98,  24, 143, 236, 123,   1, 150, 199,  80,  42, 189, 222,  73,  51, 164, 145,   6, 124, 235, 136,  31, 101, 242, 163,  52,  78, 217, 186,  45,  87, 192,
  61, 170, 208,  71,  36, 179, 201,  94,  15, 152, 226, 117,  22, 129, 251, 108,  89, 206, 180,  35,  64, 215, 173,  58, 107, 252, 134,  17, 114, 229, 159,   8},

{  0, 152, 243, 107,  37, 189, 214,  78,  74, 210, 185,  33, 111, 247, 156,   4, 148,  12, 103, 255, 177,  41,  66, 218, 222,  70,  45, 181, 251,  99,   8, 144,
 235, 115,  24, 128, 206,  86,  61, 165, 161,  57,  82, 202, 132,  28, 119, 239, 127, 231, 140,  20,  90, 194, 169,  49,  53, 173, 198,  94,  16, 136, 227, 123,
  21, 141, 230, 126,  48, 168, 195,  91,  95, 199, 172,  52, 122, 226, 137,  17, 129,  25, 114, 234, 164,  60,  87, 207, 203,  83,  56, 160, 238, 118,  29, 133,
 254, 102,  13, 149, 219,  67,  40, 176, 180,  44,  71, 223, 145,   9,  98, 250, 106, 242, 153,   1,  79, 215, 188,  36,  32, 184, 211,  75,   5, 157, 246, 110,
  42, 178, 217,  65,  15, 151, 252, 100,  96, 248, 147,  11,  69, 221, 182,  46, 190,  38,  77, 213, 155,   3, 104, 240, 244, 108,   7, 159, 209,  73,  34, 186,
 193,  89,  50, 170, 228, 124,  23, 143, 139,  19, 120, 224, 174,  54,  93, 197,  85, 205, 166,  62, 112, 232, 131,  27,  31, 135, 236, 116,  58, 162, 201,  81,
  63, 167, 204,  84,  26, 130, 233, 113, 117, 237, 134,  30,  80, 200, 163,  59, 171,  51,  88, 192, 142,  22, 125, 229, 225, 121,  18, 138, 196,  92,  55, 175,
 212,  76,  39, 191, 241, 105,   2, 154, 158,   6, 109, 245, 187,  35,  72, 208,  64, 216, 179,  43, 101, 253, 150,  14,  10, 146, 249,  97,  47, 183, 220,  68},

{  0, 153, 241, 104,  33, 184, 208,  73,  66, 219, 179,  42,  99, 250, 146,  11, 132,  29, 117, 236, 165,  60,  84, 205, 198,  95,  55, 174, 231, 126,  22, 143,
 203,  82,  58, 163, 234, 115,  27, 130, 137,  16, 120, 225, 168,  49,  89, 192,  79, 214, 190,  39, 110, 247, 159,   6,  13, 148, 252, 101,  44, 181, 221,  68,
  85, 204, 164,  61, 116, 237, 133,  28,  23, 142, 230, 127,  54, 175, 199,  94, 209,  72,  32, 185, 240, 105,   1, 152, 147,  10,  98, 251, 178,  43,  67, 218,
 158,   7, 111, 246, 191,  38,  78, 215, 220,  69,  45, 180, 253, 100,  12, 149,  26, 131, 235, 114,  59, 162, 202,  83,  88, 193, 169,  48, 121, 224, 136,  17,
 170,  51,  91, 194, 139,  18, 122, 227, 232, 113,  25, 128, 201,  80,  56, 161,  46, 183, 223,  70,  15, 150, 254, 103, 108, 245, 157,   4,  77, 212, 188,  37,
  97, 248, 144,   9,  64, 217, 177,  40,  35, 186, 210,  75,   2, 155, 243, 106, 229, 124,  20, 141, 196,  93,  53, 172, 167,  62,  86, 207, 134,  31, 119, 238,
 255, 102,  14, 151, 222,  71,  47, 182, 189,  36,  76, 213, 156,   5, 109, 244, 123, 226, 138,  19,  90, 195, 171,  50,  57, 160, 200,  81,  24, 129, 233, 112,
  52, 173, 197,  92,  21, 140, 228, 125, 118, 239, 135,  30,  87, 206, 166,  63, 176,  41,  65, 216, 145,   8,  96, 249, 242, 107,   3, 154, 211,  74,  34, 187},

{  0, 154, 247, 109,  45, 183, 218,  64,  90, 192, 173,  55, 119, 237, 128,  26, 180,  46,  67, 217, 153,   3, 110, 244, 238, 116,  25, 131, 195,  89,  52, 174,
 171,  49,  92, 198, 134,  28, 113, 235, 241, 107,   6, 156, 220,  70,  43, 177,  31, 133, 232, 114,  50, 168, 197,  95,  69, 223, 178,  40, 104, 242, 159,   5,
 149,  15,  98, 248, 184,  34,  79, 213, 207,  85,  56, 162, 226, 120,  21, 143,  33, 187, 214,  76,  12, 150, 251,  97, 123, 225, 140,  22,  86, 204, 161,  59,
  62, 164, 201,  83,  19, 137, 228, 126, 100, 254, 147,   9,  73, 211, 190,  36, 138,  16, 125, 231, 167,  61,  80, 202, 208,  74,  39, 189, 253, 103,  10, 144,
 233, 115,  30, 132, 196,  94,  51, 169, 179,  41,  68, 222, 158,   4, 105, 243,  93, 199, 170,  48, 112, 234, 135,  29,   7, 157, 240, 106,  42, 176, 221,  71,
  66, 216, 181,  47, 111, 245, 152,   2,  24, 130, 239, 117,  53, 175, 194,  88, 246, 108,   1, 155, 219,  65,  44, 182, 172,  54,  91, 193, 129,  27, 118, 236,
 124, 230, 139,  17,  81, 203, 166,  60,  38, 188, 209,  75,  11, 145, 252, 102, 200,  82,  63, 165, 229, 127,  18, 136, 146,   8, 101, 255, 191,  37,  72, 210,
 215,  77,  32, 186, 250,  96,  13, 151, 141,  23, 122, 224, 160,  58,  87, 205,  99, 249, 148,  14,  78, 212, 185,  35,  57, 163, 206,  84,  20, 142, 227, 121},

{  0, 155, 245, 110,  41, 178, 220,  71,  82, 201, 167,  60, 123, 224, 142,  21, 164,  63,  81, 202, 141,  22, 120, 227, 246, 109,   3, 152, 223,  68,  42, 177,
 139,  16, 126, 229, 162,  57,  87, 204, 217,  66,  44, 183, 240, 107,   5, 158,  47, 180, 218,  65,   6, 157, 243, 104, 125, 230, 136,  19,  84, 207, 161,  58,
 213,  78,  32, 187, 252, 103,   9, 146, 135,  28, 114, 233, 174,  53,  91, 192, 113, 234, 132,  31,  88, 195, 173,  54,  35, 184, 214,  77,  10, 145, 255, 100,
  94, 197, 171,  48, 119, 236, 130,  25,  12, 151, 249,  98,  37, 190, 208,  75, 250,  97,  15, 148, 211,  72,  38, 189, 168,  51,  93, 198, 129,  26, 116, 239,
 105, 242, 156,   7,  64, 219, 181,  46,  59, 160, 206,  85,  18, 137, 231, 124, 205,  86,  56, 163, 228, 127,  17, 138, 159,   4, 106, 241, 182,  45,  67, 216,
 226, 121,  23, 140, 203,  80,  62, 165, 176,  43,  69, 222, 153,   2, 108, 247,  70, 221, 179,  40, 111, 244, 154,   1,  20, 143, 225, 122,  61, 166, 200,  83,
 188,  39,  73, 210, 149,  14,  96, 251, 238, 117,  27, 128, 199,  92,  50, 169,  24, 131, 237, 118,  49, 170, 196,  95,  74, 209, 191,  36,  99, 248, 150,  13,
  55, 172, 194,  89,  30, 133, 235, 112, 101, 254, 144,  11,  76, 215, 185,  34, 147,   8, 102, 253, 186,  33,  79, 212, 193,  90,  52, 175, 232, 115,  29, 134},

{  0, 156, 251, 103,  53, 169, 206,  82, 106, 246, 145,  13,  95, 195, 164,  56, 212,  72,  47, 179, 225, 125,  26, 134, 190,  34,  69, 217, 139,  23, 112, 236,
 107, 247, 144,  12,  94, 194, 165,  57,   1, 157, 250, 102,  52, 168, 207,  83, 191,  35,  68, 216, 138,  22, 113, 237, 213,  73,  46, 178, 224, 124,  27, 135,
 214,  74,  45, 177, 227, 127,  24, 132, 188,  32,  71, 219, 137,  21, 114, 238,   2, 158, 249, 101,  55, 171, 204,  80, 104, 244, 147,  15,  93, 193, 166,  58,
 189,  33,  70, 218, 136,  20, 115, 239, 215,  75,  44, 176, 226, 126,  25, 133, 105, 245, 146,  14,  92, 192, 167,  59,   3, 159, 248, 100,  54, 170, 205,  81,
 111, 243, 148,   8,  90, 198, 161,  61,   5, 153, 254,  98,  48, 172, 203,  87, 187,  39,  64, 220, 142,  18, 117, 233, 209,  77,  42, 182, 228, 120,  31, 131,
   4, 152, 255,  99,  49, 173, 202,  86, 110, 242, 149,   9,  91, 199, 160,  60, 208,  76,  43, 183, 229, 121,  30, 130, 186,  38,  65, 221, 143,  19, 116, 232,
 185,  37,  66, 222, 140,  16, 119, 235, 211,  79,  40, 180, 230, 122,  29, 129, 109, 241, 150,  10,  88, 196, 163,  63,   7, 155, 252,  96,  50, 174, 201,  85,
 210,  78,  41, 181, 231, 123,  28, 128, 184,  36,  67, 223, 141,  17, 118, 234,   6, 154, 253,  97,  51, 175, 200,  84, 108, 240, 151,  11,  89, 197, 162,  62},

{  0, 157, 249, 100,  49, 172, 200,  85,  98, 255, 155,   6,  83, 206, 170,  55, 196,  89,  61, 160, 245, 104,  12, 145, 166,  59,  95, 194, 151,  10, 110, 243,
  75, 214, 178,  47, 122, 231, 131,  30,  41, 180, 208,  77,  24, 133, 225, 124, 143,  18, 118, 235, 190,  35,  71, 218, 237, 112,  20, 137, 220,  65,  37, 184,
 150,  11, 111, 242, 167,  58,  94, 195, 244, 105,  13, 144, 197,  88,  60, 161,  82, 207, 171,  54,  99, 254, 154,   7,  48, 173, 201,  84,   1, 156, 248, 101,
 221,  64,  36, 185, 236, 113,  21, 136, 191,  34,  70, 219, 142,  19, 119, 234,  25, 132, 224, 125,  40, 181, 209,  76, 123, 230, 130,  31,  74, 215, 179,  46,
 239, 114,  22, 139, 222,  67,  39, 186, 141,  16, 116, 233, 188,  33,  69, 216,  43, 182, 210,  79,  26, 135, 227, 126,  73, 212, 176,  45, 120, 229, 129,  28,
 164,  57,  93, 192, 149,   8, 108, 241, 198,  91,  63, 162, 247, 106,  14, 147,  96, 253, 153,   4,  81, 204, 168,  53,   2, 159, 251, 102,  51, 174, 202,  87,
 121, 228, 128,  29,  72, 213, 177,  44,  27, 134, 226, 127,  42, 183, 211,  78, 189,  32,  68, 217, 140,  17, 117, 232, 223,  66,  38, 187, 238, 115,  23, 138,
  50, 175, 203,  86,   3, 158, 250, 103,  80, 205, 169,  52,  97, 252, 152,   5, 246, 107,  15, 146, 199,  90,  62, 163, 148,   9, 109, 240, 165,  56,  92, 193},

{  0, 158, 255,  97,  61, 163, 194,  92, 122, 228, 133,  27,  71, 217, 184,  38, 244, 106,  11, 149, 201,  87,  54, 168, 142,  16, 113, 239, 179,  45,  76, 210,
  43, 181, 212,  74,  22, 136, 233, 119,  81, 207, 174,  48, 108, 242, 147,  13, 223,  65,  32, 190, 226, 124,  29, 131, 165,  59,  90, 196, 152,   6, 103, 249,
  86, 200, 169,  55, 107, 245, 148,  10,  44, 178, 211,  77,  17, 143, 238, 112, 162,  60,  93, 195, 159,   1,  96, 254, 216,  70,  39, 185, 229, 123,  26, 132,
 125, 227, 130,  28,  64, 222, 191,  33,   7, 153, 248, 102,  58, 164, 197,  91, 137,  23, 118, 232, 180,  42,  75, 213, 243, 109,  12, 146, 206,  80,  49, 175,
 172,  50,  83, 205, 145,  15, 110, 240, 214,  72,  41, 183, 235, 117,  20, 138,  88, 198, 167,  57, 101, 251, 154,   4,  34, 188, 221,  67,  31, 129, 224, 126,
 135,  25, 120, 230, 186,  36,  69, 219, 253,  99,   2, 156, 192,  94,  63, 161, 115, 237, 140,  18,  78, 208, 177,  47,   9, 151, 246, 104,  52, 170, 203,  85,
 250, 100,   5, 155, 199,  89,  56, 166, 128,  30, 127, 225, 189,  35,  66, 220,  14, 144, 241, 111,  51, 173, 204,  82, 116, 234, 139,  21,  73, 215, 182,  40,
 209,  79,  46, 176, 236, 114,  19, 141, 171,  53,  84, 202, 150,   8, 105, 247,  37, 187, 218,  68,  24, 134, 231, 121,  95, 193, 160,  62,  98, 252, 157,   3},

{  0, 159, 253,  98,  57, 166, 196,  91, 114, 237, 143,  16,  75, 212, 182,  41, 228, 123,  25, 134, 221,  66,  32, 191, 150,   9, 107, 244, 175,  48,  82, 205,
  11, 148, 246, 105,  50, 173, 207,  80, 121, 230, 132,  27,  64, 223, 189,  34, 239, 112,  18, 141, 214,  73,  43, 180, 157,   2,  96, 255, 164,  59,  89, 198,
  22, 137, 235, 116,  47, 176, 210,  77, 100, 251, 153,   6,  93, 194, 160,  63, 242, 109,  15, 144, 203,  84,  54, 169, 128,  31, 125, 226, 185,  38,  68, 219,
  29, 130, 224, 127,  36, 187, 217,  70, 111, 240, 146,  13,  86, 201, 171,  52, 249, 102,   4, 155, 192,  95,  61, 162, 139,  20, 118, 233, 178,  45,  79, 208,
  44, 179, 209,  78,  21, 138, 232, 119,  94, 193, 163,  60, 103, 248, 154,   5, 200,  87,  53, 170, 241, 110,  12, 147, 186,  37,  71, 216, 131,  28, 126, 225,
  39, 184, 218,  69,  30, 129, 227, 124,  85, 202, 168,  55, 108, 243, 145,  14, 195,  92,  62, 161, 250, 101,   7, 152, 177,  46,  76, 211, 136,  23, 117, 234,
  58, 165, 199,  88,   3, 156, 254,  97,  72, 215, 181,  42, 113, 238, 140,  19, 222,  65,  35, 188, 231, 120,  26, 133, 172,  51,  81, 206, 149,  10, 104, 247,
  49, 174, 204,  83,   8, 151, 245, 106,  67, 220, 190,  33, 122, 229, 135,  24, 213,  74,  40, 183, 236, 115,  17, 142, 167,  56,  90, 197, 158,   1,  99, 252},

{  0, 160, 131,  35, 197, 101,  70, 230,  73, 233, 202, 106, 140,  44,  15, 175, 146,  50,  17, 177,  87, 247, 212, 116, 219, 123,  88, 248,  30, 190, 157,  61,
 231,  71, 100, 196,  34, 130, 161,   1, 174,  14,  45, 141, 107, 203, 232,  72, 117, 213, 246,  86, 176,  16,  51, 147,  60, 156, 191,  31, 249,  89, 122, 218,
  13, 173, 142,  46, 200, 104,  75, 235,  68, 228, 199, 103, 129,  33,   2, 162, 159,  63,  28, 188,  90, 250, 217, 121, 214, 118,  85, 245,  19, 179, 144,  48,
 234,  74, 105, 201,  47, 143, 172,  12, 163,   3,  32, 128, 102, 198, 229,  69, 120, 216, 251,  91, 189,  29,  62, 158,  49, 145, 178,  18, 244,  84, 119, 215,
  26, 186, 153,  57, 223, 127,  92, 252,  83, 243, 208, 112, 150,  54,  21, 181, 136,  40,  11, 171,  77, 237, 206, 110, 193,  97,  66, 226,   4, 164, 135,  39,
 253,  93, 126, 222,  56, 152, 187,  27, 180,  20,  55, 151, 113, 209, 242,  82, 111, 207, 236,  76, 170,  10,  41, 137,  38, 134, 165,   5, 227,  67,  96, 192,
  23, 183, 148,  52, 210, 114,  81, 241,  94, 254, 221, 125, 155,  59,  24, 184, 133,  37,   6, 166,  64, 224, 195,  99, 204, 108,  79, 239,   9, 169, 138,  42,
 240,  80, 115, 211,  53, 149, 182,  22, 185,  25,  58, 154, 124, 220, 255,  95,  98, 194, 225,  65, 167,   7,  36, 132,  43, 139, 168,   8, 238,  78, 109, 205},

{  0, 161, 129,  32, 193,  96,  64, 225,  65, 224, 192,  97, 128,  33,   1, 160, 130,  35,   3, 162,  67, 226, 194,  99, 195,  98,  66, 227,   2, 163, 131,  34,
 199, 102,  70, 231,   6, 167, 135,  38, 134,  39,   7, 166,  71, 230, 198, 103,  69, 228, 196, 101, 132,  37,   5, 164,   4, 165, 133,  36, 197, 100,  68, 229,
  77, 236, 204, 109, 140,  45,  13, 172,  12, 173, 141,  44, 205, 108,  76, 237, 207, 110,  78, 239,  14, 175, 143,  46, 142,  47,  15, 174,  79, 238, 206, 111,
 138,  43,  11, 170,  75, 234, 202, 107, 203, 106,  74, 235,  10, 171, 139,  42,   8, 169, 137,  40, 201, 104,  72, 233,  73, 232, 200, 105, 136,  41,   9, 168,
 154,  59,  27, 186,  91, 250, 218, 123, 219, 122,  90, 251,  26, 187, 155,  58,  24, 185, 153,  56, 217, 120,  88, 249,  89, 248, 216, 121, 152,  57,  25, 184,
  93, 252, 220, 125, 156,  61,  29, 188,  28, 189, 157,  60, 221, 124,  92, 253, 223, 126,  94, 255,  30, 191, 159,  62, 158,  63,  31, 190,  95, 254, 222, 127,
 215, 118,  86, 247,  22, 183, 151,  54, 150,  55,  23, 182,  87, 246, 214, 119,  85, 244, 212, 117, 148,  53,  21, 180,  20, 181, 149,  52, 213, 116,  84, 245,
  16, 177, 145,  48, 209, 112,  80, 241,  81, 240, 208, 113, 144,  49,  17, 176, 146,  51,  19, 178,  83, 242, 210, 115, 211, 114,  82, 243,  18, 179, 147,  50},

{  0, 162, 135,  37, 205, 111,  74, 232,  89, 251, 222, 124, 148,  54,  19, 177, 178,  16,  53, 151, 127, 221, 248,  90, 235,  73, 108, 206,  38, 132, 161,   3,
 167,   5,  32, 130, 106, 200, 237,  79, 254,  92, 121, 219,  51, 145, 180,  22,  21, 183, 146,  48, 216, 122,  95, 253,  76, 238, 203, 105, 129,  35,   6, 164,
 141,  47,  10, 168,  64, 226, 199, 101, 212, 118,  83, 241,  25, 187, 158,  60,  63, 157, 184,  26, 242,  80, 117, 215, 102, 196, 225,  67, 171,   9,  44, 142,
  42, 136, 173,  15, 231,  69,  96, 194, 115, 209, 244,  86, 190,  28,  57, 155, 152,  58,  31, 189,  85, 247, 210, 112, 193,  99,  70, 228,  12, 174, 139,  41,
 217, 123,  94, 252,  20, 182, 147,  49, 128,  34,   7, 165,  77, 239, 202, 104, 107, 201, 236,  78, 166,   4,  33, 131,  50, 144, 181,  23, 255,  93, 120, 218,
 126, 220, 249,  91, 179,  17,  52, 150,  39, 133, 160,   2, 234,  72, 109, 207, 204, 110,  75, 233,   1, 163, 134,  36, 149,  55,  18, 176,  88, 250, 223, 125,
  84, 246, 211, 113, 153,  59,  30, 188,  13, 175, 138,  40, 192,  98,  71, 229, 230,  68,  97, 195,  43, 137, 172,  14, 191,  29,  56, 154, 114, 208, 245,  87,
 243,  81, 116, 214,  62, 156, 185,  27, 170,   8,  45, 143, 103, 197, 224,  66,  65, 227, 198, 100, 140,  46,  11, 169,  24, 186, 159,  61, 213, 119,  82, 240},

{  0, 163, 133,  38, 201, 106,  76, 239,  81, 242, 212, 119, 152,  59,  29, 190, 162,   1,  39, 132, 107, 200, 238,  77, 243,  80, 118, 213,  58, 153, 191,  28,
 135,  36,   2, 161,  78, 237, 203, 104, 214, 117,  83, 240,  31, 188, 154,  57,  37, 134, 160,   3, 236,  79, 105, 202, 116, 215, 241,  82, 189,  30,  56, 155,
 205, 110,  72, 235,   4, 167, 129,  34, 156,  63,  25, 186,  85, 246, 208, 115, 111, 204, 234,  73, 166,   5,  35, 128,  62, 157, 187,  24, 247,  84, 114, 209,
  74, 233, 207, 108, 131,  32,   6, 165,  27, 184, 158,  61, 210, 113,  87, 244, 232,  75, 109, 206,  33, 130, 164,   7, 185,  26,  60, 159, 112, 211, 245,  86,
  89, 250, 220, 127, 144,  51,  21, 182,   8, 171, 141,  46, 193,  98,  68, 231, 251,  88, 126, 221,  50, 145, 183,  20, 170,   9,  47, 140,  99, 192, 230,  69,
 222, 125,  91, 248,  23, 180, 146,  49, 143,  44,  10, 169,  70, 229, 195,  96, 124, 223, 249,  90, 181,  22,  48, 147,  45, 142, 168,  11, 228,  71,  97, 194,
 148,  55,  17, 178,  93, 254, 216, 123, 197, 102,  64, 227,  12, 175, 137,  42,  54, 149, 179,  16, 255,  92, 122, 217, 103, 196, 226,  65, 174,  13,  43, 136,
  19, 176, 150,  53, 218, 121,  95, 252,  66, 225, 199, 100, 139,  40,  14, 173, 177,  18,  52, 151, 120, 219, 253,  94, 224,  67, 101, 198,  41, 138, 172,  15},

{  0, 164, 139,  47, 213, 113,  94, 250, 105, 205, 226,  70, 188,  24,  55, 147, 210, 118,  89, 253,   7, 163, 140,  40, 187,  31,  48, 148, 110, 202, 229,  65,
 103, 195, 236,  72, 178,  22,  57, 157,  14, 170, 133,  33, 219, 127,  80, 244, 181,  17,  62, 154,  96, 196, 235,  79, 220, 120,  87, 243,   9, 173, 130,  38,
 206, 106,  69, 225,  27, 191, 144,  52, 167,   3,  44, 136, 114, 214, 249,  93,  28, 184, 151,  51, 201, 109,  66, 230, 117, 209, 254,  90, 160,   4,  43, 143,
 169,  13,  34, 134, 124, 216, 247,  83, 192, 100,  75, 239,  21, 177, 158,  58, 123, 223, 240,  84, 174,  10,  37, 129,  18, 182, 153,  61, 199,  99,  76, 232,
  95, 251, 212, 112, 138,  46,   1, 165,  54, 146, 189,  25, 227,  71, 104, 204, 141,  41,   6, 162,  88, 252, 211, 119, 228,  64, 111, 203,  49, 149, 186,  30,
  56, 156, 179,  23, 237,  73, 102, 194,  81, 245, 218, 126, 132,  32,  15, 171, 234,  78,  97, 197,  63, 155, 180,  16, 131,  39,   8, 172,  86, 242, 221, 121,
 145,  53,  26, 190,  68, 224, 207, 107, 248,  92, 115, 215,  45, 137, 166,   2,  67, 231, 200, 108, 150,  50,  29, 185,  42, 142, 161,   5, 255,  91, 116, 208,
 246,  82, 125, 217,  35, 135, 168,  12, 159,  59,  20, 176,  74, 238, 193, 101,  36, 128, 175,  11, 241,  85, 122, 222,  77, 233, 198,  98, 152,  60,  19, 183},

{  0, 165, 137,  44, 209, 116,  88, 253,  97, 196, 232,  77, 176,  21,  57, 156, 194, 103,  75, 238,  19, 182, 154,  63, 163,   6,  42, 143, 114, 215, 251,  94,
  71, 226, 206, 107, 150,  51,  31, 186,  38, 131, 175,  10, 247,  82, 126, 219, 133,  32,  12, 169,  84, 241, 221, 120, 228,  65, 109, 200,  53, 144, 188,  25,
 142,  43,   7, 162,  95, 250, 214, 115, 239,  74, 102, 195,  62, 155, 183,  18,  76, 233, 197,  96, 157,  56,  20, 177,  45, 136, 164,   1, 252,  89, 117, 208,
 201, 108,  64, 229,  24, 189, 145,  52, 168,  13,  33, 132, 121, 220, 240,  85,  11, 174, 130,  39, 218, 127,  83, 246, 106, 207, 227,  70, 187,  30,  50, 151,
 223, 122,  86, 243,  14, 171, 135,  34, 190,  27,  55, 146, 111, 202, 230,  67,  29, 184, 148,  49, 204, 105,  69, 224, 124, 217, 245,  80, 173,   8,  36, 129,
 152,  61,  17, 180,  73, 236, 192, 101, 249,  92, 112, 213,  40, 141, 161,   4,  90, 255, 211, 118, 139,  46,   2, 167,  59, 158, 178,  23, 234,  79,  99, 198,
  81, 244, 216, 125, 128,  37,   9, 172,  48, 149, 185,  28, 225,  68, 104, 205, 147,  54,  26, 191,  66, 231, 203, 110, 242,  87, 123, 222,  35, 134, 170,  15,
  22, 179, 159,  58, 199,  98,  78, 235, 119, 210, 254,  91, 166,   3,  47, 138, 212, 113,  93, 248,   5, 160, 140,  41, 181,  16,  60, 153, 100, 193, 237,  72},

{  0, 166, 143,  41, 221, 123,  82, 244, 121, 223, 246,  80, 164,   2,  43, 141, 242,  84, 125, 219,  47, 137, 160,   6, 139,  45,   4, 162,  86, 240, 217, 127,
  39, 129, 168,  14, 250,  92, 117, 211,  94, 248, 209, 119, 131,  37,  12, 170, 213, 115,  90, 252,   8, 174, 135,  33, 172,  10,  35, 133, 113, 215, 254,  88,
  78, 232, 193, 103, 147,  53,  28, 186,  55, 145, 184,  30, 234,  76, 101, 195, 188,  26,  51, 149,  97, 199, 238,  72, 197,  99,  74, 236,  24, 190, 151,  49,
 105, 207, 230,  64, 180,  18,  59, 157,  16, 182, 159,  57, 205, 107,  66, 228, 155,  61,  20, 178,  70, 224, 201, 111, 226,  68, 109, 203,  63, 153, 176,  22,
 156,  58,  19, 181,  65, 231, 206, 104, 229,  67, 106, 204,  56, 158, 183,  17, 110, 200, 225,  71, 179,  21,  60, 154,  23, 177, 152,  62, 202, 108,  69, 227,
 187,  29,  52, 146, 102, 192, 233,  79, 194, 100,  77, 235,  31, 185, 144,  54,  73, 239, 198,  96, 148,  50,  27, 189,  48, 150, 191,  25, 237,  75,  98, 196,
 210, 116,  93, 251,  15, 169, 128,  38, 171,  13,  36, 130, 118, 208, 249,  95,  32, 134, 175,   9, 253,  91, 114, 212,  89, 255, 214, 112, 132,  34,  11, 173,
 245,  83, 122, 220,  40, 142, 167,   1, 140,  42,   3, 165,  81, 247, 222, 120,   7, 161, 136,  46, 218, 124,  85, 243, 126, 216, 241,  87, 163,   5,  44, 138},

{  0, 167, 141,  42, 217, 126,  84, 243, 113, 214, 252,  91, 168,  15,  37, 130, 226,  69, 111, 200,  59, 156, 182,  17, 147,  52,  30, 185,  74, 237, 199,  96,
   7, 160, 138,  45, 222, 121,  83, 244, 118, 209, 251,  92, 175,   8,  34, 133, 229,  66, 104, 207,  60, 155, 177,  22, 148,  51,  25, 190,  77, 234, 192, 103,
  14, 169, 131,  36, 215, 112,  90, 253, 127, 216, 242,  85, 166,   1,  43, 140, 236,  75,  97, 198,  53, 146, 184,  31, 157,  58,  16, 183,  68, 227, 201, 110,
   9, 174, 132,  35, 208, 119,  93, 250, 120, 223, 245,  82, 161,   6,  44, 139, 235,  76, 102, 193,  50, 149, 191,  24, 154,  61,  23, 176,  67, 228, 206, 105,
  28, 187, 145,  54, 197,  98,  72, 239, 109, 202, 224,  71, 180,  19,  57, 158, 254,  89, 115, 212,  39, 128, 170,  13, 143,  40,   2, 165,  86, 241, 219, 124,
  27, 188, 150,  49, 194, 101,  79, 232, 106, 205, 231,  64, 179,  20,  62, 153, 249,  94, 116, 211,  32, 135, 173,  10, 136,  47,   5, 162,  81, 246, 220, 123,
  18, 181, 159,  56, 203, 108,  70, 225,  99, 196, 238,  73, 186,  29,  55, 144, 240,  87, 125, 218,  41, 142, 164,   3, 129,  38,  12, 171,  88, 255, 213, 114,
  21, 178, 152,  63, 204, 107,  65, 230, 100, 195, 233,  78, 189,  26,  48, 151, 247,  80, 122, 221,  46, 137, 163,   4, 134,  33,  11, 172,  95, 248, 210, 117},

{  0, 168, 147,  59, 229,  77, 118, 222,   9, 161, 154,  50, 236,  68, 127, 215,  18, 186, 129,  41, 247,  95, 100, 204,  27, 179, 136,  32, 254,  86, 109, 197,
  36, 140, 183,  31, 193, 105,  82, 250,  45, 133, 190,  22, 200,  96,  91, 243,  54, 158, 165,  13, 211, 123,  64, 232,  63, 151, 172,   4, 218, 114,  73, 225,
  72, 224, 219, 115, 173,   5,  62, 150,  65, 233, 210, 122, 164,  12,  55, 159,  90, 242, 201,  97, 191,  23,  44, 132,  83, 251, 192, 104, 182,  30,  37, 141,
 108, 196, 255,  87, 137,  33,  26, 178, 101, 205, 246,  94, 128,  40,  19, 187, 126, 214, 237,  69, 155,  51,   8, 160, 119, 223, 228,  76, 146,  58,   1, 169,
 144,  56,   3, 171, 117, 221, 230,  78, 153,  49,  10, 162, 124, 212, 239,  71, 130,  42,  17, 185, 103, 207, 244,  92, 139,  35,  24, 176, 110, 198, 253,  85,
 180,  28,  39, 143,  81, 249, 194, 106, 189,  21,  46, 134,  88, 240, 203,  99, 166,  14,  53, 157,  67, 235, 208, 120, 175,   7,  60, 148,  74, 226, 217, 113,
 216, 112,  75, 227,  61, 149, 174,   6, 209, 121,  66, 234,  52, 156, 167,  15, 202,  98,  89, 241,  47, 135, 188,  20, 195, 107,  80, 248,  38, 142, 181,  29,
 252,  84, 111, 199,  25, 177, 138,  34, 245,  93, 102, 206,  16, 184, 131,  43, 238,  70, 125, 213,  11, 163, 152,  48, 231,  79, 116, 220,   2, 170, 145,  57},

{  0, 169, 145,  56, 225,  72, 112, 217,   1, 168, 144,  57, 224,  73, 113, 216,   2, 171, 147,  58, 227,  74, 114, 219,   3, 170, 146,  59, 226,  75, 115, 218,
   4, 173, 149,  60, 229,  76, 116, 221,   5, 172, 148,  61, 228,  77, 117, 220,   6, 175, 151,  62, 231,  78, 118, 223,   7, 174, 150,  63, 230,  79, 119, 222,
   8, 161, 153,  48, 233,  64, 120, 209,   9, 160, 152,  49, 232,  65, 121, 208,  10, 163, 155,  50, 235,  66, 122, 211,  11, 162, 154,  51, 234,  67, 123, 210,
  12, 165, 157,  52, 237,  68, 124, 213,  13, 164, 156,  53, 236,  69, 125, 212,  14, 167, 159,  54, 239,  70, 126, 215,  15, 166, 158,  55, 238,  71, 127, 214,
  16, 185, 129,  40, 241,  88,  96, 201,  17, 184, 128,  41, 240,  89,  97, 200,  18, 187, 131,  42, 243,  90,  98, 203,  19, 186, 130,  43, 242,  91,  99, 202,
  20, 189, 133,  44, 245,  92, 100, 205,  21, 188, 132,  45, 244,  93, 101, 204,  22, 191, 135,  46, 247,  94, 102, 207,  23, 190, 134,  47, 246,  95, 103, 206,
  24, 177, 137,  32, 249,  80, 104, 193,  25, 176, 136,  33, 248,  81, 105, 192,  26, 179, 139,  34, 251,  82, 106, 195,  27, 178, 138,  35, 250,  83, 107, 194,
  28, 181, 141,  36, 253,  84, 108, 197,  29, 180, 140,  37, 252,  85, 109, 196,  30, 183, 143,  38, 255,  86, 110, 199,  31, 182, 142,  39, 254,  87, 111, 198},

{  0, 170, 151,  61, 237,  71, 122, 208,  25, 179, 142,  36, 244,  94,  99, 201,  50, 152, 165,  15, 223, 117,  72, 226,  43, 129, 188,  22, 198, 108,  81, 251,
 100, 206, 243,  89, 137,  35,  30, 180, 125, 215, 234,  64, 144,  58,   7, 173,  86, 252, 193, 107, 187,  17,  44, 134,  79, 229, 216, 114, 162,   8,  53, 159,
 200,  98,  95, 245,  37, 143, 178,  24, 209, 123,  70, 236,  60, 150, 171,   1, 250,  80, 109, 199,  23, 189, 128,  42, 227,  73, 116, 222,  14, 164, 153,  51,
 172,   6,  59, 145,  65, 235, 214, 124, 181,  31,  34, 136,  88, 242, 207, 101, 158,  52,   9, 163, 115, 217, 228,  78, 135,  45,  16, 186, 106, 192, 253,  87,
  83, 249, 196, 110, 190,  20,  41, 131,  74, 224, 221, 119, 167,  13,  48, 154,  97, 203, 246,  92, 140,  38,  27, 177, 120, 210, 239,  69, 149,  63,   2, 168,
  55, 157, 160,  10, 218, 112,  77, 231,  46, 132, 185,  19, 195, 105,  84, 254,   5, 175, 146,  56, 232,  66, 127, 213,  28, 182, 139,  33, 241,  91, 102, 204,
 155,  49,  12, 166, 118, 220, 225,  75, 130,  40,  21, 191, 111, 197, 248,  82, 169,   3,  62, 148,  68, 238, 211, 121, 176,  26,  39, 141,  93, 247, 202,  96,
 255,  85, 104, 194,  18, 184, 133,  47, 230,  76, 113, 219,  11, 161, 156,  54, 205, 103,  90, 240,  32, 138, 183,  29, 212, 126,  67, 233,  57, 147, 174,   4},

{  0, 171, 149,  62, 233,  66, 124, 215,  17, 186, 132,  47, 248,  83, 109, 198,  34, 137, 183,  28, 203,  96,  94, 245,  51, 152, 166,  13, 218, 113,  79, 228,
  68, 239, 209, 122, 173,   6,  56, 147,  85, 254, 192, 107, 188,  23,  41, 130, 102, 205, 243,  88, 143,  36,  26, 177, 119, 220, 226,  73, 158,  53,  11, 160,
 136,  35,  29, 182,  97, 202, 244,  95, 153,  50,  12, 167, 112, 219, 229,  78, 170,   1,  63, 148,  67, 232, 214, 125, 187,  16,  46, 133,  82, 249, 199, 108,
 204, 103,  89, 242,  37, 142, 176,  27, 221, 118,  72, 227,  52, 159, 161,  10, 238,  69, 123, 208,   7, 172, 146,  57, 255,  84, 106, 193,  22, 189, 131,  40,
 211, 120,  70, 237,  58, 145, 175,   4, 194, 105,  87, 252,  43, 128, 190,  21, 241,  90, 100, 207,  24, 179, 141,  38, 224,  75, 117, 222,   9, 162, 156,  55,
 151,  60,   2, 169, 126, 213, 235,  64, 134,  45,  19, 184, 111, 196, 250,  81, 181,  30,  32, 139,  92, 247, 201,  98, 164,  15,  49, 154,  77, 230, 216, 115,
  91, 240, 206, 101, 178,  25,  39, 140,  74, 225, 223, 116, 163,   8,  54, 157, 121, 210, 236,  71, 144,  59,   5, 174, 104, 195, 253,  86, 129,  42,  20, 191,
  31, 180, 138,  33, 246,  93,  99, 200,  14, 165, 155,  48, 231,  76, 114, 217,  61, 150, 168,   3, 212, 127,  65, 234,  44, 135, 185,  18, 197, 110,  80, 251},

{  0, 172, 155,  55, 245,  89, 110, 194,  41, 133, 178,  30, 220, 112,  71, 235,  82, 254, 201, 101, 167,  11,  60, 144, 123, 215, 224,  76, 142,  34,  21, 185,
 164,   8,  63, 147,  81, 253, 202, 102, 141,  33,  22, 186, 120, 212, 227,  79, 246,  90, 109, 193,   3, 175, 152,  52, 223, 115,  68, 232,  42, 134, 177,  29,
 139,  39,  16, 188, 126, 210, 229,  73, 162,  14,  57, 149,  87, 251, 204,  96, 217, 117,  66, 238,  44, 128, 183,  27, 240,  92, 107, 199,   5, 169, 158,  50,
  47, 131, 180,  24, 218, 118,  65, 237,   6, 170, 157,  49, 243,  95, 104, 196, 125, 209, 230,  74, 136,  36,  19, 191,  84, 248, 207,  99, 161,  13,  58, 150,
 213, 121,  78, 226,  32, 140, 187,  23, 252,  80, 103, 203,   9, 165, 146,  62, 135,  43,  28, 176, 114, 222, 233,  69, 174,   2,  53, 153,  91, 247, 192, 108,
 113, 221, 234,  70, 132,  40,  31, 179,  88, 244, 195, 111, 173,   1,  54, 154,  35, 143, 184,  20, 214, 122,  77, 225,  10, 166, 145,  61, 255,  83, 100, 200,
  94, 242, 197, 105, 171,   7,  48, 156, 119, 219, 236,  64, 130,  46,  25, 181,  12, 160, 151,  59, 249,  85,  98, 206,  37, 137, 190,  18, 208, 124,  75, 231,
 250,  86,  97, 205,  15, 163, 148,  56, 211, 127,  72, 228,  38, 138, 189,  17, 168,   4,  51, 159,  93, 241, 198, 106, 129,  45,  26, 182, 116, 216, 239,  67},

{  0, 173, 153,  52, 241,  92, 104, 197,  33, 140, 184,  21, 208, 125,  73, 228,  66, 239, 219, 118, 179,  30,  42, 135,  99, 206, 250,  87, 146,  63,  11, 166,
 132,  41,  29, 176, 117, 216, 236,  65, 165,   8,  60, 145,  84, 249, 205,  96, 198, 107,  95, 242,  55, 154, 174,   3, 231,  74, 126, 211,  22, 187, 143,  34,
 203, 102,  82, 255,  58, 151, 163,  14, 234,  71, 115, 222,  27, 182, 130,  47, 137,  36,  16, 189, 120, 213, 225,  76, 168,   5,  49, 156,  89, 244, 192, 109,
  79, 226, 214, 123, 190,  19,  39, 138, 110, 195, 247,  90, 159,  50,   6, 171,  13, 160, 148,  57, 252,  81, 101, 200,  44, 129, 181,  24, 221, 112,  68, 233,
  85, 248, 204,  97, 164,   9,  61, 144, 116, 217, 237,  64, 133,  40,  28, 177,  23, 186, 142,  35, 230,  75, 127, 210,  54, 155, 175,   2, 199, 106,  94, 243,
 209, 124,  72, 229,  32, 141, 185,  20, 240,  93, 105, 196,   1, 172, 152,  53, 147,  62,  10, 167,  98, 207, 251,  86, 178,  31,  43, 134,  67, 238, 218, 119,
 158,  51,   7, 170, 111, 194, 246,  91, 191,  18,  38, 139,  78, 227, 215, 122, 220, 113,  69, 232,  45, 128, 180,  25, 253,  80, 100, 201,  12, 161, 149,  56,
  26, 183, 131,  46, 235,  70, 114, 223,  59, 150, 162,  15, 202, 103,  83, 254,  88, 245, 193, 108, 169,   4,  48, 157, 121, 212, 224,  77, 136,  37,  17, 188},

{  0, 174, 159,  49, 253,  83,  98, 204,  57, 151, 166,   8, 196, 106,  91, 245, 114, 220, 237,  67, 143,  33,  16, 190,  75, 229, 212, 122, 182,  24,  41, 135,
 228,  74, 123, 213,  25, 183, 134,  40, 221, 115,  66, 236,  32, 142, 191,  17, 150,  56,   9, 167, 107, 197, 244,  90, 175,   1,  48, 158,  82, 252, 205,  99,
  11, 165, 148,  58, 246,  88, 105, 199,  50, 156, 173,   3, 207,  97,  80, 254, 121, 215, 230,  72, 132,  42,  27, 181,  64, 238, 223, 113, 189,  19,  34, 140,
 239,  65, 112, 222,  18, 188, 141,  35, 214, 120,  73, 231,  43, 133, 180,  26, 157,  51,   2, 172,  96, 206, 255,  81, 164,  10,  59, 149,  89, 247, 198, 104,
  22, 184, 137,  39, 235,  69, 116, 218,  47, 129, 176,  30, 210, 124,  77, 227, 100, 202, 251,  85, 153,  55,   6, 168,  93, 243, 194, 108, 160,  14,  63, 145,
 242,  92, 109, 195,  15, 161, 144,  62, 203, 101,  84, 250,  54, 152, 169,   7, 128,  46,  31, 177, 125, 211, 226,  76, 185,  23,  38, 136,  68, 234, 219, 117,
  29, 179, 130,  44, 224,  78, 127, 209,  36, 138, 187,  21, 217, 119,  70, 232, 111, 193, 240,  94, 146,  60,  13, 163,  86, 248, 201, 103, 171,   5,  52, 154,
 249,  87, 102, 200,   4, 170, 155,  53, 192, 110,  95, 241,  61, 147, 162,  12, 139,  37,  20, 186, 118, 216, 233,  71, 178,  28,  45, 131,  79, 225, 208, 126},

{  0, 175, 157,  50, 249,  86, 100, 203,  49, 158, 172,   3, 200, 103,  85, 250,  98, 205, 255,  80, 155,  52,   6, 169,  83, 252, 206,  97, 170,   5,  55, 152,
 196, 107,  89, 246,  61, 146, 160,  15, 245,  90, 104, 199,  12, 163, 145,  62, 166,   9,  59, 148,  95, 240, 194, 109, 151,  56,  10, 165, 110, 193, 243,  92,
  75, 228, 214, 121, 178,  29,  47, 128, 122, 213, 231,  72, 131,  44,  30, 177,  41, 134, 180,  27, 208, 127,  77, 226,  24, 183, 133,  42, 225,  78, 124, 211,
 143,  32,  18, 189, 118, 217, 235,  68, 190,  17,  35, 140,  71, 232, 218, 117, 237,  66, 112, 223,  20, 187, 137,  38, 220, 115,  65, 238,  37, 138, 184,  23,
 150,  57,  11, 164, 111, 192, 242,  93, 167,   8,  58, 149,  94, 241, 195, 108, 244,  91, 105, 198,  13, 162, 144,  63, 197, 106,  88, 247,  60, 147, 161,  14,
  82, 253, 207,  96, 171,   4,  54, 153,  99, 204, 254,  81, 154,  53,   7, 168,  48, 159, 173,   2, 201, 102,  84, 251,   1, 174, 156,  51, 248,  87, 101, 202,
 221, 114,  64, 239,  36, 139, 185,  22, 236,  67, 113, 222,  21, 186, 136,  39, 191,  16,  34, 141,  70, 233, 219, 116, 142,  33,  19, 188, 119, 216, 234,  69,
  25, 182, 132,  43, 224,  79, 125, 210,  40, 135, 181,  26, 209, 126,  76, 227, 123, 212, 230,  73, 130,  45,  31, 176,  74, 229, 215, 120, 179,  28,  46, 129},

{  0, 176, 163,  19, 133,  53,  38, 150, 201, 121, 106, 218,  76, 252, 239,  95,  81, 225, 242,  66, 212, 100, 119, 199, 152,  40,  59, 139,  29, 173, 190,  14,
 162,  18,   1, 177,  39, 151, 132,  52, 107, 219, 200, 120, 238,  94,  77, 253, 243,  67,  80, 224, 118, 198, 213, 101,  58, 138, 153,  41, 191,  15,  28, 172,
 135,  55,  36, 148,   2, 178, 161,  17,  78, 254, 237,  93, 203, 123, 104, 216, 214, 102, 117, 197,  83, 227, 240,  64,  31, 175, 188,  12, 154,  42,  57, 137,
  37, 149, 134,  54, 160,  16,   3, 179, 236,  92,  79, 255, 105, 217, 202, 122, 116, 196, 215, 103, 241,  65,  82, 226, 189,  13,  30, 174,  56, 136, 155,  43,
 205, 125, 110, 222,  72, 248, 235,  91,   4, 180, 167,  23, 129,  49,  34, 146, 156,  44,  63, 143,  25, 169, 186,  10,  85, 229, 246,  70, 208,  96, 115, 195,
 111, 223, 204, 124, 234,  90,  73, 249, 166,  22,   5, 181,  35, 147, 128,  48,  62, 142, 157,  45, 187,  11,  24, 168, 247,  71,  84, 228, 114, 194, 209,  97,
  74, 250, 233,  89, 207, 127, 108, 220, 131,  51,  32, 144,   6, 182, 165,  21,  27, 171, 184,   8, 158,  46,  61, 141, 210,  98, 113, 193,  87, 231, 244,  68,
 232,  88,  75, 251, 109, 221, 206, 126,  33, 145, 130,  50, 164,  20,   7, 183, 185,   9,  26, 170,  60, 140, 159,  47, 112, 192, 211,  99, 245,  69,  86, 230},

{  0, 177, 161,  16, 129,  48,  32, 145, 193, 112,  96, 209,  64, 241, 225,  80,  65, 240, 224,  81, 192, 113,  97, 208, 128,  49,  33, 144,   1, 176, 160,  17,
 130,  51,  35, 146,   3, 178, 162,  19,  67, 242, 226,  83, 194, 115,  99, 210, 195, 114,  98, 211,  66, 243, 227,  82,   2, 179, 163,  18, 131,  50,  34, 147,
 199, 118, 102, 215,  70, 247, 231,  86,   6, 183, 167,  22, 135,  54,  38, 151, 134,  55,  39, 150,   7, 182, 166,  23,  71, 246, 230,  87, 198, 119, 103, 214,
  69, 244, 228,  85, 196, 117, 101, 212, 132,  53,  37, 148,   5, 180, 164,  21,   4, 181, 165,  20, 133,  52,  36, 149, 197, 116, 100, 213,  68, 245, 229,  84,
  77, 252, 236,  93, 204, 125, 109, 220, 140,  61,  45, 156,  13, 188, 172,  29,  12, 189, 173,  28, 141,  60,  44, 157, 205, 124, 108, 221,  76, 253, 237,  92,
 207, 126, 110, 223,  78, 255, 239,  94,  14, 191, 175,  30, 143,  62,  46, 159, 142,  63,  47, 158,  15, 190, 174,  31,  79, 254, 238,  95, 206, 127, 111, 222,
 138,  59,  43, 154,  11, 186, 170,  27,  75, 250, 234,  91, 202, 123, 107, 218, 203, 122, 106, 219,  74, 251, 235,  90,  10, 187, 171,  26, 139,  58,  42, 155,
   8, 185, 169,  24, 137,  56,  40, 153, 201, 120, 104, 217,  72, 249, 233,  88,  73, 248, 232,  89, 200, 121, 105, 216, 136,  57,  41, 152,   9, 184, 168,  25},

{  0, 178, 167,  21, 141,  63,  42, 152, 217, 107, 126, 204,  84, 230, 243,  65, 113, 195, 214, 100, 252,  78,  91, 233, 168,  26,  15, 189,  37, 151, 130,  48,
 226,  80,  69, 247, 111, 221, 200, 122,  59, 137, 156,  46, 182,   4,  17, 163, 147,  33,  52, 134,  30, 172, 185,  11,  74, 248, 237,  95, 199, 117,  96, 210,
   7, 181, 160,  18, 138,  56,  45, 159, 222, 108, 121, 203,  83, 225, 244,  70, 118, 196, 209,  99, 251,  73,  92, 238, 175,  29,   8, 186,  34, 144, 133,  55,
 229,  87,  66, 240, 104, 218, 207, 125,  60, 142, 155,  41, 177,   3,  22, 164, 148,  38,  51, 129,  25, 171, 190,  12,  77, 255, 234,  88, 192, 114, 103, 213,
  14, 188, 169,  27, 131,  49,  36, 150, 215, 101, 112, 194,  90, 232, 253,  79, 127, 205, 216, 106, 242,  64,  85, 231, 166,  20,   1, 179,  43, 153, 140,  62,
 236,  94,  75, 249,  97, 211, 198, 116,  53, 135, 146,  32, 184,  10,  31, 173, 157,  47,  58, 136,  16, 162, 183,   5,  68, 246, 227,  81, 201, 123, 110, 220,
   9, 187, 174,  28, 132,  54,  35, 145, 208,  98, 119, 197,  93, 239, 250,  72, 120, 202, 223, 109, 245,  71,  82, 224, 161,  19,   6, 180,  44, 158, 139,  57,
 235,  89,  76, 254, 102, 212, 193, 115,  50, 128, 149,  39, 191,  13,  24, 170, 154,  40,  61, 143,  23, 165, 176,   2,  67, 241, 228,  86, 206, 124, 105, 219},

{  0, 179, 165,  22, 137,  58,  44, 159, 209,  98, 116, 199,  88, 235, 253,  78,  97, 210, 196, 119, 232,  91,  77, 254, 176,   3,  21, 166,  57, 138, 156,  47,
 194, 113, 103, 212,  75, 248, 238,  93,  19, 160, 182,   5, 154,  41,  63, 140, 163,  16,   6, 181,  42, 153, 143,  60, 114, 193, 215, 100, 251,  72,  94, 237,
  71, 244, 226,  81, 206, 125, 107, 216, 150,  37,  51, 128,  31, 172, 186,   9,  38, 149, 131,  48, 175,  28,  10, 185, 247,  68,  82, 225, 126, 205, 219, 104,
 133,  54,  32, 147,  12, 191, 169,  26,  84, 231, 241,  66, 221, 110, 120, 203, 228,  87,  65, 242, 109, 222, 200, 123,  53, 134, 144,  35, 188,  15,  25, 170,
 142,  61,  43, 152,   7, 180, 162,  17,  95, 236, 250,  73, 214, 101, 115, 192, 239,  92,  74, 249, 102, 213, 195, 112,  62, 141, 155,  40, 183,   4,  18, 161,
  76, 255, 233,  90, 197, 118,  96, 211, 157,  46,  56, 139,  20, 167, 177,   2,  45, 158, 136,  59, 164,  23,   1, 178, 252,  79,  89, 234, 117, 198, 208,  99,
 201, 122, 108, 223,  64, 243, 229,  86,  24, 171, 189,  14, 145,  34,  52, 135, 168,  27,  13, 190,  33, 146, 132,  55, 121, 202, 220, 111, 240,  67,  85, 230,
  11, 184, 174,  29, 130,  49,  39, 148, 218, 105, 127, 204,  83, 224, 246,  69, 106, 217, 207, 124, 227,  80,  70, 245, 187,   8,  30, 173,  50, 129, 151,  36},

{  0, 180, 171,  31, 149,  33,  62, 138, 233,  93,  66, 246, 124, 200, 215,  99,  17, 165, 186,  14, 132,  48,  47, 155, 248,  76,  83, 231, 109, 217, 198, 114,
  34, 150, 137,  61, 183,   3,  28, 168, 203, 127,  96, 212,  94, 234, 245,  65,  51, 135, 152,  44, 166,  18,  13, 185, 218, 110, 113, 197,  79, 251, 228,  80,
  68, 240, 239,  91, 209, 101, 122, 206, 173,  25,   6, 178,  56, 140, 147,  39,  85, 225, 254,  74, 192, 116, 107, 223, 188,   8,  23, 163,  41, 157, 130,  54,
 102, 210, 205, 121, 243,  71,  88, 236, 143,  59,  36, 144,  26, 174, 177,   5, 119, 195, 220, 104, 226,  86,  73, 253, 158,  42,  53, 129,  11, 191, 160,  20,
 136,  60,  35, 151,  29, 169, 182,   2,  97, 213, 202, 126, 244,  64,  95, 235, 153,  45,  50, 134,  12, 184, 167,  19, 112, 196, 219, 111, 229,  81,  78, 250,
 170,  30,   1, 181,  63, 139, 148,  32,  67, 247, 232,  92, 214,  98, 125, 201, 187,  15,  16, 164,  46, 154, 133,  49,  82, 230, 249,  77, 199, 115, 108, 216,
 204, 120, 103, 211,  89, 237, 242,  70,  37, 145, 142,  58, 176,   4,  27, 175, 221, 105, 118, 194,  72, 252, 227,  87,  52, 128, 159,  43, 161,  21,  10, 190,
 238,  90,  69, 241, 123, 207, 208, 100,   7, 179, 172,  24, 146,  38,  57, 141, 255,  75,  84, 224, 106, 222, 193, 117,  22, 162, 189,   9, 131,  55,  40, 156},

{  0, 181, 169,  28, 145,  36,  56, 141, 225,  84,  72, 253, 112, 197, 217, 108,   1, 180, 168,  29, 144,  37,  57, 140, 224,  85,  73, 252, 113, 196, 216, 109,
   2, 183, 171,  30, 147,  38,  58, 143, 227,  86,  74, 255, 114, 199, 219, 110,   3, 182, 170,  31, 146,  39,  59, 142, 226,  87,  75, 254, 115, 198, 218, 111,
   4, 177, 173,  24, 149,  32,  60, 137, 229,  80,  76, 249, 116, 193, 221, 104,   5, 176, 172,  25, 148,  33,  61, 136, 228,  81,  77, 248, 117, 192, 220, 105,
   6, 179, 175,  26, 151,  34,  62, 139, 231,  82,  78, 251, 118, 195, 223, 106,   7, 178, 174,  27, 150,  35,  63, 138, 230,  83,  79, 250, 119, 194, 222, 107,
   8, 189, 161,  20, 153,  44,  48, 133, 233,  92,  64, 245, 120, 205, 209, 100,   9, 188, 160,  21, 152,  45,  49, 132, 232,  93,  65, 244, 121, 204, 208, 101,
  10, 191, 163,  22, 155,  46,  50, 135, 235,  94,  66, 247, 122, 207, 211, 102,  11, 190, 162,  23, 154,  47,  51, 134, 234,  95,  67, 246, 123, 206, 210, 103,
  12, 185, 165,  16, 157,  40,  52, 129, 237,  88,  68, 241, 124, 201, 213,  96,  13, 184, 164,  17, 156,  41,  53, 128, 236,  89,  69, 240, 125, 200, 212,  97,
  14, 187, 167,  18, 159,  42,  54, 131, 239,  90,  70, 243, 126, 203, 215,  98,  15, 186, 166,  19, 158,  43,  55, 130, 238,  91,  71, 242, 127, 202, 214,  99},

{  0, 182, 175,  25, 157,  43,  50, 132, 249,  79,  86, 224, 100, 210, 203, 125,  49, 135, 158,  40, 172,  26,   3, 181, 200, 126, 103, 209,  85, 227, 250,  76,
  98, 212, 205, 123, 255,  73,  80, 230, 155,  45,  52, 130,   6, 176, 169,  31,  83, 229, 252,  74, 206, 120,  97, 215, 170,  28,   5, 179,  55, 129, 152,  46,
 196, 114, 107, 221,  89, 239, 246,  64,  61, 139, 146,  36, 160,  22,  15, 185, 245,  67,  90, 236, 104, 222, 199, 113,  12, 186, 163,  21, 145,  39,  62, 136,
 166,  16,   9, 191,  59, 141, 148,  34,  95, 233, 240,  70, 194, 116, 109, 219, 151,  33,  56, 142,  10, 188, 165,  19, 110, 216, 193, 119, 243,  69,  92, 234,
  75, 253, 228,  82, 214,  96, 121, 207, 178,   4,  29, 171,  47, 153, 128,  54, 122, 204, 213,  99, 231,  81,  72, 254, 131,  53,  44, 154,  30, 168, 177,   7,
  41, 159, 134,  48, 180,   2,  27, 173, 208, 102, 127, 201,  77, 251, 226,  84,  24, 174, 183,   1, 133,  51,  42, 156, 225,  87,  78, 248, 124, 202, 211, 101,
 143,  57,  32, 150,  18, 164, 189,  11, 118, 192, 217, 111, 235,  93,  68, 242, 190,   8,  17, 167,  35, 149, 140,  58,  71, 241, 232,  94, 218, 108, 117, 195,
 237,  91,  66, 244, 112, 198, 223, 105,  20, 162, 187,  13, 137,  63,  38, 144, 220, 106, 115, 197,  65, 247, 238,  88,  37, 147, 138,  60, 184,  14,  23, 161},

{  0, 183, 173,  26, 153,  46,  52, 131, 241,  70,  92, 235, 104, 223, 197, 114,  33, 150, 140,  59, 184,  15,  21, 162, 208, 103, 125, 202,  73, 254, 228,  83,
  66, 245, 239,  88, 219, 108, 118, 193, 179,   4,  30, 169,  42, 157, 135,  48,  99, 212, 206, 121, 250,  77,  87, 224, 146,  37,  63, 136,  11, 188, 166,  17,
 132,  51,  41, 158,  29, 170, 176,   7, 117, 194, 216, 111, 236,  91,  65, 246, 165,  18,   8, 191,  60, 139, 145,  38,  84, 227, 249,  78, 205, 122,  96, 215,
 198, 113, 107, 220,  95, 232, 242,  69,  55, 128, 154,  45, 174,  25,   3, 180, 231,  80,  74, 253, 126, 201, 211, 100,  22, 161, 187,  12, 143,  56,  34, 149,
 203, 124, 102, 209,  82, 229, 255,  72,  58, 141, 151,  32, 163,  20,  14, 185, 234,  93,  71, 240, 115, 196, 222, 105,  27, 172, 182,   1, 130,  53,  47, 152,
 137,  62,  36, 147,  16, 167, 189,  10, 120, 207, 213,  98, 225,  86,  76, 251, 168,  31,   5, 178,  49, 134, 156,  43,  89, 238, 244,  67, 192, 119, 109, 218,
  79, 248, 226,  85, 214,  97, 123, 204, 190,   9,  19, 164,  39, 144, 138,  61, 110, 217, 195, 116, 247,  64,  90, 237, 159,  40,  50, 133,   6, 177, 171,  28,
  13, 186, 160,  23, 148,  35,  57, 142, 252,  75,  81, 230, 101, 210, 200, 127,  44, 155, 129,  54, 181,   2,  24, 175, 221, 106, 112, 199,  68, 243, 233,  94},

{  0, 184, 179,  11, 165,  29,  22, 174, 137,  49,  58, 130,  44, 148, 159,  39, 209, 105,  98, 218, 116, 204, 199, 127,  88, 224, 235,  83, 253,  69,  78, 246,
  97, 217, 210, 106, 196, 124, 119, 207, 232,  80,  91, 227,  77, 245, 254,  70, 176,   8,   3, 187,  21, 173, 166,  30,  57, 129, 138,  50, 156,  36,  47, 151,
 194, 122, 113, 201, 103, 223, 212, 108,  75, 243, 248,  64, 238,  86,  93, 229,  19, 171, 160,  24, 182,  14,   5, 189, 154,  34,  41, 145,  63, 135, 140,  52,
 163,  27,  16, 168,   6, 190, 181,  13,  42, 146, 153,  33, 143,  55,  60, 132, 114, 202, 193, 121, 215, 111, 100, 220, 251,  67,  72, 240,  94, 230, 237,  85,
  71, 255, 244,  76, 226,  90,  81, 233, 206, 118, 125, 197, 107, 211, 216,  96, 150,  46,  37, 157,  51, 139, 128,  56,  31, 167, 172,  20, 186,   2,   9, 177,
  38, 158, 149,  45, 131,  59,  48, 136, 175,  23,  28, 164,  10, 178, 185,   1, 247,  79,  68, 252,  82, 234, 225,  89, 126, 198, 205, 117, 219,  99, 104, 208,
 133,  61,  54, 142,  32, 152, 147,  43,  12, 180, 191,   7, 169,  17,  26, 162,  84, 236, 231,  95, 241,  73,  66, 250, 221, 101, 110, 214, 120, 192, 203, 115,
 228,  92,  87, 239,  65, 249, 242,  74, 109, 213, 222, 102, 200, 112, 123, 195,  53, 141, 134,  62, 144,  40,  35, 155, 188,   4,  15, 183,  25, 161, 170,  18},

{  0, 185, 177,   8, 161,  24,  16, 169, 129,  56,  48, 137,  32, 153, 145,  40, 193, 120, 112, 201,  96, 217, 209, 104,  64, 249, 241,  72, 225,  88,  80, 233,
  65, 248, 240,  73, 224,  89,  81, 232, 192, 121, 113, 200,  97, 216, 208, 105, 128,  57,  49, 136,  33, 152, 144,  41,   1, 184, 176,   9, 160,  25,  17, 168,
 130,  59,  51, 138,  35, 154, 146,  43,   3, 186, 178,  11, 162,  27,  19, 170,  67, 250, 242,  75, 226,  91,  83, 234, 194, 123, 115, 202,  99, 218, 210, 107,
 195, 122, 114, 203,  98, 219, 211, 106,  66, 251, 243,  74, 227,  90,  82, 235,   2, 187, 179,  10, 163,  26,  18, 171, 131,  58,  50, 139,  34, 155, 147,  42,
 199, 126, 118, 207, 102, 223, 215, 110,  70, 255, 247,  78, 231,  94,  86, 239,   6, 191, 183,  14, 167,  30,  22, 175, 135,  62,  54, 143,  38, 159, 151,  46,
 134,  63,  55, 142,  39, 158, 150,  47,   7, 190, 182,  15, 166,  31,  23, 174,  71, 254, 246,  79, 230,  95,  87, 238, 198, 127, 119, 206, 103, 222, 214, 111,
  69, 252, 244,  77, 228,  93,  85, 236, 196, 125, 117, 204, 101, 220, 212, 109, 132,  61,  53, 140,  37, 156, 148,  45,   5, 188, 180,  13, 164,  29,  21, 172,
   4, 189, 181,  12, 165,  28,  20, 173, 133,  60,  52, 141,  36, 157, 149,  44, 197, 124, 116, 205, 100, 221, 213, 108,  68, 253, 245,  76, 229,  92,  84, 237},

{  0, 186, 183,  13, 173,  23,  26, 160, 153,  35,  46, 148,  52, 142, 131,  57, 241,  75,  70, 252,  92, 230, 235,  81, 104, 210, 223, 101, 197, 127, 114, 200,
  33, 155, 150,  44, 140,  54,  59, 129, 184,   2,  15, 181,  21, 175, 162,  24, 208, 106, 103, 221, 125, 199, 202, 112,  73, 243, 254,  68, 228,  94,  83, 233,
  66, 248, 245,  79, 239,  85,  88, 226, 219,  97, 108, 214, 118, 204, 193, 123, 179,   9,   4, 190,  30, 164, 169,  19,  42, 144, 157,  39, 135,  61,  48, 138,
  99, 217, 212, 110, 206, 116, 121, 195, 250,  64,  77, 247,  87, 237, 224,  90, 146,  40,  37, 159,  63, 133, 136,  50,  11, 177, 188,   6, 166,  28,  17, 171,
 132,  62,  51, 137,  41, 147, 158,  36,  29, 167, 170,  16, 176,  10,   7, 189, 117, 207, 194, 120, 216,  98, 111, 213, 236,  86,  91, 225,  65, 251, 246,  76,
 165,  31,  18, 168,   8, 178, 191,   5,  60, 134, 139,  49, 145,  43,  38, 156,  84, 238, 227,  89, 249,  67,  78, 244, 205, 119, 122, 192,  96, 218, 215, 109,
 198, 124, 113, 203, 107, 209, 220, 102,  95, 229, 232,  82, 242,  72,  69, 255,  55, 141, 128,  58, 154,  32,  45, 151, 174,  20,  25, 163,   3, 185, 180,  14,
 231,  93,  80, 234,  74, 240, 253,  71, 126, 196, 201, 115, 211, 105, 100, 222,  22, 172, 161,  27, 187,   1,  12, 182, 143,  53,  56, 130,  34, 152, 149,  47},

{  0, 187, 181,  14, 169,  18,  28, 167, 145,  42,  36, 159,  56, 131, 141,  54, 225,  90,  84, 239,  72, 243, 253,  70, 112, 203, 197, 126, 217,  98, 108, 215,
   1, 186, 180,  15, 168,  19,  29, 166, 144,  43,  37, 158,  57, 130, 140,  55, 224,  91,  85, 238,  73, 242, 252,  71, 113, 202, 196, 127, 216,  99, 109, 214,
   2, 185, 183,  12, 171,  16,  30, 165, 147,  40,  38, 157,  58, 129, 143,  52, 227,  88,  86, 237,  74, 241, 255,  68, 114, 201, 199, 124, 219,  96, 110, 213,
   3, 184, 182,  13, 170,  17,  31, 164, 146,  41,  39, 156,  59, 128, 142,  53, 226,  89,  87, 236,  75, 240, 254,  69, 115, 200, 198, 125, 218,  97, 111, 212,
   4, 191, 177,  10, 173,  22,  24, 163, 149,  46,  32, 155,  60, 135, 137,  50, 229,  94,  80, 235,  76, 247, 249,  66, 116, 207, 193, 122, 221, 102, 104, 211,
   5, 190, 176,  11, 172,  23,  25, 162, 148,  47,  33, 154,  61, 134, 136,  51, 228,  95,  81, 234,  77, 246, 248,  67, 117, 206, 192, 123, 220, 103, 105, 210,
   6, 189, 179,   8, 175,  20,  26, 161, 151,  44,  34, 153,  62, 133, 139,  48, 231,  92,  82, 233,  78, 245, 251,  64, 118, 205, 195, 120, 223, 100, 106, 209,
   7, 188, 178,   9, 174,  21,  27, 160, 150,  45,  35, 152,  63, 132, 138,  49, 230,  93,  83, 232,  79, 244, 250,  65, 119, 204, 194, 121, 222, 101, 107, 208},

{  0, 188, 187,   7, 181,   9,  14, 178, 169,  21,  18, 174,  28, 160, 167,  27, 145,  45,  42, 150,  36, 152, 159,  35,  56, 132, 131,  63, 141,  49,  54, 138,
 225,  93,  90, 230,  84, 232, 239,  83,  72, 244, 243,  79, 253,  65,  70, 250, 112, 204, 203, 119, 197, 121, 126, 194, 217, 101,  98, 222, 108, 208, 215, 107,
   1, 189, 186,   6, 180,   8,  15, 179, 168,  20,  19, 175,  29, 161, 166,  26, 144,  44,  43, 151,  37, 153, 158,  34,  57, 133, 130,  62, 140,  48,  55, 139,
 224,  92,  91, 231,  85, 233, 238,  82,  73, 245, 242,  78, 252,  64,  71, 251, 113, 205, 202, 118, 196, 120, 127, 195, 216, 100,  99, 223, 109, 209, 214, 106,
   2, 190, 185,   5, 183,  11,  12, 176, 171,  23,  16, 172,  30, 162, 165,  25, 147,  47,  40, 148,  38, 154, 157,  33,  58, 134, 129,  61, 143,  51,  52, 136,
 227,  95,  88, 228,  86, 234, 237,  81,  74, 246, 241,  77, 255,  67,  68, 248, 114, 206, 201, 117, 199, 123, 124, 192, 219, 103,  96, 220, 110, 210, 213, 105,
   3, 191, 184,   4, 182,  10,  13, 177, 170,  22,  17, 173,  31, 163, 164,  24, 146,  46,  41, 149,  39, 155, 156,  32,  59, 135, 128,  60, 142,  50,  53, 137,
 226,  94,  89, 229,  87, 235, 236,  80,  75, 247, 240,  76, 254,  66,  69, 249, 115, 207, 200, 116, 198, 122, 125, 193, 218, 102,  97, 221, 111, 211, 212, 104},

{  0, 189, 185,   4, 177,  12,   8, 181, 161,  28,  24, 165,  16, 173, 169,  20, 129,  60,  56, 133,  48, 141, 137,  52,  32, 157, 153,  36, 145,  44,  40, 149,
 193, 124, 120, 197, 112, 205, 201, 116,  96, 221, 217, 100, 209, 108, 104, 213,  64, 253, 249,  68, 241,  76,  72, 245, 225,  92,  88, 229,  80, 237, 233,  84,
  65, 252, 248,  69, 240,  77,  73, 244, 224,  93,  89, 228,  81, 236, 232,  85, 192, 125, 121, 196, 113, 204, 200, 117,  97, 220, 216, 101, 208, 109, 105, 212,
 128,  61,  57, 132,  49, 140, 136,  53,  33, 156, 152,  37, 144,  45,  41, 148,   1, 188, 184,   5, 176,  13,   9, 180, 160,  29,  25, 164,  17, 172, 168,  21,
 130,  63,  59, 134,  51, 142, 138,  55,  35, 158, 154,  39, 146,  47,  43, 150,   3, 190, 186,   7, 178,  15,  11, 182, 162,  31,  27, 166,  19, 174, 170,  23,
  67, 254, 250,  71, 242,  79,  75, 246, 226,  95,  91, 230,  83, 238, 234,  87, 194, 127, 123, 198, 115, 206, 202, 119,  99, 222, 218, 103, 210, 111, 107, 214,
 195, 126, 122, 199, 114, 207, 203, 118,  98, 223, 219, 102, 211, 110, 106, 215,  66, 255, 251,  70, 243,  78,  74, 247, 227,  94,  90, 231,  82, 239, 235,  86,
   2, 191, 187,   6, 179,  14,  10, 183, 163,  30,  26, 167,  18, 175, 171,  22, 131,  62,  58, 135,  50, 143, 139,  54,  34, 159, 155,  38, 147,  46,  42, 151},

{  0, 190, 191,   1, 189,   3,   2, 188, 185,   7,   6, 184,   4, 186, 187,   5, 177,  15,  14, 176,  12, 178, 179,  13,   8, 182, 183,   9, 181,  11,  10, 180,
 161,  31,  30, 160,  28, 162, 163,  29,  24, 166, 167,  25, 165,  27,  26, 164,  16, 174, 175,  17, 173,  19,  18, 172, 169,  23,  22, 168,  20, 170, 171,  21,
 129,  63,  62, 128,  60, 130, 131,  61,  56, 134, 135,  57, 133,  59,  58, 132,  48, 142, 143,  49, 141,  51,  50, 140, 137,  55,  54, 136,  52, 138, 139,  53,
  32, 158, 159,  33, 157,  35,  34, 156, 153,  39,  38, 152,  36, 154, 155,  37, 145,  47,  46, 144,  44, 146, 147,  45,  40, 150, 151,  41, 149,  43,  42, 148,
 193, 127, 126, 192, 124, 194, 195, 125, 120, 198, 199, 121, 197, 123, 122, 196, 112, 206, 207, 113, 205, 115, 114, 204, 201, 119, 118, 200, 116, 202, 203, 117,
  96, 222, 223,  97, 221,  99,  98, 220, 217, 103, 102, 216, 100, 218, 219, 101, 209, 111, 110, 208, 108, 210, 211, 109, 104, 214, 215, 105, 213, 107, 106, 212,
  64, 254, 255,  65, 253,  67,  66, 252, 249,  71,  70, 248,  68, 250, 251,  69, 241,  79,  78, 240,  76, 242, 243,  77,  72, 246, 247,  73, 245,  75,  74, 244,
 225,  95,  94, 224,  92, 226, 227,  93,  88, 230, 231,  89, 229,  91,  90, 228,  80, 238, 239,  81, 237,  83,  82, 236, 233,  87,  86, 232,  84, 234, 235,  85},

{  0, 191, 189,   2, 185,   6,   4, 187, 177,  14,  12, 179,   8, 183, 181,  10, 161,  30,  28, 163,  24, 167, 165,  26,  16, 175, 173,  18, 169,  22,  20, 171,
 129,  62,  60, 131,  56, 135, 133,  58,  48, 143, 141,  50, 137,  54,  52, 139,  32, 159, 157,  34, 153,  38,  36, 155, 145,  46,  44, 147,  40, 151, 149,  42,
 193, 126, 124, 195, 120, 199, 197, 122, 112, 207, 205, 114, 201, 118, 116, 203,  96, 223, 221,  98, 217, 102, 100, 219, 209, 110, 108, 211, 104, 215, 213, 106,
  64, 255, 253,  66, 249,  70,  68, 251, 241,  78,  76, 243,  72, 247, 245,  74, 225,  94,  92, 227,  88, 231, 229,  90,  80, 239, 237,  82, 233,  86,  84, 235,
  65, 254, 252,  67, 248,  71,  69, 250, 240,  79,  77, 242,  73, 246, 244,  75, 224,  95,  93, 226,  89, 230, 228,  91,  81, 238, 236,  83, 232,  87,  85, 234,
 192, 127, 125, 194, 121, 198, 196, 123, 113, 206, 204, 115, 200, 119, 117, 202,  97, 222, 220,  99, 216, 103, 101, 218, 208, 111, 109, 210, 105, 214, 212, 107,
 128,  63,  61, 130,  57, 134, 132,  59,  49, 142, 140,  51, 136,  55,  53, 138,  33, 158, 156,  35, 152,  39,  37, 154, 144,  47,  45, 146,  41, 150, 148,  43,
   1, 190, 188,   3, 184,   7,   5, 186, 176,  15,  13, 178,   9, 182, 180,  11, 160,  31,  29, 162,  25, 166, 164,  27,  17, 174, 172,  19, 168,  23,  21, 170},

{  0, 192,  67, 131, 134,  70, 197,   5, 207,  15, 140,  76,  73, 137,  10, 202,  93, 157,  30, 222, 219,  27, 152,  88, 146,  82, 209,  17,  20, 212,  87, 151,
 186, 122, 249,  57,  60, 252, 127, 191, 117, 181,  54, 246, 243,  51, 176, 112, 231,  39, 164, 100,  97, 161,  34, 226,  40, 232, 107, 171, 174, 110, 237,  45,
 183, 119, 244,  52,  49, 241, 114, 178, 120, 184,  59, 251, 254,  62, 189, 125, 234,  42, 169, 105, 108, 172,  47, 239,  37, 229, 102, 166, 163,  99, 224,  32,
  13, 205,  78, 142, 139,  75, 200,   8, 194,   2, 129,  65,  68, 132,   7, 199,  80, 144,  19, 211, 214,  22, 149,  85, 159,  95, 220,  28,  25, 217,  90, 154,
 173, 109, 238,  46,  43, 235, 104, 168,  98, 162,  33, 225, 228,  36, 167, 103, 240,  48, 179, 115, 118, 182,  53, 245,  63, 255, 124, 188, 185, 121, 250,  58,
  23, 215,  84, 148, 145,  81, 210,  18, 216,  24, 155,  91,  94, 158,  29, 221,  74, 138,   9, 201, 204,  12, 143,  79, 133,  69, 198,   6,   3, 195,  64, 128,
  26, 218,  89, 153, 156,  92, 223,  31, 213,  21, 150,  86,  83, 147,  16, 208,  71, 135,   4, 196, 193,   1, 130,  66, 136,  72, 203,  11,  14, 206,  77, 141,
 160,  96, 227,  35,  38, 230, 101, 165, 111, 175,  44, 236, 233,  41, 170, 106, 253,  61, 190, 126, 123, 187,  56, 248,  50, 242, 113, 177, 180, 116, 247,  55},

{  0, 193,  65, 128, 130,  67, 195,   2, 199,   6, 134,  71,  69, 132,   4, 197,  77, 140,  12, 205, 207,  14, 142,  79, 138,  75, 203,  10,   8, 201,  73, 136,
 154,  91, 219,  26,  24, 217,  89, 152,  93, 156,  28, 221, 223,  30, 158,  95, 215,  22, 150,  87,  85, 148,  20, 213,  16, 209,  81, 144, 146,  83, 211,  18,
 247,  54, 182, 119, 117, 180,  52, 245,  48, 241, 113, 176, 178, 115, 243,  50, 186, 123, 251,  58,  56, 249, 121, 184, 125, 188,  60, 253, 255,  62, 190, 127,
 109, 172,  44, 237, 239,  46, 174, 111, 170, 107, 235,  42,  40, 233, 105, 168,  32, 225,  97, 160, 162,  99, 227,  34, 231,  38, 166, 103, 101, 164,  36, 229,
  45, 236, 108, 173, 175, 110, 238,  47, 234,  43, 171, 106, 104, 169,  41, 232,  96, 161,  33, 224, 226,  35, 163,  98, 167, 102, 230,  39,  37, 228, 100, 165,
 183, 118, 246,  55,  53, 244, 116, 181, 112, 177,  49, 240, 242,  51, 179, 114, 250,  59, 187, 122, 120, 185,  57, 248,  61, 252, 124, 189, 191, 126, 254,  63,
 218,  27, 155,  90,  88, 153,  25, 216,  29, 220,  92, 157, 159,  94, 222,  31, 151,  86, 214,  23,  21, 212,  84, 149,  80, 145,  17, 208, 210,  19, 147,  82,
  64, 129,   1, 192, 194,   3, 131,  66, 135,  70, 198,   7,   5, 196,  68, 133,  13, 204,  76, 141, 143,  78, 206,  15, 202,  11, 139,  74,  72, 137,   9, 200},

{  0, 194,  71, 133, 142,  76, 201,  11, 223,  29, 152,  90,  81, 147,  22, 212, 125, 191,  58, 248, 243,  49, 180, 118, 162,  96, 229,  39,  44, 238, 107, 169,
 250,  56, 189, 127, 116, 182,  51, 241,  37, 231,  98, 160, 171, 105, 236,  46, 135,  69, 192,   2,   9, 203,  78, 140,  88, 154,  31, 221, 214,  20, 145,  83,
  55, 245, 112, 178, 185, 123, 254,  60, 232,  42, 175, 109, 102, 164,  33, 227,  74, 136,  13, 207, 196,   6, 131,  65, 149,  87, 210,  16,  27, 217,  92, 158,
 205,  15, 138,  72,  67, 129,   4, 198,  18, 208,  85, 151, 156,  94, 219,  25, 176, 114, 247,  53,  62, 252, 121, 187, 111, 173,  40, 234, 225,  35, 166, 100,
 110, 172,  41, 235, 224,  34, 167, 101, 177, 115, 246,  52,  63, 253, 120, 186,  19, 209,  84, 150, 157,  95, 218,  24, 204,  14, 139,  73,  66, 128,   5, 199,
 148,  86, 211,  17,  26, 216,  93, 159,  75, 137,  12, 206, 197,   7, 130,  64, 233,  43, 174, 108, 103, 165,  32, 226,  54, 244, 113, 179, 184, 122, 255,  61,
  89, 155,  30, 220, 215,  21, 144,  82, 134,  68, 193,   3,   8, 202,  79, 141,  36, 230,  99, 161, 170, 104, 237,  47, 251,  57, 188, 126, 117, 183,  50, 240,
 163,  97, 228,  38,  45, 239, 106, 168, 124, 190,  59, 249, 242,  48, 181, 119, 222,  28, 153,  91,  80, 146,  23, 213,   1, 195,  70, 132, 143,  77, 200,  10},

{  0, 195,  69, 134, 138,  73, 207,  12, 215,  20, 146,  81,  93, 158,  24, 219, 109, 174,  40, 235, 231,  36, 162,  97, 186, 121, 255,  60,  48, 243, 117, 182,
 218,  25, 159,  92,  80, 147,  21, 214,  13, 206,  72, 139, 135,  68, 194,   1, 183, 116, 242,  49,  61, 254, 120, 187,  96, 163,  37, 230, 234,  41, 175, 108,
 119, 180,  50, 241, 253,  62, 184, 123, 160,  99, 229,  38,  42, 233, 111, 172,  26, 217,  95, 156, 144,  83, 213,  22, 205,  14, 136,  75,  71, 132,   2, 193,
 173, 110, 232,  43,  39, 228,  98, 161, 122, 185,  63, 252, 240,  51, 181, 118, 192,   3, 133,  70,  74, 137,  15, 204,  23, 212,  82, 145, 157,  94, 216,  27,
 238,  45, 171, 104, 100, 167,  33, 226,  57, 250, 124, 191, 179, 112, 246,  53, 131,  64, 198,   5,   9, 202,  76, 143,  84, 151,  17, 210, 222,  29, 155,  88,
  52, 247, 113, 178, 190, 125, 251,  56, 227,  32, 166, 101, 105, 170,  44, 239,  89, 154,  28, 223, 211,  16, 150,  85, 142,  77, 203,   8,   4, 199,  65, 130,
 153,  90, 220,  31,  19, 208,  86, 149,  78, 141,  11, 200, 196,   7, 129,  66, 244,  55, 177, 114, 126, 189,  59, 248,  35, 224, 102, 165, 169, 106, 236,  47,
  67, 128,   6, 197, 201,  10, 140,  79, 148,  87, 209,  18,  30, 221,  91, 152,  46, 237, 107, 168, 164, 103, 225,  34, 249,  58, 188, 127, 115, 176,  54, 245},

{  0, 196,  75, 143, 150,  82, 221,  25, 239,  43, 164,  96, 121, 189,  50, 246,  29, 217,  86, 146, 139,  79, 192,   4, 242,  54, 185, 125, 100, 160,  47, 235,
  58, 254, 113, 181, 172, 104, 231,  35, 213,  17, 158,  90,  67, 135,   8, 204,  39, 227, 108, 168, 177, 117, 250,  62, 200,  12, 131,  71,  94, 154,  21, 209,
 116, 176,  63, 251, 226,  38, 169, 109, 155,  95, 208,  20,  13, 201,  70, 130, 105, 173,  34, 230, 255,  59, 180, 112, 134,  66, 205,   9,  16, 212,  91, 159,
  78, 138,   5, 193, 216,  28, 147,  87, 161, 101, 234,  46,  55, 243, 124, 184,  83, 151,  24, 220, 197,   1, 142,  74, 188, 120, 247,  51,  42, 238,  97, 165,
 232,  44, 163, 103, 126, 186,  53, 241,   7, 195,  76, 136, 145,  85, 218,  30, 245,  49, 190, 122,  99, 167,  40, 236,  26, 222,  81, 149, 140,  72, 199,   3,
 210,  22, 153,  93,  68, 128,  15, 203,  61, 249, 118, 178, 171, 111, 224,  36, 207,  11, 132,  64,  89, 157,  18, 214,  32, 228, 107, 175, 182, 114, 253,  57,
 156,  88, 215,  19,  10, 206,  65, 133, 115, 183,  56, 252, 229,  33, 174, 106, 129,  69, 202,  14,  23, 211,  92, 152, 110, 170,  37, 225, 248,  60, 179, 119,
 166,  98, 237,  41,  48, 244, 123, 191,  73, 141,   2, 198, 223,  27, 148,  80, 187, 127, 240,  52,  45, 233, 102, 162,  84, 144,  31, 219, 194,   6, 137,  77},

{  0, 197,  73, 140, 146,  87, 219,  30, 231,  34, 174, 107, 117, 176,  60, 249,  13, 200,  68, 129, 159,  90, 214,  19, 234,  47, 163, 102, 120, 189,  49, 244,
  26, 223,  83, 150, 136,  77, 193,   4, 253,  56, 180, 113, 111, 170,  38, 227,  23, 210,  94, 155, 133,  64, 204,   9, 240,  53, 185, 124,  98, 167,  43, 238,
  52, 241, 125, 184, 166,  99, 239,  42, 211,  22, 154,  95,  65, 132,   8, 205,  57, 252, 112, 181, 171, 110, 226,  39, 222,  27, 151,  82,  76, 137,   5, 192,
  46, 235, 103, 162, 188, 121, 245,  48, 201,  12, 128,  69,  91, 158,  18, 215,  35, 230, 106, 175, 177, 116, 248,  61, 196,   1, 141,  72,  86, 147,  31, 218,
 104, 173,  33, 228, 250,  63, 179, 118, 143,  74, 198,   3,  29, 216,  84, 145, 101, 160,  44, 233, 247,  50, 190, 123, 130,  71, 203,  14,  16, 213,  89, 156,
 114, 183,  59, 254, 224,  37, 169, 108, 149,  80, 220,  25,   7, 194,  78, 139, 127, 186,  54, 243, 237,  40, 164,  97, 152,  93, 209,  20,  10, 207,  67, 134,
  92, 153,  21, 208, 206,  11, 135,  66, 187, 126, 242,  55,  41, 236,  96, 165,  81, 148,  24, 221, 195,   6, 138,  79, 182, 115, 255,  58,  36, 225, 109, 168,
  70, 131,  15, 202, 212,  17, 157,  88, 161, 100, 232,  45,  51, 246, 122, 191,  75, 142,   2, 199, 217,  28, 144,  85, 172, 105, 229,  32,  62, 251, 119, 178},

{  0, 198,  79, 137, 158,  88, 209,  23, 255,  57, 176, 118,  97, 167,  46, 232,  61, 251, 114, 180, 163, 101, 236,  42, 194,   4, 141,  75,  92, 154,  19, 213,
 122, 188,  53, 243, 228,  34, 171, 109, 133,  67, 202,  12,  27, 221,  84, 146,  71, 129,   8, 206, 217,  31, 150,  80, 184, 126, 247,  49,  38, 224, 105, 175,
 244,  50, 187, 125, 106, 172,  37, 227,  11, 205,  68, 130, 149,  83, 218,  28, 201,  15, 134,  64,  87, 145,  24, 222,  54, 240, 121, 191, 168, 110, 231,  33,
 142,  72, 193,   7,  16, 214,  95, 153, 113, 183,  62, 248, 239,  41, 160, 102, 179, 117, 252,  58,  45, 235,  98, 164,  76, 138,   3, 197, 210,  20, 157,  91,
  43, 237, 100, 162, 181, 115, 250,  60, 212,  18, 155,  93,  74, 140,   5, 195,  22, 208,  89, 159, 136,  78, 199,   1, 233,  47, 166,  96, 119, 177,  56, 254,
  81, 151,  30, 216, 207,   9, 128,  70, 174, 104, 225,  39,  48, 246, 127, 185, 108, 170,  35, 229, 242,  52, 189, 123, 147,  85, 220,  26,  13, 203,  66, 132,
 223,  25, 144,  86,  65, 135,  14, 200,  32, 230, 111, 169, 190, 120, 241,  55, 226,  36, 173, 107, 124, 186,  51, 245,  29, 219,  82, 148, 131,  69, 204,  10,
 165,  99, 234,  44,  59, 253, 116, 178,  90, 156,  21, 211, 196,   2, 139,  77, 152,  94, 215,  17,   6, 192,  73, 143, 103, 161,  40, 238, 249,  63, 182, 112},

{  0, 199,  77, 138, 154,  93, 215,  16, 247,  48, 186, 125, 109, 170,  32, 231,  45, 234,  96, 167, 183, 112, 250,  61, 218,  29, 151,  80,  64, 135,  13, 202,
  90, 157,  23, 208, 192,   7, 141,  74, 173, 106, 224,  39,  55, 240, 122, 189, 119, 176,  58, 253, 237,  42, 160, 103, 128,  71, 205,  10,  26, 221,  87, 144,
 180, 115, 249,  62,  46, 233,  99, 164,  67, 132,  14, 201, 217,  30, 148,  83, 153,  94, 212,  19,   3, 196,  78, 137, 110, 169,  35, 228, 244,  51, 185, 126,
 238,  41, 163, 100, 116, 179,  57, 254,  25, 222,  84, 147, 131,  68, 206,   9, 195,   4, 142,  73,  89, 158,  20, 211,  52, 243, 121, 190, 174, 105, 227,  36,
 171, 108, 230,  33,  49, 246, 124, 187,  92, 155,  17, 214, 198,   1, 139,  76, 134,  65, 203,  12,  28, 219,  81, 150, 113, 182,  60, 251, 235,  44, 166,  97,
 241,  54, 188, 123, 107, 172,  38, 225,   6, 193,  75, 140, 156,  91, 209,  22, 220,  27, 145,  86,  70, 129,  11, 204,  43, 236, 102, 161, 177, 118, 252,  59,
  31, 216,  82, 149, 133,  66, 200,  15, 232,  47, 165,  98, 114, 181,  63, 248,  50, 245, 127, 184, 168, 111, 229,  34, 197,   2, 136,  79,  95, 152,  18, 213,
  69, 130,   8, 207, 223,  24, 146,  85, 178, 117, 255,  56,  40, 239, 101, 162, 104, 175,  37, 226, 242,  53, 191, 120, 159,  88, 210,  21,   5, 194,  72, 143},

{  0, 200,  83, 155, 166, 110, 245,  61, 143,  71, 220,  20,  41, 225, 122, 178, 221,  21, 142,  70, 123, 179,  40, 224,  82, 154,   1, 201, 244,  60, 167, 111,
 121, 177,  42, 226, 223,  23, 140,  68, 246,  62, 165, 109,  80, 152,   3, 203, 164, 108, 247,  63,   2, 202,  81, 153,  43, 227, 120, 176, 141,  69, 222,  22,
 242,  58, 161, 105,  84, 156,   7, 207, 125, 181,  46, 230, 219,  19, 136,  64,  47, 231, 124, 180, 137,  65, 218,  18, 160, 104, 243,  59,   6, 206,  85, 157,
 139,  67, 216,  16,  45, 229, 126, 182,   4, 204,  87, 159, 162, 106, 241,  57,  86, 158,   5, 205, 240,  56, 163, 107, 217,  17, 138,  66, 127, 183,  44, 228,
  39, 239, 116, 188, 129,  73, 210,  26, 168,  96, 251,  51,  14, 198,  93, 149, 250,  50, 169,  97,  92, 148,  15, 199, 117, 189,  38, 238, 211,  27, 128,  72,
  94, 150,  13, 197, 248,  48, 171,  99, 209,  25, 130,  74, 119, 191,  36, 236, 131,  75, 208,  24,  37, 237, 118, 190,  12, 196,  95, 151, 170,  98, 249,  49,
 213,  29, 134,  78, 115, 187,  32, 232,  90, 146,   9, 193, 252,  52, 175, 103,   8, 192,  91, 147, 174, 102, 253,  53, 135,  79, 212,  28,  33, 233, 114, 186,
 172, 100, 255,  55,  10, 194,  89, 145,  35, 235, 112, 184, 133,  77, 214,  30, 113, 185,  34, 234, 215,  31, 132,  76, 254,  54, 173, 101,  88, 144,  11, 195},

{  0, 201,  81, 152, 162, 107, 243,  58, 135,  78, 214,  31,  37, 236, 116, 189, 205,   4, 156,  85, 111, 166,  62, 247,  74, 131,  27, 210, 232,  33, 185, 112,
  89, 144,   8, 193, 251,  50, 170,  99, 222,  23, 143,  70, 124, 181,  45, 228, 148,  93, 197,  12,  54, 255, 103, 174,  19, 218,  66, 139, 177, 120, 224,  41,
 178, 123, 227,  42,  16, 217,  65, 136,  53, 252, 100, 173, 151,  94, 198,  15, 127, 182,  46, 231, 221,  20, 140,  69, 248,  49, 169,  96,  90, 147,  11, 194,
 235,  34, 186, 115,  73, 128,  24, 209, 108, 165,  61, 244, 206,   7, 159,  86,  38, 239, 119, 190, 132,  77, 213,  28, 161, 104, 240,  57,   3, 202,  82, 155,
 167, 110, 246,  63,   5, 204,  84, 157,  32, 233, 113, 184, 130,  75, 211,  26, 106, 163,  59, 242, 200,   1, 153,  80, 237,  36, 188, 117,  79, 134,  30, 215,
 254,  55, 175, 102,  92, 149,  13, 196, 121, 176,  40, 225, 219,  18, 138,  67,  51, 250,  98, 171, 145,  88, 192,   9, 180, 125, 229,  44,  22, 223,  71, 142,
  21, 220,  68, 141, 183, 126, 230,  47, 146,  91, 195,  10,  48, 249,  97, 168, 216,  17, 137,  64, 122, 179,  43, 226,  95, 150,  14, 199, 253,  52, 172, 101,
  76, 133,  29, 212, 238,  39, 191, 118, 203,   2, 154,  83, 105, 160,  56, 241, 129,  72, 208,  25,  35, 234, 114, 187,   6, 207,  87, 158, 164, 109, 245,  60},

{  0, 202,  87, 157, 174, 100, 249,  51, 159,  85, 200,   2,  49, 251, 102, 172, 253,  55, 170,  96,  83, 153,   4, 206,  98, 168,  53, 255, 204,   6, 155,  81,
  57, 243, 110, 164, 151,  93, 192,  10, 166, 108, 241,  59,   8, 194,  95, 149, 196,  14, 147,  89, 106, 160,  61, 247,  91, 145,  12, 198, 245,  63, 162, 104,
 114, 184,  37, 239, 220,  22, 139,  65, 237,  39, 186, 112,  67, 137,  20, 222, 143,  69, 216,  18,  33, 235, 118, 188,  16, 218,  71, 141, 190, 116, 233,  35,
  75, 129,  28, 214, 229,  47, 178, 120, 212,  30, 131,  73, 122, 176,  45, 231, 182, 124, 225,  43,  24, 210,  79, 133,  41, 227, 126, 180, 135,  77, 208,  26,
 228,  46, 179, 121,  74, 128,  29, 215, 123, 177,  44, 230, 213,  31, 130,  72,  25, 211,  78, 132, 183, 125, 224,  42, 134,  76, 209,  27,  40, 226, 127, 181,
 221,  23, 138,  64, 115, 185,  36, 238,  66, 136,  21, 223, 236,  38, 187, 113,  32, 234, 119, 189, 142,  68, 217,  19, 191, 117, 232,  34,  17, 219,  70, 140,
 150,  92, 193,  11,  56, 242, 111, 165,   9, 195,  94, 148, 167, 109, 240,  58, 107, 161,  60, 246, 197,  15, 146,  88, 244,  62, 163, 105,  90, 144,  13, 199,
 175, 101, 248,  50,   1, 203,  86, 156,  48, 250, 103, 173, 158,  84, 201,   3,  82, 152,   5, 207, 252,  54, 171,  97, 205,   7, 154,  80,  99, 169,  52, 254},

{  0, 203,  85, 158, 170,  97, 255,  52, 151,  92, 194,   9,  61, 246, 104, 163, 237,  38, 184, 115,  71, 140,  18, 217, 122, 177,  47, 228, 208,  27, 133,  78,
  25, 210,  76, 135, 179, 120, 230,  45, 142,  69, 219,  16,  36, 239, 113, 186, 244,  63, 161, 106,  94, 149,  11, 192,  99, 168,  54, 253, 201,   2, 156,  87,
  50, 249, 103, 172, 152,  83, 205,   6, 165, 110, 240,  59,  15, 196,  90, 145, 223,  20, 138,  65, 117, 190,  32, 235,  72, 131,  29, 214, 226,  41, 183, 124,
  43, 224, 126, 181, 129,  74, 212,  31, 188, 119, 233,  34,  22, 221,  67, 136, 198,  13, 147,  88, 108, 167,  57, 242,  81, 154,   4, 207, 251,  48, 174, 101,
 100, 175,  49, 250, 206,   5, 155,  80, 243,  56, 166, 109,  89, 146,  12, 199, 137,  66, 220,  23,  35, 232, 118, 189,  30, 213,  75, 128, 180, 127, 225,  42,
 125, 182,  40, 227, 215,  28, 130,  73, 234,  33, 191, 116,  64, 139,  21, 222, 144,  91, 197,  14,  58, 241, 111, 164,   7, 204,  82, 153, 173, 102, 248,  51,
  86, 157,   3, 200, 252,  55, 169,  98, 193,  10, 148,  95, 107, 160,  62, 245, 187, 112, 238,  37,  17, 218,  68, 143,  44, 231, 121, 178, 134,  77, 211,  24,
  79, 132,  26, 209, 229,  46, 176, 123, 216,  19, 141,  70, 114, 185,  39, 236, 162, 105, 247,  60,   8, 195,  93, 150,  53, 254,  96, 171, 159,  84, 202,   1},

{  0, 204,  91, 151, 182, 122, 237,  33, 175,  99, 244,  56,  25, 213,  66, 142, 157,  81, 198,  10,  43, 231, 112, 188,  50, 254, 105, 165, 132,  72, 223,  19,
 249,  53, 162, 110,  79, 131,  20, 216,  86, 154,  13, 193, 224,  44, 187, 119, 100, 168,  63, 243, 210,  30, 137,  69, 203,   7, 144,  92, 125, 177,  38, 234,
  49, 253, 106, 166, 135,  75, 220,  16, 158,  82, 197,   9,  40, 228, 115, 191, 172,  96, 247,  59,  26, 214,  65, 141,   3, 207,  88, 148, 181, 121, 238,  34,
 200,   4, 147,  95, 126, 178,  37, 233, 103, 171,  60, 240, 209,  29, 138,  70,  85, 153,  14, 194, 227,  47, 184, 116, 250,  54, 161, 109,  76, 128,  23, 219,
  98, 174,  57, 245, 212,  24, 143,  67, 205,   1, 150,  90, 123, 183,  32, 236, 255,  51, 164, 104,  73, 133,  18, 222,  80, 156,  11, 199, 230,  42, 189, 113,
 155,  87, 192,  12,  45, 225, 118, 186,  52, 248, 111, 163, 130,  78, 217,  21,   6, 202,  93, 145, 176, 124, 235,  39, 169, 101, 242,  62,  31, 211,  68, 136,
  83, 159,   8, 196, 229,  41, 190, 114, 252,  48, 167, 107,  74, 134,  17, 221, 206,   2, 149,  89, 120, 180,  35, 239,  97, 173,  58, 246, 215,  27, 140,  64,
 170, 102, 241,  61,  28, 208,  71, 139,   5, 201,  94, 146, 179, 127, 232,  36,  55, 251, 108, 160, 129,  77, 218,  22, 152,  84, 195,  15,  46, 226, 117, 185},

{  0, 205,  89, 148, 178, 127, 235,  38, 167, 106, 254,  51,  21, 216,  76, 129, 141,  64, 212,  25,  63, 242, 102, 171,  42, 231, 115, 190, 152,  85, 193,  12,
 217,  20, 128,  77, 107, 166,  50, 255, 126, 179,  39, 234, 204,   1, 149,  88,  84, 153,  13, 192, 230,  43, 191, 114, 243,  62, 170, 103,  65, 140,  24, 213,
 113, 188,  40, 229, 195,  14, 154,  87, 214,  27, 143,  66, 100, 169,  61, 240, 252,  49, 165, 104,  78, 131,  23, 218,  91, 150,   2, 207, 233,  36, 176, 125,
 168, 101, 241,  60,  26, 215,  67, 142,  15, 194,  86, 155, 189, 112, 228,  41,  37, 232, 124, 177, 151,  90, 206,   3, 130,  79, 219,  22,  48, 253, 105, 164,
 226,  47, 187, 118,  80, 157,   9, 196,  69, 136,  28, 209, 247,  58, 174,  99, 111, 162,  54, 251, 221,  16, 132,  73, 200,   5, 145,  92, 122, 183,  35, 238,
  59, 246,  98, 175, 137,  68, 208,  29, 156,  81, 197,   8,  46, 227, 119, 186, 182, 123, 239,  34,   4, 201,  93, 144,  17, 220,  72, 133, 163, 110, 250,  55,
 147,  94, 202,   7,  33, 236, 120, 181,  52, 249, 109, 160, 134,  75, 223,  18,  30, 211,  71, 138, 172,  97, 245,  56, 185, 116, 224,  45,  11, 198,  82, 159,
  74, 135,  19, 222, 248,  53, 161, 108, 237,  32, 180, 121,  95, 146,   6, 203, 199,  10, 158,  83, 117, 184,  44, 225,  96, 173,  57, 244, 210,  31, 139,  70},

{  0, 206,  95, 145, 190, 112, 225,  47, 191, 113, 224,  46,   1, 207,  94, 144, 189, 115, 226,  44,   3, 205,  92, 146,   2, 204,  93, 147, 188, 114, 227,  45,
 185, 119, 230,  40,   7, 201,  88, 150,   6, 200,  89, 151, 184, 118, 231,  41,   4, 202,  91, 149, 186, 116, 229,  43, 187, 117, 228,  42,   5, 203,  90, 148,
 177, 127, 238,  32,  15, 193,  80, 158,  14, 192,  81, 159, 176, 126, 239,  33,  12, 194,  83, 157, 178, 124, 237,  35, 179, 125, 236,  34,  13, 195,  82, 156,
   8, 198,  87, 153, 182, 120, 233,  39, 183, 121, 232,  38,   9, 199,  86, 152, 181, 123, 234,  36,  11, 197,  84, 154,  10, 196,  85, 155, 180, 122, 235,  37,
 161, 111, 254,  48,  31, 209,  64, 142,  30, 208,  65, 143, 160, 110, 255,  49,  28, 210,  67, 141, 162, 108, 253,  51, 163, 109, 252,  50,  29, 211,  66, 140,
  24, 214,  71, 137, 166, 104, 249,  55, 167, 105, 248,  54,  25, 215,  70, 136, 165, 107, 250,  52,  27, 213,  68, 138,  26, 212,  69, 139, 164, 106, 251,  53,
  16, 222,  79, 129, 174,  96, 241,  63, 175,  97, 240,  62,  17, 223,  78, 128, 173,  99, 242,  60,  19, 221,  76, 130,  18, 220,  77, 131, 172,  98, 243,  61,
 169, 103, 246,  56,  23, 217,  72, 134,  22, 216,  73, 135, 168, 102, 247,  57,  20, 218,  75, 133, 170, 100, 245,  59, 171, 101, 244,  58,  21, 219,  74, 132},

{  0, 207,  93, 146, 186, 117, 231,  40, 183, 120, 234,  37,  13, 194,  80, 159, 173,  98, 240,  63,  23, 216,  74, 133,  26, 213,  71, 136, 160, 111, 253,  50,
 153,  86, 196,  11,  35, 236, 126, 177,  46, 225, 115, 188, 148,  91, 201,   6,  52, 251, 105, 166, 142,  65, 211,  28, 131,  76, 222,  17,  57, 246, 100, 171,
 241,  62, 172,  99,  75, 132,  22, 217,  70, 137,  27, 212, 252,  51, 161, 110,  92, 147,   1, 206, 230,  41, 187, 116, 235,  36, 182, 121,  81, 158,  12, 195,
 104, 167,  53, 250, 210,  29, 143,  64, 223,  16, 130,  77, 101, 170,  56, 247, 197,  10, 152,  87, 127, 176,  34, 237, 114, 189,  47, 224, 200,   7, 149,  90,
  33, 238, 124, 179, 155,  84, 198,   9, 150,  89, 203,   4,  44, 227, 113, 190, 140,  67, 209,  30,  54, 249, 107, 164,  59, 244, 102, 169, 129,  78, 220,  19,
 184, 119, 229,  42,   2, 205,  95, 144,  15, 192,  82, 157, 181, 122, 232,  39,  21, 218,  72, 135, 175,  96, 242,  61, 162, 109, 255,  48,  24, 215,  69, 138,
 208,  31, 141,  66, 106, 165,  55, 248, 103, 168,  58, 245, 221,  18, 128,  79, 125, 178,  32, 239, 199,   8, 154,  85, 202,   5, 151,  88, 112, 191,  45, 226,
  73, 134,  20, 219, 243,  60, 174,  97, 254,  49, 163, 108,  68, 139,  25, 214, 228,  43, 185, 118,  94, 145,   3, 204,  83, 156,  14, 193, 233,  38, 180, 123},

{  0, 208,  99, 179, 198,  22, 165, 117,  79, 159,  44, 252, 137,  89, 234,  58, 158,  78, 253,  45,  88, 136,  59, 235, 209,   1, 178,  98,  23, 199, 116, 164,
 255,  47, 156,  76,  57, 233,  90, 138, 176,  96, 211,   3, 118, 166,  21, 197,  97, 177,   2, 210, 167, 119, 196,  20,  46, 254,  77, 157, 232,  56, 139,  91,
  61, 237,  94, 142, 251,  43, 152,  72, 114, 162,  17, 193, 180, 100, 215,   7, 163, 115, 192,  16, 101, 181,   6, 214, 236,  60, 143,  95,  42, 250,  73, 153,
 194,  18, 161, 113,   4, 212, 103, 183, 141,  93, 238,  62,  75, 155,  40, 248,  92, 140,  63, 239, 154,  74, 249,  41,  19, 195, 112, 160, 213,   5, 182, 102,
 122, 170,  25, 201, 188, 108, 223,  15,  53, 229,  86, 134, 243,  35, 144,  64, 228,  52, 135,  87,  34, 242,  65, 145, 171, 123, 200,  24, 109, 189,  14, 222,
 133,  85, 230,  54,  67, 147,  32, 240, 202,  26, 169, 121,  12, 220, 111, 191,  27, 203, 120, 168, 221,  13, 190, 110,  84, 132,  55, 231, 146,  66, 241,  33,
  71, 151,  36, 244, 129,  81, 226,  50,   8, 216, 107, 187, 206,  30, 173, 125, 217,   9, 186, 106,  31, 207, 124, 172, 150,  70, 245,  37,  80, 128,  51, 227,
 184, 104, 219,  11, 126, 174,  29, 205, 247,  39, 148,  68,  49, 225,  82, 130,  38, 246,  69, 149, 224,  48, 131,  83, 105, 185,  10, 218, 175, 127, 204,  28},

{  0, 209,  97, 176, 194,  19, 163, 114,  71, 150,  38, 247, 133,  84, 228,  53, 142,  95, 239,  62,  76, 157,  45, 252, 201,  24, 168, 121,  11, 218, 106, 187,
 223,  14, 190, 111,  29, 204, 124, 173, 152,  73, 249,  40,  90, 139,  59, 234,  81, 128,  48, 225, 147,  66, 242,  35,  22, 199, 119, 166, 212,   5, 181, 100,
 125, 172,  28, 205, 191, 110, 222,  15,  58, 235,  91, 138, 248,  41, 153,  72, 243,  34, 146,  67,  49, 224,  80, 129, 180, 101, 213,   4, 118, 167,  23, 198,
 162, 115, 195,  18,  96, 177,   1, 208, 229,  52, 132,  85,  39, 246,  70, 151,  44, 253,  77, 156, 238,  63, 143,  94, 107, 186,  10, 219, 169, 120, 200,  25,
 250,  43, 155,  74,  56, 233,  89, 136, 189, 108, 220,  13, 127, 174,  30, 207, 116, 165,  21, 196, 182, 103, 215,   6,  51, 226,  82, 131, 241,  32, 144,  65,
  37, 244,  68, 149, 231,  54, 134,  87,  98, 179,   3, 210, 160, 113, 193,  16, 171, 122, 202,  27, 105, 184,   8, 217, 236,  61, 141,  92,  46, 255,  79, 158,
 135,  86, 230,  55,  69, 148,  36, 245, 192,  17, 161, 112,   2, 211,  99, 178,   9, 216, 104, 185, 203,  26, 170, 123,  78, 159,  47, 254, 140,  93, 237,  60,
  88, 137,  57, 232, 154,  75, 251,  42,  31, 206, 126, 175, 221,  12, 188, 109, 214,   7, 183, 102,  20, 197, 117, 164, 145,  64, 240,  33,  83, 130,  50, 227},

{  0, 210, 103, 181, 206,  28, 169, 123,  95, 141,  56, 234, 145,  67, 246,  36, 190, 108, 217,  11, 112, 162,  23, 197, 225,  51, 134,  84,  47, 253,  72, 154,
 191, 109, 216,  10, 113, 163,  22, 196, 224,  50, 135,  85,  46, 252,  73, 155,   1, 211, 102, 180, 207,  29, 168, 122,  94, 140,  57, 235, 144,  66, 247,  37,
 189, 111, 218,   8, 115, 161,  20, 198, 226,  48, 133,  87,  44, 254,  75, 153,   3, 209, 100, 182, 205,  31, 170, 120,  92, 142,  59, 233, 146,  64, 245,  39,
   2, 208, 101, 183, 204,  30, 171, 121,  93, 143,  58, 232, 147,  65, 244,  38, 188, 110, 219,   9, 114, 160,  21, 199, 227,  49, 132,  86,  45, 255,  74, 152,
 185, 107, 222,  12, 119, 165,  16, 194, 230,  52, 129,  83,  40, 250,  79, 157,   7, 213,  96, 178, 201,  27, 174, 124,  88, 138,  63, 237, 150,  68, 241,  35,
   6, 212,  97, 179, 200,  26, 175, 125,  89, 139,  62, 236, 151,  69, 240,  34, 184, 106, 223,  13, 118, 164,  17, 195, 231,  53, 128,  82,  41, 251,  78, 156,
   4, 214,  99, 177, 202,  24, 173, 127,  91, 137,  60, 238, 149,  71, 242,  32, 186, 104, 221,  15, 116, 166,  19, 193, 229,  55, 130,  80,  43, 249,  76, 158,
 187, 105, 220,  14, 117, 167,  18, 192, 228,  54, 131,  81,  42, 248,  77, 159,   5, 215,  98, 176, 203,  25, 172, 126,  90, 136,  61, 239, 148,  70, 243,  33},

{  0, 211, 101, 182, 202,  25, 175, 124,  87, 132,  50, 225, 157,  78, 248,  43, 174, 125, 203,  24, 100, 183,   1, 210, 249,  42, 156,  79,  51, 224,  86, 133,
 159,  76, 250,  41,  85, 134,  48, 227, 200,  27, 173, 126,   2, 209, 103, 180,  49, 226,  84, 135, 251,  40, 158,  77, 102, 181,   3, 208, 172, 127, 201,  26,
 253,  46, 152,  75,  55, 228,  82, 129, 170, 121, 207,  28,  96, 179,   5, 214,  83, 128,  54, 229, 153,  74, 252,  47,   4, 215,  97, 178, 206,  29, 171, 120,
  98, 177,   7, 212, 168, 123, 205,  30,  53, 230,  80, 131, 255,  44, 154,  73, 204,  31, 169, 122,   6, 213,  99, 176, 155,  72, 254,  45,  81, 130,  52, 231,
  57, 234,  92, 143, 243,  32, 150,  69, 110, 189,  11, 216, 164, 119, 193,  18, 151,  68, 242,  33,  93, 142,  56, 235, 192,  19, 165, 118,  10, 217, 111, 188,
 166, 117, 195,  16, 108, 191,   9, 218, 241,  34, 148,  71,  59, 232,  94, 141,   8, 219, 109, 190, 194,  17, 167, 116,  95, 140,  58, 233, 149,  70, 240,  35,
 196,  23, 161, 114,  14, 221, 107, 184, 147,  64, 246,  37,  89, 138,  60, 239, 106, 185,  15, 220, 160, 115, 197,  22,  61, 238,  88, 139, 247,  36, 146,  65,
  91, 136,  62, 237, 145,  66, 244,  39,  12, 223, 105, 186, 198,  21, 163, 112, 245,  38, 144,  67,  63, 236,  90, 137, 162, 113, 199,  20, 104, 187,  13, 222},

{  0, 212, 107, 191, 214,   2, 189, 105, 111, 187,   4, 208, 185, 109, 210,   6, 222,  10, 181,  97,   8, 220,  99, 183, 177, 101, 218,  14, 103, 179,  12, 216,
 127, 171,  20, 192, 169, 125, 194,  22,  16, 196, 123, 175, 198,  18, 173, 121, 161, 117, 202,  30, 119, 163,  28, 200, 206,  26, 165, 113,  24, 204, 115, 167,
 254,  42, 149,  65,  40, 252,  67, 151, 145,  69, 250,  46,  71, 147,  44, 248,  32, 244,  75, 159, 246,  34, 157,  73,  79, 155,  36, 240, 153,  77, 242,  38,
 129,  85, 234,  62,  87, 131,  60, 232, 238,  58, 133,  81,  56, 236,  83, 135,  95, 139,  52, 224, 137,  93, 226,  54,  48, 228,  91, 143, 230,  50, 141,  89,
  63, 235,  84, 128, 233,  61, 130,  86,  80, 132,  59, 239, 134,  82, 237,  57, 225,  53, 138,  94,  55, 227,  92, 136, 142,  90, 229,  49,  88, 140,  51, 231,
  64, 148,  43, 255, 150,  66, 253,  41,  47, 251,  68, 144, 249,  45, 146,  70, 158,  74, 245,  33,  72, 156,  35, 247, 241,  37, 154,  78,  39, 243,  76, 152,
 193,  21, 170, 126,  23, 195, 124, 168, 174, 122, 197,  17, 120, 172,  19, 199,  31, 203, 116, 160, 201,  29, 162, 118, 112, 164,  27, 207, 166, 114, 205,  25,
 190, 106, 213,   1, 104, 188,   3, 215, 209,   5, 186, 110,   7, 211, 108, 184,  96, 180,  11, 223, 182,  98, 221,   9,  15, 219, 100, 176, 217,  13, 178, 102},

{  0, 213, 105, 188, 210,   7, 187, 110, 103, 178,  14, 219, 181,  96, 220,   9, 206,  27, 167, 114,  28, 201, 117, 160, 169, 124, 192,  21, 123, 174,  18, 199,
  95, 138,  54, 227, 141,  88, 228,  49,  56, 237,  81, 132, 234,  63, 131,  86, 145,  68, 248,  45,  67, 150,  42, 255, 246,  35, 159,  74,  36, 241,  77, 152,
 190, 107, 215,   2, 108, 185,   5, 208, 217,  12, 176, 101,  11, 222,  98, 183, 112, 165,  25, 204, 162, 119, 203,  30,  23, 194, 126, 171, 197,  16, 172, 121,
 225,  52, 136,  93,  51, 230,  90, 143, 134,  83, 239,  58,  84, 129,  61, 232,  47, 250,  70, 147, 253,  40, 148,  65,  72, 157,  33, 244, 154,  79, 243,  38,
 191, 106, 214,   3, 109, 184,   4, 209, 216,  13, 177, 100,  10, 223,  99, 182, 113, 164,  24, 205, 163, 118, 202,  31,  22, 195, 127, 170, 196,  17, 173, 120,
 224,  53, 137,  92,  50, 231,  91, 142, 135,  82, 238,  59,  85, 128,  60, 233,  46, 251,  71, 146, 252,  41, 149,  64,  73, 156,  32, 245, 155,  78, 242,  39,
   1, 212, 104, 189, 211,   6, 186, 111, 102, 179,  15, 218, 180,  97, 221,   8, 207,  26, 166, 115,  29, 200, 116, 161, 168, 125, 193,  20, 122, 175,  19, 198,
  94, 139,  55, 226, 140,  89, 229,  48,  57, 236,  80, 133, 235,  62, 130,  87, 144,  69, 249,  44,  66, 151,  43, 254, 247,  34, 158,  75,  37, 240,  76, 153},

{  0, 214, 111, 185, 222,   8, 177, 103, 127, 169,  16, 198, 161, 119, 206,  24, 254,  40, 145,  71,  32, 246,  79, 153, 129,  87, 238,  56,  95, 137,  48, 230,
  63, 233,  80, 134, 225,  55, 142,  88,  64, 150,  47, 249, 158,  72, 241,  39, 193,  23, 174, 120,  31, 201, 112, 166, 190, 104, 209,   7,  96, 182,  15, 217,
 126, 168,  17, 199, 160, 118, 207,  25,   1, 215, 110, 184, 223,   9, 176, 102, 128,  86, 239,  57,  94, 136,  49, 231, 255,  41, 144,  70,  33, 247,  78, 152,
  65, 151,  46, 248, 159,  73, 240,  38,  62, 232,  81, 135, 224,  54, 143,  89, 191, 105, 208,   6,  97, 183,  14, 216, 192,  22, 175, 121,  30, 200, 113, 167,
 252,  42, 147,  69,  34, 244,  77, 155, 131,  85, 236,  58,  93, 139,  50, 228,   2, 212, 109, 187, 220,  10, 179, 101, 125, 171,  18, 196, 163, 117, 204,  26,
 195,  21, 172, 122,  29, 203, 114, 164, 188, 106, 211,   5,  98, 180,  13, 219,  61, 235,  82, 132, 227,  53, 140,  90,  66, 148,  45, 251, 156,  74, 243,  37,
 130,  84, 237,  59,  92, 138,  51, 229, 253,  43, 146,  68,  35, 245,  76, 154, 124, 170,  19, 197, 162, 116, 205,  27,   3, 213, 108, 186, 221,  11, 178, 100,
 189, 107, 210,   4,  99, 181,  12, 218, 194,  20, 173, 123,  28, 202, 115, 165,  67, 149,  44, 250, 157,  75, 242,  36,  60, 234,  83, 133, 226,  52, 141,  91},

{  0, 215, 109, 186, 218,  13, 183,  96, 119, 160,  26, 205, 173, 122, 192,  23, 238,  57, 131,  84,  52, 227,  89, 142, 153,  78, 244,  35,  67, 148,  46, 249,
  31, 200, 114, 165, 197,  18, 168, 127, 104, 191,   5, 210, 178, 101, 223,   8, 241,  38, 156,  75,  43, 252,  70, 145, 134,  81, 235,  60,  92, 139,  49, 230,
  62, 233,  83, 132, 228,  51, 137,  94,  73, 158,  36, 243, 147,  68, 254,  41, 208,   7, 189, 106,  10, 221, 103, 176, 167, 112, 202,  29, 125, 170,  16, 199,
  33, 246,  76, 155, 251,  44, 150,  65,  86, 129,  59, 236, 140,  91, 225,  54, 207,  24, 162, 117,  21, 194, 120, 175, 184, 111, 213,   2,  98, 181,  15, 216,
 124, 171,  17, 198, 166, 113, 203,  28,  11, 220, 102, 177, 209,   6, 188, 107, 146,  69, 255,  40,  72, 159,  37, 242, 229,  50, 136,  95,  63, 232,  82, 133,
  99, 180,  14, 217, 185, 110, 212,   3,  20, 195, 121, 174, 206,  25, 163, 116, 141,  90, 224,  55,  87, 128,  58, 237, 250,  45, 151,  64,  32, 247,  77, 154,
  66, 149,  47, 248, 152,  79, 245,  34,  53, 226,  88, 143, 239,  56, 130,  85, 172, 123, 193,  22, 118, 161,  27, 204, 219,  12, 182,  97,   1, 214, 108, 187,
  93, 138,  48, 231, 135,  80, 234,  61,  42, 253,  71, 144, 240,  39, 157,  74, 179, 100, 222,   9, 105, 190,   4, 211, 196,  19, 169, 126,  30, 201, 115, 164},

{  0, 216, 115, 171, 230,  62, 149,  77,  15, 215, 124, 164, 233,  49, 154,  66,  30, 198, 109, 181, 248,  32, 139,  83,  17, 201,  98, 186, 247,  47, 132,  92,
  60, 228,  79, 151, 218,   2, 169, 113,  51, 235,  64, 152, 213,  13, 166, 126,  34, 250,  81, 137, 196,  28, 183, 111,  45, 245,  94, 134, 203,  19, 184,  96,
 120, 160,  11, 211, 158,  70, 237,  53, 119, 175,   4, 220, 145,  73, 226,  58, 102, 190,  21, 205, 128,  88, 243,  43, 105, 177,  26, 194, 143,  87, 252,  36,
  68, 156,  55, 239, 162, 122, 209,   9,  75, 147,  56, 224, 173, 117, 222,   6,  90, 130,  41, 241, 188, 100, 207,  23,  85, 141,  38, 254, 179, 107, 192,  24,
 240,  40, 131,  91,  22, 206, 101, 189, 255,  39, 140,  84,  25, 193, 106, 178, 238,  54, 157,  69,   8, 208, 123, 163, 225,  57, 146,  74,   7, 223, 116, 172,
 204,  20, 191, 103,  42, 242,  89, 129, 195,  27, 176, 104,  37, 253,  86, 142, 210,  10, 161, 121,  52, 236,  71, 159, 221,   5, 174, 118,  59, 227,  72, 144,
 136,  80, 251,  35, 110, 182,  29, 197, 135,  95, 244,  44,  97, 185,  18, 202, 150,  78, 229,  61, 112, 168,   3, 219, 153,  65, 234,  50, 127, 167,  12, 212,
 180, 108, 199,  31,  82, 138,  33, 249, 187,  99, 200,  16,  93, 133,  46, 246, 170, 114, 217,   1,  76, 148,  63, 231, 165, 125, 214,  14,  67, 155,  48, 232},

{  0, 217, 113, 168, 226,  59, 147,  74,   7, 222, 118, 175, 229,  60, 148,  77,  14, 215, 127, 166, 236,  53, 157,  68,   9, 208, 120, 161, 235,  50, 154,  67,
  28, 197, 109, 180, 254,  39, 143,  86,  27, 194, 106, 179, 249,  32, 136,  81,  18, 203,  99, 186, 240,  41, 129,  88,  21, 204, 100, 189, 247,  46, 134,  95,
  56, 225,  73, 144, 218,   3, 171, 114,  63, 230,  78, 151, 221,   4, 172, 117,  54, 239,  71, 158, 212,  13, 165, 124,  49, 232,  64, 153, 211,  10, 162, 123,
  36, 253,  85, 140, 198,  31, 183, 110,  35, 250,  82, 139, 193,  24, 176, 105,  42, 243,  91, 130, 200,  17, 185,  96,  45, 244,  92, 133, 207,  22, 190, 103,
 112, 169,   1, 216, 146,  75, 227,  58, 119, 174,   6, 223, 149,  76, 228,  61, 126, 167,  15, 214, 156,  69, 237,  52, 121, 160,   8, 209, 155,  66, 234,  51,
 108, 181,  29, 196, 142,  87, 255,  38, 107, 178,  26, 195, 137,  80, 248,  33,  98, 187,  19, 202, 128,  89, 241,  40, 101, 188,  20, 205, 135,  94, 246,  47,
  72, 145,  57, 224, 170, 115, 219,   2,  79, 150,  62, 231, 173, 116, 220,   5,  70, 159,  55, 238, 164, 125, 213,  12,  65, 152,  48, 233, 163, 122, 210,  11,
  84, 141,  37, 252, 182, 111, 199,  30,  83, 138,  34, 251, 177, 104, 192,  25,  90, 131,  43, 242, 184,  97, 201,  16,  93, 132,  44, 245, 191, 102, 206,  23},

{  0, 218, 119, 173, 238,  52, 153,  67,  31, 197, 104, 178, 241,  43, 134,  92,  62, 228,  73, 147, 208,  10, 167, 125,  33, 251,  86, 140, 207,  21, 184,  98,
 124, 166,  11, 209, 146,  72, 229,  63,  99, 185,  20, 206, 141,  87, 250,  32,  66, 152,  53, 239, 172, 118, 219,   1,  93, 135,  42, 240, 179, 105, 196,  30,
 248,  34, 143,  85,  22, 204,  97, 187, 231,  61, 144,  74,   9, 211, 126, 164, 198,  28, 177, 107,  40, 242,  95, 133, 217,   3, 174, 116,  55, 237,  64, 154,
 132,  94, 243,  41, 106, 176,  29, 199, 155,  65, 236,  54, 117, 175,   2, 216, 186,  96, 205,  23,  84, 142,  35, 249, 165, 127, 210,   8,  75, 145,  60, 230,
  51, 233,  68, 158, 221,   7, 170, 112,  44, 246,  91, 129, 194,  24, 181, 111,  13, 215, 122, 160, 227,  57, 148,  78,  18, 200, 101, 191, 252,  38, 139,  81,
  79, 149,  56, 226, 161, 123, 214,  12,  80, 138,  39, 253, 190, 100, 201,  19, 113, 171,   6, 220, 159,  69, 232,  50, 110, 180,  25, 195, 128,  90, 247,  45,
 203,  17, 188, 102,  37, 255,  82, 136, 212,  14, 163, 121,  58, 224,  77, 151, 245,  47, 130,  88,  27, 193, 108, 182, 234,  48, 157,  71,   4, 222, 115, 169,
 183, 109, 192,  26,  89, 131,  46, 244, 168, 114, 223,   5,  70, 156,  49, 235, 137,  83, 254,  36, 103, 189,  16, 202, 150,  76, 225,  59, 120, 162,  15, 213},

{  0, 219, 117, 174, 234,  49, 159,  68,  23, 204,  98, 185, 253,  38, 136,  83,  46, 245,  91, 128, 196,  31, 177, 106,  57, 226,  76, 151, 211,   8, 166, 125,
  92, 135,  41, 242, 182, 109, 195,  24,  75, 144,  62, 229, 161, 122, 212,  15, 114, 169,   7, 220, 152,  67, 237,  54, 101, 190,  16, 203, 143,  84, 250,  33,
 184,  99, 205,  22,  82, 137,  39, 252, 175, 116, 218,   1,  69, 158,  48, 235, 150,  77, 227,  56, 124, 167,   9, 210, 129,  90, 244,  47, 107, 176,  30, 197,
 228,  63, 145,  74,  14, 213, 123, 160, 243,  40, 134,  93,  25, 194, 108, 183, 202,  17, 191, 100,  32, 251,  85, 142, 221,   6, 168, 115,  55, 236,  66, 153,
 179, 104, 198,  29,  89, 130,  44, 247, 164, 127, 209,  10,  78, 149,  59, 224, 157,  70, 232,  51, 119, 172,   2, 217, 138,  81, 255,  36,  96, 187,  21, 206,
 239,  52, 154,  65,   5, 222, 112, 171, 248,  35, 141,  86,  18, 201, 103, 188, 193,  26, 180, 111,  43, 240,  94, 133, 214,  13, 163, 120,  60, 231,  73, 146,
  11, 208, 126, 165, 225,  58, 148,  79,  28, 199, 105, 178, 246,  45, 131,  88,  37, 254,  80, 139, 207,  20, 186,  97,  50, 233,  71, 156, 216,   3, 173, 118,
  87, 140,  34, 249, 189, 102, 200,  19,  64, 155,  53, 238, 170, 113, 223,   4, 121, 162,  12, 215, 147,  72, 230,  61, 110, 181,  27, 192, 132,  95, 241,  42},

{  0, 220, 123, 167, 246,  42, 141,  81,  47, 243,  84, 136, 217,   5, 162, 126,  94, 130,  37, 249, 168, 116, 211,  15, 113, 173,  10, 214, 135,  91, 252,  32,
 188,  96, 199,  27,  74, 150,  49, 237, 147,  79, 232,  52, 101, 185,  30, 194, 226,  62, 153,  69,  20, 200, 111, 179, 205,  17, 182, 106,  59, 231,  64, 156,
 187, 103, 192,  28,  77, 145,  54, 234, 148,  72, 239,  51,  98, 190,  25, 197, 229,  57, 158,  66,  19, 207, 104, 180, 202,  22, 177, 109,  60, 224,  71, 155,
   7, 219, 124, 160, 241,  45, 138,  86,  40, 244,  83, 143, 222,   2, 165, 121,  89, 133,  34, 254, 175, 115, 212,   8, 118, 170,  13, 209, 128,  92, 251,  39,
 181, 105, 206,  18,  67, 159,  56, 228, 154,  70, 225,  61, 108, 176,  23, 203, 235,  55, 144,  76,  29, 193, 102, 186, 196,  24, 191,  99,  50, 238,  73, 149,
   9, 213, 114, 174, 255,  35, 132,  88,  38, 250,  93, 129, 208,  12, 171, 119,  87, 139,  44, 240, 161, 125, 218,   6, 120, 164,   3, 223, 142,  82, 245,  41,
  14, 210, 117, 169, 248,  36, 131,  95,  33, 253,  90, 134, 215,  11, 172, 112,  80, 140,  43, 247, 166, 122, 221,   1, 127, 163,   4, 216, 137,  85, 242,  46,
 178, 110, 201,  21,  68, 152,  63, 227, 157,  65, 230,  58, 107, 183,  16, 204, 236,  48, 151,  75,  26, 198,  97, 189, 195,  31, 184, 100,  53, 233,  78, 146},

{  0, 221, 121, 164, 242,  47, 139,  86,  39, 250,  94, 131, 213,   8, 172, 113,  78, 147,  55, 234, 188,  97, 197,  24, 105, 180,  16, 205, 155,  70, 226,  63,
 156,  65, 229,  56, 110, 179,  23, 202, 187, 102, 194,  31,  73, 148,  48, 237, 210,  15, 171, 118,  32, 253,  89, 132, 245,  40, 140,  81,   7, 218, 126, 163,
 251,  38, 130,  95,   9, 212, 112, 173, 220,   1, 165, 120,  46, 243,  87, 138, 181, 104, 204,  17,  71, 154,  62, 227, 146,  79, 235,  54,  96, 189,  25, 196,
 103, 186,  30, 195, 149,  72, 236,  49,  64, 157,  57, 228, 178, 111, 203,  22,  41, 244,  80, 141, 219,   6, 162, 127,  14, 211, 119, 170, 252,  33, 133,  88,
  53, 232,  76, 145, 199,  26, 190,  99,  18, 207, 107, 182, 224,  61, 153,  68, 123, 166,   2, 223, 137,  84, 240,  45,  92, 129,  37, 248, 174, 115, 215,  10,
 169, 116, 208,  13,  91, 134,  34, 255, 142,  83, 247,  42, 124, 161,   5, 216, 231,  58, 158,  67,  21, 200, 108, 177, 192,  29, 185, 100,  50, 239,  75, 150,
 206,  19, 183, 106,  60, 225,  69, 152, 233,  52, 144,  77,  27, 198,  98, 191, 128,  93, 249,  36, 114, 175,  11, 214, 167, 122, 222,   3,  85, 136,  44, 241,
  82, 143,  43, 246, 160, 125, 217,   4, 117, 168,  12, 209, 135,  90, 254,  35,  28, 193, 101, 184, 238,  51, 151,  74,  59, 230,  66, 159, 201,  20, 176, 109},

{  0, 222, 127, 161, 254,  32, 129,  95,  63, 225,  64, 158, 193,  31, 190,  96, 126, 160,   1, 223, 128,  94, 255,  33,  65, 159,  62, 224, 191,  97, 192,  30,
 252,  34, 131,  93,   2, 220, 125, 163, 195,  29, 188,  98,  61, 227,  66, 156, 130,  92, 253,  35, 124, 162,   3, 221, 189,  99, 194,  28,  67, 157,  60, 226,
  59, 229,  68, 154, 197,  27, 186, 100,   4, 218, 123, 165, 250,  36, 133,  91,  69, 155,  58, 228, 187, 101, 196,  26, 122, 164,   5, 219, 132,  90, 251,  37,
 199,  25, 184, 102,  57, 231,  70, 152, 248,  38, 135,  89,   6, 216, 121, 167, 185, 103, 198,  24,  71, 153,  56, 230, 134,  88, 249,  39, 120, 166,   7, 217,
 118, 168,   9, 215, 136,  86, 247,  41,  73, 151,  54, 232, 183, 105, 200,  22,   8, 214, 119, 169, 246,  40, 137,  87,  55, 233,  72, 150, 201,  23, 182, 104,
 138,  84, 245,  43, 116, 170,  11, 213, 181, 107, 202,  20,  75, 149,  52, 234, 244,  42, 139,  85,  10, 212, 117, 171, 203,  21, 180, 106,  53, 235,  74, 148,
  77, 147,  50, 236, 179, 109, 204,  18, 114, 172,  13, 211, 140,  82, 243,  45,  51, 237,  76, 146, 205,  19, 178, 108,  12, 210, 115, 173, 242,  44, 141,  83,
 177, 111, 206,  16,  79, 145,  48, 238, 142,  80, 241,  47, 112, 174,  15, 209, 207,  17, 176, 110,  49, 239,  78, 144, 240,  46, 143,  81,  14, 208, 113, 175},

{  0, 223, 125, 162, 250,  37, 135,  88,  55, 232,  74, 149, 205,  18, 176, 111, 110, 177,  19, 204, 148,  75, 233,  54,  89, 134,  36, 251, 163, 124, 222,   1,
 220,   3, 161, 126,  38, 249,  91, 132, 235,  52, 150,  73,  17, 206, 108, 179, 178, 109, 207,  16,  72, 151,  53, 234, 133,  90, 248,  39, 127, 160,   2, 221,
 123, 164,   6, 217, 129,  94, 252,  35,  76, 147,  49, 238, 182, 105, 203,  20,  21, 202, 104, 183, 239,  48, 146,  77,  34, 253,  95, 128, 216,   7, 165, 122,
 167, 120, 218,   5,  93, 130,  32, 255, 144,  79, 237,  50, 106, 181,  23, 200, 201,  22, 180, 107,  51, 236,  78, 145, 254,  33, 131,  92,   4, 219, 121, 166,
 246,  41, 139,  84,  12, 211, 113, 174, 193,  30, 188,  99,  59, 228,  70, 153, 152,  71, 229,  58,  98, 189,  31, 192, 175, 112, 210,  13,  85, 138,  40, 247,
  42, 245,  87, 136, 208,  15, 173, 114,  29, 194,  96, 191, 231,  56, 154,  69,  68, 155,  57, 230, 190,  97, 195,  28, 115, 172,  14, 209, 137,  86, 244,  43,
 141,  82, 240,  47, 119, 168,  10, 213, 186, 101, 199,  24,  64, 159,  61, 226, 227,  60, 158,  65,  25, 198, 100, 187, 212,  11, 169, 118,  46, 241,  83, 140,
  81, 142,  44, 243, 171, 116, 214,   9, 102, 185,  27, 196, 156,  67, 225,  62,  63, 224,  66, 157, 197,  26, 184, 103,   8, 215, 117, 170, 242,  45, 143,  80},

{  0, 224,   3, 227,   6, 230,   5, 229,  12, 236,  15, 239,  10, 234,   9, 233,  24, 248,  27, 251,  30, 254,  29, 253,  20, 244,  23, 247,  18, 242,  17, 241,
  48, 208,  51, 211,  54, 214,  53, 213,  60, 220,  63, 223,  58, 218,  57, 217,  40, 200,  43, 203,  46, 206,  45, 205,  36, 196,  39, 199,  34, 194,  33, 193,
  96, 128,  99, 131, 102, 134, 101, 133, 108, 140, 111, 143, 106, 138, 105, 137, 120, 152, 123, 155, 126, 158, 125, 157, 116, 148, 119, 151, 114, 146, 113, 145,
  80, 176,  83, 179,  86, 182,  85, 181,  92, 188,  95, 191,  90, 186,  89, 185,  72, 168,  75, 171,  78, 174,  77, 173,  68, 164,  71, 167,  66, 162,  65, 161,
 192,  32, 195,  35, 198,  38, 197,  37, 204,  44, 207,  47, 202,  42, 201,  41, 216,  56, 219,  59, 222,  62, 221,  61, 212,  52, 215,  55, 210,  50, 209,  49,
 240,  16, 243,  19, 246,  22, 245,  21, 252,  28, 255,  31, 250,  26, 249,  25, 232,   8, 235,  11, 238,  14, 237,  13, 228,   4, 231,   7, 226,   2, 225,   1,
 160,  64, 163,  67, 166,  70, 165,  69, 172,  76, 175,  79, 170,  74, 169,  73, 184,  88, 187,  91, 190,  94, 189,  93, 180,  84, 183,  87, 178,  82, 177,  81,
 144, 112, 147, 115, 150, 118, 149, 117, 156, 124, 159, 127, 154, 122, 153, 121, 136, 104, 139, 107, 142, 110, 141, 109, 132, 100, 135, 103, 130,  98, 129,  97},

{  0, 225,   1, 224,   2, 227,   3, 226,   4, 229,   5, 228,   6, 231,   7, 230,   8, 233,   9, 232,  10, 235,  11, 234,  12, 237,  13, 236,  14, 239,  15, 238,
  16, 241,  17, 240,  18, 243,  19, 242,  20, 245,  21, 244,  22, 247,  23, 246,  24, 249,  25, 248,  26, 251,  27, 250,  28, 253,  29, 252,  30, 255,  31, 254,
  32, 193,  33, 192,  34, 195,  35, 194,  36, 197,  37, 196,  38, 199,  39, 198,  40, 201,  41, 200,  42, 203,  43, 202,  44, 205,  45, 204,  46, 207,  47, 206,
  48, 209,  49, 208,  50, 211,  51, 210,  52, 213,  53, 212,  54, 215,  55, 214,  56, 217,  57, 216,  58, 219,  59, 218,  60, 221,  61, 220,  62, 223,  63, 222,
  64, 161,  65, 160,  66, 163,  67, 162,  68, 165,  69, 164,  70, 167,  71, 166,  72, 169,  73, 168,  74, 171,  75, 170,  76, 173,  77, 172,  78, 175,  79, 174,
  80, 177,  81, 176,  82, 179,  83, 178,  84, 181,  85, 180,  86, 183,  87, 182,  88, 185,  89, 184,  90, 187,  91, 186,  92, 189,  93, 188,  94, 191,  95, 190,
  96, 129,  97, 128,  98, 131,  99, 130, 100, 133, 101, 132, 102, 135, 103, 134, 104, 137, 105, 136, 106, 139, 107, 138, 108, 141, 109, 140, 110, 143, 111, 142,
 112, 145, 113, 144, 114, 147, 115, 146, 116, 149, 117, 148, 118, 151, 119, 150, 120, 153, 121, 152, 122, 155, 123, 154, 124, 157, 125, 156, 126, 159, 127, 158},

{  0, 226,   7, 229,  14, 236,   9, 235,  28, 254,  27, 249,  18, 240,  21, 247,  56, 218,  63, 221,  54, 212,  49, 211,  36, 198,  35, 193,  42, 200,  45, 207,
 112, 146, 119, 149, 126, 156, 121, 155, 108, 142, 107, 137,  98, 128, 101, 135,  72, 170,  79, 173,  70, 164,  65, 163,  84, 182,  83, 177,  90, 184,  93, 191,
 224,   2, 231,   5, 238,  12, 233,  11, 252,  30, 251,  25, 242,  16, 245,  23, 216,  58, 223,  61, 214,  52, 209,  51, 196,  38, 195,  33, 202,  40, 205,  47,
 144, 114, 151, 117, 158, 124, 153, 123, 140, 110, 139, 105, 130,  96, 133, 103, 168,  74, 175,  77, 166,  68, 161,  67, 180,  86, 179,  81, 186,  88, 189,  95,
   3, 225,   4, 230,  13, 239,  10, 232,  31, 253,  24, 250,  17, 243,  22, 244,  59, 217,  60, 222,  53, 215,  50, 208,  39, 197,  32, 194,  41, 203,  46, 204,
 115, 145, 116, 150, 125, 159, 122, 152, 111, 141, 104, 138,  97, 131, 102, 132,  75, 169,  76, 174,  69, 167,  66, 160,  87, 181,  80, 178,  89, 187,  94, 188,
 227,   1, 228,   6, 237,  15, 234,   8, 255,  29, 248,  26, 241,  19, 246,  20, 219,  57, 220,  62, 213,  55, 210,  48, 199,  37, 192,  34, 201,  43, 206,  44,
 147, 113, 148, 118, 157, 127, 154, 120, 143, 109, 136, 106, 129,  99, 134, 100, 171,  73, 172,  78, 165,  71, 162,  64, 183,  85, 176,  82, 185,  91, 190,  92},

{  0, 227,   5, 230,  10, 233,  15, 236,  20, 247,  17, 242,  30, 253,  27, 248,  40, 203,  45, 206,  34, 193,  39, 196,  60, 223,  57, 218,  54, 213,  51, 208,
  80, 179,  85, 182,  90, 185,  95, 188,  68, 167,  65, 162,  78, 173,  75, 168, 120, 155, 125, 158, 114, 145, 119, 148, 108, 143, 105, 138, 102, 133,  99, 128,
 160,  67, 165,  70, 170,  73, 175,  76, 180,  87, 177,  82, 190,  93, 187,  88, 136, 107, 141, 110, 130,  97, 135, 100, 156, 127, 153, 122, 150, 117, 147, 112,
 240,  19, 245,  22, 250,  25, 255,  28, 228,   7, 225,   2, 238,  13, 235,   8, 216,  59, 221,  62, 210,  49, 215,  52, 204,  47, 201,  42, 198,  37, 195,  32,
 131,  96, 134, 101, 137, 106, 140, 111, 151, 116, 146, 113, 157, 126, 152, 123, 171,  72, 174,  77, 161,  66, 164,  71, 191,  92, 186,  89, 181,  86, 176,  83,
 211,  48, 214,  53, 217,  58, 220,  63, 199,  36, 194,  33, 205,  46, 200,  43, 251,  24, 254,  29, 241,  18, 244,  23, 239,  12, 234,   9, 229,   6, 224,   3,
  35, 192,  38, 197,  41, 202,  44, 207,  55, 212,  50, 209,  61, 222,  56, 219,  11, 232,  14, 237,   1, 226,   4, 231,  31, 252,  26, 249,  21, 246,  16, 243,
 115, 144, 118, 149, 121, 154, 124, 159, 103, 132,  98, 129, 109, 142, 104, 139,  91, 184,  94, 189,  81, 178,  84, 183,  79, 172,  74, 169,  69, 166,  64, 163},

{  0, 228,  11, 239,  22, 242,  29, 249,  44, 200,  39, 195,  58, 222,  49, 213,  88, 188,  83, 183,  78, 170,  69, 161, 116, 144, 127, 155,  98, 134, 105, 141,
 176,  84, 187,  95, 166,  66, 173,  73, 156, 120, 151, 115, 138, 110, 129, 101, 232,  12, 227,   7, 254,  26, 245,  17, 196,  32, 207,  43, 210,  54, 217,  61,
 163,  71, 168,  76, 181,  81, 190,  90, 143, 107, 132,  96, 153, 125, 146, 118, 251,  31, 240,  20, 237,   9, 230,   2, 215,  51, 220,  56, 193,  37, 202,  46,
  19, 247,  24, 252,   5, 225,  14, 234,  63, 219,  52, 208,  41, 205,  34, 198,  75, 175,  64, 164,  93, 185,  86, 178, 103, 131, 108, 136, 113, 149, 122, 158,
 133,  97, 142, 106, 147, 119, 152, 124, 169,  77, 162,  70, 191,  91, 180,  80, 221,  57, 214,  50, 203,  47, 192,  36, 241,  21, 250,  30, 231,   3, 236,   8,
  53, 209,  62, 218,  35, 199,  40, 204,  25, 253,  18, 246,  15, 235,   4, 224, 109, 137, 102, 130, 123, 159, 112, 148,  65, 165,  74, 174,  87, 179,  92, 184,
  38, 194,  45, 201,  48, 212,  59, 223,  10, 238,   1, 229,  28, 248,  23, 243, 126, 154, 117, 145, 104, 140,  99, 135,  82, 182,  89, 189,  68, 160,  79, 171,
 150, 114, 157, 121, 128, 100, 139, 111, 186,  94, 177,  85, 172,  72, 167,  67, 206,  42, 197,  33, 216,  60, 211,  55, 226,   6, 233,  13, 244,  16, 255,  27},

{  0, 229,   9, 236,  18, 247,  27, 254,  36, 193,  45, 200,  54, 211,  63, 218,  72, 173,  65, 164,  90, 191,  83, 182, 108, 137, 101, 128, 126, 155, 119, 146,
 144, 117, 153, 124, 130, 103, 139, 110, 180,  81, 189,  88, 166,  67, 175,  74, 216,  61, 209,  52, 202,  47, 195,  38, 252,  25, 245,  16, 238,  11, 231,   2,
 227,   6, 234,  15, 241,  20, 248,  29, 199,  34, 206,  43, 213,  48, 220,  57, 171,  78, 162,  71, 185,  92, 176,  85, 143, 106, 134,  99, 157, 120, 148, 113,
 115, 150, 122, 159,  97, 132, 104, 141,  87, 178,  94, 187,  69, 160,  76, 169,  59, 222,  50, 215,  41, 204,  32, 197,  31, 250,  22, 243,  13, 232,   4, 225,
   5, 224,  12, 233,  23, 242,  30, 251,  33, 196,  40, 205,  51, 214,  58, 223,  77, 168,  68, 161,  95, 186,  86, 179, 105, 140,  96, 133, 123, 158, 114, 151,
 149, 112, 156, 121, 135,  98, 142, 107, 177,  84, 184,  93, 163,  70, 170,  79, 221,  56, 212,  49, 207,  42, 198,  35, 249,  28, 240,  21, 235,  14, 226,   7,
 230,   3, 239,  10, 244,  17, 253,  24, 194,  39, 203,  46, 208,  53, 217,  60, 174,  75, 167,  66, 188,  89, 181,  80, 138, 111, 131, 102, 152, 125, 145, 116,
 118, 147, 127, 154, 100, 129, 109, 136,  82, 183,  91, 190,  64, 165,  73, 172,  62, 219,  55, 210,  44, 201,  37, 192,  26, 255,  19, 246,   8, 237,   1, 228},

{  0, 230,  15, 233,  30, 248,  17, 247,  60, 218,  51, 213,  34, 196,  45, 203, 120, 158, 119, 145, 102, 128, 105, 143,  68, 162,  75, 173,  90, 188,  85, 179,
 240,  22, 255,  25, 238,   8, 225,   7, 204,  42, 195,  37, 210,  52, 221,  59, 136, 110, 135,  97, 150, 112, 153, 127, 180,  82, 187,  93, 170,  76, 165,  67,
  35, 197,  44, 202,  61, 219,  50, 212,  31, 249,  16, 246,   1, 231,  14, 232,  91, 189,  84, 178,  69, 163,  74, 172, 103, 129, 104, 142, 121, 159, 118, 144,
 211,  53, 220,  58, 205,  43, 194,  36, 239,   9, 224,   6, 241,  23, 254,  24, 171,  77, 164,  66, 181,  83, 186,  92, 151, 113, 152, 126, 137, 111, 134,  96,
  70, 160,  73, 175,  88, 190,  87, 177, 122, 156, 117, 147, 100, 130, 107, 141,  62, 216,  49, 215,  32, 198,  47, 201,   2, 228,  13, 235,  28, 250,  19, 245,
 182,  80, 185,  95, 168,  78, 167,  65, 138, 108, 133,  99, 148, 114, 155, 125, 206,  40, 193,  39, 208,  54, 223,  57, 242,  20, 253,  27, 236,  10, 227,   5,
 101, 131, 106, 140, 123, 157, 116, 146,  89, 191,  86, 176,  71, 161,  72, 174,  29, 251,  18, 244,   3, 229,  12, 234,  33, 199,  46, 200,  63, 217,  48, 214,
 149, 115, 154, 124, 139, 109, 132,  98, 169,  79, 166,  64, 183,  81, 184,  94, 237,  11, 226,   4, 243,  21, 252,  26, 209,  55, 222,  56, 207,  41, 192,  38},

{  0, 231,  13, 234,  26, 253,  23, 240,  52, 211,  57, 222,  46, 201,  35, 196, 104, 143, 101, 130, 114, 149, 127, 152,  92, 187,  81, 182,  70, 161,  75, 172,
 208,  55, 221,  58, 202,  45, 199,  32, 228,   3, 233,  14, 254,  25, 243,  20, 184,  95, 181,  82, 162,  69, 175,  72, 140, 107, 129, 102, 150, 113, 155, 124,
  99, 132, 110, 137, 121, 158, 116, 147,  87, 176,  90, 189,  77, 170,  64, 167,  11, 236,   6, 225,  17, 246,  28, 251,  63, 216,  50, 213,  37, 194,  40, 207,
 179,  84, 190,  89, 169,  78, 164,  67, 135,  96, 138, 109, 157, 122, 144, 119, 219,  60, 214,  49, 193,  38, 204,  43, 239,   8, 226,   5, 245,  18, 248,  31,
 198,  33, 203,  44, 220,  59, 209,  54, 242,  21, 255,  24, 232,  15, 229,   2, 174,  73, 163,  68, 180,  83, 185,  94, 154, 125, 151, 112, 128, 103, 141, 106,
  22, 241,  27, 252,  12, 235,   1, 230,  34, 197,  47, 200,  56, 223,  53, 210, 126, 153, 115, 148, 100, 131, 105, 142,  74, 173,  71, 160,  80, 183,  93, 186,
 165,  66, 168,  79, 191,  88, 178,  85, 145, 118, 156, 123, 139, 108, 134,  97, 205,  42, 192,  39, 215,  48, 218,  61, 249,  30, 244,  19, 227,   4, 238,   9,
 117, 146, 120, 159, 111, 136,  98, 133,  65, 166,  76, 171,  91, 188,  86, 177,  29, 250,  16, 247,   7, 224,  10, 237,  41, 206,  36, 195,  51, 212,  62, 217},

{  0, 232,  19, 251,  38, 206,  53, 221,  76, 164,  95, 183, 106, 130, 121, 145, 152, 112, 139,  99, 190,  86, 173,  69, 212,  60, 199,  47, 242,  26, 225,   9,
 243,  27, 224,   8, 213,  61, 198,  46, 191,  87, 172,  68, 153, 113, 138,  98, 107, 131, 120, 144,  77, 165,  94, 182,  39, 207,  52, 220,   1, 233,  18, 250,
  37, 205,  54, 222,   3, 235,  16, 248, 105, 129, 122, 146,  79, 167,  92, 180, 189,  85, 174,  70, 155, 115, 136,  96, 241,  25, 226,  10, 215,  63, 196,  44,
 214,  62, 197,  45, 240,  24, 227,  11, 154, 114, 137,  97, 188,  84, 175,  71,  78, 166,  93, 181, 104, 128, 123, 147,   2, 234,  17, 249,  36, 204,  55, 223,
  74, 162,  89, 177, 108, 132, 127, 151,   6, 238,  21, 253,  32, 200,  51, 219, 210,  58, 193,  41, 244,  28, 231,  15, 158, 118, 141, 101, 184,  80, 171,  67,
 185,  81, 170,  66, 159, 119, 140, 100, 245,  29, 230,  14, 211,  59, 192,  40,  33, 201,  50, 218,   7, 239,  20, 252, 109, 133, 126, 150,  75, 163,  88, 176,
 111, 135, 124, 148,  73, 161,  90, 178,  35, 203,  48, 216,   5, 237,  22, 254, 247,  31, 228,  12, 209,  57, 194,  42, 187,  83, 168,  64, 157, 117, 142, 102,
 156, 116, 143, 103, 186,  82, 169,  65, 208,  56, 195,  43, 246,  30, 229,  13,   4, 236,  23, 255,  34, 202,  49, 217,  72, 160,  91, 179, 110, 134, 125, 149},

{  0, 233,  17, 248,  34, 203,  51, 218,  68, 173,  85, 188, 102, 143, 119, 158, 136,  97, 153, 112, 170,  67, 187,  82, 204,  37, 221,  52, 238,   7, 255,  22,
 211,  58, 194,  43, 241,  24, 224,   9, 151, 126, 134, 111, 181,  92, 164,  77,  91, 178,  74, 163, 121, 144, 104, 129,  31, 246,  14, 231,  61, 212,  44, 197,
 101, 140, 116, 157,  71, 174,  86, 191,  33, 200,  48, 217,   3, 234,  18, 251, 237,   4, 252,  21, 207,  38, 222,  55, 169,  64, 184,  81, 139,  98, 154, 115,
 182,  95, 167,  78, 148, 125, 133, 108, 242,  27, 227,  10, 208,  57, 193,  40,  62, 215,  47, 198,  28, 245,  13, 228, 122, 147, 107, 130,  88, 177,  73, 160,
 202,  35, 219,  50, 232,   1, 249,  16, 142, 103, 159, 118, 172,  69, 189,  84,  66, 171,  83, 186,  96, 137, 113, 152,   6, 239,  23, 254,  36, 205,  53, 220,
  25, 240,   8, 225,  59, 210,  42, 195,  93, 180,  76, 165, 127, 150, 110, 135, 145, 120, 128, 105, 179,  90, 162,  75, 213,  60, 196,  45, 247,  30, 230,  15,
 175,  70, 190,  87, 141, 100, 156, 117, 235,   2, 250,  19, 201,  32, 216,  49,  39, 206,  54, 223,   5, 236,  20, 253,  99, 138, 114, 155,  65, 168,  80, 185,
 124, 149, 109, 132,  94, 183,  79, 166,  56, 209,  41, 192,  26, 243,  11, 226, 244,  29, 229,  12, 214,  63, 199,  46, 176,  89, 161,  72, 146, 123, 131, 106},

{  0, 234,  23, 253,  46, 196,  57, 211,  92, 182,  75, 161, 114, 152, 101, 143, 184,  82, 175,  69, 150, 124, 129, 107, 228,  14, 243,  25, 202,  32, 221,  55,
 179,  89, 164,  78, 157, 119, 138,  96, 239,   5, 248,  18, 193,  43, 214,  60,  11, 225,  28, 246,  37, 207,  50, 216,  87, 189,  64, 170, 121, 147, 110, 132,
 165,  79, 178,  88, 139,  97, 156, 118, 249,  19, 238,   4, 215,  61, 192,  42,  29, 247,  10, 224,  51, 217,  36, 206,  65, 171,  86, 188, 111, 133, 120, 146,
  22, 252,   1, 235,  56, 210,  47, 197,  74, 160,  93, 183, 100, 142, 115, 153, 174,  68, 185,  83, 128, 106, 151, 125, 242,  24, 229,  15, 220,  54, 203,  33,
 137,  99, 158, 116, 167,  77, 176,  90, 213,  63, 194,  40, 251,  17, 236,   6,  49, 219,  38, 204,  31, 245,   8, 226, 109, 135, 122, 144,  67, 169,  84, 190,
  58, 208,  45, 199,  20, 254,   3, 233, 102, 140, 113, 155,  72, 162,  95, 181, 130, 104, 149, 127, 172,  70, 187,  81, 222,  52, 201,  35, 240,  26, 231,  13,
  44, 198,  59, 209,   2, 232,  21, 255, 112, 154, 103, 141,  94, 180,  73, 163, 148, 126, 131, 105, 186,  80, 173,  71, 200,  34, 223,  53, 230,  12, 241,  27,
 159, 117, 136,  98, 177,  91, 166,  76, 195,  41, 212,  62, 237,   7, 250,  16,  39, 205,  48, 218,   9, 227,  30, 244, 123, 145, 108, 134,  85, 191,  66, 168},

{  0, 235,  21, 254,  42, 193,  63, 212,  84, 191,  65, 170, 126, 149, 107, 128, 168,  67, 189,  86, 130, 105, 151, 124, 252,  23, 233,   2, 214,  61, 195,  40,
 147, 120, 134, 109, 185,  82, 172,  71, 199,  44, 210,  57, 237,   6, 248,  19,  59, 208,  46, 197,  17, 250,   4, 239, 111, 132, 122, 145,  69, 174,  80, 187,
 229,  14, 240,  27, 207,  36, 218,  49, 177,  90, 164,  79, 155, 112, 142, 101,  77, 166,  88, 179, 103, 140, 114, 153,  25, 242,  12, 231,  51, 216,  38, 205,
 118, 157,  99, 136,  92, 183,  73, 162,  34, 201,  55, 220,   8, 227,  29, 246, 222,  53, 203,  32, 244,  31, 225,  10, 138,  97, 159, 116, 160,  75, 181,  94,
   9, 226,  28, 247,  35, 200,  54, 221,  93, 182,  72, 163, 119, 156,  98, 137, 161,  74, 180,  95, 139,  96, 158, 117, 245,  30, 224,  11, 223,  52, 202,  33,
 154, 113, 143, 100, 176,  91, 165,  78, 206,  37, 219,  48, 228,  15, 241,  26,  50, 217,  39, 204,  24, 243,  13, 230, 102, 141, 115, 152,  76, 167,  89, 178,
 236,   7, 249,  18, 198,  45, 211,  56, 184,  83, 173,  70, 146, 121, 135, 108,  68, 175,  81, 186, 110, 133, 123, 144,  16, 251,   5, 238,  58, 209,  47, 196,
 127, 148, 106, 129,  85, 190,  64, 171,  43, 192,  62, 213,   1, 234,  20, 255, 215,  60, 194,  41, 253,  22, 232,   3, 131, 104, 150, 125, 169,  66, 188,  87},

{  0, 236,  27, 247,  54, 218,  45, 193, 108, 128, 119, 155,  90, 182,  65, 173, 216,  52, 195,  47, 238,   2, 245,  25, 180,  88, 175,  67, 130, 110, 153, 117,
 115, 159, 104, 132,  69, 169,  94, 178,  31, 243,   4, 232,  41, 197,  50, 222, 171,  71, 176,  92, 157, 113, 134, 106, 199,  43, 220,  48, 241,  29, 234,   6,
 230,  10, 253,  17, 208,  60, 203,  39, 138, 102, 145, 125, 188,  80, 167,  75,  62, 210,  37, 201,   8, 228,  19, 255,  82, 190,  73, 165, 100, 136, 127, 147,
 149, 121, 142,  98, 163,  79, 184,  84, 249,  21, 226,  14, 207,  35, 212,  56,  77, 161,  86, 186, 123, 151,  96, 140,  33, 205,  58, 214,  23, 251,  12, 224,
  15, 227,  20, 248,  57, 213,  34, 206,  99, 143, 120, 148,  85, 185,  78, 162, 215,  59, 204,  32, 225,  13, 250,  22, 187,  87, 160,  76, 141,  97, 150, 122,
 124, 144, 103, 139,  74, 166,  81, 189,  16, 252,  11, 231,  38, 202,  61, 209, 164,  72, 191,  83, 146, 126, 137, 101, 200,  36, 211,  63, 254,  18, 229,   9,
 233,   5, 242,  30, 223,  51, 196,  40, 133, 105, 158, 114, 179,  95, 168,  68,  49, 221,  42, 198,   7, 235,  28, 240,  93, 177,  70, 170, 107, 135, 112, 156,
 154, 118, 129, 109, 172,  64, 183,  91, 246,  26, 237,   1, 192,  44, 219,  55,  66, 174,  89, 181, 116, 152, 111, 131,  46, 194,  53, 217,  24, 244,   3, 239},

{  0, 237,  25, 244,  50, 223,  43, 198, 100, 137, 125, 144,  86, 187,  79, 162, 200,  37, 209,  60, 250,  23, 227,  14, 172,  65, 181,  88, 158, 115, 135, 106,
  83, 190,  74, 167,  97, 140, 120, 149,  55, 218,  46, 195,   5, 232,  28, 241, 155, 118, 130, 111, 169,  68, 176,  93, 255,  18, 230,  11, 205,  32, 212,  57,
 166,  75, 191,  82, 148, 121, 141,  96, 194,  47, 219,  54, 240,  29, 233,   4, 110, 131, 119, 154,  92, 177,  69, 168,  10, 231,  19, 254,  56, 213,  33, 204,
 245,  24, 236,   1, 199,  42, 222,  51, 145, 124, 136, 101, 163,  78, 186,  87,  61, 208,  36, 201,  15, 226,  22, 251,  89, 180,  64, 173, 107, 134, 114, 159,
 143,  98, 150, 123, 189,  80, 164,  73, 235,   6, 242,  31, 217,  52, 192,  45,  71, 170,  94, 179, 117, 152, 108, 129,  35, 206,  58, 215,  17, 252,   8, 229,
 220,  49, 197,  40, 238,   3, 247,  26, 184,  85, 161,  76, 138, 103, 147, 126,  20, 249,  13, 224,  38, 203,  63, 210, 112, 157, 105, 132,  66, 175,  91, 182,
  41, 196,  48, 221,  27, 246,   2, 239,  77, 160,  84, 185, 127, 146, 102, 139, 225,  12, 248,  21, 211,  62, 202,  39, 133, 104, 156, 113, 183,  90, 174,  67,
 122, 151,  99, 142,  72, 165,  81, 188,  30, 243,   7, 234,  44, 193,  53, 216, 178,  95, 171,  70, 128, 109, 153, 116, 214,  59, 207,  34, 228,   9, 253,  16},

{  0, 238,  31, 241,  62, 208,  33, 207, 124, 146,  99, 141,  66, 172,  93, 179, 248,  22, 231,   9, 198,  40, 217,  55, 132, 106, 155, 117, 186,  84, 165,  75,
  51, 221,  44, 194,  13, 227,  18, 252,  79, 161,  80, 190, 113, 159, 110, 128, 203,  37, 212,  58, 245,  27, 234,   4, 183,  89, 168,  70, 137, 103, 150, 120,
 102, 136, 121, 151,  88, 182,  71, 169,  26, 244,   5, 235,  36, 202,  59, 213, 158, 112, 129, 111, 160,  78, 191,  81, 226,  12, 253,  19, 220,  50, 195,  45,
  85, 187,  74, 164, 107, 133, 116, 154,  41, 199,  54, 216,  23, 249,   8, 230, 173,  67, 178,  92, 147, 125, 140,  98, 209,  63, 206,  32, 239,   1, 240,  30,
 204,  34, 211,  61, 242,  28, 237,   3, 176,  94, 175,  65, 142,  96, 145, 127,  52, 218,  43, 197,  10, 228,  21, 251,  72, 166,  87, 185, 118, 152, 105, 135,
 255,  17, 224,  14, 193,  47, 222,  48, 131, 109, 156, 114, 189,  83, 162,  76,   7, 233,  24, 246,  57, 215,  38, 200, 123, 149, 100, 138,  69, 171,  90, 180,
 170,  68, 181,  91, 148, 122, 139, 101, 214,  56, 201,  39, 232,   6, 247,  25,  82, 188,  77, 163, 108, 130, 115, 157,  46, 192,  49, 223,  16, 254,  15, 225,
 153, 119, 134, 104, 167,  73, 184,  86, 229,  11, 250,  20, 219,  53, 196,  42,  97, 143, 126, 144,  95, 177,  64, 174,  29, 243,   2, 236,  35, 205,  60, 210},

{  0, 239,  29, 242,  58, 213,  39, 200, 116, 155, 105, 134,  78, 161,  83, 188, 232,   7, 245,  26, 210,  61, 207,  32, 156, 115, 129, 110, 166,  73, 187,  84,
  19, 252,  14, 225,  41, 198,  52, 219, 103, 136, 122, 149,  93, 178,  64, 175, 251,  20, 230,   9, 193,  46, 220,  51, 143,  96, 146, 125, 181,  90, 168,  71,
  38, 201,  59, 212,  28, 243,   1, 238,  82, 189,  79, 160, 104, 135, 117, 154, 206,  33, 211,  60, 244,  27, 233,   6, 186,  85, 167,  72, 128, 111, 157, 114,
  53, 218,  40, 199,  15, 224,  18, 253,  65, 174,  92, 179, 123, 148, 102, 137, 221,  50, 192,  47, 231,   8, 250,  21, 169,  70, 180,  91, 147, 124, 142,  97,
  76, 163,  81, 190, 118, 153, 107, 132,  56, 215,  37, 202,   2, 237,  31, 240, 164,  75, 185,  86, 158, 113, 131, 108, 208,  63, 205,  34, 234,   5, 247,  24,
  95, 176,  66, 173, 101, 138, 120, 151,  43, 196,  54, 217,  17, 254,  12, 227, 183,  88, 170,  69, 141,  98, 144, 127, 195,  44, 222,  49, 249,  22, 228,  11,
 106, 133, 119, 152,  80, 191,  77, 162,  30, 241,   3, 236,  36, 203,  57, 214, 130, 109, 159, 112, 184,  87, 165,  74, 246,  25, 235,   4, 204,  35, 209,  62,
 121, 150, 100, 139,  67, 172,  94, 177,  13, 226,  16, 255,  55, 216,  42, 197, 145, 126, 140,  99, 171,  68, 182,  89, 229,  10, 248,  23, 223,  48, 194,  45},

{  0, 240,  35, 211,  70, 182, 101, 149, 140, 124, 175,  95, 202,  58, 233,  25, 219,  43, 248,   8, 157, 109, 190,  78,  87, 167, 116, 132,  17, 225,  50, 194,
 117, 133,  86, 166,  51, 195,  16, 224, 249,   9, 218,  42, 191,  79, 156, 108, 174,  94, 141, 125, 232,  24, 203,  59,  34, 210,   1, 241, 100, 148,  71, 183,
 234,  26, 201,  57, 172,  92, 143, 127, 102, 150,  69, 181,  32, 208,   3, 243,  49, 193,  18, 226, 119, 135,  84, 164, 189,  77, 158, 110, 251,  11, 216,  40,
 159, 111, 188,  76, 217,  41, 250,  10,  19, 227,  48, 192,  85, 165, 118, 134,  68, 180, 103, 151,   2, 242,  33, 209, 200,  56, 235,  27, 142, 126, 173,  93,
  23, 231,  52, 196,  81, 161, 114, 130, 155, 107, 184,  72, 221,  45, 254,  14, 204,  60, 239,  31, 138, 122, 169,  89,  64, 176,  99, 147,   6, 246,  37, 213,
  98, 146,  65, 177,  36, 212,   7, 247, 238,  30, 205,  61, 168,  88, 139, 123, 185,  73, 154, 106, 255,  15, 220,  44,  53, 197,  22, 230, 115, 131,  80, 160,
 253,  13, 222,  46, 187,  75, 152, 104, 113, 129,  82, 162,  55, 199,  20, 228,  38, 214,   5, 245,  96, 144,  67, 179, 170,  90, 137, 121, 236,  28, 207,  63,
 136, 120, 171,  91, 206,  62, 237,  29,   4, 244,  39, 215,  66, 178,  97, 145,  83, 163, 112, 128,  21, 229,  54, 198, 223,  47, 252,  12, 153, 105, 186,  74},

{  0, 241,  33, 208,  66, 179,  99, 146, 132, 117, 165,  84, 198,  55, 231,  22, 203,  58, 234,  27, 137, 120, 168,  89,  79, 190, 110, 159,  13, 252,  44, 221,
  85, 164, 116, 133,  23, 230,  54, 199, 209,  32, 240,   1, 147,  98, 178,  67, 158, 111, 191,  78, 220,  45, 253,  12,  26, 235,  59, 202,  88, 169, 121, 136,
 170,  91, 139, 122, 232,  25, 201,  56,  46, 223,  15, 254, 108, 157,  77, 188,  97, 144,  64, 177,  35, 210,   2, 243, 229,  20, 196,  53, 167,  86, 134, 119,
 255,  14, 222,  47, 189,  76, 156, 109, 123, 138,  90, 171,  57, 200,  24, 233,  52, 197,  21, 228, 118, 135,  87, 166, 176,  65, 145,  96, 242,   3, 211,  34,
 151, 102, 182,  71, 213,  36, 244,   5,  19, 226,  50, 195,  81, 160, 112, 129,  92, 173, 125, 140,  30, 239,  63, 206, 216,  41, 249,   8, 154, 107, 187,  74,
 194,  51, 227,  18, 128, 113, 161,  80,  70, 183, 103, 150,   4, 245,  37, 212,   9, 248,  40, 217,  75, 186, 106, 155, 141, 124, 172,  93, 207,  62, 238,  31,
  61, 204,  28, 237, 127, 142,  94, 175, 185,  72, 152, 105, 251,  10, 218,  43, 246,   7, 215,  38, 180,  69, 149, 100, 114, 131,  83, 162,  48, 193,  17, 224,
 104, 153,  73, 184,  42, 219,  11, 250, 236,  29, 205,  60, 174,  95, 143, 126, 163,  82, 130, 115, 225,  16, 192,  49,  39, 214,   6, 247, 101, 148,  68, 181},

{  0, 242,  39, 213,  78, 188, 105, 155, 156, 110, 187,  73, 210,  32, 245,   7, 251,   9, 220,  46, 181,  71, 146,  96, 103, 149,  64, 178,  41, 219,  14, 252,
  53, 199,  18, 224, 123, 137,  92, 174, 169,  91, 142, 124, 231,  21, 192,  50, 206,  60, 233,  27, 128, 114, 167,  85,  82, 160, 117, 135,  28, 238,  59, 201,
 106, 152,  77, 191,  36, 214,   3, 241, 246,   4, 209,  35, 184,  74, 159, 109, 145,  99, 182,  68, 223,  45, 248,  10,  13, 255,  42, 216,  67, 177, 100, 150,
  95, 173, 120, 138,  17, 227,  54, 196, 195,  49, 228,  22, 141, 127, 170,  88, 164,  86, 131, 113, 234,  24, 205,  63,  56, 202,  31, 237, 118, 132,  81, 163,
 212,  38, 243,   1, 154, 104, 189,  79,  72, 186, 111, 157,   6, 244,  33, 211,  47, 221,   8, 250,  97, 147,  70, 180, 179,  65, 148, 102, 253,  15, 218,  40,
 225,  19, 198,  52, 175,  93, 136, 122, 125, 143,  90, 168,  51, 193,  20, 230,  26, 232,  61, 207,  84, 166, 115, 129, 134, 116, 161,  83, 200,  58, 239,  29,
 190,  76, 153, 107, 240,   2, 215,  37,  34, 208,   5, 247, 108, 158,  75, 185,  69, 183,  98, 144,  11, 249,  44, 222, 217,  43, 254,  12, 151, 101, 176,  66,
 139, 121, 172,  94, 197,  55, 226,  16,  23, 229,  48, 194,  89, 171, 126, 140, 112, 130,  87, 165,  62, 204,  25, 235, 236,  30, 203,  57, 162,  80, 133, 119},

{  0, 243,  37, 214,  74, 185, 111, 156, 148, 103, 177,  66, 222,  45, 251,   8, 235,  24, 206,  61, 161,  82, 132, 119, 127, 140,  90, 169,  53, 198,  16, 227,
  21, 230,  48, 195,  95, 172, 122, 137, 129, 114, 164,  87, 203,  56, 238,  29, 254,  13, 219,  40, 180,  71, 145,  98, 106, 153,  79, 188,  32, 211,   5, 246,
  42, 217,  15, 252,  96, 147,  69, 182, 190,  77, 155, 104, 244,   7, 209,  34, 193,  50, 228,  23, 139, 120, 174,  93,  85, 166, 112, 131,  31, 236,  58, 201,
  63, 204,  26, 233, 117, 134,  80, 163, 171,  88, 142, 125, 225,  18, 196,  55, 212,  39, 241,   2, 158, 109, 187,  72,  64, 179, 101, 150,  10, 249,  47, 220,
  84, 167, 113, 130,  30, 237,  59, 200, 192,  51, 229,  22, 138, 121, 175,  92, 191,  76, 154, 105, 245,   6, 208,  35,  43, 216,  14, 253,  97, 146,  68, 183,
  65, 178, 100, 151,  11, 248,  46, 221, 213,  38, 240,   3, 159, 108, 186,  73, 170,  89, 143, 124, 224,  19, 197,  54,  62, 205,  27, 232, 116, 135,  81, 162,
 126, 141,  91, 168,  52, 199,  17, 226, 234,  25, 207,  60, 160,  83, 133, 118, 149, 102, 176,  67, 223,  44, 250,   9,   1, 242,  36, 215,  75, 184, 110, 157,
 107, 152,  78, 189,  33, 210,   4, 247, 255,  12, 218,  41, 181,  70, 144,  99, 128, 115, 165,  86, 202,  57, 239,  28,  20, 231,  49, 194,  94, 173, 123, 136},

{  0, 244,  43, 223,  86, 162, 125, 137, 172,  88, 135, 115, 250,  14, 209,  37, 155, 111, 176,  68, 205,  57, 230,  18,  55, 195,  28, 232,  97, 149,  74, 190,
 245,   1, 222,  42, 163,  87, 136, 124,  89, 173, 114, 134,  15, 251,  36, 208, 110, 154,  69, 177,  56, 204,  19, 231, 194,  54, 233,  29, 148,  96, 191,  75,
  41, 221,   2, 246, 127, 139,  84, 160, 133, 113, 174,  90, 211,  39, 248,  12, 178,  70, 153, 109, 228,  16, 207,  59,  30, 234,  53, 193,  72, 188,  99, 151,
 220,  40, 247,   3, 138, 126, 161,  85, 112, 132,  91, 175,  38, 210,  13, 249,  71, 179, 108, 152,  17, 229,  58, 206, 235,  31, 192,  52, 189,  73, 150,  98,
  82, 166, 121, 141,   4, 240,  47, 219, 254,  10, 213,  33, 168,  92, 131, 119, 201,  61, 226,  22, 159, 107, 180,  64, 101, 145,  78, 186,  51, 199,  24, 236,
 167,  83, 140, 120, 241,   5, 218,  46,  11, 255,  32, 212,  93, 169, 118, 130,  60, 200,  23, 227, 106, 158,  65, 181, 144, 100, 187,  79, 198,  50, 237,  25,
 123, 143,  80, 164,  45, 217,   6, 242, 215,  35, 252,   8, 129, 117, 170,  94, 224,  20, 203,  63, 182,  66, 157, 105,  76, 184, 103, 147,  26, 238,  49, 197,
 142, 122, 165,  81, 216,  44, 243,   7,  34, 214,   9, 253, 116, 128,  95, 171,  21, 225,  62, 202,  67, 183, 104, 156, 185,  77, 146, 102, 239,  27, 196,  48},

{  0, 245,  41, 220,  82, 167, 123, 142, 164,  81, 141, 120, 246,   3, 223,  42, 139, 126, 162,  87, 217,  44, 240,   5,  47, 218,   6, 243, 125, 136,  84, 161,
 213,  32, 252,   9, 135, 114, 174,  91, 113, 132,  88, 173,  35, 214,  10, 255,  94, 171, 119, 130,  12, 249,  37, 208, 250,  15, 211,  38, 168,  93, 129, 116,
 105, 156,  64, 181,  59, 206,  18, 231, 205,  56, 228,  17, 159, 106, 182,  67, 226,  23, 203,  62, 176,  69, 153, 108,  70, 179, 111, 154,  20, 225,  61, 200,
 188,  73, 149,  96, 238,  27, 199,  50,  24, 237,  49, 196,  74, 191,  99, 150,  55, 194,  30, 235, 101, 144,  76, 185, 147, 102, 186,  79, 193,  52, 232,  29,
 210,  39, 251,  14, 128, 117, 169,  92, 118, 131,  95, 170,  36, 209,  13, 248,  89, 172, 112, 133,  11, 254,  34, 215, 253,   8, 212,  33, 175,  90, 134, 115,
   7, 242,  46, 219,  85, 160, 124, 137, 163,  86, 138, 127, 241,   4, 216,  45, 140, 121, 165,  80, 222,  43, 247,   2,  40, 221,   1, 244, 122, 143,  83, 166,
 187,  78, 146, 103, 233,  28, 192,  53,  31, 234,  54, 195,  77, 184, 100, 145,  48, 197,  25, 236,  98, 151,  75, 190, 148,  97, 189,  72, 198,  51, 239,  26,
 110, 155,  71, 178,  60, 201,  21, 224, 202,  63, 227,  22, 152, 109, 177,  68, 229,  16, 204,  57, 183,  66, 158, 107,  65, 180, 104, 157,  19, 230,  58, 207},

{  0, 246,  47, 217,  94, 168, 113, 135, 188,  74, 147, 101, 226,  20, 205,  59, 187,  77, 148,  98, 229,  19, 202,  60,   7, 241,  40, 222,  89, 175, 118, 128,
 181,  67, 154, 108, 235,  29, 196,  50,   9, 255,  38, 208,  87, 161, 120, 142,  14, 248,  33, 215,  80, 166, 127, 137, 178,  68, 157, 107, 236,  26, 195,  53,
 169,  95, 134, 112, 247,   1, 216,  46,  21, 227,  58, 204,  75, 189, 100, 146,  18, 228,  61, 203,  76, 186,  99, 149, 174,  88, 129, 119, 240,   6, 223,  41,
  28, 234,  51, 197,  66, 180, 109, 155, 160,  86, 143, 121, 254,   8, 209,  39, 167,  81, 136, 126, 249,  15, 214,  32,  27, 237,  52, 194,  69, 179, 106, 156,
 145, 103, 190,  72, 207,  57, 224,  22,  45, 219,   2, 244, 115, 133,  92, 170,  42, 220,   5, 243, 116, 130,  91, 173, 150,  96, 185,  79, 200,  62, 231,  17,
  36, 210,  11, 253, 122, 140,  85, 163, 152, 110, 183,  65, 198,  48, 233,  31, 159, 105, 176,  70, 193,  55, 238,  24,  35, 213,  12, 250, 125, 139,  82, 164,
  56, 206,  23, 225, 102, 144,  73, 191, 132, 114, 171,  93, 218,  44, 245,   3, 131, 117, 172,  90, 221,  43, 242,   4,  63, 201,  16, 230,  97, 151,  78, 184,
 141, 123, 162,  84, 211,  37, 252,  10,  49, 199,  30, 232, 111, 153,  64, 182,  54, 192,  25, 239, 104, 158,  71, 177, 138, 124, 165,  83, 212,  34, 251,  13},

{  0, 247,  45, 218,  90, 173, 119, 128, 180,  67, 153, 110, 238,  25, 195,  52, 171,  92, 134, 113, 241,   6, 220,  43,  31, 232,  50, 197,  69, 178, 104, 159,
 149,  98, 184,  79, 207,  56, 226,  21,  33, 214,  12, 251, 123, 140,  86, 161,  62, 201,  19, 228, 100, 147,  73, 190, 138, 125, 167,  80, 208,  39, 253,  10,
 233,  30, 196,  51, 179,  68, 158, 105,  93, 170, 112, 135,   7, 240,  42, 221,  66, 181, 111, 152,  24, 239,  53, 194, 246,   1, 219,  44, 172,  91, 129, 118,
 124, 139,  81, 166,  38, 209,  11, 252, 200,  63, 229,  18, 146, 101, 191,  72, 215,  32, 250,  13, 141, 122, 160,  87,  99, 148,  78, 185,  57, 206,  20, 227,
  17, 230,  60, 203,  75, 188, 102, 145, 165,  82, 136, 127, 255,   8, 210,  37, 186,  77, 151,  96, 224,  23, 205,  58,  14, 249,  35, 212,  84, 163, 121, 142,
 132, 115, 169,  94, 222,  41, 243,   4,  48, 199,  29, 234, 106, 157,  71, 176,  47, 216,   2, 245, 117, 130,  88, 175, 155, 108, 182,  65, 193,  54, 236,  27,
 248,  15, 213,  34, 162,  85, 143, 120,  76, 187,  97, 150,  22, 225,  59, 204,  83, 164, 126, 137,   9, 254,  36, 211, 231,  16, 202,  61, 189,  74, 144, 103,
 109, 154,  64, 183,  55, 192,  26, 237, 217,  46, 244,   3, 131, 116, 174,  89, 198,  49, 235,  28, 156, 107, 177,  70, 114, 133,  95, 168,  40, 223,   5, 242},

{  0, 248,  51, 203, 102, 158,  85, 173, 204,  52, 255,   7, 170,  82, 153,  97,  91, 163, 104, 144,  61, 197,  14, 246, 151, 111, 164,  92, 241,   9, 194,  58,
 182,  78, 133, 125, 208,  40, 227,  27, 122, 130,  73, 177,  28, 228,  47, 215, 237,  21, 222,  38, 139, 115, 184,  64,  33, 217,  18, 234,  71, 191, 116, 140,
 175,  87, 156, 100, 201,  49, 250,   2,  99, 155,  80, 168,   5, 253,  54, 206, 244,  12, 199,  63, 146, 106, 161,  89,  56, 192,  11, 243,  94, 166, 109, 149,
  25, 225,  42, 210, 127, 135,  76, 180, 213,  45, 230,  30, 179,  75, 128, 120,  66, 186, 113, 137,  36, 220,  23, 239, 142, 118, 189,  69, 232,  16, 219,  35,
 157, 101, 174,  86, 251,   3, 200,  48,  81, 169,  98, 154,  55, 207,   4, 252, 198,  62, 245,  13, 160,  88, 147, 107,  10, 242,  57, 193, 108, 148,  95, 167,
  43, 211,  24, 224,  77, 181, 126, 134, 231,  31, 212,  44, 129, 121, 178,  74, 112, 136,  67, 187,  22, 238,  37, 221, 188,  68, 143, 119, 218,  34, 233,  17,
  50, 202,   1, 249,  84, 172, 103, 159, 254,   6, 205,  53, 152,  96, 171,  83, 105, 145,  90, 162,  15, 247,  60, 196, 165,  93, 150, 110, 195,  59, 240,   8,
 132, 124, 183,  79, 226,  26, 209,  41,  72, 176, 123, 131,  46, 214,  29, 229, 223,  39, 236,  20, 185,  65, 138, 114,  19, 235,  32, 216, 117, 141,  70, 190},

{  0, 249,  49, 200,  98, 155,  83, 170, 196,  61, 245,  12, 166,  95, 151, 110,  75, 178, 122, 131,  41, 208,  24, 225, 143, 118, 190,  71, 237,  20, 220,  37,
 150, 111, 167,  94, 244,  13, 197,  60,  82, 171,  99, 154,  48, 201,   1, 248, 221,  36, 236,  21, 191,  70, 142, 119,  25, 224,  40, 209, 123, 130,  74, 179,
 239,  22, 222,  39, 141, 116, 188,  69,  43, 210,  26, 227,  73, 176, 120, 129, 164,  93, 149, 108, 198,  63, 247,  14,  96, 153,  81, 168,   2, 251,  51, 202,
 121, 128,  72, 177,  27, 226,  42, 211, 189,  68, 140, 117, 223,  38, 238,  23,  50, 203,   3, 250,  80, 169,  97, 152, 246,  15, 199,  62, 148, 109, 165,  92,
  29, 228,  44, 213, 127, 134,  78, 183, 217,  32, 232,  17, 187,  66, 138, 115,  86, 175, 103, 158,  52, 205,   5, 252, 146, 107, 163,  90, 240,   9, 193,  56,
 139, 114, 186,  67, 233,  16, 216,  33,  79, 182, 126, 135,  45, 212,  28, 229, 192,  57, 241,   8, 162,  91, 147, 106,   4, 253,  53, 204, 102, 159,  87, 174,
 242,  11, 195,  58, 144, 105, 161,  88,  54, 207,   7, 254,  84, 173, 101, 156, 185,  64, 136, 113, 219,  34, 234,  19, 125, 132,  76, 181,  31, 230,  46, 215,
 100, 157,  85, 172,   6, 255,  55, 206, 160,  89, 145, 104, 194,  59, 243,  10,  47, 214,  30, 231,  77, 180, 124, 133, 235,  18, 218,  35, 137, 112, 184,  65},

{  0, 250,  55, 205, 110, 148,  89, 163, 220,  38, 235,  17, 178,  72, 133, 127, 123, 129,  76, 182,  21, 239,  34, 216, 167,  93, 144, 106, 201,  51, 254,   4,
 246,  12, 193,  59, 152,  98, 175,  85,  42, 208,  29, 231,  68, 190, 115, 137, 141, 119, 186,  64, 227,  25, 212,  46,  81, 171, 102, 156,  63, 197,   8, 242,
  47, 213,  24, 226,  65, 187, 118, 140, 243,   9, 196,  62, 157, 103, 170,  80,  84, 174,  99, 153,  58, 192,  13, 247, 136, 114, 191,  69, 230,  28, 209,  43,
 217,  35, 238,  20, 183,  77, 128, 122,   5, 255,  50, 200, 107, 145,  92, 166, 162,  88, 149, 111, 204,  54, 251,   1, 126, 132,  73, 179,  16, 234,  39, 221,
  94, 164, 105, 147,  48, 202,   7, 253, 130, 120, 181,  79, 236,  22, 219,  33,  37, 223,  18, 232,  75, 177, 124, 134, 249,   3, 206,  52, 151, 109, 160,  90,
 168,  82, 159, 101, 198,  60, 241,  11, 116, 142,  67, 185,  26, 224,  45, 215, 211,  41, 228,  30, 189,  71, 138, 112,  15, 245,  56, 194,  97, 155,  86, 172,
 113, 139,  70, 188,  31, 229,  40, 210, 173,  87, 154,  96, 195,  57, 244,  14,  10, 240,  61, 199, 100, 158,  83, 169, 214,  44, 225,  27, 184,  66, 143, 117,
 135, 125, 176,  74, 233,  19, 222,  36,  91, 161, 108, 150,  53, 207,   2, 248, 252,   6, 203,  49, 146, 104, 165,  95,  32, 218,  23, 237,  78, 180, 121, 131},

{  0, 251,  53, 206, 106, 145,  95, 164, 212,  47, 225,  26, 190,  69, 139, 112, 107, 144,  94, 165,   1, 250,  52, 207, 191,  68, 138, 113, 213,  46, 224,  27,
 214,  45, 227,  24, 188,  71, 137, 114,   2, 249,  55, 204, 104, 147,  93, 166, 189,  70, 136, 115, 215,  44, 226,  25, 105, 146,  92, 167,   3, 248,  54, 205,
 111, 148,  90, 161,   5, 254,  48, 203, 187,  64, 142, 117, 209,  42, 228,  31,   4, 255,  49, 202, 110, 149,  91, 160, 208,  43, 229,  30, 186,  65, 143, 116,
 185,  66, 140, 119, 211,  40, 230,  29, 109, 150,  88, 163,   7, 252,  50, 201, 210,  41, 231,  28, 184,  67, 141, 118,   6, 253,  51, 200, 108, 151,  89, 162,
 222,  37, 235,  16, 180,  79, 129, 122,  10, 241,  63, 196,  96, 155,  85, 174, 181,  78, 128, 123, 223,  36, 234,  17,  97, 154,  84, 175,  11, 240,  62, 197,
   8, 243,  61, 198,  98, 153,  87, 172, 220,  39, 233,  18, 182,  77, 131, 120,  99, 152,  86, 173,   9, 242,  60, 199, 183,  76, 130, 121, 221,  38, 232,  19,
 177,  74, 132, 127, 219,  32, 238,  21, 101, 158,  80, 171,  15, 244,  58, 193, 218,  33, 239,  20, 176,  75, 133, 126,  14, 245,  59, 192, 100, 159,  81, 170,
 103, 156,  82, 169,  13, 246,  56, 195, 179,  72, 134, 125, 217,  34, 236,  23,  12, 247,  57, 194, 102, 157,  83, 168, 216,  35, 237,  22, 178,  73, 135, 124},

{  0, 252,  59, 199, 118, 138,  77, 177, 236,  16, 215,  43, 154, 102, 161,  93,  27, 231,  32, 220, 109, 145,  86, 170, 247,  11, 204,  48, 129, 125, 186,  70,
  54, 202,  13, 241,  64, 188, 123, 135, 218,  38, 225,  29, 172,  80, 151, 107,  45, 209,  22, 234,  91, 167,  96, 156, 193,  61, 250,   6, 183,  75, 140, 112,
 108, 144,  87, 171,  26, 230,  33, 221, 128, 124, 187,  71, 246,  10, 205,  49, 119, 139,  76, 176,   1, 253,  58, 198, 155, 103, 160,  92, 237,  17, 214,  42,
  90, 166,  97, 157,  44, 208,  23, 235, 182,  74, 141, 113, 192,  60, 251,   7,  65, 189, 122, 134,  55, 203,  12, 240, 173,  81, 150, 106, 219,  39, 224,  28,
 216,  36, 227,  31, 174,  82, 149, 105,  52, 200,  15, 243,  66, 190, 121, 133, 195,  63, 248,   4, 181,  73, 142, 114,  47, 211,  20, 232,  89, 165,  98, 158,
 238,  18, 213,  41, 152, 100, 163,  95,   2, 254,  57, 197, 116, 136,  79, 179, 245,   9, 206,  50, 131, 127, 184,  68,  25, 229,  34, 222, 111, 147,  84, 168,
 180,  72, 143, 115, 194,  62, 249,   5,  88, 164,  99, 159,  46, 210,  21, 233, 175,  83, 148, 104, 217,  37, 226,  30,  67, 191, 120, 132,  53, 201,  14, 242,
 130, 126, 185,  69, 244,   8, 207,  51, 110, 146,  85, 169,  24, 228,  35, 223, 153, 101, 162,  94, 239,  19, 212,  40, 117, 137,  78, 178,   3, 255,  56, 196},

{  0, 253,  57, 196, 114, 143,  75, 182, 228,  25, 221,  32, 150, 107, 175,  82,  11, 246,  50, 207, 121, 132,  64, 189, 239,  18, 214,  43, 157,  96, 164,  89,
  22, 235,  47, 210, 100, 153,  93, 160, 242,  15, 203,  54, 128, 125, 185,  68,  29, 224,  36, 217, 111, 146,  86, 171, 249,   4, 192,  61, 139, 118, 178,  79,
  44, 209,  21, 232,  94, 163, 103, 154, 200,  53, 241,  12, 186,  71, 131, 126,  39, 218,  30, 227,  85, 168, 108, 145, 195,  62, 250,   7, 177,  76, 136, 117,
  58, 199,   3, 254,  72, 181, 113, 140, 222,  35, 231,  26, 172,  81, 149, 104,  49, 204,   8, 245,  67, 190, 122, 135, 213,  40, 236,  17, 167,  90, 158,  99,
  88, 165,  97, 156,  42, 215,  19, 238, 188,  65, 133, 120, 206,  51, 247,  10,  83, 174, 106, 151,  33, 220,  24, 229, 183,  74, 142, 115, 197,  56, 252,   1,
  78, 179, 119, 138,  60, 193,   5, 248, 170,  87, 147, 110, 216,  37, 225,  28,  69, 184, 124, 129,  55, 202,  14, 243, 161,  92, 152, 101, 211,  46, 234,  23,
 116, 137,  77, 176,   6, 251,  63, 194, 144, 109, 169,  84, 226,  31, 219,  38, 127, 130,  70, 187,  13, 240,  52, 201, 155, 102, 162,  95, 233,  20, 208,  45,
  98, 159,  91, 166,  16, 237,  41, 212, 134, 123, 191,  66, 244,   9, 205,  48, 105, 148,  80, 173,  27, 230,  34, 223, 141, 112, 180,  73, 255,   2, 198,  59},

{  0, 254,  63, 193, 126, 128,  65, 191, 252,   2, 195,  61, 130, 124, 189,  67,  59, 197,   4, 250,  69, 187, 122, 132, 199,  57, 248,   6, 185,  71, 134, 120,
 118, 136,  73, 183,   8, 246,  55, 201, 138, 116, 181,  75, 244,  10, 203,  53,  77, 179, 114, 140,  51, 205,  12, 242, 177,  79, 142, 112, 207,  49, 240,  14,
 236,  18, 211,  45, 146, 108, 173,  83,  16, 238,  47, 209, 110, 144,  81, 175, 215,  41, 232,  22, 169,  87, 150, 104,  43, 213,  20, 234,  85, 171, 106, 148,
 154, 100, 165,  91, 228,  26, 219,  37, 102, 152,  89, 167,  24, 230,  39, 217, 161,  95, 158,  96, 223,  33, 224,  30,  93, 163,  98, 156,  35, 221,  28, 226,
  27, 229,  36, 218, 101, 155,  90, 164, 231,  25, 216,  38, 153, 103, 166,  88,  32, 222,  31, 225,  94, 160,  97, 159, 220,  34, 227,  29, 162,  92, 157,  99,
 109, 147,  82, 172,  19, 237,  44, 210, 145, 111, 174,  80, 239,  17, 208,  46,  86, 168, 105, 151,  40, 214,  23, 233, 170,  84, 149, 107, 212,  42, 235,  21,
 247,   9, 200,  54, 137, 119, 182,  72,  11, 245,  52, 202, 117, 139,  74, 180, 204,  50, 243,  13, 178,  76, 141, 115,  48, 206,  15, 241,  78, 176, 113, 143,
 129, 127, 190,  64, 255,   1, 192,  62, 125, 131,  66, 188,   3, 253,  60, 194, 186,  68, 133, 123, 196,  58, 251,   5,  70, 184, 121, 135,  56, 198,   7, 249},

{  0, 255,  61, 194, 122, 133,  71, 184, 244,  11, 201,  54, 142, 113, 179,  76,  43, 212,  22, 233,  81, 174, 108, 147, 223,  32, 226,  29, 165,  90, 152, 103,
  86, 169, 107, 148,  44, 211,  17, 238, 162,  93, 159,  96, 216,  39, 229,  26, 125, 130,  64, 191,   7, 248,  58, 197, 137, 118, 180,  75, 243,  12, 206,  49,
 172,  83, 145, 110, 214,  41, 235,  20,  88, 167, 101, 154,  34, 221,  31, 224, 135, 120, 186,  69, 253,   2, 192,  63, 115, 140,  78, 177,   9, 246,  52, 203,
 250,   5, 199,  56, 128, 127, 189,  66,  14, 241,  51, 204, 116, 139,  73, 182, 209,  46, 236,  19, 171,  84, 150, 105,  37, 218,  24, 231,  95, 160,  98, 157,
 155, 100, 166,  89, 225,  30, 220,  35, 111, 144,  82, 173,  21, 234,  40, 215, 176,  79, 141, 114, 202,  53, 247,   8,  68, 187, 121, 134,  62, 193,   3, 252,
 205,  50, 240,  15, 183,  72, 138, 117,  57, 198,   4, 251,  67, 188, 126, 129, 230,  25, 219,  36, 156,  99, 161,  94,  18, 237,  47, 208, 104, 151,  85, 170,
  55, 200,  10, 245,  77, 178, 112, 143, 195,  60, 254,   1, 185,  70, 132, 123,  28, 227,  33, 222, 102, 153,  91, 164, 232,  23, 213,  42, 146, 109, 175,  80,
  97, 158,  92, 163,  27, 228,  38, 217, 149, 106, 168,  87, 239,  16, 210,  45,  74, 181, 119, 136,  48, 207,  13, 242, 190,  65, 131, 124, 196,  59, 249,   6}};


/****************************************************/
/* Base and conversion functions                    */
/****************************************************/

/* S conversion function                            */
void S(unsigned long int * block)
 {
  unsigned long int valtmp;

  valtmp  = ((unsigned long int)(pi[(block[0] >> 56) & 0xFF]) << 56);
  valtmp |= ((unsigned long int)(pi[(block[0] >> 48) & 0xFF]) << 48);
  valtmp |= ((unsigned long int)(pi[(block[0] >> 40) & 0xFF]) << 40);
  valtmp |= ((unsigned long int)(pi[(block[0] >> 32) & 0xFF]) << 32);
  valtmp |= ((unsigned long int)(pi[(block[0] >> 24) & 0xFF]) << 24);
  valtmp |= ((unsigned long int)(pi[(block[0] >> 16) & 0xFF]) << 16);
  valtmp |= ((unsigned long int)(pi[(block[0] >>  8) & 0xFF]) <<  8);
  valtmp |=  (unsigned long int)(pi[block[0] & 0xFF]);

  block[0] = valtmp;

  valtmp  = ((unsigned long int)(pi[(block[1] >> 56) & 0xFF]) << 56);
  valtmp |= ((unsigned long int)(pi[(block[1] >> 48) & 0xFF]) << 48);
  valtmp |= ((unsigned long int)(pi[(block[1] >> 40) & 0xFF]) << 40);
  valtmp |= ((unsigned long int)(pi[(block[1] >> 32) & 0xFF]) << 32);
  valtmp |= ((unsigned long int)(pi[(block[1] >> 24) & 0xFF]) << 24);
  valtmp |= ((unsigned long int)(pi[(block[1] >> 16) & 0xFF]) << 16);
  valtmp |= ((unsigned long int)(pi[(block[1] >>  8) & 0xFF]) <<  8);
  valtmp |=  (unsigned long int)(pi[block[1] & 0xFF]);

  block[1] = valtmp;
 }

/* Inverse of S conversion function                */
void S_inv(unsigned long int * block)
 {
  unsigned long int valtmp;

  valtmp  = ((unsigned long int)(pi_inv[(block[0] >> 56) & 0xFF]) << 56);
  valtmp |= ((unsigned long int)(pi_inv[(block[0] >> 48) & 0xFF]) << 48);
  valtmp |= ((unsigned long int)(pi_inv[(block[0] >> 40) & 0xFF]) << 40);
  valtmp |= ((unsigned long int)(pi_inv[(block[0] >> 32) & 0xFF]) << 32);
  valtmp |= ((unsigned long int)(pi_inv[(block[0] >> 24) & 0xFF]) << 24);
  valtmp |= ((unsigned long int)(pi_inv[(block[0] >> 16) & 0xFF]) << 16);
  valtmp |= ((unsigned long int)(pi_inv[(block[0] >>  8) & 0xFF]) <<  8);
  valtmp |=  (unsigned long int)(pi_inv[block[0] & 0xFF]);

  block[0] = valtmp;

  valtmp  = ((unsigned long int)(pi_inv[(block[1] >> 56) & 0xFF]) << 56);
  valtmp |= ((unsigned long int)(pi_inv[(block[1] >> 48) & 0xFF]) << 48);
  valtmp |= ((unsigned long int)(pi_inv[(block[1] >> 40) & 0xFF]) << 40);
  valtmp |= ((unsigned long int)(pi_inv[(block[1] >> 32) & 0xFF]) << 32);
  valtmp |= ((unsigned long int)(pi_inv[(block[1] >> 24) & 0xFF]) << 24);
  valtmp |= ((unsigned long int)(pi_inv[(block[1] >> 16) & 0xFF]) << 16);
  valtmp |= ((unsigned long int)(pi_inv[(block[1] >>  8) & 0xFF]) <<  8);
  valtmp |=  (unsigned long int)(pi_inv[block[1] & 0xFF]);

  block[1] = valtmp;
 }

/* Linear transformation                           */

unsigned char ll(unsigned long int block[2])
 {
  unsigned char val;

  val  =  mult_mod_poly[148][(block[0] >> 56) & 0xFF];
  val ^=  mult_mod_poly[ 32][(block[0] >> 48) & 0xFF];
  val ^=  mult_mod_poly[133][(block[0] >> 40) & 0xFF];
  val ^=  mult_mod_poly[ 16][(block[0] >> 32) & 0xFF];
  val ^=  mult_mod_poly[194][(block[0] >> 24) & 0xFF];
  val ^=  mult_mod_poly[192][(block[0] >> 16) & 0xFF];
  val ^=  mult_mod_poly[  1][(block[0] >>  8) & 0xFF];
  val ^=  mult_mod_poly[251][(block[0] >>  0) & 0xFF];

  val ^=  mult_mod_poly[  1][(block[1] >> 56) & 0xFF];
  val ^=  mult_mod_poly[192][(block[1] >> 48) & 0xFF];
  val ^=  mult_mod_poly[194][(block[1] >> 40) & 0xFF];
  val ^=  mult_mod_poly[ 16][(block[1] >> 32) & 0xFF];
  val ^=  mult_mod_poly[133][(block[1] >> 24) & 0xFF];
  val ^=  mult_mod_poly[ 32][(block[1] >> 16) & 0xFF];
  val ^=  mult_mod_poly[148][(block[1] >>  8) & 0xFF];
  val ^=  mult_mod_poly[  1][(block[1] >>  0) & 0xFF];

  return(val);
 }

/* R conversion function                            */
void R(unsigned long int * block)
 {
  unsigned long int valtmp[2];
  unsigned char val;

  valtmp[0] = block[0];
  valtmp[1] = block[1];
  val = ll(valtmp);

  block[1] >>= 8;
  block[1]  |= (((block[0]) & 0xFF) << 56);

  block[0] >>= 8;
  block[0]  |= ((unsigned long int)(val) << 56);
 }

/* Inverse of R conversion function                 */
void R_inv(unsigned long int * block)
 {
  unsigned long int valtmp[2];
  unsigned char val;

  valtmp[0]  = (block[0] << 8);
  valtmp[0] |= ((block[1] >> 56) & 0xFF);
  valtmp[1]  = (block[1] << 8);
  valtmp[1] |= ((block[0] >> 56) & 0xFF);

  val = ll(valtmp);

  block[0]  = valtmp[0];
  block[1]  = (valtmp[1] & 0xFFFFFFFFFFFFFF00L);
  block[1] |= val;
 }

/* L conversion function (16 iteration of R)        */
void L(unsigned long int * block)
 {
  R(block); R(block); R(block); R(block);
  R(block); R(block); R(block); R(block);
  R(block); R(block); R(block); R(block);
  R(block); R(block); R(block); R(block);
 }

/* Inverse of L conversion function (16 iteration of R_inv) */
void L_inv(unsigned long int * block)
 {
  R_inv(block); R_inv(block); R_inv(block); R_inv(block);
  R_inv(block); R_inv(block); R_inv(block); R_inv(block);
  R_inv(block); R_inv(block); R_inv(block); R_inv(block);
  R_inv(block); R_inv(block); R_inv(block); R_inv(block);
 }

/* F conversion function (used in key setup)        */
void F(unsigned long int * k, unsigned long int * block1, unsigned long int * block0)
 {
  unsigned long int tmpblock[2];

  /* Bitwise xor of k with block2 */
  tmpblock[0] = (block1[0] ^ k[0]);
  tmpblock[1] = (block1[1] ^ k[1]);

  /* Apply S conversion function  */
  S(tmpblock);

  /* Apply L conversion function  */
  L(tmpblock);

  /* Add a0 to the the result     */
  tmpblock[0] ^= block0[0];
  tmpblock[1] ^= block0[1];

  /* Update the results           */
  block0[0] = block1[0];
  block0[1] = block1[1];

  block1[0] = tmpblock[0];
  block1[1] = tmpblock[1];
 }

/****************************************************/
/****************************************************/
/* The three core functions                         */
/****************************************************/
/****************************************************/

/****************************************************/
/* Key setup procedure                              */
/****************************************************/
void key_setup(unsigned long int * master_key, unsigned long int * * subkeys)
 {
  unsigned long int c_values[32][2], blocktmp[2], blocktmp2[2];
  unsigned char i;

  /* Compute the C_i values       */
  for(i = 0;i < 32;i++)
   {
    blocktmp[0] = 0L;
    blocktmp[1] = (unsigned long int)(i + 1);
    L(blocktmp);
    c_values[i][0] = blocktmp[0]; c_values[i][1] = blocktmp[1];
   }

  /* Compute subkeys K_1 and K_2  */
  subkeys[0][0] =  master_key[0]; subkeys[0][1] =  master_key[1];
  subkeys[1][0] =  master_key[2]; subkeys[1][1] =  master_key[3];

  /* Compute subkeys K_3 and K_4  */
  blocktmp[0] = subkeys[0][0]; blocktmp[1] = subkeys[0][1];
  blocktmp2[0] = subkeys[1][0]; blocktmp2[1] = subkeys[1][1];
  F(c_values[0], blocktmp, blocktmp2); F(c_values[1], blocktmp, blocktmp2);
  F(c_values[2], blocktmp, blocktmp2); F(c_values[3], blocktmp, blocktmp2);
  F(c_values[4], blocktmp, blocktmp2); F(c_values[5], blocktmp, blocktmp2);
  F(c_values[6], blocktmp, blocktmp2); F(c_values[7], blocktmp, blocktmp2);

  subkeys[2][0] = blocktmp[0]; subkeys[2][1] = blocktmp[1];
  subkeys[3][0] = blocktmp2[0]; subkeys[3][1] = blocktmp2[1];

  /* Compute subkeys K_5 and K_6  */
  F(c_values[ 8], blocktmp, blocktmp2); F(c_values[ 9], blocktmp, blocktmp2);
  F(c_values[10], blocktmp, blocktmp2); F(c_values[11], blocktmp, blocktmp2);
  F(c_values[12], blocktmp, blocktmp2); F(c_values[13], blocktmp, blocktmp2);
  F(c_values[14], blocktmp, blocktmp2); F(c_values[15], blocktmp, blocktmp2);

  subkeys[4][0] = blocktmp[0]; subkeys[4][1] = blocktmp[1];
  subkeys[5][0] = blocktmp2[0]; subkeys[5][1] = blocktmp2[1];

  /* Compute subkeys K_7 and K_8  */
  F(c_values[16], blocktmp, blocktmp2); F(c_values[17], blocktmp, blocktmp2);
  F(c_values[18], blocktmp, blocktmp2); F(c_values[19], blocktmp, blocktmp2);
  F(c_values[20], blocktmp, blocktmp2); F(c_values[21], blocktmp, blocktmp2);
  F(c_values[22], blocktmp, blocktmp2); F(c_values[23], blocktmp, blocktmp2);

  subkeys[6][0] = blocktmp[0]; subkeys[6][1] = blocktmp[1];
  subkeys[7][0] = blocktmp2[0]; subkeys[7][1] = blocktmp2[1];

  /* Compute subkeys K_9 and K_{10} */
  F(c_values[24], blocktmp, blocktmp2); F(c_values[25], blocktmp, blocktmp2);
  F(c_values[26], blocktmp, blocktmp2); F(c_values[27], blocktmp, blocktmp2);
  F(c_values[28], blocktmp, blocktmp2); F(c_values[29], blocktmp, blocktmp2);
  F(c_values[30], blocktmp, blocktmp2); F(c_values[31], blocktmp, blocktmp2);

  subkeys[8][0] = blocktmp[0]; subkeys[8][1] = blocktmp[1];
  subkeys[9][0] = blocktmp2[0]; subkeys[9][1] = blocktmp2[1];
 }

/****************************************************/
/* Encryption procedure                             */
/****************************************************/
void grasshopper_encrypt(unsigned long int * * subkeys, unsigned long int * plaintext, unsigned long int * ciphertext)
 {
  /* Round 1 with subkey 1 */
  ciphertext[0] = plaintext[0] ^ subkeys[0][0]; ciphertext[1] = plaintext[1] ^ subkeys[0][1];
  S(ciphertext); L(ciphertext);

  /* Round 2 with subkey 2 */
  ciphertext[0] ^= subkeys[1][0]; ciphertext[1] ^= subkeys[1][1];
  S(ciphertext); L(ciphertext);

  /* Round 3 with subkey 3 */
  ciphertext[0] ^= subkeys[2][0]; ciphertext[1] ^= subkeys[2][1];
  S(ciphertext); L(ciphertext);

  /* Round 4 with subkey 4 */
  ciphertext[0] ^= subkeys[3][0]; ciphertext[1] ^= subkeys[3][1];
  S(ciphertext); L(ciphertext);

  /* Round 5 with subkey 5 */
  ciphertext[0] ^= subkeys[4][0]; ciphertext[1] ^= subkeys[4][1];
  S(ciphertext); L(ciphertext);

  /* Round 6 with subkey 6 */
  ciphertext[0] ^= subkeys[5][0]; ciphertext[1] ^= subkeys[5][1];
  S(ciphertext); L(ciphertext);

  /* Round 7 with subkey 7 */
  ciphertext[0] ^= subkeys[6][0]; ciphertext[1] ^= subkeys[6][1];
  S(ciphertext); L(ciphertext);

  /* Round 8 with subkey 8 */
  ciphertext[0] ^= subkeys[7][0]; ciphertext[1] ^= subkeys[7][1];
  S(ciphertext); L(ciphertext);

  /* Round 9 with subkey 9 */
  ciphertext[0] ^= subkeys[8][0]; ciphertext[1] ^= subkeys[8][1];
  S(ciphertext); L(ciphertext);

  /* Round 10 with subkey 10 */
  ciphertext[0] ^= subkeys[9][0]; ciphertext[1] ^= subkeys[9][1];
 }

/****************************************************/
/* Decryption procedure                             */
/****************************************************/
void grasshopper_decrypt(unsigned long int * * subkeys, unsigned long int * ciphertext, unsigned long int * plaintext)
 {
  /* Round 1 with subkey 10 */
  plaintext[0] = ciphertext[0] ^ subkeys[9][0]; plaintext[1] = ciphertext[1] ^ subkeys[9][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 2 with subkey 9 */
  plaintext[0] ^= subkeys[8][0]; plaintext[1] ^= subkeys[8][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 3 with subkey 8 */
  plaintext[0] ^= subkeys[7][0]; plaintext[1] ^= subkeys[7][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 4 with subkey 7 */
  plaintext[0] ^= subkeys[6][0]; plaintext[1] ^= subkeys[6][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 5 with subkey 6 */
  plaintext[0] ^= subkeys[5][0]; plaintext[1] ^= subkeys[5][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 6 with subkey 5 */
  plaintext[0] ^= subkeys[4][0]; plaintext[1] ^= subkeys[4][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 7 with subkey 4 */
  plaintext[0] ^= subkeys[3][0]; plaintext[1] ^= subkeys[3][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 8 with subkey 3 */
  plaintext[0] ^= subkeys[2][0]; plaintext[1] ^= subkeys[2][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 9 with subkey 2 */
  plaintext[0] ^= subkeys[1][0]; plaintext[1] ^= subkeys[1][1];
  L_inv(plaintext); S_inv(plaintext);

  /* Round 10 with subkey 1 */
  plaintext[0] ^= subkeys[0][0]; plaintext[1] ^= subkeys[0][1];
  /*L_inv(plaintext); S_inv(plaintext);*/
 }


